OC.L10N.register(
    "spreed",
    {
    "a conversation" : "pogovor",
    "(Duration %s)" : "(Trajanje %s)",
    "You attended a call with {user1}" : "Opravite klic: {user1}",
    "_%n guest_::_%n guests_" : ["%n gost","%n gosta","%n gostje","%n gostov"],
    "You attended a call with {user1} and {user2}" : "Opravite klic: {user1} in {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Opravite klic: {user1}, {user2} in {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Opravite klic: {user1}, {user2}, {user3} in {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Opravite klic: {user1}, {user2}, {user3}, {user4} in {user5}",
    "_%n other_::_%n others_" : ["%n drug","%n druga","%n drugi","%n drugih"],
    "{actor} invited you to {call}" : "{actor} pošlje povabilo na {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Povabljeni ste bili v <strong>pogovor</strong>, ali pa ste prejeli <strong>klic</strong>",
    "Other activities" : "Druge dejavnosti",
    "Talk" : "Talk",
    "Guest" : "Gost",
    "## Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "## Dobrodošli v program Nextcloud Talk!\nTa pogovor je namenjen obvestilom in podrobnostim o novih zmožnosti programa.",
    "## New in Talk %s" : "## Novo v Talk %s",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Po novem tudi programa Microsoft Edge in Safari podpirata zvočno in video klicanje.",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- Pogovori Ena-na-Ena so po novem stalni in jih ni več mogoče po nesreči pretvoriti v skupinski pogovor. Prav tako se, ko eden izmed udeležencev zapusti pogovor, ta samodejno ne izbriše. Izbriše se šele, ko pogovor zapustita oba udeleženca.",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Mogoče je poslati obvestilo vsem udeležencem z vpisom »@all« v vpisno polje.",
    "- With the \"arrow-up\" key you can repost your last message" : "- Pritisk tipke »puščico navzgor« ponovi izpis zadnjega vnosa klepeta.",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Program podpira ukaze v vnosni vrstici; napišite »/help« kot sporočilo, če so ukazi skrbniško omogočeni.",
    "- With projects you can create quick links between conversations, files and other items" : "- S projekti lahko ustvarite hitre povezave med pogovori, da datotekami in drugimi predmeti.",
    "- You can now mention guests in the chat" : "- V klepetu je mogoče omeniti goste.",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Pogovori imajo možnost čakalnice. Ta omogoča moderatorjem pripravo, usklajevanje in pogovor pred začetkom sestanka, uporabniki in gosti pa čakajo na začetek.",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- Mogoče je neposredno odgovoriti na posamezno sporočilo in omogočiti kontekst sporočila.",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- iskalnik pogovorov in stikov omogoča filtriranje obstoječih pogovorov in s tem hitrejše iskanje predhodnih.",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- Dodati je mogoče skupine uporabnikov po meri, če je nameščen tudi program Krogi.",
    "- Check out the new grid and call view" : "- Preizkusite nov mrežni in posodobljen klicni pogled.",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- Po novem je mogoče poslati datoteke neposredno iz naprave v pogovor.",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- Datoteke v souporabi se sedaj odprejo znotraj klepetalnega pogleda s programi za pregledovanje.",
    "- You can now search for chats and messages in the unified search in the top bar" : "- Mogoče je iskati med klepeti in sporočili prek enotnega iskalnega polja.",
    "- Spice up your messages with emojis from the emoji picker" : "- Poživite sporočila z izraznimi ikonami prek izbirnika.",
    "- You can now change your camera and microphone while being in a call" : "- Spremeniti je mogoče kamero in mikrofon kar med klicem.",
    "- Give your conversations some context with a description and open it up so logged in users can find it and join themselves" : "- Pogovoru je mogoče dodati vsebinski opis in ga odpreti, da se prijavljeni uporabniki enostavno pridružijo.",
    "- See a read status and send failed messages again" : "- Prikazano je stanje branja in možnost ponovnega pošiljanja spodletelega sporočila.",
    "- Raise your hand in a call with the R key" : "- Roko je mogoče dvigniti s pritiskom na tipko » R «.",
    "- Join the same conversation and call from multiple devices" : "- Možnost povezave v isti pogovor z več različnih naprav.",
    "- Send voice messages, share your location or contact details" : "- Pošiljanje glasovnih sporočil, objavo položaja in podrobnosti profila.",
    "- Add groups to a conversation and new group members will automatically be added as participants" : "- Dodajanje skupin v pogovor in samodejno dodajanje novih članov skupine kot udeležence.",
    "- A preview of your audio and video is shown before joining a call" : "- Pred vklopom v pogovor je na voljo predogled slike iz zvoka.",
    "- You can now blur your background in the newly designed call view" : "- V na novo zasnovanem pogledu klica je mogoče zamegliti ozadje.",
    "- Moderators can now assign general and individual permissions to participants" : "- Moderatorji lahko dodelijo splošna in posamezna dovoljenja udeležencem.",
    "- You can now react to chat messages" : "- Po novem se je mogoče odzvati na sporočila v klepetu.",
    "- In the sidebar you can now find an overview of the latest shared items" : "- V bočnem oknu je sedaj pregledni seznam predmetov v souporabi.",
    "- Use a poll to collect the opinions of others or settle on a date" : "- Uporabite lahko anketo za zbiranje mnenj in usklajevanje datumov dogodkov.",
    "- Configure an expiration time for chat messages" : "- Podprto je nastavljanje časa poteka sporočil v klepetu.",
    "- Start calls without notifying others in big conversations. You can send individual call notifications once the call has started." : "- Mogoče je začeti posamezen klic brez vednosti udeležencev v pogovorih z več sodelujočimi. Po začetku je mogoče pošiljati tudi posamezna obvestila.",
    "- Send chat messages without notifying the recipients in case it is not urgent" : "- Mogoče je poslati sporočila v klepet brez prikaza obvestila, če sporočilo ni pomembno.",
    "- Emojis can now be autocompleted by typing a \":\"" : "- Izrazne ikone je mogoče izrisovati z vpisom dvopičja »:«.",
    "- Link various items using the new smart-picker by typing a \"/\"" : "- Različne predmete je mogoče povezovati z uporabo izbirnika » / «.",
    "- Moderators can now create breakout rooms (requires the High-performance backend)" : "- Moderatorji lahko ustvarjajo ločene skupine (zahteva nastavitev zunanjega signalnega strežnika).",
    "- Calls can now be recorded (requires the High-performance backend)" : "- Klice je mogoče posneti (zahteva nastavitev zunanjega signalnega strežnika)",
    "- Conversations can now have an avatar or emoji as icon" : "- Pogovoru je mogoče določiti podobo ali izrazno ikono.",
    "- Virtual backgrounds are now available in addition to the blurred background in video calls" : "- Ob zamegljenem so na voljo tudi navidezna ozadja v videokonferencah.",
    "- Reactions are now available during calls" : "- Med klicem je mogoče uporabiti grafične odzive.",
    "- Typing indicators show which users are currently typing a message" : "- Kazalnik tipkanja se zažene, ko uporabniki začnejo vpisovati sporočila.",
    "- Groups can now be mentioned in chats" : "- V pogovorih je mogoče omeniti tudi skupine.",
    "- Call recordings are automatically transcribed if a transcription provider app is registered" : "- Posnetke klicev je mogoče samodejno prepisati v besedilo, če je na voljo podporni program.",
    "- Chat messages can be translated if a translation provider app is registered" : "- Sporočila klepeta je mogoče samodejno prevesti, če je na voljo podporni program.",
    "- **Markdown** can now be used in _chat_ messages" : "- V pogovorih je mogoče uporabiti oblikovanje **Markdown**.",
    "- Webhooks are now available to implement bots. See the documentation for more information https://nextcloud-talk.readthedocs.io/en/latest/bot-list/" : "- Na voljo so spletne kljuke za dodajanje botov. Več podrobnosti je zapisanih v dokumentaciji https://nextcloud-talk.readthedocs.io/en/latest/bot-list/.",
    "- Set a reminder on a chat message to be notified later again" : "- Nastaviti je mogoče opomnik na sporočilo klepeta za kasnejše obveščanje.",
    "- Use the **Note to self** conversation to take notes and share information between your devices" : "- »Sporočilo sebi« je mogoče uporabiti za opomnike in izmenjavo podatkov med različnimi napravami.",
    "- Captions allow to send a message with a file at the same time" : "- Napisi omogočajo pošiljanje sporočila sočasno z datoteko.",
    "- Video of the speaker is now visible while sharing the screen and call reactions are animated" : "- Video govorca je zdaj vidno med souporabo zaslona, odzivi slušateljev pa so animirani.",
    "- Messages can now be edited by logged-in authors and moderators for 6 hours" : "- Sporočila lahko prijavljeni avtorji in moderatorji urejajo še 6 ur po vpisu",
    "- Unsent message drafts are now saved in your browser" : "- Neposlani osnutki sporočil se shranjujejo v pomnilnik brskalnika",
    "- Text chatting can now be done in a federated way with other Talk servers" : "- Klepetanje je mogoče tudi z zveznimi uporabniki z zunanjimi strežniki Talk",
    "_All %n participant_::_All %n participants_" : ["%n udeleženec","%n udeleženca"," %n udeleženci"," %n udeležencev"],
    "Talk updates ✅" : "Posodobitve programa Talk ✅",
    "Reaction deleted by author" : "Avtor izbriše odziv",
    "{actor} created the conversation" : "{actor} ustvari pogovor",
    "You created the conversation" : "Ustvarite pogovor",
    "System created the conversation" : "Sistem ustvari pogovor",
    "An administrator created the conversation" : "Skrbnik je ustvaril pogovor",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} preimenuje pogovor »%1$s« v »%2$s«",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Preimenujete pogovor »%1$s« v »%2$s",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Skrbnik je preimenoval pogovor »%1$s« v »%2$s«",
    "{actor} set the description" : "{actor} nastavi opis",
    "You set the description" : "Nastavite opis",
    "An administrator set the description" : "Skrbnik nastavi opis",
    "{actor} removed the description" : "{actor} odstrani opis",
    "You removed the description" : "Odstranite opis",
    "An administrator removed the description" : "Skrbnik odstrani opis",
    "You started a silent call" : "Začeli ste tihi klic",
    "Outgoing silent call" : "Odhodni tihi klic",
    "{actor} started a silent call" : "{actor} začne tihi klic",
    "Incoming silent call" : "Dohodni tihi klic",
    "You started a call" : "Začnete klic",
    "Outgoing call" : "Odhodni klic",
    "{actor} started a call" : "{actor} začne klic",
    "Incoming call" : "Dohodni klic",
    "{actor} joined the call" : "{actor} se pridruži klicu",
    "You joined the call" : "Pridružite se klicu",
    "{actor} left the call" : "{actor} zapusti klic",
    "You left the call" : "Zapustite klic",
    "{actor} unlocked the conversation" : "{actor} odklene pogovor",
    "You unlocked the conversation" : "Odklenete pogovor",
    "An administrator unlocked the conversation" : "Skrbnik je odklenil pogovor",
    "{actor} locked the conversation" : "{actor} zaklene pogovor",
    "You locked the conversation" : "Zaklenete pogovor",
    "An administrator locked the conversation" : "Skrbnik je zaklenil pogovor",
    "{actor} limited the conversation to the current participants" : "{actor} omeji pogovor na trenutno povezane udeležence",
    "You limited the conversation to the current participants" : "Omejili ste pogovor na trenutno povezane udeležence",
    "An administrator limited the conversation to the current participants" : "Skrbnik je omejil pogovor na trenutno povezane udeležence",
    "{actor} opened the conversation to registered users" : "{actor} odpre pogovor za vse vpisane uporabnike",
    "You opened the conversation to registered users" : "Odprli ste pogovor za vse vpisane uporabnike",
    "An administrator opened the conversation to registered users" : "Skrbnik je odprl pogovor za vse vpisane uporabnike",
    "{actor} opened the conversation to registered users and users created with the Guests app" : "{actor} odpre pogovor za vpisane uporabnike in tiste, ki katerih račun je ustvarjen kot gosti.",
    "You opened the conversation to registered users and users created with the Guests app" : "Odprete pogovor za vpisane uporabnike in tiste, ki katerih račun je ustvarjen kot gosti.",
    "An administrator opened the conversation to registered users and users created with the Guests app" : "Skrbnik odpre pogovor za vpisane uporabnike in tiste, ki katerih račun je ustvarjen kot gosti.",
    "The conversation is now open to everyone" : "Pogovor je sedaj odprt za vse",
    "{actor} opened the conversation to everyone" : "{actor} odpre pogovor za vse",
    "You opened the conversation to everyone" : "Odprete pogovor za vse",
    "{actor} restricted the conversation to moderators" : "{actor} omeji pogovor na moderatorje",
    "You restricted the conversation to moderators" : "Omejite pogovor na moderatorje",
    "{actor} started breakout rooms" : "{actor} odpre mesta za ločene skupine",
    "You started breakout rooms" : "Odprete mesta za ločene skupine",
    "{actor} stopped breakout rooms" : "{actor} zapre ločene skupine",
    "You stopped breakout rooms" : "Zaprli ste ločene skupine",
    "{actor} allowed guests" : "{actor} dovoli sodelovanje gostov",
    "You allowed guests" : "Dovolite sodelovanje gostov",
    "An administrator allowed guests" : "Skrbnik je odobril dostop gostom",
    "{actor} disallowed guests" : "{actor} prepove sodelovanje gostom",
    "You disallowed guests" : "Prepoveste sodelovanje gostom",
    "An administrator disallowed guests" : "Skrbnik je onemogočil dostop gostom",
    "{actor} set a password" : "{actor} nastavi geslo",
    "You set a password" : "Nastavite geslo",
    "An administrator set a password" : "Skrbnik je nastavil geslo",
    "{actor} removed the password" : "{actor} odstrani geslo",
    "You removed the password" : "Odstranite geslo",
    "An administrator removed the password" : "Skrbnik je odstranil geslo",
    "{actor} added {user}" : "{actor} doda stik {user}",
    "You joined the conversation" : "Pridružite se pogovoru",
    "{actor} joined the conversation" : "{actor} se pridruži pogovoru",
    "You added {user}" : "Dodate uporabnika {user}",
    "{actor} added you" : "{actor} vas doda v pogovor",
    "An administrator added you" : "Skrbnik vas je dodal",
    "An administrator added {user}" : "Skrbnik doda uporabnika: {user}",
    "You left the conversation" : "Zapustite pogovor",
    "{actor} left the conversation" : "{actor} zapusti pogovor",
    "{actor} removed {user}" : "{actor} odstrani stik {user}",
    "You removed {user}" : "Odstranite uporabnika {user}",
    "{actor} removed you" : "{actor} vas odstrani",
    "An administrator removed you" : "Skrbnik vas je odstranil",
    "An administrator removed {user}" : "Skrbnik odstrani uporabnika: {user}",
    "{actor} invited {federated_user}" : "{actor} povabi {federated_user}",
    "You invited {federated_user}" : "Povabite {federated_user}",
    "You accepted the invitation" : "Sprejeli ste vabilo",
    "{actor} invited you" : "{actor} vsa povabi v klepet",
    "An administrator invited you" : "Skrbnik vas je povabil",
    "An administrator invited {federated_user}" : "Skrbnik povabi osebo {federated_user}",
    "{federated_user} accepted the invitation" : "{federated_user} sprejme povabilo",
    "{actor} removed {federated_user}" : "{actor} odstrani osebo {federated_user}",
    "You removed {federated_user}" : "Odstranite osebo {federated_user}",
    "You declined the invitation" : "Zavrnete povabilo",
    "An administrator removed {federated_user}" : "Skrbnik odstrani osebo {federated_user}",
    "{federated_user} declined the invitation" : "{federated_user} zavrne povabilo",
    "{actor} added group {group}" : "{actor} doda skupino {group}",
    "You added group {group}" : "Dodate skupino {group}",
    "An administrator added group {group}" : "Skrbnik doda skupino {group}",
    "{actor} removed group {group}" : "{actor} odstrani skupino {group}",
    "You removed group {group}" : "Odstranite skupino {group}",
    "An administrator removed group {group}" : "Skrbnik odstrani skupino {group}",
    "{actor} added {phone}" : "{actor} doda telefonsko številko {phone}",
    "You added {phone}" : "Dodate telefonsko številko {phone}",
    "An administrator added {phone}" : "Skrbnik doda telefonsko številko {phone}",
    "{actor} removed {phone}" : "{actor} odstrani telefonsko številko {phone}",
    "You removed {phone}" : "Odstranite telefonsko številko {phone}",
    "An administrator removed {phone}" : "Skrbnik odstrani telefonsko številko {phone}",
    "{actor} promoted {user} to moderator" : "{actor} dodeli osebi {user} vlogo moderatorja",
    "You promoted {user} to moderator" : "Osebi {user} ste dodelili vlogo moderatorja",
    "{actor} promoted you to moderator" : "{actor} vam dodali vlogo moderatorja",
    "An administrator promoted you to moderator" : "Skrbnik vam dodeli vlogo moderatorja",
    "An administrator promoted {user} to moderator" : "Skrbnik je določil moderatorja: {user}",
    "{actor} demoted {user} from moderator" : "{actor} osebi {user} odstrani vlogo moderatorja",
    "You demoted {user} from moderator" : "Osebi {user} ste odvzeli vlogo moderatorja",
    "{actor} demoted you from moderator" : "{actor} vam odvzame vlogo moderatorja",
    "An administrator demoted you from moderator" : "Skrbnik vam je odvzel vlogo moderatorja",
    "An administrator demoted {user} from moderator" : "Skrbnik je odstranil moderatorja: {user}",
    "{actor} shared a file which is no longer available" : "{actor}: datoteka v souporabi ni več na voljo",
    "You shared a file which is no longer available" : "Datoteka ni več na voljo ...",
    "The shared location is malformed" : "Objavljeno trenutno mesto je napačno oblikovano",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} nastavi povezavo Matterbridge za usklajevanje tega pogovora z drugimi klepeti.",
    "You set up Matterbridge to synchronize this conversation with other chats" : "Nastavite povezavo Matterbridge za usklajevanje tega pogovora z drugimi klepeti.",
    "{actor} updated the Matterbridge configuration" : "{actor} posodobi nastavitve Matterbridge.",
    "You updated the Matterbridge configuration" : "Posodobite nastavitev Matterbridge.",
    "{actor} removed the Matterbridge configuration" : "{actor} odstrani nastavitve Matterbridge.",
    "You removed the Matterbridge configuration" : "Odstranili ste nastavitve Matterbridge.",
    "{actor} started Matterbridge" : "{actor} omogoči Matterbridge.",
    "You started Matterbridge" : "Omogočite Matterbridge.",
    "{actor} stopped Matterbridge" : "{actor} zaustavi Matterbridge.",
    "You stopped Matterbridge" : "Zaustavite Matterbridge.",
    "{actor} deleted a message" : "{actor} izbriše sporočilo",
    "You deleted a message" : "Izbrisali ste sporočilo",
    "You edited a message" : "Uredili ste sporočilo",
    "{actor} deleted a reaction" : "{actor} izbriše odziv",
    "You deleted a reaction" : "Izbrisali ste odziv",
    "_You set the message expiration to %n week_::_You set the message expiration to %n weeks_" : ["Pretek sporočil ste nastavili na %n teden","Pretek sporočil ste nastavili na %n tedna","Pretek sporočil ste nastavili na %n tedne","Pretek sporočil ste nastavili na %n tednov"],
    "_You set the message expiration to %n day_::_You set the message expiration to %n days_" : ["Pretek sporočil ste nastavili na %n dan","Pretek sporočil ste nastavili na %n dneva","Pretek sporočil ste nastavili na %n dni","Pretek sporočil ste nastavili na %n dni"],
    "_You set the message expiration to %n hour_::_You set the message expiration to %n hours_" : ["Pretek sporočil ste nastavili na %n uro","Pretek sporočil ste nastavili na %n uri","Pretek sporočil ste nastavili na %n ure","Pretek sporočil ste nastavili na %n ur"],
    "_You set the message expiration to %n minute_::_You set the message expiration to %n minutes_" : ["Pretek sporočil ste nastavili na %n minuto","Pretek sporočil ste nastavili na %n minuti","Pretek sporočil ste nastavili na %n minute","Pretek sporočil ste nastavili na %n minut"],
    "_{actor} set the message expiration to %n week_::_{actor} set the message expiration to %n weeks_" : ["{actor} nastavi pretek sporočil na %n teden","{actor} nastavi pretek sporočil na %n tedna","{actor} nastavi pretek sporočil na %n tedne","{actor} nastavi pretek sporočil na %n tednov"],
    "_{actor} set the message expiration to %n day_::_{actor} set the message expiration to %n days_" : ["{actor} nastavi pretek sporočil na %n dan","{actor} nastavi pretek sporočil na %n dneva","{actor} nastavi pretek sporočil na %n dni","{actor} nastavi pretek sporočil na %n dni"],
    "_{actor} set the message expiration to %n hour_::_{actor} set the message expiration to %n hours_" : ["{actor} nastavi pretek sporočil na %n uro","{actor} nastavi pretek sporočil na %n uri","{actor} nastavi pretek sporočil na %n ure","{actor} nastavi pretek sporočil na %n ur"],
    "_{actor} set the message expiration to %n minute_::_{actor} set the message expiration to %n minutes_" : ["{actor} nastavi pretek sporočil na %n minuto","{actor} nastavi pretek sporočil na %n minuti","{actor} nastavi pretek sporočil na %n minute","{actor} nastavi pretek sporočil na %n minut"],
    "{actor} disabled message expiration" : "{actor} onemogoči pretek sporočil",
    "You disabled message expiration" : "Onemogočili ste pretek sporočil",
    "{actor} cleared the history of the conversation" : "{actor} počisti zgodovino pogovora.",
    "You cleared the history of the conversation" : "Počistili ste zgodovino pogovora.",
    "{actor} set the conversation picture" : "{actor} nastavi sliko pogovora",
    "You set the conversation picture" : "Nastavili ste sliko pogovora",
    "{actor} removed the conversation picture" : "{actor} odstrani sliko pogovora",
    "You removed the conversation picture" : "Odstranili ste sliko pogovora",
    "{actor} ended the poll {poll}" : "{actor} konča anketo {poll}",
    "You ended the poll {poll}" : "Končate anketo {poll}",
    "{actor} started the video recording" : "{actor} začne snemati video",
    "You started the video recording" : "Začnete snemati video",
    "{actor} stopped the video recording" : "{actor} zaustavi snemanje videa",
    "You stopped the video recording" : "Zaustavite snemanje videa",
    "{actor} started the audio recording" : "{actor} začne snemati zvok",
    "You started the audio recording" : "Začnete snemati zvok",
    "{actor} stopped the audio recording" : "{actor} zaustavi snemanje zvoka",
    "You stopped the audio recording" : "Zaustavite snemanje zvoka",
    "The recording failed" : "Snemanje je spodletelo",
    "Someone voted on the poll {poll}" : "Nekdo je oddal glas v anketi {poll}",
    "Message deleted by author" : "Sporočilo je avtor izbrisal.",
    "Message deleted by {actor}" : "{actor} je izbrisal sporočilo",
    "Message deleted by you" : "Sporočilo ste izbrisali",
    "Deleted user" : "Izbrisan uporabnik",
    "Unknown number" : "Neznana številka",
    "Administration" : "Skrbništvo",
    "System" : "Sistem",
    "%s (guest)" : "%s (gost)",
    "Missed call" : "Zgrešen klic",
    "Unanswered call" : "Neodgovorjen klic",
    "Call ended (Duration {duration})" : "Konferenčni klic je končan (Trajanje: {duration})",
    "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["{actor} konča klic z %n gostom (trajanje: {duration}).","{actor} konča klic s skupaj %n gostoma (trajanje: {duration}).","{actor} konča klic s skupaj %n gosti (trajanje: {duration}).","{actor} konča klic s skupaj %n gosti (trajanje: {duration})."],
    "{actor} ended the call with {user1} (Duration {duration})" : "{actor} konča klic z osebo {user1} (trajanje {duration})",
    "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor} konča klic z osebama {user1} in {user2} (trajanje {duration})",
    "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor} konča klic z osebami {user1}, {user2} in {user3} (trajanje {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{actor} konča klic z osebami {user1}, {user2}, {user3} in {user4} (trajanje {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{actor} konča klic z osebami {user1}, {user2}, {user3}, {user4} in {user5} (trajanje {duration})",
    "Message of {user} in {conversation}" : "Sporočilo osebe {user} v pogovoru {conversation}",
    "Message of {user}" : "Sporočilo osebe {user}",
    "Message of a deleted user in {conversation}" : "Sporočilo izbrisane osebe v pogovoru {conversation}",
    "Talk conversations" : "Pogovori Talk",
    "Call %s" : "Klic %s",
    "An error occurred. Please contact your administrator." : "Prišlo je do napake. Stopite v stik s skrbnikom sistema.",
    "File not found" : "Datoteke ni mogoče najti",
    "File is not shared, or shared but not with the user" : "Datoteka ni v uporabi, ali pa ni v uporabi z uporabnikom",
    "No account available to delete." : "Ni računa za brisanje.",
    "Poll" : "Anketa",
    "Password needs to be set" : "Nastaviti je treba geslo",
    "Uploading the file failed" : "Pošiljanje datoteke je spodletelo",
    "No image file provided" : "Ni podane slikovne datoteke",
    "File is too big" : "Datoteka je prevelika",
    "Invalid file provided" : "Podana je neveljavna daoteka",
    "Invalid image" : "Neveljavna slika",
    "Unknown filetype" : "Neznana vrsta datoteke",
    "Talk mentions" : "Omembe v Talk",
    "More conversations" : "Več pogovorov",
    "Say hi to your friends and colleagues!" : "Pozdravite prijatelje in znance.",
    "No unread mentions" : "Ni neprebranih sporočil",
    "Call in progress" : "Klic je v teku ...",
    "You were mentioned" : "Omenjeni ste bili v klepetu",
    "Write to conversation" : "Zapisuj v pogovor",
    "Writes event information into a conversation of your choice" : "Zapiše podrobnosti dogodka v pogovor po vaši izbiri",
    "Conversation invitation" : "Povabilo k pogovoru",
    "Scheduled time" : "Načrtovan time",
    "Description" : "Opis",
    "You can also dial-in via phone with the following details" : "Povezati se je mogoče tudi prek telefonske povezave z naslednjimi podatki",
    "Dial-in information" : "Podrobnosti klicne povezave",
    "Meeting ID" : "ID Sestanka",
    "Your PIN" : "Koda PIN",
    "Meeting" : "Srečanje",
    "Password request: %s" : "Geslo: %s",
    "Private conversation" : "Zasebni pogovor",
    "Deleted user (%s)" : "Izbrisan uporabnik (%s)",
    "Failed to upload call recording" : "Pošiljanje posnetka pogovora je spodletelo",
    "The recording server failed to upload recording of call {call}. Please reach out to the administration." : "Pošiljanje posnetka s strežnika za snemanje je spodletelo za klic {call}. Stopite v stik s skrbnikom sistema.",
    "Share to chat" : "Objavi v pogovor",
    "Dismiss notification" : "Opusti obvestilo",
    "Call recording now available" : "Posnetek klica je zdaj na voljo",
    "Transcript now available" : "Prepis je sedaj na voljo",
    "Failed to transcript call recording" : "Prepis posnetka je spodletel",
    "Accept" : "Sprejmi",
    "Decline" : "Zavrni",
    "Someone reacted" : "Nekdo se je odzval",
    "New message" : "Novo sporočilo",
    "Reminder" : "Opomnik",
    "Notification" : "Obvestilo",
    "Reminder: Guest in {call}" : "Opomnik: Gost v klicu {call}",
    "{user} in {call}" : "{user} v pogovoru {call}",
    "Deleted user in {call}" : "Iz klica {call} je izbrisan uporabnik",
    "{guest} (guest) in {call}" : "{guest} (gost) v klicu {call}",
    "Guest in {call}" : "Gost v klicu {call}",
    "{user} sent you a private message" : "{user} vam pošlje zasebno sporočilo",
    "{user} sent a message in conversation {call}" : "{actor} vam pošlje sporočilo v pogovor {call} ",
    "A deleted user sent a message in conversation {call}" : "Izbrisan uporabnik pošlje sporočilo v pogovor {call}",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (gost) pošlje sporočilo v pogovor {call}",
    "A guest sent a message in conversation {call}" : "Gost je poslal sporočilo v pogovor {call}",
    "{user} replied to your private message" : "{user} odgovori na vaše zasebno sporočilo",
    "{user} replied to your message in conversation {call}" : "{user} odgovori na vaše sporočilo v pogovoru {call}",
    "A deleted user replied to your message in conversation {call}" : "Izbrisan uporabnik odgovori na vaše sporočilo v pogovoru {call}",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (gost) odgovori na vaše sporočilo v pogovoru {call}",
    "A guest replied to your message in conversation {call}" : "Gost odgovori na vaše sporočilo v pogovoru {call}",
    "{user} reacted with {reaction} to your private message" : "{user} se odzove z {reaction} v zasebnem sporočilu",
    "{user} reacted with {reaction} to your message in conversation {call}" : "{user} se odzove z {reaction} na vaše sporočilo v klicu {call}",
    "A deleted user reacted with {reaction} to your message in conversation {call}" : "Izbrisan uporabnik se odzove z {reaction} na vaše sporočilo v klicu {call}",
    "{guest} (guest) reacted with {reaction} to your message in conversation {call}" : "{guest} (gost) se odzove z {reaction} na vaše sporočilo v klicu {call}",
    "A guest reacted with {reaction} to your message in conversation {call}" : "Gost se odzove z {reaction} na vaše sporočilo v klicu {call}",
    "{user} mentioned you in a private conversation" : "{user} vas omeni v zasebnem pogovoru",
    "{user} mentioned group {group} in conversation {call}" : "{user} omeni skupino {group} v pogovoru {call}",
    "{user} mentioned everyone in conversation {call}" : "{user} omeni vse v pogovoru {call}",
    "{user} mentioned you in conversation {call}" : "{user} vas omeni v pogovoru {call}",
    "A deleted user mentioned you in conversation {call}" : "Izbrisan uporabnik vas omeni v pogovoru {call}",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (gost) vas omeni v pogovoru {call}",
    "A guest mentioned you in conversation {call}" : "Gost vas omeni v pogovoru {call}",
    "View message" : "Poglej sporočilo",
    "Dismiss reminder" : "Opusti opomnik",
    "View chat" : "Pokaži klepet",
    "{user} invited you to a group conversation: {call}" : "{user} pošlje povabilo na skupinski pogovor: {call}",
    "Join call" : "Pridruži se klicu",
    "Answer call" : "Odzovi se na klic",
    "{user} would like to talk with you" : "{user} želi govoriti z vami",
    "Call back" : "Pokličite nazaj",
    "You missed a call from {user}" : "Zamudili ste klic stika {user}",
    "Accept call" : "Sprejmi klic",
    "A group call has started in {call}" : "Začet je skupinski pogovor v {call}",
    "You missed a group call in {call}" : "Zamudili ste skupinski klic {call}",
    "{email} is requesting the password to access {file}" : "{email} zahteva geslo za dostop do datoteke {file}",
    "{email} tried to request the password to access {file}" : "{email} prosi za geslo za dostop do datoteke {file}",
    "Someone is requesting the password to access {file}" : "Nekdo zahteva geslo za dostop do datoteke {file}",
    "Someone tried to request the password to access {file}" : "Nekdo prosi za geslo za dostop do datoteke {file}",
    "Open settings" : "Odpri nastavitve",
    "The hosted signaling server is now configured and will be used." : "Gostiteljski signalni strežnik je nastavljen in bo v uporabi.",
    "The hosted signaling server was removed and will not be used anymore." : "Gostiteljski signalni strežnik je bil odstranjen in ne bo več v uporabi.",
    "The hosted signaling server account has changed the status from \"{oldstatus}\" to \"{newstatus}\"." : "Račun gostiteljskega signalnega strežnika je spremenjen iz stanja  »{oldstatus}« v »{newstatus}«.",
    "pending" : "na čakanju",
    "active" : "dejavno",
    "expired" : "poteklo",
    "blocked" : "zavrnjeno",
    "error" : "napaka",
    "The certificate of {host} expires in {days} days" : "Potrdilo gostitelja {host} poteče v {days} dneh",
    "The certificate of {host} expired" : "Potrdilo gostitelja {host} je poteklo",
    "Contact via Talk" : "Stopi v stik s Talk",
    "Open Talk" : "Odpri Talk",
    "Default" : "Privzeta",
    "Presentation" : "Predstavitev",
    "Webinar" : "Webinar",
    "Conversations" : "Pogovori",
    "Messages in current conversation" : "Sporočila v trenutnem pogovoru",
    "{user}" : "{user}",
    "Messages" : "Sporočila",
    "{user} in {conversation}" : "{user} v pogovoru {conversation}",
    "Messages in other conversations" : "Sporočila v drugih pogovorih",
    "Invalid emoji character" : "Neveljaven znak izrazne ikone",
    "Invalid background color" : "Neveljavna barva ozadja",
    "Avatar image is not square" : "Slika podobe ni kvadratna",
    "Room {number}" : "Skupina {number}",
    "Favorites" : "Priljubljeno",
    "Other" : "Drugo",
    "Failed to request trial because the trial server is unreachable. Please try again later." : "Izdaja preizkusne zahteve je spodletela, ker preizkusni strežnik ni dosegljiv.",
    "There is a problem with the authentication of this instance. Maybe it is not reachable from the outside to verify it's URL." : "Prišlo je do težav z overitvijo zagnane seje. Morda strežnik ni dosegljiv od zunaj za preverjanje naslova URL.",
    "Something unexpected happened." : "Prišlo jo do nepričakovane napake.",
    "The URL is invalid." : "Naslov URL je neveljaven.",
    "An HTTPS URL is required." : "Zahtevan je naslov URL HTTPS.",
    "The email address is invalid." : "Naslov elektronske pošte je neveljaven.",
    "The language is invalid." : "Izbran jezik je neveljaven.",
    "The country is invalid." : "Izbrana država je neveljavna.",
    "There is a problem with the request of the trial. Please check your logs for further information." : "Prišlo je do težav z zahtevanjem preizkusa. Preverite dnevniške zapise za podrobnosti.",
    "Too many requests are send from your servers address. Please try again later." : "Z naslova strežnika je poslanih preveč zahtev. Poskusite znova kasneje.",
    "There is already a trial registered for this Nextcloud instance." : "Preizkusni strežnik način za to namestitev je že vpisan.",
    "Something unexpected happened. Please try again later." : "Prišlo jo do nepričakovane napake. Poskusite znova kasneje.",
    "Failed to request trial because the trial server behaved wrongly. Please try again later." : "Izdaja preizkusne zahteve je spodletela, ker pošilja preizkusni strežnik neustrezne odzive. Poskusite znova kasneje.",
    "Trial requested but failed to get account information. Please check back later." : "Poslana je zahteva za preizkusni način, a je spodletelo pridobivanje podrobnosti računa. Opravilo ponovite kasneje.",
    "There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it's URL." : "Prišlo je do težav z overitvijo zahteve. Morda strežnik ni dosegljiv od zunaj za preverjanje naslova URL.",
    "Failed to fetch account information because the trial server behaved wrongly. Please check back later." : "Pridobivanje podrobnosti računa je spodletelo, ker pošilja preizkusni strežnik neustrezne odzive. Poskusite znova kasneje.",
    "There is a problem with fetching the account information. Please check your logs for further information." : "Prišlo je do napake med pridobivanjem podrobnosti računa. Preverite dnevniške zapise za podrobnosti.",
    "There is no such account registered." : "Takega računa še ni vpisanega.",
    "Failed to fetch account information because the trial server is unreachable. Please check back later." : "Pridobivanje podrobnosti računa je spodletelo, je preizkusni strežnik nedosegljiv. Poskusite znova kasneje.",
    "Deleting the hosted signaling server account failed. Please check back later." : "Brisanje gostiteljskega signalnega strežnika je spodletelo. Opravilo ponovite kasneje.",
    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "Brisanje računa je spodletelo, ker pošilja preizkusni strežnik neustrezne odzive. Poskusite znova kasneje.",
    "There is a problem with deleting the account. Please check your logs for further information." : "Prišlo je do napake med brisanjem računa. Preverite dnevniške zapise za podrobnosti.",
    "Too many requests are sent from your servers address. Please try again later." : "Z naslova strežnika je poslanih preveč zahtev. Poskusite znova kasneje.",
    "Failed to delete the account because the trial server is unreachable. Please check back later." : "Brisanje računa je spodletelo, ker preizkusni strežnik ni dosegljiv. Opravilo ponovite kasneje.",
    "Note to self" : "Opomba sebi",
    "A place for your private notes, thoughts and ideas" : "Mesto za zasebne opombe, misli in zamisli",
    "Let's get started!" : "Začnimo!",
    "Andorra" : "Andora",
    "United Arab Emirates" : "Združeni Arabski Emirati",
    "Afghanistan" : "Afganistan",
    "Antigua and Barbuda" : "Antigva in Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albanija",
    "Armenia" : "Armenija",
    "Angola" : "Angola",
    "Antarctica" : "Antarktika",
    "Argentina" : "Argentina",
    "American Samoa" : "Ameriška Samoa",
    "Austria" : "Avstrija",
    "Australia" : "Australija",
    "Aruba" : "Aruba",
    "Åland Islands" : "Otočje Åland",
    "Azerbaijan" : "Azerbajdžan",
    "Bosnia and Herzegovina" : "Bosna in Hercegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladeš",
    "Belgium" : "Belgija",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bolgarija",
    "Bahrain" : "Bahrain",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Saint Barthélemy",
    "Bermuda" : "Bermuda",
    "Brunei Darussalam" : "Brunej Darussalam",
    "Bolivia, Plurinational State of" : "Bolivija, večnacionalna država",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius in Saba",
    "Brazil" : "Brazilija",
    "Bahamas" : "Bahami",
    "Bhutan" : "Butan",
    "Bouvet Island" : "Otok Bouvet",
    "Botswana" : "Botsvana",
    "Belarus" : "Belorusija",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Cocos (Keeling) Islands" : "Kokosovi otoki (Keeling)",
    "Congo, the Democratic Republic of the" : "Kongo, demokratična republika",
    "Central African Republic" : "Centralno Afriška Republika",
    "Congo" : "Kongo",
    "Switzerland" : "Švica",
    "Côte d'Ivoire" : "Slonokoščeni otoki",
    "Cook Islands" : "Cookovi otoki",
    "Chile" : "Čile",
    "Cameroon" : "Kamerun",
    "China" : "Kitajska",
    "Colombia" : "Kolumbija",
    "Costa Rica" : "Kostarika",
    "Cuba" : "Kuba",
    "Cabo Verde" : "Cabo Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Božični otoki",
    "Cyprus" : "Ciper",
    "Czechia" : "Češka",
    "Germany" : "Nemčija",
    "Djibouti" : "Džibuti",
    "Denmark" : "Danska",
    "Dominica" : "Dominika",
    "Dominican Republic" : "Dominikanska republika",
    "Algeria" : "Alžirija",
    "Ecuador" : "Ekvador",
    "Estonia" : "Estonija",
    "Egypt" : "Egipt",
    "Western Sahara" : "Severna Sahara",
    "Eritrea" : "Eritreja",
    "Spain" : "Španija",
    "Ethiopia" : "Etiopija",
    "Finland" : "Finska",
    "Fiji" : "Fiji",
    "Falkland Islands (Malvinas)" : "Falklandski otoki",
    "Micronesia, Federated States of" : "Mikronezija, federativne države",
    "Faroe Islands" : "Ferski otoki",
    "France" : "Francija",
    "Gabon" : "Gabon",
    "United Kingdom of Great Britain and Northern Ireland" : "Združeno kraljestvo Velike Britanije in Severne Irske",
    "Grenada" : "Grenada",
    "Georgia" : "Gruzija",
    "French Guiana" : "Francoska Gvajana",
    "Guernsey" : "Guernsey",
    "Ghana" : "Gana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Grenlandija",
    "Gambia" : "Gambija",
    "Guinea" : "Gvineja",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Ekvatorialna Gvineja",
    "Greece" : "Grčija",
    "South Georgia and the South Sandwich Islands" : "Južna Georgija in Južni Sandwichevi otoki",
    "Guatemala" : "Gvatemala",
    "Guam" : "Gvam",
    "Guinea-Bissau" : "Gvineja-Bissau",
    "Guyana" : "Gvajana",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Otoka Heard in McDonald",
    "Honduras" : "Honduras",
    "Croatia" : "Hrvaška",
    "Haiti" : "Haiti",
    "Hungary" : "Madžarska",
    "Indonesia" : "Indonezija",
    "Ireland" : "Irska",
    "Israel" : "Izrael",
    "Isle of Man" : "Otok Man",
    "India" : "Indija",
    "British Indian Ocean Territory" : "Britanski teritorij v Indijskem oceanu",
    "Iraq" : "Irak",
    "Iran, Islamic Republic of" : "Iran, Islamska republika",
    "Iceland" : "Islandija",
    "Italy" : "Italija",
    "Jersey" : "Jersey",
    "Jamaica" : "Jamajka",
    "Jordan" : "Jordanija",
    "Japan" : "Japonska",
    "Kenya" : "Kenija",
    "Kyrgyzstan" : "Kirgizistan",
    "Cambodia" : "Kambodža",
    "Kiribati" : "Kiribati",
    "Comoros" : "Komori",
    "Saint Kitts and Nevis" : "Sveti Krištof in Nevis",
    "Korea, Democratic People's Republic of" : "Koreja, Demokratična ljudska republika",
    "Korea, Republic of" : "Koreja, republika",
    "Kuwait" : "Kuvajt",
    "Cayman Islands" : "Kajmansko otočje",
    "Kazakhstan" : "Kazahstan",
    "Lao People's Democratic Republic" : "Laos, Ljudska demokratična republika",
    "Lebanon" : "Libanon",
    "Saint Lucia" : "Sveta Lucija",
    "Liechtenstein" : "Lihtenštajn",
    "Sri Lanka" : "Šrilanka",
    "Liberia" : "Liberija",
    "Lesotho" : "Lesoto",
    "Lithuania" : "Litva",
    "Luxembourg" : "Luksemburg",
    "Latvia" : "Latvija",
    "Libya" : "Libija",
    "Morocco" : "Maroko",
    "Monaco" : "Monako",
    "Moldova, Republic of" : "Moldavija, republika",
    "Montenegro" : "Črna Gora",
    "Saint Martin (French part)" : "Sveti Martin (francoski del)",
    "Madagascar" : "Madagaskar",
    "Marshall Islands" : "Maršalovi otoki",
    "North Macedonia" : "Severna Makedonija",
    "Mali" : "Mali",
    "Myanmar" : "Mjanmar",
    "Mongolia" : "Mongolija",
    "Macao" : "Makao",
    "Northern Mariana Islands" : "Severni Marijanski otoki",
    "Martinique" : "Martinik",
    "Mauritania" : "Mavretanija",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mavricijus",
    "Maldives" : "Maldivi",
    "Malawi" : "Malavi",
    "Mexico" : "Mehika",
    "Malaysia" : "Malezija",
    "Mozambique" : "Mozambik",
    "Namibia" : "Namibija",
    "New Caledonia" : "Nova Kaledonija",
    "Niger" : "Niger",
    "Norfolk Island" : "Otok Norfolk",
    "Nigeria" : "Nigerija",
    "Nicaragua" : "Nikaragva",
    "Netherlands" : "Nizozemska",
    "Norway" : "Norveška",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Nova Zelandija",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Francoska polinezija",
    "Papua New Guinea" : "Papua Nova Gvineja",
    "Philippines" : "Filipini",
    "Pakistan" : "Pakistan",
    "Poland" : "Poljska",
    "Saint Pierre and Miquelon" : "Saint Pierre in Miquelon",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Portoriko",
    "Palestine, State of" : "Palestina",
    "Portugal" : "Portugalska",
    "Palau" : "Palau",
    "Paraguay" : "Paragvaj",
    "Qatar" : "Katar",
    "Réunion" : "Réunion",
    "Romania" : "Romunija",
    "Serbia" : "Srbija",
    "Russian Federation" : "Ruska federacija",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Savdova Arabija",
    "Solomon Islands" : "Solomonovi otoki",
    "Seychelles" : "Sejšeli",
    "Sudan" : "Sudan",
    "Sweden" : "Švedska",
    "Singapore" : "Singapur",
    "Saint Helena, Ascension and Tristan da Cunha" : "Sveta Helena, Ascension in Tristan da Cunha",
    "Slovenia" : "Slovenija",
    "Svalbard and Jan Mayen" : "Svalbard in Jan Mayen",
    "Slovakia" : "Slovaška",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalija",
    "Suriname" : "Surinam",
    "South Sudan" : "Južni Sudan",
    "Sao Tome and Principe" : "Sao Tome in Principe",
    "El Salvador" : "El Salvador",
    "Sint Maarten (Dutch part)" : "Sveti Martin (nizozemski del)",
    "Syrian Arab Republic" : "Sirska arabska republika",
    "Eswatini" : "Esvatini",
    "Turks and Caicos Islands" : "Otoki Turks in Caicos",
    "Chad" : "Čad",
    "French Southern Territories" : "Francoski južni teritorij",
    "Togo" : "Togo",
    "Thailand" : "Tajska",
    "Tajikistan" : "Tadžikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor-Leste",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunizija",
    "Tonga" : "Tonga",
    "Turkey" : "Turčija",
    "Trinidad and Tobago" : "Trinidad in Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan, Province of China" : "Tajvan, provinca Kitajske",
    "Tanzania, United Republic of" : "Tanzania",
    "Ukraine" : "Ukrajina",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Ameriški mali oddaljeni otoki",
    "United States of America" : "Združene države Amerike",
    "Uruguay" : "Urugvaj",
    "Uzbekistan" : "Uzbekistan",
    "Holy See" : "Sveti sedež",
    "Saint Vincent and the Grenadines" : "Sveti Vincencij in Grenadine",
    "Venezuela, Bolivarian Republic of" : "Venezuela, bolivarska republika",
    "Virgin Islands, British" : "Deviški otoki, britanski",
    "Virgin Islands, U.S." : "Deviški otoki, ameriški",
    "Viet Nam" : "Vijetnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis in Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Jemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Južna Afrika",
    "Zambia" : "Zambija",
    "Zimbabwe" : "Zimbabve",
    "Background blur" : "Zamegljeno ozadje",
    "Federation" : "Zvezni oblaki",
    "High-performance backend" : "Visoko zmogljivi ozadnji program",
    "Error: Cannot connect to server" : "Napaka: ni se mogoče povezati s strežnikom",
    "Error: Server did not respond with proper JSON" : "Napaka: odziv strežnika ni ustrezno oblikovan v zapisu JSON",
    "Error: Certificate expired" : "Napaka: potrdilo je poteklo",
    "Could not get version" : "Ni mogoče pridobiti podatkov različice",
    "Error: Running version: {version}; Server needs to be updated to be compatible with this version of Talk" : "Napaka zagnane različice {version}: za pravilno delovanje je treba strežnik posodobiti na različico, skladno s trenutno nameščenim programom Talk.",
    "Error: Server responded with: {error}" : "Napaka: odziv strežnika: {error}",
    "Error: Unknown error occurred" : "Napak: prišlo je do neznane napake",
    "Recording backend" : "Ozadje posnetka",
    "SIP configuration" : "Nastavitve klicne seje SIP",
    "Invalid date, date format must be YYYY-MM-DD" : "Neveljaven zapis časa; biti mora v zapisu YYYY-MM-DD",
    "Conversation not found" : "Pogovora ni mogoče najti",
    "Chat, video & audio-conferencing using WebRTC" : "Klepet in videokonferenčni klici z uporabo WebRT",
    "Leave call" : "Zapusti klic",
    "Navigating away from the page will leave the call in {conversation}" : "Odhod s strani pusti odprt klic {converstaion}",
    "Stay in call" : "Ostani v klicu",
    "Duplicate session" : "Podvojena seja",
    "Discuss this file" : "Pogovor o datoteki",
    "Loading …" : "Poteka nalaganje …",
    "Share this file with others to discuss it" : "Za pogovor o datoteki je treba najprej omogočiti souporabo.",
    "Join conversation" : "Pridruži se pogovoru",
    "Share this file" : "Omogoči souporabo",
    "Error occurred when joining the conversation" : "Prišlo je do napake med povezovanjem v pogovor",
    "This conversation is password-protected." : "Ta pogovor je zaščiten z geslom",
    "We have detected multiple invalid password attempts from your IP. Therefore your next attempt is throttled up to 30 seconds." : "Zaznanih je več neveljavnih poskusov prijave iz trenutnega naslova IP. Iz varnostnih razlogov bo možnost naslednjega poskusa prijave zadržana za 30 sekund.",
    "The password is wrong. Try again." : "Geslo je napačno. Poskusite znova.",
    "Password" : "Geslo",
    "Submit" : "Pošlji",
    "Error requesting the password." : "Prišlo je do napake med zahtevanjem gesla",
    "Request password" : "Zahtevaj geslo",
    "This conversation has ended" : "Pogovor je končan",
    "Close Talk sidebar" : "Zapri bočno okno Talk",
    "Open Talk sidebar" : "Odpri bočno okno Talk",
    "Everyone" : "Vsi",
    "Users and moderators" : "Uporabniki in moderatorji",
    "Moderators only" : "Le moderatorji",
    "Disable calls" : "Onemogoči klice",
    "Save changes" : "Shrani spremembe",
    "Saving …" : "Shranjevanje...",
    "Saved!" : "Shranjeno!",
    "Limit to groups" : "Omeji na skupine",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "Ko je izbrana vsaj ena skupina, so lahko udeleženci pogovora le člani izbranih skupin.",
    "Guests can still join public conversations." : "Gosti se še vedno lahko pridružijo javnim pogovorom.",
    "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Uporabniki, ki ne morejo več uporabljati programa Talk, bodo še vedno na seznamu udeležencev v predhodnih pogovorih, ohranjena bodo tudi njihova sporočila.",
    "Limit using Talk" : "Omeji uporabo programa Talk",
    "Limit creating a public and group conversation" : "Omeji ustvarjanje javnega ali skupinskega pogovora",
    "Limit creating conversations" : "Omeji ustvarjanje pogovorov",
    "Limit starting a call" : "Omeji začenjanje pogovora",
    "Limit starting calls" : "Omeji začenjanje pogovora",
    "When a call has started, everyone with access to the conversation can join the call." : "Ko se klic začne, se lahko kdorkoli z dostopom do pogovora samodejno pridruži.",
    "The following bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "Na strežniku so nameščeni navedeni boti. V dokumentaciji lahko najdete več podrobnosti o {linkstart1}izgradnji lastnih botov{linkend} oziroma možnosti {linkstart2}dodajanja že obstoječih{linkend} na strežnik.",
    "No bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "Na strežniku ni nameščenega nobenega bota. V dokumentaciji lahko najdete več podrobnosti o {linkstart1}izgradnji lastnih botov{linkend} oziroma možnosti {linkstart2}dodajanja že obstoječih{linkend} na strežnik.",
    "Description is not provided" : "Opis ni podan",
    "Locked for moderators" : "Zaklenjeno za moderatorje",
    "Enabled" : "Omogočeno",
    "Disabled" : "Onemogočeno",
    "Bots settings" : "Nastavitve botov",
    "State" : "Stanje",
    "Name" : "Ime",
    "Last error" : "Zadnja napaka",
    "Total errors count" : "Skupno število napak",
    "Find more bots" : "Poišči več botov",
    "Beta" : "Preizkusno",
    "Enable Federation in Talk app" : "Omogoči podporo zveznim povezavam v programu Talk",
    "Permissions" : "Dovoljenja",
    "Select groups …" : "Izbor skupin ...",
    "All messages" : "Vsa sporočila",
    "@-mentions only" : "Le @-omembe",
    "Off" : "Onemogočeno",
    "General settings" : "Splošne nastavitve",
    "Default notification settings" : "Privzete nastavitve obveščanja",
    "Default group notification" : "Privzeta skupinska obveščanja",
    "Default group notification for new groups" : "Privzeto skupinsko obveščanje za nove skupine",
    "Integration into other apps" : "Združevanje z drugimi programi",
    "Allow conversations on files" : "Dovoli pogovore pri datotekah",
    "Allow conversations on public shares for files" : "Dovoli pogovore na javnih povezavah pri datotekah",
    "Enable encryption" : "Omogoči šifriranje",
    "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}." : "S klikom na potrditveni gumb bodo podatki poslani na strežnik Struktur AG. Več podrobnosti je zbranih na povezavi  {linkstart}spreed.eu{linkend}.",
    "Pending" : "Na čakanju ...",
    "Error" : "Napaka",
    "Blocked" : "Zavrnjen",
    "Active" : "Dejavno",
    "Expired" : "Preteklo",
    "Never" : "nikoli",
    "The trial could not be requested. Please try again later." : "Zahteve za dostop do preizkusnega strežnika ni mogoče poslati. Poskusite znova kasneje.",
    "The account could not be deleted. Please try again later." : "Računa ni mogoče izbrisati. Poskusite znova kasneje.",
    "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "Partnersko podjetje Struktur AG ponuja storitev, pri kateri je mogoče zahtevati dostop do gostujočega signalnega strežnika. Izpolniti je treba le spodnji obrazec in zahteva bo poslana. Ko je strežnik nastavljen za uporabo bodo vaša poverila samodejno posodobljena, kar prepiše obstoječe nastavitve.",
    "URL of this Nextcloud instance" : "Naslov URL te namestitve Nextcloud",
    "Full name of the user requesting the trial" : "Polno ime uporabnika, ki zahteva preizkusni dostop",
    "Email of the user" : "Elektronski naslov uporabnika",
    "Language" : "Jezik",
    "Country" : "Država",
    "Request signaling server trial" : "Zahtevaj preizkusno uporabo signalnega strežnika",
    "You can see the current status of your hosted signaling server in the following table." : "Trenutno stanje gositeljskega signalnega strežnika si lahko ogledate v spodnji razpredelnici.",
    "Status" : "Stanje",
    "Created at" : "Ustvarjeno",
    "Expires at" : "Preteče",
    "Limits" : "Omejitve",
    "Yes" : "Da",
    "No" : "Ne",
    "Delete the signaling server account" : "Izbriši račun signalnega strežnika",
    "_%n user_::_%n users_" : ["%n uporabnik","%n uporabnika","%n uporabniki","%n uporabnikov"],
    "Installed version: {version}" : "Nameščena različica: {version}",
    "You can install the Matterbridge to link Nextcloud Talk to some other services, visit their {linkstart1}GitHub page{linkend} for more details. Downloading and installing the app can take a while. In case it times out, please install it manually from the {linkstart2}Nextcloud App Store{linkend}." : "Namestitev protokola Matterbridge omogoča povezovanje programa Nextcloud Talk z drugimi storitvami. Za več podrobnosti si oglejte {linkstart1}strani GitHub{linkend}. Prejemanje in nameščanje programa je lahko dolgotrajno, če pa časovno poteče, bo treba namestitev izvesti ročno iz {linkstart2}Trgovine Nextcloud{linkend}.",
    "Matterbridge binary was not found or couldn't be executed." : "Zagonske datoteke Matterbridge ni mogoče najti, ali pa je ni mogoče zagnati.",
    "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "Pot do izvedljive datoteke Matterbridge je mogoče nastaviti tudi ročno med nastavitvami. Za več podrobnosti si oglejte {linkstart}Dokumentacijo združevalnika Matterbridge{linkend}.",
    "Downloading …" : "Poteka prejemanje …",
    "Install Talk Matterbridge" : "Namesti Talk Matterbridge",
    "An error occurred while installing the Matterbridge app" : "Prišlo je do napake med nameščanjem programa Matterbridge.",
    "An error occurred while installing the Talk Matterbridge. Please install it manually" : "Prišlo je do napake med nameščanjem programa Matterbridge Talk. Namestite ga ročno.",
    "Failed to execute Matterbridge binary." : "Zagon izvedljive datoteke Matterbridge je spodletel.",
    "Matterbridge integration" : "Združevalnik Matterbridge",
    "Enable Matterbridge integration" : "Omogoči združevalnik Matterbridge",
    "Status: Checking connection" : "Stanje: preverjanje povezave",
    "OK: Running version: {version}" : "Brez napak: zagnana različica: {version}",
    "Error: Server seems to be a Signaling server" : "Napaka: kaže, da je povezan signalni strežnik",
    "Recording backend URL" : "Naslov URL ozadja posnetka",
    "Validate SSL certificate" : "Overi potrdilo SSL",
    "Delete this server" : "Izbriši strežnik",
    "Test this server" : "Preizkusi strežnik",
    "Disabled for all calls" : "Onemogoči za vse klice",
    "Enabled for all calls" : "Omogoči za vse klice",
    "The PHP settings \"upload_max_filesize\" or \"post_max_size\" only will allow to upload files up to {maxUpload}." : "Nastavitvi PHP »upload_max_filesize« oziroma »post_max_size« omogočata pošiljanje datotek do velikosti {maxUpload}.",
    "Recording backend settings saved" : "Nastavitve snemalnega ozadnjega strežnika so shranjene",
    "Add a new recording backend server" : "Dodaj nov snemalni ozadnji strežnik",
    "Shared secret" : "Skrivna koda",
    "Recording consent" : "Strinjanje s snemanjem",
    "SIP configuration saved!" : "Nastavitve klicne seje SIP so shranjene!",
    "Restrict SIP configuration" : "Omeji nastavitve klicne seje SIP",
    "Enable SIP configuration" : "Omogoči nastavitve sklicne seje SIP",
    "Only users of the following groups can enable SIP in conversations they moderate" : "Le uporabniki navedenih skupin lahko omogočijo klicno sejo SIP pri pogovorih, ki jih vodijo.",
    "Phone number (Country)" : "Telefonska številka (država)",
    "This information is sent in invitation emails as well as displayed in the sidebar to all participants." : "Te podrobnosti so poslane v vabilih, prav tako so prikazane v bočnem oknu vseh udeležencev.",
    "Error code" : "Koda napake",
    "High-performance backend URL" : "Naslov URL do gostujočega visoko zmogljivega ozadnjega programa",
    "High-performance backend settings saved" : "Nastavitve visoko zmogljivega ozadnjega strežnika so shranjene",
    "STUN server URL" : "Naslov URL strežnika STUN",
    "The server address is invalid" : "Naslov strežnika ni veljaven",
    "STUN settings saved" : "Nastavitve strežnika STUN so shranjene",
    "STUN servers" : "Strežniki STUN",
    "A STUN server is used to determine the public IP address of participants behind a router." : "Strežnik TURN se uporablja za določanje javnega naslova IP udeležencev za požarnim zidom.",
    "Add a new STUN server" : "Dodaj nov strežnik STUN",
    "{schema} scheme must be used with a domain" : "Shema {schema} mora biti uporabljena z domeno.",
    "{option1} and {option2}" : "{option1} in {option2}",
    "{option} only" : "le {option}",
    "OK: Successful ICE candidates returned by the TURN server" : "OK: strežnik TURN vrača uspešno zaznane kandidate ICE",
    "Error: No working ICE candidates returned by the TURN server" : "Napaka: strežnik TURN ni vrnil seznama kandidateov ICE",
    "Testing whether the TURN server returns ICE candidates" : "Preizkušanje, ali strežnik TURN vrne seznam kandidatov ICE",
    "TURN server schemes" : "Sheme strežnika TURN",
    "TURN server URL" : "Naslov URL strežnika TURN",
    "TURN server secret" : "Skrivno geslo strežnika TURN",
    "TURN server protocols" : "Protokoli strežnika TURN",
    "A TURN server is used to proxy the traffic from participants behind a firewall. If individual participants cannot connect to others a TURN server is most likely required. See {linkstart}this documentation{linkend} for setup instructions." : "Strežnik TURN se uporablja za posredovanje podatkovnega prometa udeležencev za požarnimi zidovi. O tovrstnih rešitvah je dobro razmisliti, kadar se uporabniki ne uspejo povezati drug z drugim. Za več podrobnosti o možnostih namestitve in uporabe strežnikov TURN si oglejte {linkstart}dokumentacijo{linkend}.",
    "TURN settings saved" : "Nastavitve strežnika TURN so shranjene",
    "TURN servers" : "Strežniki TURN",
    "Add a new TURN server" : "Dodaj nov strežnik TURN",
    "Failed" : "Opravilo je spodletelo!",
    "OK" : "V redu",
    "Checking …" : "Poteka preverjanje ...",
    "Failed: WebAssembly is disabled or not supported in this browser. Please enable WebAssembly or use a browser with support for it to do the check." : "Spodletelo opravilo: program WebAssembly je onemogočen ali pa v tej različici brskalnika ni podprt. Omogočite program oziroma uporabite ustreznejši brskalnik za preverjanje.",
    "Failed: \".wasm\" and \".tflite\" files were not properly returned by the web server. Please check \"System requirements\" section in Talk documentation." : "Spodletelo opravilo: s strežnika so vrnjene neustrezne datoteke ».wasm« in ».tflite«. V dokumentaciji »Sistemskih zahtev« preverite določila za program Talk.",
    "OK: \".wasm\" and \".tflite\" files were properly returned by the web server." : "Uspešna izvedba: s spletnega strežnika so vrnjene ustrezne datoteke ».wasm« in ».tflite«.",
    "Web server setup checks" : "Preverjanje nastavitev spletnega strežnika",
    "Files required for virtual background can be loaded" : "Datoteke, uporabljene za zamegljevanje ozadja, je mogoče naložiti.",
    "Federated user" : "Zvezni uporabnik",
    "Assign participants to rooms" : "Dodeli udeležence v skupine",
    "Configure breakout rooms" : "Nastavi ločene skupine",
    "Number of breakout rooms" : "Število ločenih skupin",
    "Assignment method" : "Način dodeljevanja",
    "Automatically assign participants" : "Samodejno razvrsti udeležence",
    "Manually assign participants" : "Ročno razvrsti udeležence",
    "Allow participants to choose" : "Dovoli udeležencem izbor skupine",
    "Create rooms" : "Ustvari ločene skupine",
    "Confirm" : "Potrdi",
    "Create breakout rooms" : "Ustvari ločene skupine",
    "Reset" : "Ponastavi",
    "Delete breakout rooms" : "Izbriši ločene skupine",
    "Room {roomNumber}" : "Skupina {roomNumber}",
    "Current breakout rooms and settings will be lost" : "Trenutne nastavitve skupin in dejavne skupine bodo odstranjenje",
    "Cancel" : "Prekliči",
    "Unassigned participants" : "Nedodeljeni udeleženci",
    "Back" : "Nazaj",
    "Assign" : "Dodeli",
    "Add participant \"{user}\"" : "Dodaj uporabnika »{user}«",
    "Invalid calendar selected" : "Izbran je neveljaven koledar",
    "Unknown error occurred" : "Prišlo je do neznane napake.",
    "Meeting created" : "Srečanje je ustvarjeno.",
    "Upcoming meetings" : "Prihajajoča srečanja",
    "No upcoming meetings" : "Ni prihajajočih srečanj",
    "Schedule a meeting" : "Načrtovanje srečanja",
    "Meeting title" : "Naslov srečanja",
    "From" : "Od",
    "To" : "Za",
    "Calendar" : "Koledar",
    "Attendees" : "Udeleženci",
    "Add attendees" : "Dodaj udeležence",
    "Save" : "Shrani",
    "Search participants" : "Poišči udeležence",
    "No results" : "Ni zadetkov",
    "Done" : "Končano",
    "Exit full screen (F)" : "Končaj celozaslonski način (F)",
    "Full screen (F)" : "Celozaslonski način (F)",
    "Speaker view" : "Pogled govorca",
    "Grid view" : "Mrežni pogled",
    "Recording consent is required" : "Zahtevano je soglasje za snamenje",
    "This conversation is read-only" : "Ta pogovor je le za branje",
    "Connection failed" : "Povezava je spodletela",
    "Reload" : "Ponovno naloži",
    "{nickName} raised their hand." : "{nickName} dvigne roko.",
    "A participant raised their hand." : "Udeleženec dvigne roko.",
    "Collapse stripe" : "Skrči polja",
    "Expand stripe" : "Razširi polja",
    "Previous page of videos" : "Predhodna stran videoposnetkov",
    "Next page of videos" : "Naslednja stran videoposnetkov",
    "Connecting …" : "Poteka vzpostavljanje povezave ...",
    "Calling …" : "Poteka klicanje ...",
    "Waiting for {user} to join the call" : "Čakajoč na osebo {user}, da se pridruži klicu ...",
    "Waiting for others to join the call …" : "V pričakovanju odziva drugih udeleženev ...",
    "You can invite others in the participant tab of the sidebar" : "Sogovornike lahko dodate z uporabo iskalnika v zavihku Udeleženci bočnega okna",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Sogovornike lahko dodate prek iskalnika v zavihku Udeleženci bočnega okna, ali pa jim pošljete povezavo!",
    "Share this link to invite others!" : "Objavite to povezavo in povabite tudi druge!",
    "Copy link" : "Kopiraj povezavo",
    "You are not allowed to enable audio" : "Ni ustreznih dovoljenj za omogočanje zvoka",
    "No audio. Click to select device" : "Ni zvoka. Kliknite za izbor naprave.",
    "Mute audio" : "Utišaj zvok",
    "Mute audio (M)" : "Utišaj zvok (M)",
    "Unmute audio" : "Povrni zvok",
    "Unmute audio (M)" : "Povrni zvok (M)",
    "None" : "Brez",
    "Access to camera was denied" : "Dostop do kamere je bil zavrnjen.",
    "Error while accessing camera: It is likely in use by another program" : "Napaka dostopa do kamere: najverjetneje je v uporabi pri drugem programu.",
    "Error while accessing camera" : "Napaka med dostopom do kamere",
    "You have been muted by a moderator" : "Moderator vas je začasno utišal",
    "Hide presenter video" : "Skrij video predstavljalca",
    "You are not allowed to enable video" : "Ni ustreznih dovoljenj za omogočanje videa",
    "No video. Click to select device" : "Ni slike. Kliknite za izbor naprave.",
    "Disable video" : "Onemogoči video",
    "Disable video (V)" : "Onemogoči video (V)",
    "Enable video" : "Omogoči video",
    "Enable video (V)" : "Omogoči video (V)",
    "Enable video - Your connection will be briefly interrupted when enabling the video for the first time" : "Omogoči video – Med prvim omogočanjem bo povezava za trenutek prekinjena.",
    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "Omogoči video (v) – Med prvim omogočanjem bo povezava za trenutek prekinjena.",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Omogoči video. – Med prvim omogočanjem bo povezava za trenutek prekinjena.",
    "Show presenter" : "Pokaži govorca",
    "You" : "Jaz",
    "Mute" : "Utišaj",
    "Muted" : "Utišano",
    "Show screen" : "Pokaži zaslon",
    "Stop following" : "Prekini osrednji pogled",
    "Connection could not be established …" : "Povezave ni mogoče vzpostaviti ...",
    "Connection was lost and could not be re-established …" : "Povezava je izgubljena in je ni mogoče znova vzpostaviti ...",
    "Connection could not be established. Trying again …" : "Povezave ni bilo mogoče vzpostaviti. Poteka ponovno vzpostavljanje ...",
    "Connection lost. Trying to reconnect …" : "Povezava je bila prekinjena. Poteka poskus ponovne povezave ...",
    "Connection problems …" : "Zaznane so težave s povezavo ...",
    "Collapse" : "Skrči",
    "Expand" : "Razširi",
    "You need to be logged in to upload files" : "Za pošiljanje datotek morate biti prijavljeni v oblak",
    "Drop your files to upload" : "Spustite datoteke za pošiljanje v oblak",
    "Conversation messages" : "Sporočila pogovora",
    "Scroll to bottom" : "Podrsajte do dna",
    "Post message" : "Objavi sporočilo",
    "Federated conversation" : "Zvezni pogovor",
    "Public conversation" : "Javni pogovor",
    "Favorite" : "Priljubljeno",
    "Banned users" : "Zavrnjeni uporabniki",
    "Date:" : "Datum:",
    "Note:" : "Opomba:",
    "Hide details" : "Skrij podrobnosti",
    "Show details" : "Pokaži podrobnosti",
    "Error while updating conversation name" : "Prišlo je do napake med posodabljanjem imena pogovora",
    "Error while updating conversation description" : "Prišlo je do napake med posodabljanjem opisa pogovora",
    "Enter a name for this conversation" : "Naziv novega pogovora",
    "Edit conversation name" : "Uredi ime pogovora",
    "Edit conversation description" : "Uredi opis pogovora",
    "Enter a description for this conversation" : "Vpis opisa za ta pogovor",
    "Picture" : "Slika",
    "The following bots can be enabled in this conversation. Reach out to your administration to get more bots installed on this server." : "V pogovoru so na voljo navedeni boti. Za več možnosti stopite v stik s skrbnikom sistema.",
    "No bots are installed on this server. Reach out to your administration to get bots installed on this server." : "Na strežniku še ni nameščenih botov. Za uporabo te možnosti stopite v stik s skrbnikom sistema.",
    "Disable" : "Onemogoči",
    "Enable" : "Omogoči",
    "Breakout rooms" : "Ločene skupine",
    "Manage breakout rooms" : "Upravljaj ločene skupine",
    "Set up breakout rooms for this conversation" : "Nastavitev ločenih skupin za ta pogovor",
    "Please select a valid PNG or JPG file" : "Izbrati je treba veljavno datoteko png ali jpg.",
    "Choose your conversation picture" : "Izberi sliko pogovora",
    "Choose" : "Izbor",
    "Error setting conversation picture" : "Prišlo je do napake med nastavljanjem slike pogovora",
    "Could not set the conversation picture: {error}" : "Ni mogoče nastaviti slike pogovora: {error}",
    "Error cropping conversation picture" : "Prišlo je do napake med obrezovanjem slike pogovora",
    "Error removing conversation picture" : "Prišlo je do napake med odstranjevanjem slike pogovora",
    "Set emoji as conversation picture" : "Nastavi izrazno ikono kot sliko pogovora",
    "Set background color for conversation picture" : "Nastavi barvo ozadja za sliko pogovora",
    "Upload conversation picture" : "Pošlji sliko pogovora",
    "Choose conversation picture from files" : "Izberi sliko pogovore med datotekami",
    "Remove conversation picture" : "Odstrani sliko pogovora",
    "The file must be a PNG or JPG" : "Datoteka mora biti v zapisu PNG ali JPG",
    "Set picture" : "Nastavi sliko",
    "Default permissions modified for {conversationName}" : "Za pogovor {conversationName} so spremenjena privzeta dovoljenja.",
    "Could not modify default permissions for {conversationName}" : "Za pogovor {conversationName} ni mogoče spremeniti privzetih dovoljenj.",
    "Edit the default permissions for participants in this conversation. These settings do not affect moderators." : "Nastavitve določajo privzeta dovoljenja udeležencev tega pogovora. Te ne posegajo v dovoljenja moderatorjev.",
    "Every time permissions are modified in this section, custom permissions previously assigned to individual participants will be lost." : "Po vsaki spremembi dovoljenj v tem odseku se dovoljenja po meri, predhodno dodeljena posameznim udeležencem, samodejno odstranijo.",
    "All permissions" : "Vsa dovoljenja",
    "Participants have permissions to start a call, join a call, enable audio and video, and share screen." : "Udeleženci imajo dovoljenje začeti klic, se pridružiti klicu, omogočiti zvok in sliko ter omogočiti prikaz zaslona.",
    "Restricted" : "Omejeno",
    "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "Udeleženci se lahko pridružijo klicu, vendar ne morejo omogočiti zvoka, videa in prikaza zaslona, dokler jim moderator ročno ne dodeli teh dovoljenj.",
    "Advanced permissions" : "Napredna dovoljenja",
    "Edit permissions" : "Uredi dovoljenja",
    "Conversation settings" : "Nastavitve pogovora",
    "Basic Info" : "Osnovni podatki",
    "Personal" : "Osebno",
    "Moderation" : "Moderacija",
    "Setup overview" : "Pregled nastavitve",
    "Breakout Rooms" : "Ločene skupine",
    "Matterbridge" : "Matterbridge",
    "Bots" : "Boti",
    "Danger zone" : "Spremljanje pogovora",
    "Leave conversation" : "Zapusti pogovor",
    "You need to promote a new moderator before you can leave the conversation" : "Pred odhodom iz pogovora je treba nekoga določiti za moderatorja.",
    "Delete conversation" : "Razumem tveganje, izbriši pogovor",
    "Do you really want to delete \"{displayName}\"?" : "Ali res želite izbrisati »{displayName}«?",
    "Error while deleting conversation" : "Napaka med brisanjem pogovora",
    "Delete all chat messages" : "Izbriši vsa sporočila klepeta",
    "Do you really want to delete all messages in \"{displayName}\"?" : "Ali res želite izbrisati vsa sporočila v »{displayName}«?",
    "Error while clearing chat history" : "Prišlo je do napake med čiščenjem zgodovine klepeta",
    "Be careful, these actions cannot be undone." : "Nepremišljenega izbora možnosti spodaj ni mogoče povrniti. Priporočena je previdnost pri uporabi.",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Ko pogovor enkrat zapustite, se sami ne morete več pridružiti, za pogovor morate spet prejeti povabilo. To ne velja za odprte pogovore, ti so vedno dostopni.",
    "Permanently delete this conversation." : "Trajno izbriši ta pogovor.",
    "Delete chat messages" : "Izbriši sporočila klepeta",
    "Permanently delete all the messages in this conversation." : "Trajno izbriši vsa sporočila tega pogovora.",
    "Custom expiration time" : "Datum preteka po meri",
    "Message expiration disabled" : "Možnost preteka sporočila je onemogočena",
    "Message expiration set: {duration}" : "Možnost preteka sporočila je nastavljena: {duration}",
    "Error when trying to set message expiration" : "Napaka pri nastavljanju preteka sporočil",
    "Message expiration" : "Pretek sporočila",
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "Sporočila klepeta lahko po določenem času potečejo. Opomba: datoteke, ki so v skupni rabi v klepetu, se za lastnika ne izbrišejo, vendar se bodo več zbrane v pogovoru.",
    "Set message expiration" : "Nastavi pretek sporočila",
    "Current message expiration" : "Trenuten pretek sporočila",
    "Password copied to clipboard" : "Geslo je kopirano v odložišče!",
    "Password could not be copied" : "Gesla ni mogoče kopirati.",
    "Guest access" : "Dostop gostov",
    "Allow guests to join this conversation via link" : "Dovoli gostom povezovanje v pogovor prek povezave",
    "Password protection" : "Zaščiti z geslom",
    "Set a password" : "Nastavi geslo",
    "Change password" : "Spremeni geslo",
    "Enter new password" : "Vpis novega gesla",
    "Save password" : "Shrani geslo",
    "Copy password" : "Kopiraj geslo",
    "Resend invitations" : "Ponovno pošlji vabila",
    "This conversation is limited to the current participants" : "Pogovor je omejen na trenutne udeležence",
    "Error occurred when opening or limiting the conversation" : "Prišlo je do napake med odpiranjem oziroma omejevanjem dostopa do pogovora",
    "Open conversation to registered users, showing it in search results" : "Odpri pogovor za vpisane uporabnike in prikaži pogovor med zadetki iskanja.",
    "Open conversation" : "Odpri pogovor",
    "Start time: {date}" : "Začetek: {date}",
    "Start time has been updated" : "Čas začetka je posodobljen",
    "Error occurred while updating start time" : "Prišlo je do napake med posodabljanjem časa začetka.",
    "Enabling the lobby will remove non-moderators from the ongoing call." : "Omogočanje čakalnice odstrani udeležence iz trenutnega pogovora. Vloga moderatorja se ne spremeni.",
    "Enable lobby, restricting the conversation to moderators" : "Omogoči čakalnico in omeji pogovor na moderatorje",
    "Meeting start time" : "Čas začetka sestanka",
    "Start time (optional)" : "Čas začetka (izbirno)",
    "Error occurred when locking the conversation" : "Prišlo je do napake med zaklepanjem pogovora.",
    "Error occurred when unlocking the conversation" : "Prišlo je do napake med odklepanjem pogovora.",
    "Lock conversation" : "Zakleni pogovor",
    "This will also terminate the ongoing call." : "S tem dejanjem bo končan tudi trenutni klic.",
    "Lock the conversation to prevent anyone to post messages or start calls" : "Zakleni pogovor in prepreči vsakršno objavljanje sporočil in začenjanje klicev.",
    "Edit" : "Uredi",
    "More information" : "Več podrobnosti",
    "Delete" : "Izbriši",
    "Add new bridged channel to current conversation" : "Dodaj nov premostitveni kanal za trenutni pogovor",
    "unknown state" : "neznano stanje",
    "running" : "zagnano",
    "not running, check Matterbridge log" : "ni zagnano; preverite dnevniški zapis Matterbridge",
    "not running" : "nedejavno",
    "Bridge saved" : "Premostitveni kanal je shranjen",
    "You can bridge channels from various instant messaging systems with Matterbridge." : "Z Matterbridge je mogoče premostiti kanale različnih sistemov hipnega sporočanja.",
    "More info on Matterbridge" : "Več podrobnosti o Matterbridge",
    "Enable bridge" : "Omogoči premoščanje",
    "Show Matterbridge log" : "Pokaži dnevnik Matterbridge",
    "Log content" : "Vsebina dnevnika",
    "Notifications" : "Obvestila",
    "Notify about calls in this conversation" : "Obvesti o klicih v pogovoru",
    "Important conversation" : "Pomemben pogovor",
    "SIP dial-in is now possible without PIN requirement" : "Klicanje preko SIP je mogoče brez zahteve vpisa kode PIN",
    "SIP dial-in is now enabled" : "Povezovanje prek klicne seje SIP je omogočeno",
    "SIP dial-in is now disabled" : "Povezovanje prek klicne seje SIP je onemogočeno",
    "Error occurred when enabling SIP dial-in" : "Prišlo je do napake med omogočanjem povezave prek klicne seje SIP",
    "Error occurred when disabling SIP dial-in" : "Prišlo je do napake med onemogočanjem povezave prek klicne seje SIP",
    "Phone and SIP dial-in" : "Telefonske in klicne povezave SIP",
    "Enable phone and SIP dial-in" : "Omogoči telefonske in klicne povezave SIP",
    "Allow to dial-in without a PIN" : "Dovoli klicanje brez kode PIN",
    "{dayPrefix} {dateTime}" : "{dayPrefix} {dateTime}",
    "Join" : "Pridruži se",
    "Error while creating the conversation" : "Prišlo je do napake med ustvarjanjem pogovora",
    "Create a new conversation" : "Ustvari nov pogovor",
    "Join open conversations" : "Pridruži se odprtemu pogovoru",
    "Call a phone number" : "Pokliči telefonsko številko",
    "Unread mentions" : "Neprebrane omembe",
    "Create conversation" : "Ustvari pogovor",
    "Enter your name" : "Vpišite ime",
    "Submit name and join" : "Pošlji ime in se pridruži",
    "Log in" : "Prijava",
    "Import a file" : "Uvozi datoteko",
    "Browse" : "Prebrskaj",
    "Verifying uploaded file …" : "Overi poslano datoteko ...",
    "This might take a moment" : "Opravilo lahko traja.",
    "Send invitations" : "Pošlji vabila",
    "Creating the conversation …" : "Poteka ustvarjanje pogovora ...",
    "Mark as read" : "Označi kot prebrano",
    "Mark as unread" : "Označi kot neprebrano",
    "Remove from favorites" : "Odstrani iz priljubljenih",
    "Add to favorites" : "Dodaj med priljubljene",
    "You need to promote a new moderator before you can leave the conversation." : "Pred odhodom iz pogovora je treba nekoga določiti za moderatorja.",
    "New tag" : "Nova oznaka",
    "Tag name" : "Ime oznake",
    "Conversation actions" : "Dejanja pogovora",
    "Tags" : "Oznake",
    "Hide message text" : "Skrij besedilo sporočila",
    "Rename tag" : "Preimenuj oznako",
    "Delete tag" : "Izbriši oznako",
    "Move up" : "Premakni navzgor",
    "Move down" : "Premakni navzdol",
    "Pending invitations" : "Čakajoča vabila",
    "Decline invitation" : "Zavrni povabilo",
    "Accept invitation" : "Sprejmi povabilo",
    "Home" : "Začetna stran",
    "Unread" : "Neprebrano",
    "Mentions" : "Omembe",
    "Meetings" : "Srečanja",
    "Alphabetically" : "Abecedno",
    "No matches found" : "Ni najdenih zadetkov",
    "No conversations found" : "Pogovora ni mogoče najti",
    "You have no unread mentions." : "Ni neodgovorjenih omemb.",
    "You have no unread messages." : "Ni neodgovorjenih spodočil.",
    "An error occurred while performing the search" : "Me iskanjem je prišlo do napake",
    "Conversation list" : "Seznam pogovorov",
    "Unread messages" : "Neprebrana sporočila",
    "Clear filters" : "Počisti filtre",
    "New personal note" : "Novo osebno sporočilo",
    "Clear filter" : "Počisti filter",
    "App settings" : "Nastavitve programa",
    "Users" : "Uporabniki",
    "Groups" : "Skupine",
    "Teams" : "Ekipe",
    "Federated users" : "Zvezni uporabniki",
    "New private conversation" : "Nov zasebni pogovor",
    "Other sources" : "Drugi viri",
    "Open conversations" : "Odprti pogovori",
    "No search results" : "Ni zadetkov iskanja",
    "Users, groups and teams" : "Uporabniki, skupine in ekipe",
    "Users and groups" : "Uporabniki in skupine",
    "Users and teams" : "Uporabniki in ekipe",
    "Groups and teams" : "Skupine in ekipe",
    "The meeting will start soon" : "Srečanje se bo kmalu začelo",
    "This meeting is scheduled for {startTime}" : "Začetek srečanja je načrtovan ob {startTime}",
    "You are currently waiting in the lobby" : "Trenutno čakate v spletni čakalnici.",
    "Advanced" : "Napredno",
    "Select microphone" : "Izbor mikrofona",
    "No microphone available" : "Ni razpoložljivega mikrofona",
    "Select camera" : "Izbor kamere",
    "No camera available" : "Ni razpoložljive kamere",
    "Select a device" : "Izbor naprave",
    "Playing …" : "Predvajanje ...",
    "Test speakers" : "Preizkusi zvočnike",
    "Test" : "Preizkus",
    "Devices" : "Naprave",
    "Backgrounds" : "Ozadja",
    "No audio" : "Brez zvoka",
    "No camera" : "Ni zaznane kamere",
    "Calls are not supported in your browser" : "Klici v tem brskalniku niso podprti",
    "Access to microphone is only possible with HTTPS" : "Dostop do mikrofona je mogoče le prek protokola HTTPS",
    "Access to microphone was denied" : "Dostop do mikrofona je bil zavrnjen.",
    "Error while accessing microphone" : "Napaka med dostopom do mikrofona",
    "Access to camera is only possible with HTTPS" : "Dostop do kamere je mogoče le prek protokola HTTPS",
    "The call is being recorded." : "Klic se snema.",
    "The call might be recorded." : "Klic se morda snema.",
    "Apply settings" : "Uveljavi nastavitve",
    "Select virtual office background" : "Izbor slike pisarne za ozadje",
    "Select virtual home background" : "Izbor domačega okolja za sliko ozadja",
    "Select virtual abstract background" : "Izbor abstraktne slike za ozadje",
    "Select virtual beach background" : "Izbor slike plaže za ozadje",
    "Select virtual park background" : "Izbor slike parka za ozadje",
    "Select virtual theater background" : "Izbor slike gledališče za ozadje",
    "Select virtual library background" : "Izbor slike knjižnice za ozadje",
    "Select virtual space station background" : "Izbor slike vesoljske postaje za ozadje",
    "Error while uploading the file" : "Prišlo je do napake med pošiljanjem slike",
    "Select a file" : "Izbor datoteke",
    "Invalid path selected" : "Izbrana je neveljavna pot",
    "Select virtual background from file {fileName}" : "Izbor slike ozadje iz datoteke {fileName}",
    "Blur" : "Zameglitev",
    "Upload" : "Pošlji",
    "Files" : "Datoteke",
    "(editing)" : "(urejanje)",
    "(edited)" : "(spremenjeno)",
    "The message has expired or has been deleted" : "Sporočilo je poteklo ali pa je bilo izbrisano",
    "Cancel quote" : "Prekliči navedek",
    "24 hours" : "24 ur",
    "7 days" : "7 dni",
    "Clear reminder – {timeLocale}" : "Počisti opomnik – {timeLocale}",
    "Message text copied to clipboard" : "Besedilo sporočila je kopirano v odložišče",
    "Message text could not be copied" : "Besedila sporočila ni mogoče kopirati",
    "A reminder was successfully removed" : "Opomnik je uspešno odstranjen",
    "Error occurred when removing a reminder" : "Prišlo je do napake med odstranjevanjem opomnika",
    "Error occurred when creating a reminder" : "Prišlo je do napake med ustvarjanjem opomnika",
    "Add a reaction to this message" : "Dodaj odziv na to sporočilo",
    "Reply" : "Odgovori",
    "More actions" : "Več dejanj",
    "Set reminder" : "Nastavi opomnik",
    "Reply privately" : "Odgovori zasebno",
    "Edit message" : "Uredi sporočilo",
    "Copy message" : "Kopiraj sporočilo",
    "Copy message link" : "Kopiraj povezavo sporočila",
    "Go to file" : "Odpri mesto datoteke",
    "Download file" : "Prejmi datoteko",
    "Forward message" : "Posreduj sporočilo",
    "Translate" : "Prevodi",
    "Set custom reminder" : "Nastavi opomnik po meri",
    "Close reactions menu" : "Zapri meni odzivov",
    "React with {emoji}" : "Odzovi se z {emoji}",
    "React with another emoji" : "Odzovi se z novo izrazno ikono",
    "Choose a conversation to forward the selected message." : "Izbor pogovora za posredovanje izbranega sporočila.",
    "Error while forwarding message" : "Prišlo je do napake med posredovanjem sporočil.",
    "The message has been forwarded to {selectedConversationName}" : "Sporočilo je posredovano v pogovor {selectedConversationName}",
    "Dismiss" : "Opusti",
    "Go to conversation" : "Pojdi na pogovor",
    "Detect language" : "Zaznava jezika",
    "The message could not be translated" : "Sporočila ni mogoče prevesti",
    "Translation copied to clipboard" : "Prevod je kopiran v odložišče",
    "Translation could not be copied" : "Prevoda ni mogoče kopirati!",
    "Translate message" : "Prevedi sporočilo",
    "Source language to translate from" : "Izvorni jezik za prevod",
    "Translate from" : "Prevedi iz",
    "Target language to translate into" : "Ciljni jezik za prevod",
    "Translate to" : "Prevedi v",
    "Translating" : "Poteka prevajanje",
    "Copy translated text" : "Kopiraj prevedeno besedilo",
    "Send now" : "Pošlji takoj",
    "Message read by everyone who shares their reading status" : "Sporočilo lahko prebere vsak, ki objavlja nastavitev stanja branja",
    "Message sent" : "Sporočilo je poslano",
    "Deleting message" : "Brisanje sporočila",
    "Message deleted successfully" : "Sporočilo je uspešno izbrisano",
    "Message could not be deleted because it is too old" : "Sporočila ni mogoče izbrisati, ker je prestaro",
    "Only normal chat messages can be deleted" : "Izbrisati je mogoče le običajna sporočila v klepetu",
    "An error occurred while deleting the message" : "Prišlo je do napake med brisanjem sporočila",
    "Your browser does not support playing audio files" : "Določen spletni brskalnik ne podpira možnosti predvajanja zvoka.",
    "Contact" : "Stik",
    "{stack} in {board}" : "{stack} v {board}",
    "Deck Card" : "Naloga Deck",
    "Remove {fileName}" : "Odstrani datoteko {fileName}",
    "Open this location in OpenStreetMap" : "Odpri to mesto v programu Openstreetmap",
    "Sending message" : "Poteka pošiljanje sporočila",
    "Failed to send the message. Click to try again" : "Pošiljanje sporočila je spodletelo. Poskusite znova.",
    "Not enough free space to upload file" : "Ni dovolj prostora za pošiljanje datoteke",
    "You cannot send messages to this conversation at the moment" : "Trenutno v ta pogovor ni mogoče pošiljati sporočil.",
    "Could not update the message" : "Sporočila ni mogoče posodobiti",
    "Open poll" : "Odprta anketa",
    "See results" : "Pokaži rezultate",
    "Reactions" : "Odzivi",
    "No permission to post reactions in this conversation" : "Ni ustreznih dovoljenj za objavo odzivov v pogovoru",
    "Show all reactions" : "Pokaži vse odzive",
    "Add more reactions" : "Dodaj več odzivov",
    "Show or collapse system messages" : "Pokaže ali skrije sistemska sporočila",
    "No messages" : "Ni sporočil",
    "All messages have expired or have been deleted." : "Vsa sporočila so potekla ali pa so bila izbrisana",
    "Unpin" : "Odpni",
    "Cancel search" : "Prekliči iskanje",
    "Add a phone number" : "Dodaj telefonsko številko",
    "Create a new group conversation" : "Ustvari nov skupinski pogovor",
    "Add participants" : "Dodaj udeležence",
    "Conversation visibility" : "Vidnost pogovora",
    "Allow guests to join via link" : "Dovoli gostom povezovanje prek povezave",
    "Enter password" : "Vpis gesla",
    "This conversation has been locked" : "Ta pogovor je zaklenjen",
    "No permission to post messages in this conversation" : "Za objavo sporočil v ta pogovor so zahtevana posebna dovoljenja.",
    "Joining conversation …" : "Poteka povezovanje v pogovor ...",
    "Send message silently" : "Sporočila pošlji tiho",
    "Send message" : "Pošlji sporočilo",
    "Send without notification" : "Pošlji brez obvestila",
    "The participant will not be notified about new messages" : "Udeleženec ne bo obveščen o tem sporočilu",
    "File to share" : "Datoteka za souporabo",
    "File upload is not available in this conversation" : "V tem pogovoru pošiljanje datotek ni mogoče",
    "Add emoji" : "Vstavi izrazno ikono",
    "Send later" : "Pošlji kasneje",
    "Cancel editing" : "Prekliči urejanje",
    "{user} is out of office and might not respond." : "{user} ni na voljo in morda ne bo odziva.",
    "Share from {nextcloud}" : "Pošlji iz {nextcloud}",
    "Share from Files" : "Poveži iz oblaka",
    "Share files to the conversation" : "Poveži datoteke s pogovorom",
    "Upload from device" : "Pošlji z naprave",
    "Create new poll" : "Ustvari novo anketo",
    "Smart picker" : "Pametni izbirnik",
    "Record voice message" : "Posnemi glasovno sporočilo",
    "End recording and send" : "Končaj snemanje in pošlji",
    "Dismiss recording" : "Opusti posnetek",
    "Access to the microphone was denied" : "Dostop do mikrofona je bil zavrnjen.",
    "Microphone either not available or disabled in settings" : "Mikrofon ni na voljo ali pa je onemogočen med nastavitvami",
    "Error while recording audio" : "Prišlo je do napake med snemanjem zvoka",
    "New file" : "Nova datoteka",
    "Blank" : "Prazno",
    "Error while creating file" : "Prišlo je do napake med ustvarjanjem datoteke",
    "Create and share a new file" : "Ustvari in omogoči souporabo nove datoteke",
    "Name of the new file" : "Ime nove datoteke",
    "Create file" : "Ustvari datoteko",
    "Someone is typing …" : "Nekdo vnaša besedilo ...",
    "{user1} is typing …" : "{user1} vnaša besedilo ...",
    "{user1} and {user2} are typing …" : "{user1} in {user2} vnašata besedilo …",
    "{user1}, {user2} and {user3} are typing …" : "{user1}, {user2} in {user3} vnašajo besedilo …",
    "_{user1}, {user2}, {user3} and %n other are typing …_::_{user1}, {user2}, {user3} and %n others are typing …_" : ["{user1}, {user2}, {user3} in %n drug uporabnik vnašajo besedilo …","{user1}, {user2}, {user3} in %n druga uporabnika vnašajo besedilo …","{user1}, {user2}, {user3} in %n drugih uporabniki vnašajo besedilo …","{user1}, {user2}, {user3} in %n drugih uporabnikov vnaša besedilo …"],
    "Add more files" : "Dodaj več datotek",
    "Send" : "Pošlji",
    "In this conversation <strong>{user}</strong> can:" : "V tem pogovoru lahko <strong>{user}</strong>:",
    "Edit default permissions for participants in <strong>{conversationName}</strong>" : "Napredna dovoljenja za udeležence v pogovoru <strong>{conversationName}</strong>",
    "Start a call" : "Začenjanje klicev",
    "Skip the lobby" : "Preskakovanje čakalnice",
    "Can post messages and reactions" : "Pošiljanje sporočil in odzivov",
    "Enable the microphone" : "Omogočanje mikrofona",
    "Enable the camera" : "Omogočanje kamere",
    "Share the screen" : "Omogočanje prikaza zaslona",
    "Update permissions" : "Posodobi dovoljenja",
    "Updating permissions" : "Poteka posodabljanje dovoljenj",
    "Create poll" : "Ustvari anketo",
    "Question" : "Vprašanje",
    "Ask a question" : "Zastavite vprašanje",
    "Answers" : "Dogovori",
    "Answer {option}" : "Odgovor {option}",
    "Delete poll option" : "Izbriši možnost ankete",
    "Add answer" : "Dodaj odgovor",
    "Settings" : "Nastavitve",
    "Anonymous poll" : "Anonimna anketa",
    "Multiple answers" : "Več odgovorov",
    "You voted for this option" : "Glasovali ste za to možnost",
    "End poll" : "Končaj anketo",
    "Change your vote" : "Spremenite glasovanje",
    "Results" : "Zadetki",
    "Voted participants" : "Dejavni udeleženci",
    "Send a message to \"{roomName}\"" : "Pošlji sporočilo v skupino »{roomName}«",
    "Hide list of participants" : "Skrij seznam udeležencev",
    "Show list of participants" : "Pokaži seznam udeležencev",
    "Assistance requested in {roomName}" : "Poslana je zahteva za pomoč v ločeni skupini {roomName}",
    "The message was sent to \"{roomName}\"" : "Sporočilo je poslano v skupino »{roomName}«",
    "Dismiss request for assistance" : "Opusti zahtevo za pomoč",
    "Send message to room" : "Pošlji sporočilo v ločene skupine",
    "Back to main room" : "Nazaj na skupno mesto",
    "Back to your room" : "Nazaj v dodeljeno ločeno skupino",
    "Message all rooms" : "Sporočilo za vse ločene skupine",
    "Start session" : "Začni sejo",
    "Start a call before you start a breakout room session" : "Pred odpiranjem ločenih skupin je treba začeti klic",
    "Stop session" : "Zaustavi sejo",
    "The message was sent to all breakout rooms" : "Sporočilo je bilo poslano v vse ločene skupine",
    "Send a message to all breakout rooms" : "Pošlji sporočilo v vse ločene skupine",
    "Breakout rooms are not started" : "Ločene seje niso zagnane",
    "Disable lobby" : "Onemogoči čakalnico",
    "Settings for participant \"{user}\"" : "Nastavitve za udeleženca »{user}«",
    "Participant \"{user}\"" : "Uporabnik »{user}«",
    "moderator" : "moderator",
    "bot" : "bot",
    "guest" : "gost",
    "Ringing …" : "Zvoni na drugi strani ...",
    "Call rejected" : "Klic je zavrnjen",
    "{time} talking …" : "{time} pogovora …",
    "{time} talking time" : "{time} pogovora",
    "Raised their hand" : "Dvigne roko",
    "Joined with video" : "Povezano z videom",
    "Joined via phone" : "Povezano pred telefona",
    "Joined with audio" : "Povezano z zvokom",
    "The text must be less than or equal to {maxLength} characters long. Your current text is {charactersCount} characters long." : "Opis lahko sestavlja največ {maxLength} znakov. Trenutno sporočilo jih ima {charactersCount}.",
    "Remove group and members" : "Odstrani skupino in člane",
    "Remove team and members" : "odstrani ekipo in člane",
    "Remove participant" : "Odstrani udeleženca",
    "Permissions set to default for {displayName}" : "Dovoljenja za {displayName} so nastavljena na privzete vrednosti.",
    "Phone number could not be muted" : "Telefonske številke ni mogoče utišati",
    "Phone number could not be unmuted" : "Telefonski številki ni mogoče povrniti glasu",
    "DTMF message could not be sent" : "Sporočila DTMF ni mogoče poslati.",
    "Phone number copied to clipboard" : "Telefonska številka je kopirana v odložišče",
    "Phone number could not be copied" : "Telefonske številke ni mogoče kopirati",
    "in the lobby" : "v čakalnici",
    "Dial out phone" : "Pokliči telefon",
    "Hang up phone" : "Prekini telefon",
    "Move back to lobby" : "Premakni nazaj v čakalnico",
    "Move to conversation" : "Premakni v pogovor",
    "Dial-in PIN" : "Koda PIN klica",
    "Demote from moderator" : "Odstrani vlogo moderatorja",
    "Promote to moderator" : "Dodeli vlogo moderatorja",
    "Resend invitation" : "Ponovno pošlji vabilo",
    "Send call notification" : "Pošlji obvestilo klica",
    "Dial out phone number" : "Pokliči telefonsko številko",
    "Resume call for phone number" : "Obnovi klic telefonske številke",
    "Put phone number on hold" : "Zadrži klic telefonske številke",
    "Unmute phone number" : "Povrni zvok telefonske številke",
    "Mute phone number" : "Utišaj telefonsko številko",
    "Copy phone number" : "Kopiraj telefonsko številko",
    "Reset custom permissions" : "Ponastavi dovoljenja po meri",
    "Grant all permissions" : "Odobri vsa dovoljenja",
    "Remove all permissions" : "Odstrani vsa dovoljenja",
    "Remove" : "Odstrani",
    "Add users, groups or teams" : "Dodaj uporabnike, skupine in ekipe",
    "Add users or groups" : "Dodaj uporabnike ali skupine",
    "Add users or teams" : "Dodaj uporabnike ali ekipe",
    "Add users" : "Dodaj uporabnike",
    "Add groups or teams" : "Dodaj skupine ali ekipe",
    "Add groups" : "Dodaj skupine",
    "Add teams" : "Dodaj ekipe",
    "Add other sources" : "Dodaj druge vire",
    "Add emails" : "Dodaj elektronske naslove",
    "Integrations" : "Združevalniki",
    "Add federated users" : "Dodaj zvezne uporabnike",
    "Searching …" : "Poteka iskanje ...",
    "Search for more users" : "Poišči več uporabnikov",
    "Search or add participants" : "Iskanje in dodajanje udeležencev",
    "An error occurred while adding the participants" : "Prišlo je do napake med dodajanjem udeležencev",
    "Participants" : "Udeleženci",
    "Participants ({count})" : "Udeleženci ({count})",
    "Open chat" : "Odpri klepet",
    "You have new unread messages in the chat." : "V pogovoru imate neprebrana sporočila.",
    "You have been mentioned in the chat." : "Omenjeni ste bili v klepetu.",
    "Chat" : "Pogovor",
    "Details" : "Podrobnosti",
    "Shared items" : "Predmeti v souporabi",
    "Search options" : "Možnosti iskanja",
    "Until" : "Do",
    "No results found" : "Ni najdenih zadetkov",
    "Load more results" : "Naloži več zadetkov",
    "Projects" : "Projekti",
    "No shared items" : "Ni predmetov v souporabi",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "Link to a conversation" : "Povezava do pogovora",
    "No open conversations found" : "Ni mogoče najti nobenega odprtega pogovora",
    "Either there are no open conversations or you joined all of them." : "Ali ni odprtih pogovorov ali pa ste se pridružili vsem.",
    "Check spelling or use complete words." : "Preveri črkovanje oziroma uporabi celotne besede.",
    "Search conversations or users" : "Poišči med stiki in pogovori",
    "Select conversation" : "pogovora",
    "Number length is not valid" : "Dolžina telefonske številke ni veljavna",
    "Region code is not valid" : "Koda regije ni veljavna",
    "Number length is too short" : "Dolžina telefonske številke je prekratka",
    "Number length is too long" : "Dolžina telefonske številke je predolga",
    "Number is not valid" : "Številka ni veljavna",
    "Phone numbers" : "Telefonske številke",
    "Display name: {name}" : "Prikazano ime: {name}",
    "Edit display name" : "Uredi prikazno ime",
    "Save name" : "Shrani ime",
    "Error while saving sounds setting" : "Prišlo je do napake med shranjevanjem nastavitev zvoka",
    "Play sounds when participants join or leave a call" : "Predvajaj zvok ob priklopu oziroma odklopu uporabnika.",
    "Notification settings" : "Nastavitve obveščanja",
    "Default language" : "Privzeti jezik",
    "Select location for attachments" : "Izbor mesta prilog",
    "Error while setting attachment folder" : "Napaka med nastavljanjem mape prilog",
    "Error while setting read status privacy" : "Napaka med nastavljanjem stanja zasebnosti",
    "Error while setting typing status privacy" : "Napaka med nastavljanjem zasebnosti stanja pisanja",
    "Privacy" : "Zasebnost",
    "Attachments folder" : "Mapa prilog",
    "Toggle full screen" : "Preklopi celozaslonski način",
    "Search" : "Odpre iskalno polje.",
    "Focus the chat input" : "V žarišče postavi vnosno polje klepeta",
    "Unfocus the chat input to use shortcuts" : "Zaustavi vnos besedila za uporabo tipkovnih bližnjic.",
    "Shortcuts while in a call" : "Omogoči tipkovne bližnjice tudi v času klica.",
    "Camera on and off" : "Preklop in izklop kamere",
    "Microphone on and off" : "Preklopi delovanje mikrofona",
    "Raise or lower hand" : "Dvigne ali Spusti digitalno roko",
    "Push to talk or push to mute" : "Pritisk tipke omogoči govor, ponoven pritisk utišanje.",
    "Start call silently" : "Začni klic tiho",
    "Start call" : "Začni klic",
    "End call" : "Končaj klic",
    "You will be able to join the call only after a moderator starts it." : "Pogovoru se je mogoče pridružiti šele, ko ga moderator začne.",
    "End call for everyone" : "Končaj klic za vse",
    "Starting the recording" : "Poteka začenjanje snemanja",
    "Recording" : "Snemanje",
    "The call has been running for one hour." : "Pogovor traja že eno uro.",
    "Cancel recording start" : "Prekliči začenjanje snemanja",
    "Stop recording" : "Ustavi snemanje",
    "Raise hand" : "Dvigni roko",
    "Raise hand (R)" : "Dvigni roko (R)",
    "Lower hand" : "Spusti roko",
    "Lower hand (R)" : "Spusti roko (R)",
    "Send a reaction" : "Pošlji odziv",
    "React with {reaction}" : "Odzovi se z {reaction}",
    "_%n participant in call_::_%n participants in call_" : ["Sodeluje %n udeleženec","Sodelujeta %n udeleženca","Sodelujejo %n udeleženci","Sodeluje %n udeležencev"],
    "You are not allowed to enable screensharing" : "Ni ustreznih dovoljenj za omogočanje prikaza zaslonske slike",
    "No screensharing" : "Prikaz zaslona ni na voljo",
    "Screensharing options" : "Možnosti prikazovanja zaslona",
    "Enable screensharing" : "Omogoči souporabo zaslona",
    "Bad sent video and screen quality." : "Poslana je slaba kakovost videa in slike zaslona. ",
    "Bad sent screen quality." : "Poslana je slaba kakovost slike zaslona.",
    "Bad sent video quality." : "Poslana je slaba kakovost videa.",
    "Bad sent audio, video and screen quality." : "Poslana je slaba kakovost videa, zvoka in slike zaslona.",
    "Bad sent audio and screen quality." : "Poslana je slaba kakovost zvoka in slike zaslona.",
    "Bad sent audio and video quality." : "Poslana je slaba kakovost videa in zvoka.",
    "Bad sent audio quality." : "Poslana je slaba kakovost zvoka.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "Spletna povezava oziroma delovanje računalnika je preobremenjeno, zato udeleženci morda ne bodo videli zaslona. Za izboljšanje delovanja poskusite med prikazovanjem zaslona izklopiti zabrisano ozadje ali prikaz videa.",
    "Disable background blur" : "Onemogoči motno ozadje",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "Spletna povezava oziroma delovanje računalnika je preobremenjeno, zato udeleženci morda ne bodo zaslona. Za izboljšanje delovanja poskusite med prikazovanjem zaslona izklopiti prikaz videa.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Spletna povezava oziroma delovanje računalnika je preobremenjeno, zato vas drugi udeleženci morda ne bodo videli zaslonske slike.",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "Spletna povezava oziroma delovanje računalnika je preobremenjeno, zato vas drugi udeleženci morda ne bodo videli.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video while doing a screenshare." : "Spletna povezava oziroma delovanje računalnika je preobremenjeno, zato vas udeleženci morda ne bodo ne videli ne slišali. Za izboljšanje delovanja poskusite med prikazovanjem zaslona izklopiti zabrisano ozadje ali prikaz videa.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Spletna povezava oziroma delovanje računalnika je preobremenjeno, zato vas drugi udeleženci morda ne bodo razumeli in videli. Za izboljšanje prikaza poskusite med prikazom zaslona video onemogočiti.",
    "Your internet connection or computer are busy and other participants might be unable to understand you and see your screen. To improve the situation try to disable your screenshare." : "Spletna povezava oziroma delovanje računalnika je preobremenjeno, zato drugi udeleženci morda ne bodo ne videli ne slišali. Za izboljšanje delovanja poskusite onemogočiti prikazovanje zaslona.",
    "Disable screenshare" : "Onemogoči souporabo zaslona",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video." : "Spletna povezava oziroma delovanje računalnika je preobremenjeno, zato vas udeleženci morda ne bodo ne videli ne slišali. Za izboljšanje delovanja poskusite med prikazovanjem zaslona izklopiti zabrisano ozadje ali prikaz videa.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Spletna povezava oziroma delovanje računalnika je preobremenjeno, zato vas drugi udeleženci morda ne bodo razumeli in videli. Za izboljšanje prikaza poskusite onemogočiti video.",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "Spletna povezava oziroma delovanje računalnika je preobremenjeno, zato vas drugi udeleženci morda ne bodo razumeli.",
    "Screen sharing is not supported by your browser." : "Uporabljen spletni brskalnik ne podpira prikazovanja zaslona",
    "Screen sharing requires the page to be loaded through HTTPS." : "Prikaz zaslona zahteva povezavo strani prek protokola HTTPS.",
    "Screensharing requires the page to be loaded through HTTPS." : "Prikaz zaslona zahteva povezavo strani prek protokola HTTPS.",
    "An error occurred while starting screensharing." : "Prišlo je do napake med omogočanjem souporabe zaslona.",
    "Show your screen" : "Pokaži zaslon",
    "Stop screensharing" : "Prekini prikaz zaslona",
    "Mute others" : "Utišaj ostale",
    "Start recording" : "Začni s snemanjem",
    "Set up breakout rooms" : "Začni ločene sobe",
    "Remove participant {name}" : "Odstrani udeleženca {name}",
    "Delete now" : "Izbriši",
    "Keep" : "Ohrani",
    "Open dialpad" : "Pokaži številčnico",
    "Select a region" : "Izbor regije",
    "Local time: {time}" : "Krajevni čas: {time}",
    "Search …" : "Poišči …",
    "Message without mention" : "Sporočilo brez omenjanja",
    "Mention myself" : "Omenjanje sebe",
    "Mention everyone" : "Omeni vse",
    "Select a conversation" : "Izbor pogovora",
    "Select a mode" : "Izbor načina",
    "The conversation does not exist" : "Pogovor ne obstaja",
    "Join a conversation or start a new one!" : "Pridružite se pogovoru ali pa začnite novega!",
    "Join a conversation or start a new one" : "Pridružite se pogovoru, ali pa začnite novega.",
    "Error while joining the conversation" : "Prišlo je do napake med pridruževanjem k pogovoru",
    "Nextcloud URL" : "Naslov URL Nextcloud",
    "Nextcloud user" : "Uporabnik Nextcloud",
    "User password" : "Uporabniško geslo",
    "Talk conversation" : "Pogovor Talk",
    "Skip TLS verification" : "Preskoči overjanje TLS",
    "Matrix server URL" : "Naslov URL strežnika Matrix",
    "User" : "Uporabnik",
    "Matrix channel" : "Kanal Matrix",
    "Mattermost server URL" : "Naslov URL strežnika Mattermost",
    "Mattermost user" : "Uporabnik Mattermost",
    "Team name" : "Ime skupine",
    "Channel name" : "Ime kanala",
    "Rocket.Chat server URL" : "Naslov URL strežnika Rocket.Chat",
    "User name or email address" : "Uporabniško ime ali elektronski naslov",
    "Rocket.Chat channel" : "Kanal Rocket.Chat",
    "Zulip server URL" : "Naslov URL strežnika Zulip",
    "Bot user name" : "Ime uporabniškega bota",
    "Bot API key" : "Ključ vmesnika API bota",
    "Zulip channel" : "Kanal Zulip",
    "API token" : "Žeton vmesnika API",
    "Slack channel" : "Kanal Slack",
    "Server ID or name" : "Določilo ID strežnika ali ime",
    "Channel" : "Kanal",
    "Login" : "Prijava",
    "Chat ID" : "Določilo ID klepeta",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "Naslov URL strežnika IRC (npr. chat.freenode.net:6667)",
    "Nickname" : "Vzdevek",
    "Connection password" : "Geslo povezave",
    "IRC channel" : "Kanal IRC",
    "Channel password" : "Geslo kanala",
    "NickServ nickname" : "Vzdevek NickServ",
    "NickServ password" : "Geslo NickServ",
    "Use TLS" : "Uporabi TLS",
    "Use SASL" : "Uporabi SASL",
    "Tenant ID" : "ID Udeleženca",
    "Client ID" : "ID odjemalca",
    "Team ID" : "ID Skupine",
    "Thread ID" : "ID Niti",
    "XMPP/Jabber server URL" : "Naslov URL strežnika XMPP/Jabber",
    "MUC server URL" : "Naslov URL strežnika MUC",
    "Jabber ID" : "Jabber ID",
    "Media" : "Predstavna vsebina",
    "Polls" : "Ankete",
    "Deck cards" : "Zbirke nalog",
    "Voice messages" : "Glasovna sporočila",
    "Locations" : "Mesta",
    "Call recordings" : "Posnetki klicev",
    "Audio" : "Zvok",
    "Show all media" : "Pokaži vso predstavno vsebino",
    "Show all files" : "Pokaži vse datoteke",
    "Show all polls" : "Pokaži vse ankete",
    "Show all deck cards" : "Pokaži vse zbirke nalog",
    "Show all voice messages" : "Pokaži vsa glasovna sporočila",
    "Show all locations" : "Pokaži vsa mesta",
    "Show all call recordings" : "Pokaži vse posnetke klicev",
    "Show all audio" : "Pokaži vse zvočne posnetke",
    "Show all other" : "Pokaži vse ostalo",
    "Group" : "Skupina",
    "Team" : "Skupina",
    "You: {lastMessage}" : "Jaz: {lastMessage}",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "The recording failed. Please contact your administrator." : "Snemanje je spodletelo. Stopite v stik s skrbnikom sistema.",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Pogovoru ste se pridružili v novem oknu brskalnika, ali na drugi napravi. Nextcloud Talk te možnosti trenutno ne omogoča. Kako želite nadaljevati?",
    "Leave this page" : "Zapusti trenutno stran",
    "Join here" : "Pridruži se v tem oknu",
    "An error occurred while posting deck card to conversation" : "Prišlo je do napake med dodajanjem naloge v pogovor.",
    "Post to a conversation" : "Dodaj v pogovor",
    "Post to conversation" : "Dodaj v pogovor",
    "An error occurred while posting location to conversation" : "Prišlo je do napake med pošiljanjem podatkom o trenutnem mestu v pogovor.",
    "Share to a conversation" : "Objavi v pogovor",
    "Share to conversation" : "Dodaj v pogovor",
    "In conversation" : "V pogovoru",
    "Error while clearing conversation history" : "Prišlo je do napake med čiščenjem zgodovine pogovora",
    "Error occurred while allowing guests" : "Prišlo je do napake med omogočanjem dostopa gostov.",
    "Error occurred while disallowing guests" : "Prišlo je do napake med onemogočanjem dostopa gostov.",
    "Error occurred when restricting the conversation to moderator" : "Prišlo je do napake med omejevanjem pogovora za moderatorja.",
    "Error occurred when opening the conversation to everyone" : "Prišlo je do napake med odpiranjem pogovora za vse udeležence.",
    "Conversation password has been saved" : "Geslo pogovora je shranjeno",
    "Conversation password has been removed" : "Geslo pogovora je odstranjeno",
    "Error occurred while saving conversation password" : "Prišlo je do napake med shranjevanjem gesla pogovora.",
    "Call recording is starting." : "Začenja se snemanje pogovora",
    "Call recording stopped while starting." : "Začenja se snemanje pogovora se je ustavilo.",
    "Call recording stopped. You will be notified once the recording is available." : "Snemanje klica je ustavljeno. Ko bo posnetek na voljo, bo prikazano obvestilo.",
    "Conversation picture set" : "Slika pogovora je nastavljena",
    "Conversation picture deleted" : "Slika pogovora je izbrisana",
    "Could not delete the conversation picture" : "Ni mogoče izbrisati slike pogovora",
    "Could not post message: {errorMessage}" : "Sporočila ni mogoče objaviti: {errorMessage}",
    "An error occurred while fetching the participants" : "Med pridobivanjem udeležencev je prišlo do napake",
    "Could not send invitation to {actorId}" : "Ni mogoče poslati povabila: {actorId}.",
    "Invitations sent" : "Vabila so poslana.",
    "Error occurred when sending invitations" : "Med pošiljanjem vabil je prišlo do napake.",
    "An error occurred while creating breakout rooms" : "Prišlo je do napake med ustvarjanjem ločenih skupin",
    "An error occurred while deleting breakout rooms" : "Prišlo je do napake med brisanjem ločenih skupin",
    "An error occurred while starting breakout rooms" : "Prišlo je do napake med začenjanjem ločenih skupin",
    "An error occurred while stopping breakout rooms" : "Prišlo je do napake med prekinjanjem ločenih skupin",
    "An error occurred while sending a message to the breakout rooms" : "Prišlo je do napake med pošiljanjem sporočila v ločene skupine",
    "An error occurred while requesting assistance" : "Prišlo je do napake med pošiljanjem zahteve za pomoč",
    "An error occurred while resetting the request for assistance" : "Prišlo je do napake med ponastavljanjem zahteve za pomoč",
    "An error occurred while joining breakout room" : "Prišlo je do napake med pridruževanjem v ločeno skupino",
    "{guest} (guest)" : "{guest} (gost)",
    "An error occurred while submitting your vote" : "Prišlo je do napake med pošiljanjem odziva na anketo",
    "An error occurred while ending the poll" : "Prišlo je do napake med končanjem ankete",
    "Failed to add reaction" : "Dodajanje odziva je spodletelo",
    "Failed to remove reaction" : "Odstranjevanje odziva je spodletelo",
    "Error while uploading file \"{fileName}\"" : "Napaka pri pošiljanju datoteke »{fileName}«",
    "Not enough free space to upload file \"{fileName}\"" : "Ni dovolj prostora za pošiljanje datoteke »{fileName}«",
    "You are not allowed to share files" : "Ni ustreznih dovoljenj za omogočanje souporabe datotek",
    "Error while sharing file" : "Prišlo je do napake med souporabo datoteke",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Brskalnik, ki ga trenutno uporabljate ne podpira popolnoma možnosti programa Nextcloud Talk. Priporočljivo je uporabiti najnovejšo različico brskalnika Mozilla Firefox, Microsoft Edge, Google Chrome oziroma Apple Safari.",
    "_%n hour_::_%n hours_" : ["%n ura","%n uri","%n ure","%n ur"],
    "_%n day_::_%n days_" : ["%n dan","%n dneva","%n dni","%n dni"],
    "_%n week_::_%n weeks_" : ["%n teden","%n tedna","%n tedne","%n tednov"],
    "_In %n hour_::_In %n hours_" : ["Čez %n uro","Čez %n uri","Čez %n ure","Čez %n ur"],
    "_%n minute _::_%n minutes_" : ["%n minuta","%n minuti","%n minute","%n minut"],
    "In {hours} and {minutes}" : "Čez {hours} in {minutes}",
    "_In %n minute_::_In %n minutes_" : ["Čez %n minuto","Čez %n minuti","Čez %n minute","Čez %n minut"],
    "Later today – {timeLocale}" : "Danes – {timeLocale}",
    "Tomorrow – {timeLocale}" : "Jutri – {timeLocale}",
    "This weekend – {timeLocale}" : "Ta teden – {timeLocale}",
    "Next week – {timeLocale}" : "Naslednji teden – {timeLocale}",
    "Message link copied to clipboard" : "Povezava sporočila je kopirana v odložišče.",
    "Conversation link copied to clipboard" : "Povezava do pogovora je kopirana v odložišče.",
    "The link could not be copied" : "Povezave ni mogoče kopirati.",
    "Sending signaling message has failed" : "Pošiljanje signalnega sporočila je spodletelo.",
    "Lost connection to signaling server. Trying to reconnect." : "Povezava s signalnim strežnikom je izgubljena. Izveden bo ponovni poskus povezave.",
    "The configured signaling server needs to be updated to be compatible with this version of Talk. Please contact your administration." : "Nastavljen signalni strežnik je treba posodobiti, da bo skladen s trenutno uporabljeno različico programa Talk. Stopite v stik s skrbnikom sistema.",
    "Please reload the page." : "Stran je treba osvežiti.",
    "Do not disturb" : "Ne pustim se motiti",
    "Away" : "Trenutno ne spremljam",
    "Microphone {number}" : "Mikrofon {number}",
    "Camera {number}" : "Kamera {number}",
    "Speaker {number}" : "Zvočnik {number}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Kaže, da govorite, medtem ko ste utišani. Povrnite zvok, da vas drugi udeleženci slišijo.",
    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "Ni mogoče vzpostaviti povezave z niti enim udeležencem. Za vaš pogovor je morda treba nastaviti strežnik TURN. Stopite v stik s skrbnikom za nastavitev po navodilih, zapisanih v {linkstart}documentaciji{linkend}.",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Opravilo traja dlje, kot je pričakovano. Ali so dovoljenja za dostop do predstavnih predmetov odobrena (ali zavrnjena)? Če to drži, ponovno zaženite brskalnik, ker trenutno zvoka in slike ni mogoče uporabiti.",
    "Access to microphone & camera is only possible with HTTPS" : "Dostop do mikrofona in kamere je mogoče le z uporabo protokola HTTPS",
    "Please move your setup to HTTPS" : "Prilagodite nastavite za uporabo protokola HTTPS",
    "Access to microphone & camera was denied" : "Dostop do mikrofona in kamere je bil zavrnjen.",
    "WebRTC is not supported in your browser" : "Uporabljen brskalnik ne podpira protokola WebRTC",
    "Please use a different browser like Firefox or Chrome" : "Priporočljivo je uporabiti drug brskalnik, kot sta Firefox in Chrome",
    "Error while accessing microphone & camera" : "Napaka med dostopom do mikrofona in kamere",
    "%s Talk on your mobile devices" : "%s Talk na vaši mobilni napravi",
    "Join conversations at any time, anywhere, on any device." : "Pridružite se pogovoru kadarkoli, kjerkoli in s katerekoli naprave.",
    "Android app" : "Odjemalec za Android",
    "iOS app" : "Odjemalec za iOS",
    "__language_name__" : "Slovenščina",
    "Call summary (%s)" : "Povzetek klica (%s)",
    "The call summary bot posts an overview message after the call listing all participants and outlining tasks" : "Vstavek za povzetek klica po koncu pogovora pokaže pregledno sporočilo, v katerem so navedeni vsi udeleženci in opisane naloge.",
    "Tasks" : "Naloge",
    "Notes" : "Beležke",
    "Reports" : "Poročila",
    "Decisions" : "Odločitve",
    "Call summary" : "Povzetek klica",
    "Call summary - {title}" : "Povzetek klica – {title}",
    "Talk to %s" : "Pogovor: %s",
    "Next meeting" : "Naslednje srečanje",
    "Set reminder for later today" : "Nastavi opomnik za danes",
    "Set reminder for tomorrow" : "Nastavi opomnik za jutri",
    "Set reminder for this weekend" : "Nastavi opomnik za ta teden",
    "Set reminder for next week" : "Nastavi opomnik za naslednji teden",
    "Open poll • You voted already" : "Odprta anketa • Glas ste že oddali",
    "Open poll • Click to vote" : "Odprta anketa • Kliknite za glasovanje",
    "Poll • Ended" : "Anketa • Zaključena",
    "Talk recording from {time} ({conversation})" : "Snemanje pogovora Talk {time} ({conversation})",
    "_Poll results • %n vote_::_Poll results • %n votes_" : ["Rezultati ankete • %n glas","Rezultati ankete • %n glasova","Rezultati ankete • %n glasovi","Rezultati ankete • %n glasov"],
    "_Open poll • %n vote_::_Open poll • %n votes_" : ["Odprta anketa • %n glas","Odprta anketa • %n glasovs","Odprta anketa • %n glasovi","Odprta anketa • %n glasov"],
    "Submit vote" : "Objavi glasovanje",
    "Your privacy setting has been saved" : "Nastavitve zasebnosti so shranjene.",
    "Failed to save sounds setting" : "Shranjevanje nastavitev zvoka je spodletelo",
    "Sounds setting saved" : "Nastavitve zvokov so shranjene.",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Pogovoru ste se pridružili v novem oknu brskalnika, ali na drugi napravi. Nextcloud Talk te možnosti trenutno ne omogoča, zato je bila druga seja preklicana."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
