"use strict";(self.rspackChunktalk=self.rspackChunktalk||[]).push([["node_modules_nextcloud_vue_dist_assets_NcColorPicker-DVYGs8R3_css-node_modules_nextcloud_vue_-975502"],{71415(s,e,u){u.r(e);var _=u(42493);u.d(e,{default:()=>_.N})}}]);