OC.L10N.register(
    "spreed",
    {
    "Other activities" : "กิจกรรมอื่น ๆ",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} ได้ตั้งค่า Matterbridge เพื่อซิงโครไนซ์การสนทนานี้กับแชทอื่น ๆ",
    "You set up Matterbridge to synchronize this conversation with other chats" : "คุณได้ตั้งค่า Matterbridge เพื่อซิงโครไนซ์การสนทนานี้กับแชทอื่น ๆ",
    "Message deleted by author" : "ข้อความถูกลบโดยผู้เขียน",
    "System" : "ระบบ",
    "File not found" : "ไม่พบไฟล์",
    "File is too big" : "ไฟล์ใหญ่เกินไป",
    "Invalid file provided" : "ไฟล์ที่ระบุไม่ถูกต้อง",
    "Invalid image" : "รูปภาพไม่ถูกต้อง",
    "Unknown filetype" : "ชนิดไฟล์ที่ไม่รู้จัก",
    "Description" : "รายละเอียด",
    "Dismiss notification" : "ปิดการแจ้งเตือน",
    "Accept" : "ยอมรับ",
    "Decline" : "ปฏิเสธ",
    "Notification" : "การแจ้งเตือน",
    "Open settings" : "เปิดการตั้งค่า",
    "error" : "ข้อผิดพลาด",
    "Default" : "ค่าเริ่มต้น",
    "Presentation" : "งานนำเสนอ",
    "Favorites" : "รายการโปรด",
    "Other" : "อื่น ๆ",
    "Federation" : "ที่ติดต่อกับภายนอก",
    "Invalid date, date format must be YYYY-MM-DD" : "วันที่ไม่ถูกต้อง รูปแบบวันที่จะต้องเป็น ปปปป-ดด-วว",
    "Conversation not found" : "ไม่พบการสนทนา",
    "The password is wrong. Try again." : "รหัสผ่านไม่ถูกต้อง กรุณาลองอีกครั้ง",
    "Password" : "รหัสผ่าน",
    "Submit" : "ส่ง",
    "Everyone" : "ทุกคน",
    "Save changes" : "บันทึกการเปลี่ยนแปลง",
    "Saving …" : "กำลังบันทึก …",
    "Enabled" : "เปิดใช้งาน",
    "Disabled" : "ปิดใช้งาน",
    "Name" : "ชื่อ",
    "All messages" : "ข้อความทั้งหมด",
    "@-mentions only" : "เฉพาะการกล่าวถึงแบบ @",
    "Enable encryption" : "เปิดใช้งานการเข้ารหัส",
    "Pending" : "รอดำเนินการ",
    "Error" : "ข้อผิดพลาด",
    "Never" : "ไม่เคย",
    "Language" : "ภาษา",
    "Country" : "ประเทศ",
    "Status" : "สถานะ",
    "Created at" : "สร้างเมื่อ",
    "Yes" : "ใช่",
    "No" : "ไม่ตกลง",
    "OK" : "ตกลง",
    "Confirm" : "ยืนยัน",
    "Reset" : "รีเซ็ต",
    "Cancel" : "ยกเลิก",
    "Back" : "ย้อนกลับ",
    "Now" : "ตอนนี้",
    "Calendar" : "ปฏิทิน",
    "Attendees" : "ผู้เข้าร่วมกิจกรรม",
    "Save" : "บันทึก",
    "No results" : "ไม่มีผลลัพธ์",
    "Grid view" : "มุมมองแบบตาราง",
    "Reload" : "โหลดใหม่",
    "Copy link" : "คัดลอกลิงก์",
    "Mute audio" : "ปิดเสียง",
    "Unmute audio" : "เลิกปิดเสียง",
    "None" : "ไม่มี",
    "Check devices" : "ตรวจสอบอุปกรณ์",
    "Collapse" : "ย่อ",
    "Favorite" : "รายการโปรด",
    "Hide details" : "ซ่อนข้อมูล",
    "Show details" : "แสดงข้อมูล",
    "Enter a name for this conversation" : "กรอกชื่อของการสนทนานี้",
    "Disable" : "ปิดใช้งาน",
    "Choose" : "เลือก",
    "Restricted" : "ถูกจำกัด",
    "Personal" : "ส่วนตัว",
    "Password protection" : "ป้องกันด้วยรหัสผ่าน",
    "Edit" : "แก้ไข",
    "Delete" : "ลบ",
    "Notifications" : "การแจ้งเตือน",
    "Start meeting now" : "เริ่มการประชุมตอนนี้",
    "Give your meeting a title" : "ตั้งชื่อการประชุมของคุณ",
    "Create and copy link" : "สร้างและคัดลอกลิงค์",
    "Create a new conversation" : "สร้างการสนทนาใหม่",
    "Open calendar" : "เปิดปฏิทิน",
    "Messages where you were mentioned will show up here. You can mention people by typing @ followed by their name" : "ข้อความที่คุณถูกกล่าวถึงจะแสดงที่นี่ คุณสามารถกล่าวถึงผู้อื่นได้โดยการพิมพ์ @ ตามด้วยชื่อของพวกเขา",
    "Log in" : "เข้าสู่ระบบ",
    "Remove from favorites" : "เอาออกจากรายการโปรด",
    "Add to favorites" : "เพิ่มในรายการโปรด",
    "Tags" : "แท็ก",
    "Home" : "หน้าหลัก",
    "Alphabetically" : "ตัวอักษร",
    "Users" : "ผู้ใช้",
    "Groups" : "กลุ่ม",
    "Advanced" : "ขั้นสูง",
    "Devices" : "อุปกรณ์",
    "Backgrounds" : "พื้นหลัง",
    "Invalid path selected" : "เลือกเส้นทางไม่ถูกต้อง",
    "Blur" : "เบลอ",
    "Upload" : "อัปโหลด",
    "Files" : "ไฟล์",
    "Reply" : "ตอบกลับ",
    "Translate" : "แปลภาษา",
    "Dismiss" : "ปิดทิ้ง",
    "Add participants" : "เพิ่มผู้เข้าร่วม",
    "Send message" : "ส่งข้อความ",
    "New file" : "ไฟล์ใหม่",
    "Blank" : "ว่าง",
    "Send" : "ส่ง",
    "Settings" : "การตั้งค่า",
    "Results" : "ผลลัพธ์",
    "bot" : "บอต",
    "guest" : "ผู้เยี่ยมชม",
    "Remove" : "ลบออก",
    "Add users or groups" : "เพิ่มผู้ใช้หรือกลุ่ม",
    "Searching …" : "กำลังค้นหา …",
    "Participants ({count})" : "ผู้เข้าร่วม ({count})",
    "Chat" : "แชท",
    "Details" : "รายละเอียด",
    "Shared items" : "สิ่งที่แชร์",
    "Load more results" : "โหลดผลลัพธ์เพิ่มเติม",
    "Default language" : "ภาษาค่าเริ่มต้น",
    "Privacy" : "ความเป็นส่วนตัว",
    "Search" : "ค้นหา",
    "Keep" : "เก็บ",
    "User" : "ผู้ใช้",
    "Login" : "เข้าสู่ระบบ",
    "Nickname" : "ชื่อเล่น",
    "Client ID" : "รหัสไคลเอ็นต์",
    "Media" : "สื่อ",
    "Locations" : "สถานที่",
    "Audio" : "เสียง",
    "Group" : "กลุ่ม",
    "Please reload the page." : "โปรดโหลดหน้าเว็บใหม่",
    "Do not disturb" : "ห้ามรบกวน",
    "Away" : "ไม่อยู่",
    "Android app" : "แอป Android",
    "iOS app" : "แอป iOS",
    "__language_name__" : "ไทย",
    "Tasks" : "งาน",
    "Notes" : "โน้ต"
},
"nplurals=1; plural=0;");
