OC.L10N.register(
    "spreed",
    {
    "a conversation" : "разговор",
    "(Duration %s)" : "(Времетраење %s)",
    "You attended a call with {user1}" : "Присуствувавте на повик со {user1}",
    "_%n guest_::_%n guests_" : ["1 гостин","%n гости"],
    "You attended a call with {user1} and {user2}" : "Присуствувавте на повик со {user1} и {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Присуствувавте на повик со {user1}, {user2} и {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Присуствувавте на повик со {user1}, {user2}, {user3} и {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Присуствувавте на повик со {user1}, {user2}, {user3}, {user4} и {user5}",
    "_%n other_::_%n others_" : ["уште %n","%n други"],
    "{actor} invited you to {call}" : "{actor} ве покани во {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Поканети сте во <strong>разговор</strong> или имате <strong>повик</strong>",
    "Other activities" : "Други активности",
    "Talk" : "Разговор",
    "Guest" : "Гостин",
    "## New in Talk %s" : "## Ново во Talk %s",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge и Safari сега може да се користат за учество во аудио и видео повици",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- Разговорите еден на еден сега се постојани и не можат повеќе случајно да се претвораат во групни разговори. Исто така, кога еден од учесниците го напушта разговорот, разговорот не се брише автоматски. Само ако двајцата учесници заминат, разговорот е избришан од серверот",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Сега можете да ги известите сите учесници со објавување на „@all“ во разговорот",
    "- With the \"arrow-up\" key you can repost your last message" : "- Со копчето \"стрелка нагоре\" можете повторно да ја објавите вашата последна порака",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Разговорот сега може да има команди, испратете \"/help\" како порака во разговорот за да видите дали вашиот администратор конфигурирал некои",
    "- With projects you can create quick links between conversations, files and other items" : "- Со проекти можете да создадете брзи врски помеѓу разговорите, датотеките и другите ставки",
    "- You can now mention guests in the chat" : "- Сега можете да ги споменете гостите во разговорот",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Разговорите сега можат да имаат лоби. Ова ќе им овозможи на модераторите да се приклучат на разговорот и да се јават за да ја подготват средбата, додека корисниците и гостите треба да почекаат",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- Сега можете директно да одговорите на пораките што им даваат на другите корисници поголем контекст за што се однесува вашата порака",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- Пребарувањето разговори и учесници исто така ќе ги филтрира вашите постојни разговори, што ќе го олесни наоѓањето на претходните разговори",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- Сега можете да додавате кориснички кориснички групи во разговорите кога е инсталирана апликацијата кругови",
    "- Check out the new grid and call view" : "- Проверете ја новата мрежа и прегледот на повикот",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- Сега можете да испраќате и повлекувате датотеки директно од вашиот уред во разговорот",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- Споделените датотеки сега се отвораат директно во погледот на разговор со апликациите за прегледување",
    "- You can now search for chats and messages in the unified search in the top bar" : "- Сега можете да пребарувате разговори и пораки во унифицираното пребарување во горната лента",
    "- Spice up your messages with emojis from the emoji picker" : "- Додадете емотикони на вашите пораки од бирачот на емотикони",
    "- You can now change your camera and microphone while being in a call" : "- Сега можете да ги менувате камерата и микрофонот додека сте на повик",
    "- Use a poll to collect the opinions of others or settle on a date" : "- Користи анкета за да го дознаете мислењето на другите или за да договорите датум",
    "- Set a reminder on a chat message to be notified later again" : "- Постави потсетник на порака во разговор за да бидете известени",
    "_All %n participant_::_All %n participants_" : ["Сите %n учесници","Сите %n учесници"],
    "Talk updates ✅" : "Talk ажурирања ✅",
    "Reaction deleted by author" : "Реакцијата е отстранета од авторот",
    "{actor} created the conversation" : "{actor} креираше разговор",
    "You created the conversation" : "Креиравте разговор",
    "System created the conversation" : "Системот креираше разговор",
    "An administrator created the conversation" : "Администраторот креираше разговор",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} го преименува разговорот од \"%1$s\" во \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Го преименувавте разговорот од \"%1$s\" to \"%2$s\"",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Администраторот го преименуваше разговорот од \"%1$s\" во \"%2$s\"",
    "{actor} set the description" : "{actor} го постави описот",
    "You set the description" : "Го поставивте описот",
    "An administrator set the description" : "Администраторот го постави описот",
    "{actor} removed the description" : "{actor} го избриша описот",
    "You removed the description" : "Го избришавте описот",
    "An administrator removed the description" : "Администраторот го избриша описот",
    "You started a silent call" : "Стартувавте тивок повик",
    "Outgoing silent call" : "Појдовен тивок повик",
    "{actor} started a silent call" : "{actor} стартуваше тивок повик",
    "Incoming silent call" : "Дојдовен тивок повик",
    "You started a call" : "Стартувавте повик",
    "Outgoing call" : "Појдовен повик",
    "{actor} started a call" : "{actor} стартуваше повик",
    "Incoming call" : "Дојдовен повик",
    "{actor} joined the call" : "{actor} се приклучи кон ковикот",
    "You joined the call" : "Се приклучивте кон повикот",
    "{actor} left the call" : "{actor} го напушти повикот",
    "You left the call" : "Го напуштивте повикот",
    "{actor} unlocked the conversation" : "{actor} го отклучи разговорот",
    "You unlocked the conversation" : "Го отклучивте разговорот",
    "An administrator unlocked the conversation" : "Администраторот го отклучи разговорот",
    "{actor} locked the conversation" : "{actor} го заклучи разговорот",
    "You locked the conversation" : "Го заклучивте разговорот",
    "An administrator locked the conversation" : "Администраторот го заклучи разговорот",
    "{actor} limited the conversation to the current participants" : "{actor} го ограничи разговорот на сегашните учесници",
    "You limited the conversation to the current participants" : "Оо ограничивте разговорот на сегашните учесници",
    "An administrator limited the conversation to the current participants" : "Администраторот го ограничи разговорот на сегашните учесници",
    "{actor} opened the conversation to registered users" : "{actor} го отвори разговорот за регистрирани корисници",
    "You opened the conversation to registered users" : "Го отворивте разговорот за регистрирани корисници",
    "An administrator opened the conversation to registered users" : "Администраторот го отвори разговорот за регистрирани корисници",
    "The conversation is now open to everyone" : "Разговорот сега е отворен за сите",
    "{actor} opened the conversation to everyone" : "{actor} го отвори разговорот за сите",
    "You opened the conversation to everyone" : "Го отворивте разговорот за сите",
    "{actor} restricted the conversation to moderators" : "{actor} го ограничи разговорот само на модератори",
    "You restricted the conversation to moderators" : "Го ограничивте разговорот само на модератори",
    "{actor} allowed guests" : "{actor} овозможи гости",
    "You allowed guests" : "Овозможивте гости",
    "An administrator allowed guests" : "Администраторот овозможи гости",
    "{actor} disallowed guests" : "{actor} забрани гости",
    "You disallowed guests" : "Забранивте гости",
    "An administrator disallowed guests" : "Администраторот оневозможи гости",
    "{actor} set a password" : "{actor} постави лозинка",
    "You set a password" : "Поставивте лозинка",
    "An administrator set a password" : "Администраторот постави лозинка",
    "{actor} removed the password" : "{actor} ја отстрани лозинката",
    "You removed the password" : "Ја отстранивте лозинката",
    "An administrator removed the password" : "Администраторот ја избриша лозинката",
    "{actor} added {user}" : "{actor} го додаде {user}",
    "You joined the conversation" : "Се приклучивте кон разговорот",
    "{actor} joined the conversation" : "{actor} се приклучи кон разговорот",
    "You added {user}" : "Го додадовте {user}",
    "{actor} added you" : "{actor} ве додаде",
    "An administrator added you" : "Администраторот ве додаде",
    "An administrator added {user}" : "Администраторот го додаде  {user}",
    "You left the conversation" : "Го напуштивте разговорот",
    "{actor} left the conversation" : "{actor} го напушти разговорот",
    "{actor} removed {user}" : "{actor} го отстрани {user}",
    "You removed {user}" : "го отстранивте {user}",
    "{actor} removed you" : "{actor} ве отстрани",
    "An administrator removed you" : "Администраторот ве отстрани",
    "An administrator removed {user}" : "Администраторот го отстрани {user}",
    "{actor} invited you" : "{actor} те покани",
    "{federated_user} accepted the invitation" : "{federated_user} ја прифати поканата",
    "{actor} removed {federated_user}" : "{actor} го отстрани {federated_user}",
    "You removed {federated_user}" : "го отстранивте {federated_user}",
    "An administrator removed {federated_user}" : "Администраторот го отстрани {federated_user}",
    "{federated_user} declined the invitation" : "{federated_user} ја одби поканата",
    "{actor} added group {group}" : "{actor} додаде група {group}",
    "You added group {group}" : "Додадовте група {group}",
    "An administrator added group {group}" : "Администраторот додаде група {group}",
    "{actor} removed group {group}" : "{actor} отстрани група {group}",
    "You removed group {group}" : "Отстранивте {group}",
    "An administrator removed group {group}" : "Администраторот отстрани група {group}",
    "{actor} promoted {user} to moderator" : "{actor} го промовираше {user} во модератор",
    "You promoted {user} to moderator" : "Го промовиравте {user} во модератор",
    "{actor} promoted you to moderator" : "{actor} ве промовираше во модератор",
    "An administrator promoted you to moderator" : "Администраторот ве промовирање во модератор",
    "An administrator promoted {user} to moderator" : "Администраторот го промовираше {user} во модератор",
    "{actor} demoted {user} from moderator" : "{actor} го деградираше {user} од модератор",
    "You demoted {user} from moderator" : "Го деградиравте {user} од модератор",
    "{actor} demoted you from moderator" : "{actor} те деградираше од модератор",
    "An administrator demoted you from moderator" : "Администраторот ве деградираше од модератор",
    "An administrator demoted {user} from moderator" : "Администраторот го деградираше {user} од модератор",
    "{actor} shared a file which is no longer available" : "{actor} сподели датотека која не е достапна повеќе",
    "You shared a file which is no longer available" : "Споделивте датотека која не е достапна повеќе",
    "The shared location is malformed" : "Споделената локација е погрешно зададена",
    "{actor} deleted a message" : "{actor} избриша порака",
    "You deleted a message" : "Избришавте порака",
    "{actor} edited a message" : "{actor} измени порака",
    "You edited a message" : "Изменивте порака",
    "{actor} deleted a reaction" : "{actor} избриша реакција",
    "You deleted a reaction" : "Избришавте реакциј",
    "You cleared the history of the conversation" : "Ја избришавте историјата на разговорот",
    "{actor} set the conversation picture" : "{actor} постави слика на разговорот",
    "You set the conversation picture" : "Поставивте слика на разговорот",
    "{actor} ended the poll {poll}" : "{actor} ја затвори анкетата {poll}",
    "You ended the poll {poll}" : "Ја затворивте анкетата {poll}",
    "Someone voted on the poll {poll}" : "Некој гласаше на анкетата {poll}",
    "Message deleted by author" : "Пораката е избришана од авторот",
    "Message deleted by {actor}" : "Порака избришана од {actor}",
    "Message deleted by you" : "Порака избришана од вас",
    "Deleted user" : "Избришан корисник",
    "Administration" : "Администрација",
    "System" : "Систем",
    "%s (guest)" : "%s (гостин)",
    "Missed call" : "Пропуштен повик",
    "Unanswered call" : "Неодговорен повик",
    "Call ended (Duration {duration})" : "Повикот заврши (Времетраење {duration})",
    "{actor} ended the call (Duration {duration})" : "{actor} го заврши повикот (Времетраење {duration})",
    "_Call with %n guest was ended, as it reached the maximum call duration (Duration {duration})_::_Call with %n guests was ended, as it reached the maximum call duration (Duration {duration})_" : ["Повикот со %n гостин заврши, го достигна максималното времетраење (Времетраење {duration})","Повикот со %n гости заврши, го достигна максималното времетраење (Времетраење {duration})"],
    "_Call with %n guest ended (Duration {duration})_::_Call with %n guests ended (Duration {duration})_" : ["Повикот со %n гостин заврши (Времетраење {duration})","Повикот со %n гости заврши (Времетраење {duration})"],
    "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["{actor} го заврши повикот со 1 гостин (Времетраење {duration})","{actor} го заврши повикот со %n гости (Времетраење {duration})"],
    "Call with {user1} was ended, as it reached the maximum call duration (Duration {duration})" : "Повикот со {user1} заврши, го достигна максималното времетраење (Времетраење {duration})",
    "Call with {user1} ended (Duration {duration})" : "Повикот со {user1} заврши (Времетраење {duration})",
    "{actor} ended the call with {user1} (Duration {duration})" : "{actor} го заврши повикот со {user1} (Времетраење {duration})",
    "Call with {user1} and {user2} was ended, as it reached the maximum call duration (Duration {duration})" : "Повикот со {user1} и {user2} заврши, го достигна максималното времетраење (Времетраење {duration})",
    "Call with {user1} and {user2} ended (Duration {duration})" : "Повикот со {user1} и {user2} заврши (Времетраење {duration})",
    "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor} го заврши повикот со {user1} и {user2} (Времетраење {duration})",
    "Call with {user1}, {user2} and {user3} was ended, as it reached the maximum call duration (Duration {duration})" : "Повикот со {user1}, {user2} и {user3} заврши, го достигна максималното времетраење (Времетраење {duration})",
    "Call with {user1}, {user2} and {user3} ended (Duration {duration})" : "Повикот со {user1}, {user2} и {user3} заврши (Времетраење {duration})",
    "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor} го заврши повикот со {user1}, {user2 } и {user3} (Времетраење {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} was ended, as it reached the maximum call duration (Duration {duration})" : "Повикот со {user1}, {user2}, {user3} и {user4} заврши, го достигна максималното времетраење (Времетраење {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} ended (Duration {duration})" : "Повикот со {user1}, {user2}, {user3} и {user4} заврши (Времетраење {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{actor} го заврши повикот со {user1}, {user2}, {user3} и {user4} (Времетраење {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} was ended, as it reached the maximum call duration (Duration {duration})" : "Повикот со {user1}, {user2}, {user3}, {user4} и {user5} заврши, го достигна максималното времетраење (Времетраење {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} ended (Duration {duration})" : "Повикот со {user1}, {user2}, {user3}, {user4} и {user5} заврши (Времетраење {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{actor} го заврши повикот со {user1}, {user2}, {user3}, {user4} и {user5} (Времетраење {duration})",
    "Message of {user} in {conversation}" : "Порака од {user} во {conversation}",
    "Message of {user}" : "Порака од {user}",
    "Talk conversations" : "Talk разговори",
    "Call %s" : "Повикај %s",
    "Chat with %s" : "Разговор со %s",
    "File not found" : "Датотеката не е пронајдена",
    "File is not shared, or shared but not with the user" : "Датотеката не е споделена, или е споделена но не со корисници",
    "No account available to delete." : "Нема сметка достапна за бришење.",
    "Poll" : "Анкета",
    "Password needs to be set" : "Треба да се постави лозинка",
    "Uploading the file failed" : "Неуспешно прикачување на датотека",
    "No image file provided" : "Не е доставена фотографија или датотека",
    "File is too big" : "Датотеката е премногу голема",
    "Invalid file provided" : "Доставена е невалидна датотека",
    "Invalid image" : "Невалидна фотографија",
    "Unknown filetype" : "Непознат тип на датотека",
    "Talk mentions" : "Спомнувања",
    "Say hi to your friends and colleagues!" : "Кажи им здраво на твојте пријатели и колеги!",
    "No unread mentions" : "Нема непрочитани спомнувања",
    "Call in progress" : "Повик е во тек",
    "You were mentioned" : "Споменати сте",
    "Write to conversation" : "Пишивајте во разговорот",
    "Writes event information into a conversation of your choice" : "Напишете информации за настанот во разговорот по ваш избор",
    "Conversation invitation" : "Покана за разговор",
    "Scheduled time" : "Закажано време",
    "Description" : "Опис",
    "You can also dial-in via phone with the following details" : "Истотака можете да се приклучите преку телефон со следниве детали",
    "Dial-in information" : "Информации",
    "Meeting ID" : "ID на средба",
    "Your PIN" : "Вашиот ПИН",
    "Click the button below to join the lobby now." : "Кликнете на копчето подолу за да се приклучите кон лобито.",
    "Click the link below to join the lobby now." : "Кликнете на линкот подолу за да се приклучите кон лобито.",
    "Join lobby for \"%s\"" : "Придружете се на лобито на \"%s\"",
    "Meeting" : "Средба",
    "Password request: %s" : "Барање за лозинка: %s",
    "Private conversation" : "Приватен разговор",
    "Deleted user (%s)" : "Избришан корисник (%s)",
    "Dismiss notification" : "Отфрли известување",
    "Accept" : "Прифати",
    "Decline" : "Одбиј",
    "New message" : "Нова порака",
    "Reminder" : "Потсетник",
    "Notification" : "Известување",
    "You received a message in a private conversation" : "Добивте порака во приватен разговор",
    "Reminder: You in {call}" : "Потсетник: Вие во {call}",
    "Reminder: {user} in {call}" : "Потсетник: {user} во {call}",
    "Reminder: Deleted user in {call}" : "Потсетник: Избришан корисник во {call}",
    "Reminder: {guest} (guest) in {call}" : "Потсетник: {guest} (гостин) во {call}",
    "Reminder: Guest in {call}" : "Потсетник: гостин во {call}",
    "{user} reacted with {reaction} in {call}" : "{user} реагираше со {reaction} во {call}",
    "Deleted user reacted with {reaction} in {call}" : "Избришан корисник реагираше со {reaction} во {call}",
    "{guest} (guest) reacted with {reaction} in {call}" : "{guest} (гостин) реагираше со {reaction} во {call}",
    "Guest reacted with {reaction} in {call}" : "Гостин реагираше со {reaction} во {call}",
    "{user} in {call}" : "{user} во {call}",
    "Deleted user in {call}" : "Избришан корисник во {call}",
    "{guest} (guest) in {call}" : "{guest} (guest) во {call}",
    "Guest in {call}" : "Гостин во {call}",
    "{user} sent you a private message" : "{user} ви испрати приватна порака",
    "{user} sent a message in conversation {call}" : "{user} ви испрати порака во разговорот {call}",
    "A deleted user sent a message in conversation {call}" : "Избришан корисник ви испрати порака во разговорот {call}",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (guest) ви испрати порака во разговорот {call}",
    "A guest sent a message in conversation {call}" : "гостин ви испрати порака во разговорот {call}",
    "{user} replied to your private message" : "{user} одговори на вашата приватна порака",
    "{user} replied to your message in conversation {call}" : "{user} одговори на вашата порака во разговорот {call}",
    "A deleted user replied to your message in conversation {call}" : "Избришан корисник одговори на  вашата порака во разговорот {call}",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (guest) одговори на вашата порака во разговорот {call}",
    "A guest replied to your message in conversation {call}" : "Гостин одговори на вашата порака во разговорот {call}",
    "Reminder: You in private conversation {call}" : "Потсетник: Вие во приватен разговор {call}",
    "Reminder: A deleted user in private conversation {call}" : "Потсетник: Избришан корисник во приватен разговор {call}",
    "Reminder: {user} in private conversation" : "Потсетник: {user} во приватен разговор",
    "Reminder: You in conversation {call}" : "Потсетник: Вие во разговор {call}",
    "Reminder: {user} in conversation {call}" : "Потсетник: {user} во разговор {call}",
    "Reminder: A deleted user in conversation {call}" : "Reminder: Избришан корисник во разговор {call}",
    "Reminder: {guest} (guest) in conversation {call}" : "Потсетник: {guest} (гостин) во разговор {call}",
    "Reminder: A guest in conversation {call}" : "Потсетник: Гостин во разговор {call}",
    "{user} reacted with {reaction} to your message in conversation {call}" : "{user} реагираше со {reaction} на вашата порака во разговорот {call}",
    "A deleted user reacted with {reaction} to your message in conversation {call}" : "Избришан корисник реагираше со {reaction} на вашата порака во разговорот {call}",
    "{guest} (guest) reacted with {reaction} to your message in conversation {call}" : "{guest} (guest) реагираше со {reaction} на вашата порака во повикот {call}",
    "A guest reacted with {reaction} to your message in conversation {call}" : "Gostin реагираше со {reaction} на вашата порака во повикот {call}",
    "{user} mentioned you in a private conversation" : "{user} те спомна во приватен разговор",
    "{user} mentioned you in conversation {call}" : "{user} те спомна во разговор {call}",
    "A deleted user mentioned you in conversation {call}" : "Избришан корисник те спомна во разговор {call}",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (guest) те спомна во разговор {call}",
    "A guest mentioned you in conversation {call}" : "Гостин те спомна во разговор {call}",
    "View message" : "Види порака",
    "Dismiss reminder" : "Избриши потсетник",
    "View chat" : "Погледнете го разговорот",
    "{user} invited you to a group conversation: {call}" : "{user} те покани на групен разговор: {call}",
    "Join call" : "Приклучи се кон повикот",
    "Answer call" : "Одговори на повикот",
    "{user} would like to talk with you" : "{user} сака да разговара со вас",
    "Call back" : "Јавете се назад",
    "You missed a call from {user}" : "Имате пропуштен повик од {user}",
    "A group call has started in {call}" : "Започна групен повик {call}",
    "You missed a group call in {call}" : "Имате пропуштен групен повик во {call}",
    "{email} is requesting the password to access {file}" : "{email} побара лозинка за пристап до {file}",
    "{email} tried to request the password to access {file}" : "{email} побара лозинка за да пристапи до {file}",
    "Someone is requesting the password to access {file}" : "Некој побара лозинка за да пристапи до {file}",
    "Someone tried to request the password to access {file}" : "Некој се обиде да побара лозинка за да пристапи до {file}",
    "Open settings" : "Отвори параметри",
    "The hosted signaling server is now configured and will be used." : "Signaling сервер е конфигуриран и сега ќе се користи.",
    "The hosted signaling server was removed and will not be used anymore." : "Signaling серверот е избришан и нема да се користи повеќе.",
    "error" : "грешка",
    "Contact via Talk" : "Разговор",
    "Open Talk" : "Започни разговор",
    "Default" : "Стандардно",
    "Presentation" : "Презентација",
    "Restricted conversation with lobby enabled, ideal for public webinars." : "Ограничен разговор со овозможено лоби, идеално за јавни вебинари.",
    "Conversations" : "Разговори",
    "{user}" : "{user}",
    "Messages" : "Пораки",
    "{user} in {conversation}" : "{user} во {conversation}",
    "Messages in other conversations" : "Пораки во други разговори",
    "One-to-one rooms always need to show the other users avatar" : "Собите еден-на-еден секогаш треба да го прикажуваат аватарот на другите корисници",
    "Avatar image is not square" : "Сликата за Аватар не е квадратна",
    "Room {number}" : "Соба {number}",
    "Favorites" : "Омилени",
    "Other" : "Останато",
    "Something unexpected happened." : "Се случи нешто неочекувано.",
    "The URL is invalid." : "Невалидна URL адреса.",
    "An HTTPS URL is required." : "Потебна е HTTPS URL.",
    "The email address is invalid." : "Невалидна е-пошта.",
    "The language is invalid." : "Невалиден јазик.",
    "The country is invalid." : "Невалидна држава.",
    "Something unexpected happened. Please try again later." : "Се случи нешто неочекувано. Обидете се покасно.",
    "Note to self" : "Забелешка за себе",
    "A place for your private notes, thoughts and ideas" : "Место за вашите приватни белешки, мисли и идеи",
    "Andorra" : "Андора",
    "United Arab Emirates" : "Обединети Арапски Емирати",
    "Afghanistan" : "Афганистан",
    "Antigua and Barbuda" : "Антигва и Барбуда",
    "Anguilla" : "Ангила",
    "Albania" : "Албанија",
    "Armenia" : "Ерменија",
    "Angola" : "Ангола",
    "Antarctica" : "Антарктик",
    "Argentina" : "Аргентина",
    "American Samoa" : "Американска Самоа",
    "Austria" : "Австрија",
    "Australia" : "Австралија",
    "Aruba" : "Аруба",
    "Åland Islands" : "Оландски острови",
    "Azerbaijan" : "Азербејџан",
    "Bosnia and Herzegovina" : "Босна и Херцеговина",
    "Barbados" : "Барбадос",
    "Bangladesh" : "Бангладеш",
    "Belgium" : "Белгија",
    "Burkina Faso" : "Буркина Фасо",
    "Bulgaria" : "Бугарија",
    "Bahrain" : "Бахреин",
    "Burundi" : "Бурунди",
    "Benin" : "Бенин",
    "Saint Barthélemy" : "Свети Вартоломеј",
    "Bermuda" : "Бермуда",
    "Brunei Darussalam" : "Брунеј",
    "Bolivia, Plurinational State of" : "Боливија, Повеќенационална Држава",
    "Bonaire, Sint Eustatius and Saba" : "Бонер, Свети Евстахиј и Саба",
    "Brazil" : "Бразил",
    "Bahamas" : "Бахами",
    "Bhutan" : "Бутан",
    "Bouvet Island" : "Остров Буве",
    "Botswana" : "Боцвана",
    "Belarus" : "Белорусија",
    "Belize" : "Белизе",
    "Canada" : "Канада",
    "Cocos (Keeling) Islands" : "Кокосови Острови",
    "Congo, the Democratic Republic of the" : "Конго, Демократска Република",
    "Central African Republic" : "Централна Африканска Република",
    "Congo" : "Конго",
    "Switzerland" : "Швајцарија",
    "Côte d'Ivoire" : "Брегот на Слоновата Коска",
    "Cook Islands" : "Кукови Острови",
    "Chile" : "Чиле",
    "Cameroon" : "Камерун",
    "China" : "Кина",
    "Colombia" : "Колумбија",
    "Costa Rica" : "Костарика",
    "Cuba" : "Куба",
    "Cabo Verde" : "Зелен ’Рт",
    "Curaçao" : "Курасао",
    "Christmas Island" : "Божиќен Остров",
    "Cyprus" : "Кипар",
    "Czechia" : "Чешка",
    "Germany" : "Германија",
    "Djibouti" : "Џибути",
    "Denmark" : "Данска",
    "Dominica" : "Доминика",
    "Dominican Republic" : "Доминиканска Република",
    "Algeria" : "Алжир",
    "Ecuador" : "Еквадор",
    "Estonia" : "Естонија",
    "Egypt" : "Египет",
    "Western Sahara" : "Западна Сахара",
    "Eritrea" : "Еритреја",
    "Spain" : "Шпанија",
    "Ethiopia" : "Етиопија",
    "Finland" : "Финска",
    "Fiji" : "Фиџи",
    "Falkland Islands (Malvinas)" : "Фолкландски Острови",
    "Micronesia, Federated States of" : "Микронезија, Сојузни Држави",
    "Faroe Islands" : "Фарски Острови",
    "France" : "Франција",
    "Gabon" : "Габон",
    "United Kingdom of Great Britain and Northern Ireland" : "Кралство на Велика Британија и Северна Ирска",
    "Grenada" : "Гренада",
    "Georgia" : "Грузија",
    "French Guiana" : "Француска Гвајана",
    "Guernsey" : "Гернзи",
    "Ghana" : "Гана",
    "Gibraltar" : "Гибралтар",
    "Greenland" : "Гренланд",
    "Gambia" : "Гамбија",
    "Guinea" : "Гвинеја",
    "Guadeloupe" : "Гваделуп",
    "Equatorial Guinea" : "Екваторијална Гвинеја",
    "Greece" : "Грција",
    "South Georgia and the South Sandwich Islands" : "Јужна Џорџија и Јужни Сендвички Острови",
    "Guatemala" : "Гватемала",
    "Guam" : "Гуам",
    "Guinea-Bissau" : "Гвинеја-Бисао",
    "Guyana" : "Гвајана",
    "Hong Kong" : "Хонгконг",
    "Heard Island and McDonald Islands" : "Островите Хард и Мекдоналдс",
    "Honduras" : "Хондурас",
    "Croatia" : "Хрватска",
    "Haiti" : "Хаити",
    "Hungary" : "Унгарија",
    "Indonesia" : "Индонезија",
    "Ireland" : "Ирска",
    "Israel" : "Израел",
    "Isle of Man" : "Остров Ман",
    "India" : "Индија",
    "British Indian Ocean Territory" : "Британска Индоокеанска Територија",
    "Iraq" : "Ирак",
    "Iran, Islamic Republic of" : "Иран, Исламска Република",
    "Iceland" : "Исланд",
    "Italy" : "Италија",
    "Jersey" : "Џерси",
    "Jamaica" : "Јамајка",
    "Jordan" : "Јордан",
    "Japan" : "Јапонија",
    "Kenya" : "Кенија",
    "Kyrgyzstan" : "Киргистан",
    "Cambodia" : "Камбоџа",
    "Kiribati" : "Кирибати",
    "Comoros" : "Коморски Острови",
    "Saint Kitts and Nevis" : "Свети Кристофер и Невис",
    "Korea, Democratic People's Republic of" : "Кореја, Демократска Народна Република",
    "Korea, Republic of" : "Кореја, Република",
    "Kuwait" : "Кувајт",
    "Cayman Islands" : "Кајмански Острови",
    "Kazakhstan" : "Казахстан",
    "Lao People's Democratic Republic" : "Лаошка Народна Демократска Република",
    "Lebanon" : "Либан",
    "Saint Lucia" : "Света Луција",
    "Liechtenstein" : "Лихтенштајн",
    "Sri Lanka" : "Шри Ланка",
    "Liberia" : "Либерија",
    "Lesotho" : "Лесото",
    "Lithuania" : "Литванија",
    "Luxembourg" : "Луксембург",
    "Latvia" : "Летонија",
    "Libya" : "Либија",
    "Morocco" : "Мароко",
    "Monaco" : "Монако",
    "Moldova, Republic of" : "Молдавија, Република",
    "Montenegro" : "Црна Гора",
    "Saint Martin (French part)" : "Свети Мартин (остров)",
    "Madagascar" : "Мадагаскар",
    "Marshall Islands" : "Маршалски Острови",
    "North Macedonia" : "Македонија",
    "Mali" : "Мали",
    "Myanmar" : "Мјанмар",
    "Mongolia" : "Монголија",
    "Macao" : "Макао",
    "Northern Mariana Islands" : "Северни Маријански Острови",
    "Martinique" : "Мартиник",
    "Mauritania" : "Мавританија",
    "Montserrat" : "Монтсерат",
    "Malta" : "Малта",
    "Mauritius" : "Маврициус",
    "Maldives" : "Малдиви",
    "Malawi" : "Малави",
    "Mexico" : "Мексико",
    "Malaysia" : "Малезија",
    "Mozambique" : "Мозамбик",
    "Namibia" : "Намибија",
    "New Caledonia" : "Нова Каледонија",
    "Niger" : "Нигер",
    "Norfolk Island" : "Норфолшки Остров",
    "Nigeria" : "Нигерија",
    "Nicaragua" : "Никарагва",
    "Netherlands" : "Холандија",
    "Norway" : "Норвешка",
    "Nepal" : "Непал",
    "Nauru" : "Република Науру",
    "Niue" : "Ниуе",
    "New Zealand" : "Нов Зеланд",
    "Oman" : "Оман",
    "Panama" : "Панама",
    "Peru" : "Перу",
    "French Polynesia" : "Француска Полинезија",
    "Papua New Guinea" : "Папуа Нова Гвинеја",
    "Philippines" : "Филипини",
    "Pakistan" : "Пакистан",
    "Poland" : "Полска",
    "Saint Pierre and Miquelon" : "Свети Пјер и Микелон",
    "Pitcairn" : "Питкерн",
    "Puerto Rico" : "Порто Рико",
    "Palestine, State of" : "Држава Палестина",
    "Portugal" : "Португалија",
    "Palau" : "Република Палау",
    "Paraguay" : "Парагвај",
    "Qatar" : "Катар",
    "Réunion" : "Реинион",
    "Romania" : "Романија",
    "Serbia" : "Србија",
    "Russian Federation" : "Руска Федерација",
    "Rwanda" : "Руанда",
    "Saudi Arabia" : "Саудиска Арабија",
    "Solomon Islands" : "Соломонски острови",
    "Seychelles" : "Сејшели",
    "Sudan" : "Судан",
    "Sweden" : "Шведска",
    "Singapore" : "Сингапур",
    "Saint Helena, Ascension and Tristan da Cunha" : "Света Елена, Вознесение и Тристан да Куња",
    "Slovenia" : "Словенија",
    "Svalbard and Jan Mayen" : "Свалбард и Јан Мејн\n ",
    "Slovakia" : "Словачка",
    "Sierra Leone" : "Сиера Леоне",
    "San Marino" : "Сан Марино",
    "Senegal" : "Сенегал",
    "Somalia" : "Сомалија",
    "Suriname" : "Суринам",
    "South Sudan" : "Јужен Судан",
    "Sao Tome and Principe" : "Сао Томе и Принсипе",
    "El Salvador" : "Ел Салвадор",
    "Sint Maarten (Dutch part)" : "Свети Мартин (Холандија)",
    "Syrian Arab Republic" : "Сириска Арапска Република",
    "Eswatini" : "Есватини",
    "Turks and Caicos Islands" : "Туркс и Кајкос",
    "Chad" : "Чад",
    "French Southern Territories" : "Француски Јужни и Антарктички Земји",
    "Togo" : "Того",
    "Thailand" : "Тајланд",
    "Tajikistan" : "Таџикистан",
    "Tokelau" : "Токелау",
    "Timor-Leste" : "Тимор-Лест",
    "Turkmenistan" : "Туркменистан",
    "Tunisia" : "Тунис",
    "Tonga" : "Tonga",
    "Turkey" : "Турција",
    "Trinidad and Tobago" : "Тринидад и Тобаго",
    "Tuvalu" : "Тувалу",
    "Taiwan, Province of China" : "Таиван, Провинција на Кина",
    "Tanzania, United Republic of" : "Обединета Република Танзанија",
    "Ukraine" : "Украина",
    "Uganda" : "Уганда",
    "United States Minor Outlying Islands" : "Мали оддалечени острови на САД",
    "United States of America" : "Соединетите Американски Држави",
    "Uruguay" : "Уругвај",
    "Uzbekistan" : "Узбекистан",
    "Holy See" : "Света столица",
    "Saint Vincent and the Grenadines" : "Свети Винцент и Гренадини",
    "Venezuela, Bolivarian Republic of" : "Венецуела, Боливарска република",
    "Virgin Islands, British" : "Девствени Острови, Британски",
    "Virgin Islands, U.S." : "Девствени Острови, Обединети Држави",
    "Viet Nam" : "Социјалистичка Република Виетнам",
    "Vanuatu" : "Вануату",
    "Wallis and Futuna" : "Валис и Футуна",
    "Samoa" : "Самоа",
    "Yemen" : "Јемен",
    "Mayotte" : "Мајот",
    "South Africa" : "Јужна Африка",
    "Zambia" : "Замбија",
    "Zimbabwe" : "Зимбабве",
    "Federation" : "Федерација",
    "Error: Server did not respond with proper JSON" : "Грешка: Серверот не одговори со соодветна JSON",
    "Error: Server responded with: {error}" : "Грешка: Серверот одговори со: {error}",
    "Error: Unknown error occurred" : "Грешка: Се појави непозната грешка",
    "{notify_push} is not installed. This may lead to delayed Talk notifications." : "{notify_push} не е инсталирано. Ова може да доведе до доцнење на известувањата за Talk.",
    "SIP configuration" : "SIP конфигурација",
    "Invalid date, date format must be YYYY-MM-DD" : "Невалиден датум, форматот мора да биде ГГГГ-ММ-ДД",
    "Conversation not found" : "Разговорот не е пронајден",
    "Chat, video & audio-conferencing using WebRTC" : "Разговор, видео и аудио конференција со користење на WebRTC",
    "Leave call" : "Напушти го повикот",
    "Stay in call" : "Остани во повикот",
    "Duplicate session" : "Дупликат сесија",
    "Discuss this file" : "Дискусија за оваа датотека",
    "Loading …" : "Се вчитува…",
    "Share this file with others to discuss it" : "Сподели ја оваа датотека со другите за да дискутирате за неа",
    "Join conversation" : "Приклучи се на разговорот",
    "Share this file" : "Сподели ја оваа датотека",
    "This conversation is password-protected." : "Овој разговор е заштитен со лозинка.",
    "We have detected multiple invalid password attempts from your IP. Therefore your next attempt is throttled up to 30 seconds." : "Детектирани се повеќе неуспешни најавувања од вашата IP адреса. Затоа вашиот следен обид за најавување е одложено за 30 секунди.",
    "The password is wrong. Try again." : "Лозинката е погрешна. Обидите се повторно.",
    "Password" : "Лозинка",
    "Submit" : "Испрати",
    "Error requesting the password." : "Грешка при барање на лозинка",
    "Request password" : "Барање на лозинка",
    "This conversation has ended" : "Овој разговор е завршен",
    "Everyone" : "Сите",
    "Users and moderators" : "Корисници и модератори",
    "Moderators only" : "Само модераторите",
    "Disable calls" : "Оневозможи повици",
    "Save changes" : "Зачувај ги промените",
    "Saving …" : "Зачувува ...",
    "Saved!" : "Зачувано!",
    "Limit to groups" : "Ограничување на групи",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "Кога една група е избрана, само корисниците на таа група можат да бидат дел од разговорот.",
    "Guests can still join public conversations." : "Гостите сеуште можат да се приклучат кон јавните разговори.",
    "Limit using Talk" : "Ограничи користење на Talk",
    "Limit creating a public and group conversation" : "Ограничи креирање на јавни и групни разговори",
    "Limit creating conversations" : "Ограничи креирање на разговори",
    "Limit starting a call" : "Ограничи започнување на повик",
    "Limit starting calls" : "Ограничи започнување на повик",
    "When a call has started, everyone with access to the conversation can join the call." : "Кога повикот е започнат, секој со пристап до разговорот може да се приклучи кон повикот.",
    "Enabled" : "Овозможено",
    "Disabled" : "Оневозможен",
    "State" : "Статус",
    "Name" : "Име",
    "Last error" : "Последна грешка",
    "Beta" : "Бета",
    "Permissions" : "Дозволи",
    "All messages" : "Сите пораки",
    "@-mentions only" : "само @-спомнување ",
    "Off" : "Исклучени",
    "General settings" : "Општи параметри",
    "Default notification settings" : "Стандардни поставки за известување",
    "Default group notification" : "Стандардни групни известувања",
    "Default group notification for new groups" : "Стандардни групни известувања за нови групи",
    "Integration into other apps" : "Интеграција со други апликации",
    "Allow conversations on files" : "Дозволи разговор на датотеките",
    "Allow conversations on public shares for files" : "Дозволи разговор на јавно споделените датотеки",
    "Enable encryption" : "Овозможи енкрипција",
    "Pending" : "Чекање",
    "Error" : "Грешка",
    "Blocked" : "Блокирани",
    "Active" : "Активно",
    "Expired" : "Истечен",
    "Never" : "Никогаш",
    "URL of this Nextcloud instance" : "URL од оваа Nextcloud истанца",
    "Language" : "Јазик",
    "Country" : "Држава",
    "Status" : "Статус",
    "Created at" : "Создадено на",
    "Expires at" : "Истекува на",
    "Limits" : "Ограничувања",
    "Yes" : "Да",
    "No" : "Не",
    "_%n user_::_%n users_" : ["1 корисник","%n корисници"],
    "Installed version: {version}" : "Инсталирана верзија: {version}",
    "Downloading …" : "Преземање ...",
    "Install Talk Matterbridge" : "Инсталирај мост интеграција",
    "Matterbridge integration" : "Мост интеграција",
    "Enable Matterbridge integration" : "Овозможи мост интеграција",
    "Status: Checking connection" : "Статус: Проверка на врската",
    "OK: Running version: {version}" : "OK: Стартувана верзија: {version}",
    "Delete this server" : "Избриши го овој сервер",
    "Test this server" : "Тестирај го овој сервер",
    "STUN server URL" : "STUN сервер URL",
    "STUN servers" : "STUN сервери",
    "{option1} and {option2}" : "{option1} и {option2}",
    "{option} only" : "само {option}",
    "TURN server URL" : "TURN сервер URL",
    "TURN servers" : "TURN сервери",
    "Failed" : "Неуспешно",
    "OK" : "Добро",
    "Checking …" : "Проверка ...",
    "Federated user" : "Федерален корисник",
    "Allow participants to choose" : "Дозволи на учесниците да изберат",
    "Create rooms" : "Креирај соби",
    "Confirm" : "Потврди",
    "Reset" : "Ресетирање",
    "Room {roomNumber}" : "Соба {roomNumber}",
    "Cancel" : "Откажи",
    "Back" : "Назад",
    "Add participant \"{user}\"" : "Додади учесник \"{user}\"",
    "Now" : "Сега",
    "From" : "Од",
    "To" : "До",
    "Calendar" : "Календар",
    "Attendees" : "Присутни",
    "Save" : "Зачувај",
    "Search participants" : "Барај учесници",
    "No results" : "Нема резултати",
    "Done" : "Готово",
    "Exit full screen (F)" : "Излез од цел екран (F)",
    "Full screen (F)" : "Приказ на цел екран (F)",
    "Speaker view" : "Поглед на тој што зборува",
    "Grid view" : "Мрежа",
    "This conversation is read-only" : "Разговорот е само за читање",
    "Lobby is still active and you're not a moderator" : "Лобито е сè уште активно, а вие не сте модератор",
    "{nickName} raised their hand." : "{nickName} крена рака.",
    "A participant raised their hand." : "Еден учесник крена рака.",
    "Connecting …" : "Поврзување ...",
    "Calling …" : "Повикување ...",
    "Waiting for {user} to join the call" : "Чекање на {user} да се приклучи кон повикот",
    "Waiting for others to join the call …" : "Чекање на останатите да се приклучат кон повикот ...",
    "You can invite others in the participant tab of the sidebar" : "Можете да поканите други учесници во картичката за учесници во страничната лента",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Можете да поканите други учесници во картичката за учесници во страничната лента или да ја споделите оваа врска за да поканите други учесници!",
    "Share this link to invite others!" : "Споделете ја оваа врска за да поканите други учесници!",
    "Copy link" : "Копирај линк",
    "No audio. Click to select device" : "Нема звук. Кликни за да избереш уред",
    "Mute audio" : "Занеми (Mute) аудио",
    "Mute audio (M)" : "Занеми (Mute) го аудиото (М)",
    "Unmute audio" : "Одзанеми (Unmute) го аудиото",
    "Unmute audio (M)" : "Одзанеми (Unmute) го аудиото (М)",
    "None" : "Ништо",
    "Select a microphone" : "Избери микрофон",
    "Select a speaker" : "Избери звучник",
    "Microphone settings" : "Поставки за микрофонот",
    "Check devices" : "Провери уреди",
    "Access to camera was denied" : "Нема пристап до камерата",
    "Error while accessing camera: It is likely in use by another program" : "Грешка при пристапување до камерата: Веројатно ја користи друга програма",
    "Error while accessing camera" : "Грешка при пристап до камера",
    "You have been muted by a moderator" : "Администраторот ве занеми",
    "You are not allowed to enable video" : "Не сте овластени да го овозможите видеото",
    "No video. Click to select device" : "Нема видео. Кликни за да избереш уред",
    "Disable video" : "Оневозможи видео",
    "Disable video (V)" : "Овозможи видео (V)",
    "Enable video" : "Овозможи видео",
    "Enable video (V)" : "Оневозможи видео (V)",
    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "Овозможи видео (V) - Вашата врска ќе биде кратко прекината при овозможување на видеото за прв пат",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Овозможи видео. Вашата врска ќе биде кратко прекината при овозможување на видеото за прв пат",
    "Select a video device" : "Избери видео уред",
    "You" : "Ти",
    "Mute" : "Занеми",
    "Muted" : "Занемен",
    "Show screen" : "Прикажи екран",
    "Stop following" : "Престани да следиш",
    "Connection could not be established …" : "Врската неможе да се воспостави ...",
    "Collapse" : "Собери",
    "You need to be logged in to upload files" : "Треба да бидете најавени за да можете да прикачите датотеки",
    "Drop your files to upload" : "Повлечи датотеки за да прикачите",
    "Scroll to bottom" : "Скролај до долу",
    "Favorite" : "Омилени",
    "Banned users" : "Банирани корисници",
    "Manage the list of banned users in this conversation." : "Уреди ја листата на банирани корисници во овој разговор.",
    "Manage bans" : "Уреди банови",
    "No banned users" : "Нема банирани корисници",
    "Date:" : "Датум:",
    "Note:" : "Белешка:",
    "Hide details" : "Сокриј детали",
    "Show details" : "Прикажи детали",
    "Unban" : "Одбанирај",
    "Enter a name for this conversation" : "Внеси име за овој разговор",
    "Edit conversation name" : "Уреди име на разговор",
    "Edit conversation description" : "Уреди опис на разговор",
    "Enter a description for this conversation" : "Внесете опис за овој разговор",
    "Picture" : "Слика",
    "The following bots can be enabled in this conversation. Reach out to your administration to get more bots installed on this server." : "Следните ботови можат да бидат овозможени во овој разговор. Контактирајте ја вашата администрација за да инсталирате повеќе ботови на овој сервер.",
    "Disable" : "Оневозможи",
    "Enable" : "Овозможи",
    "Please select a valid PNG or JPG file" : "Изберете валидна PNG или JPG датотека",
    "Choose your conversation picture" : "Избери ваша слика за во разговорот",
    "Choose" : "Избери",
    "Error setting conversation picture" : "Грешка при поставување на слика за разговорот",
    "Could not set the conversation picture: {error}" : "Неможе да се постави слика на разговорот: {error}",
    "Set emoji as conversation picture" : "Постави emoji како слика за разговорот",
    "Set background color for conversation picture" : "Постави боја на позадина за сликата на разговорот",
    "Upload conversation picture" : "Прикачи слика за разговорот",
    "Choose conversation picture from files" : "Избери слика за разговорот од датотеките",
    "Remove conversation picture" : "Избриши слика за разговорот",
    "The file must be a PNG or JPG" : "Датотеката мора да биде PNG или JPG",
    "Set picture" : "Постави слика",
    "Edit the default permissions for participants in this conversation. These settings do not affect moderators." : "Уреди ги стандардните дозволи за учесниците во овој разговор. Овие параметри не влијаат на модераторите.",
    "Every time permissions are modified in this section, custom permissions previously assigned to individual participants will be lost." : "Секој пат кога дозволите се менуваат во овој дел, прилагодените дозволи претходно доделени на поединечните учесници ќе бидат изгубени.",
    "All permissions" : "Сите дозволи",
    "Participants have permissions to start a call, join a call, enable audio and video, and share screen." : "Учесниците имаат дозвола да започнат повик, да се придружуваат на повик, да овозможат аудио и видео и да споделуваат екран.",
    "Restricted" : "Ограничена",
    "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "Учесниците може да се придружуваат на повици, но не можат да овозможат аудио или видео, ниту да споделуваат екран додека модераторот рачно не им даде дозвола.",
    "Advanced permissions" : "Напредни дозволи",
    "Edit permissions" : "Уреди дозволи",
    "Conversation settings" : "Параметри за разговор",
    "Basic Info" : "Основни информации",
    "Personal" : "Лично",
    "Moderation" : "Модерација",
    "Setup overview" : "Преглед на поставките",
    "Bots" : "Ботови",
    "Danger zone" : "Опасна зона",
    "Archive conversation" : "Архивирање на разговор",
    "Archived conversations are hidden from the conversation list by default. However, they will still appear when you search for the conversation name or access a list of archived conversations." : "Архивираните разговори се скриени од листата на разговори по стандард. Сепак, тие сè уште ќе се појавуваат кога ќе го пребарувате името на разговорот или ќе пристапите до листа на архивирани разговори.",
    "Leave conversation" : "Напушти разговор",
    "Delete conversation" : "Избриши разговор",
    "Do you really want to delete \"{displayName}\"?" : "Дали навистина сакате да го избришете \"{displayName}\"?",
    "Delete all chat messages" : "Избришете ги сите пораки од разгоровот",
    "Do you really want to delete all messages in \"{displayName}\"?" : "Дали навистина сакате да ги избришете сите пораки во \"{displayName}\"?",
    "Be careful, these actions cannot be undone." : "Бидете внимателни, овие дејства не можат да повратат.",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Откако ќе излезете од разговорот, за повторно да се придружите на затворен разговор, потребна е покана. На отворен разговор може повторно да се придружите во секое време.",
    "Permanently delete this conversation." : "Трајно избришете го овој разговор",
    "Delete chat messages" : "Избришете ги пораките од разгоровот",
    "Permanently delete all the messages in this conversation." : "Трајно избришете ги сите пораки во овој разговор.",
    "Message expiration set: {duration}" : "Поставен рок на траење на пораките: {duration}",
    "Message expiration" : "Времетраење на пораки",
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "Пораките од разговорот може да истечат по одредено време. Забелешка: Датотеките споделени во разговорот нема да бидат избришани за сопственикот, но повеќе нема да бидат споделувани во разговорот.",
    "Set message expiration" : "Постави рок на траење на пораки",
    "Current message expiration" : "Моментално истекување на пораките",
    "Password copied to clipboard" : "Лозинката е копирана во клипборд",
    "Password could not be copied" : "Лозинката неможе да се копира",
    "Guest access" : "Гостински пристап",
    "Allow guests to join this conversation via link" : "Дозволи им на гостите да се приклучат на овој разговор преку линк",
    "Password protection" : "Заштитено со лозинка",
    "This conversation is password-protected. Guests need password to join" : "Разговорот е заштитен со лозинка. Гостите треба да ја внесат лозинката за да се приклучат.",
    "Password protection is needed for public conversations" : "Потребна е заштита со лозинка за јавни разговори",
    "Set a password" : "Постави лозинка",
    "Change password" : "Смени лозинка",
    "Enter new password" : "Внеси нова лозинка",
    "Save password" : "Зачувај лозинка",
    "Copy password" : "Копирај лозинка",
    "Guests are allowed to join this conversation via link" : "Гости неможат да се приклучат на овој разговор",
    "Guests are not allowed to join this conversation" : "Гости можат да се приклучат на овој разговор",
    "Resend invitations" : "Повторно испратете ги поканите",
    "Open conversation to registered users, showing it in search results" : "Отвори го разговорот за регистрирани корисници, прикажувајќи го во резултатите од пребарувањето",
    "Enabling the lobby will remove non-moderators from the ongoing call." : "Овозможувањето на лобито ќе ги отстрани лицата кои не се модератори од тековниот повик.",
    "Enable lobby, restricting the conversation to moderators" : "Овозможи лоби, ограничувајќи го разговорот само за модератори",
    "Meeting start time" : "Време на почеток на состанокот",
    "Start time (optional)" : "Време на почеток (опционално)",
    "Import email participants" : "Увези учесници преку е-поштата",
    "You can import a list of email participants from a CSV file." : "Можете да увезете список на учесници во е-поштата од CSV-датотека.",
    "Poll drafts" : "Нацрти за анкета",
    "Browse poll drafts" : "Прелистај нацрти за анкета",
    "Lock conversation" : "Заклучи разговор",
    "This will also terminate the ongoing call." : "Ова исто така ќе го прекине тековниот повик.",
    "Lock the conversation to prevent anyone to post messages or start calls" : "Заклучете го разговорот за да спречите некој да објавува пораки или да започнува повици",
    "Edit" : "Уреди",
    "More information" : "Повеќе информации",
    "Delete" : "Избриши",
    "Log content" : "Содржина на записот",
    "All participants are allowed to mention @all" : "Сите учесници имаат право да го споменат @all",
    "Participants are now allowed to mention @all." : "Учесниците сега имаат право да го споменат @all.",
    "Allow participants to mention @all" : "Сите учесници имаат право да ги споменат @all",
    "Mention permissions" : "Дозволи за споменување",
    "Notifications" : "Известувања",
    "Notify about calls in this conversation" : "Извести ме за повиците во овој разговор",
    "Important conversation" : "Важен разговор",
    "\"Do not disturb\" user status is ignored for important conversations" : "Статусот на корисникот „Не вознемирувај“ се игнорира за важни разговори",
    "Sensitive conversation" : "Сензитивен разговор",
    "Message preview will be disabled in conversation list and notifications" : "Преглед на пораките ќе биде оневозможен во листата со разговори и известувањата",
    "In {conversation}" : "во {conversation}",
    "Join" : "Приклучи се",
    "Error while creating the conversation" : "Грешка при креирање на разговор",
    "Hello, {displayName}" : "Здраво, {displayName}",
    "Start meeting now" : "Започнете состанок",
    "Give your meeting a title" : "Дајте му наслов на вашиот состанок",
    "Create and copy link" : "Креирај и копирај линк",
    "Create a new conversation" : "Креирај нов разговор",
    "Join open conversations" : "Приклучи се на отворени разговори",
    "Schedule meetings" : "Закажи состанок",
    "You don't have any upcoming meetings" : "Немате претстојни состаноци",
    "Open calendar" : "Отвори календар",
    "Unread mentions" : "Непрочитани споменувања",
    "Messages where you were mentioned will show up here. You can mention people by typing @ followed by their name" : "Пораките каде што сте споменати ќе се појават тука. Можете да споменете луѓе со пишување @ проследено со нивното име",
    "Message reminders" : "Пораки за потсетници",
    "Set a reminder on a message to be notified" : "Постави потсетник на порака за да бидете известени",
    "Create conversation" : "Креирајте разговор",
    "Enter your name" : "Внесете го вашето име",
    "Submit name and join" : "Испрати име и придружи се",
    "Do you already have an account?" : "Дали веќе имате сметка?",
    "Log in" : "Најава",
    "Creating the conversation …" : "Креирање разговор ...",
    "Mark as read" : "Означи како прочитано",
    "Mark as unread" : "Означи како непрочитано",
    "Remove from favorites" : "Отстрани од фаворити",
    "Add to favorites" : "Додади во фаворити",
    "Unarchive conversation" : "Врати го разговорот од архива",
    "Ignore \"Do not disturb\"" : "Игнорирај „Не вознемирувај“",
    "You need to promote a new moderator before you can leave the conversation." : "Треба да промовирате нов модератор пред да го напуштите разговорот.",
    "Tag name" : "Име на ознака",
    "Conversation actions" : "Дејства за разговорот",
    "Tags" : "Ознаки",
    "Notify about calls" : "Известувај за повици",
    "Rename tag" : "Преимени ознака",
    "Move up" : "Помести горе",
    "Move down" : "Помести доле",
    "Home" : "Дома",
    "Unread" : "Непрочитана",
    "Alphabetically" : "Азбучно",
    "No matches found" : "Не се пронајдени совпаѓања",
    "No conversations found" : "Нема пронајдено разговори",
    "You have no archived conversations." : "Немате архивирани разговори.",
    "You have no unread mentions." : "Немате непрочитани спомнувања.",
    "An error occurred while performing the search" : "Настана грешка при обидот за пребарување",
    "Unread messages" : "Непрочитани пораки",
    "Back to conversations" : "Назад до разговорите",
    "Archived conversations" : "Архивирани разговори",
    "Clear filter" : "Исчисти филтри",
    "App settings" : "Параметри за алпикацијата",
    "Users" : "Корисници",
    "Groups" : "Групи",
    "Teams" : "Тимови",
    "Other sources" : "Други извори",
    "No search results" : "Нема резултати од пребарувањето",
    "Users and groups" : "Корисници и групи",
    "This meeting is scheduled for {startTime}" : "Состанокот е закажан за {startTime}",
    "You are currently waiting in the lobby" : "Моментално чекате во лобито",
    "Enable noise suppression" : "Овозможи потиснување на бучавата",
    "Reduce background noises for better voice quality" : "Ги редуцира звуците во позадина за подобар квалитет на гласот",
    "Advanced" : "Напредно",
    "Enable echo cancellation" : "Овозможи поништување на ехото",
    "Minimize echo effect from own surrounding" : "Го минимизира ефектот на ехо од околината",
    "Enable auto gain control" : "Овозможи автоматска контрола на засилување",
    "Dynamically adjust microphone volume for consistent level" : "Динамички ја прилагодува јачината на звукот на микрофонот за конзистентно ниво",
    "Select microphone" : "Избери микрофон",
    "No microphone available" : "Нема микрофон",
    "Select speaker" : "Избери звучник",
    "Select camera" : "Избери камера",
    "No camera available" : "Нема камера",
    "Select a device" : "Избери уред",
    "Playing …" : "Пуштено ...",
    "Test speakers" : "Тест на звучници",
    "Test" : "Тест",
    "Devices" : "Уреди",
    "Backgrounds" : "Позадини",
    "No audio" : "Нема аудио",
    "No camera" : "Нема камера",
    "Calls are not supported in your browser" : "Повици не се поддржани од вашиот прелистувач",
    "Access to microphone is only possible with HTTPS" : "Пристап до микрофонот е возможен само преку безбедноска врска HTTPS",
    "Access to microphone was denied" : "Нема пристап до микрофонот",
    "Error while accessing microphone" : "Грешка при пристап до микрофон",
    "Access to camera is only possible with HTTPS" : "Пристап до камерата е возможен само преку безбедноска врска HTTPS",
    "The recording might include your voice, video from camera, and screen share. Your consent is required before joining the call." : "Снимката може да го вклучува вашиот глас, видео од камерата и споделување на екранот. Потребна е ваша согласност пред да се придружите на повикот.",
    "Notify all participants about this call" : "Извести ги сите учесници за овој повик",
    "Apply settings" : "Примени",
    "Error while uploading the file" : "Грешка при прикачување на датотека",
    "Select a file" : "Избери датотека",
    "Invalid path selected" : "Избрана невалидна патека",
    "Select virtual background from file {fileName}" : "Избери виртуелна позадина од датотека {fileName}",
    "Blur" : "Замаглување",
    "Upload" : "Прикачи",
    "Files" : "Датотеки",
    "24 hours" : "24 часа",
    "7 days" : "7 дена",
    "30 days" : "30 дена",
    "Clear reminder – {timeLocale}" : "Избришан потсетник – {timeLocale}",
    "Message text copied to clipboard" : "Пораката е копирана во клипборд",
    "Message forwarded to \"Note to self\"" : "Пораката е препратена до \"Забелешка за себе\"",
    "Error while forwarding message to \"Note to self\"" : "Грешка при препраќање на пораката до \"Забелешка за себе\"",
    "A reminder was successfully removed" : "Потсетникот е успешно избришан",
    "A reminder was successfully set at {datetime}" : "Успешно е поставен потсетник во {datetime}",
    "Error occurred when creating a reminder" : "Настана грешка при обид за поставување потсетник",
    "Reply" : "Одговор",
    "More actions" : "Повеќе акции",
    "Set reminder" : "Постави потсетник",
    "Edit message" : "Уреди порака",
    "Copy message" : "Копирај порака",
    "Copy message link" : "Копирај линк на пораката",
    "Go to file" : "Оди до датотеката",
    "Download file" : "Преземи датотека",
    "Forward message" : "Препрати порака",
    "Translate" : "Преведи",
    "Set custom reminder" : "Постави прилагоден потсетник",
    "Choose a conversation to forward the selected message." : "Избери разговор за да препратите избраната порака.",
    "Error while forwarding message" : "Грешка при препраќање на пораката",
    "The message has been forwarded to {selectedConversationName}" : "Пораката е препратена до {selectedConversationName}",
    "Dismiss" : "Отфрли",
    "Reschedule" : "Презакажи",
    "Send now" : "Испрати сега",
    "Choose a time" : "Избери време",
    "Message sent" : "Пораката е испратена",
    "Contact" : "Контакт",
    "{stack} in {board}" : "{stack} во {board}",
    "Remove {fileName}" : "Избриши {fileName}",
    "Not enough free space to upload file" : "Нема доволно простор за да се прикачи датотека",
    "_Poll draft • %n option_::_Poll draft • %n options_" : ["Нацрт за анкета • %n опција","Нацрт за анкета • %n опции"],
    "Edit poll draft" : "Уреди нацрт за анкета",
    "Delete poll draft" : "Избриши нацрт анкета",
    "Open poll" : "Отворена анкета",
    "See results" : "Vidi rezultati",
    "No messages" : "Нема пораки",
    "Unpin" : "Од-ппинувај",
    "Error: A password is required to create the conversation." : "Грешка: Потребна е лозинка за да креирате разговор.",
    "All set, the conversation \"{conversationName}\" was created." : "Готово, разговорот \"{conversationName}\" е креиран.",
    "Create a new group conversation" : "Креирајте нов групен разговор",
    "Add participants" : "Додади учесници",
    "Conversation visibility" : "Видливост на разговорот",
    "Allow guests to join via link" : "Дозволи им на гостите да се приклучат преку линк",
    "Enter password" : "Внеси лозинка",
    "This conversation has been locked" : "Разговорот е заклучен",
    "No permission to post messages in this conversation" : "Немате дозвола да испратите порака во овој разговор",
    "Write a message without notification" : "Напиши порака без известување",
    "Send message" : "Испрати порака",
    "Send without notification" : "Испрати без известување",
    "Message will be sent {datetimeString}" : "Пораката ќе биде испратена на {datetimeString}",
    "File to share" : "Датотека за споделување",
    "File upload is not available in this conversation" : "Не е дозволено прикачување на датотеки во овој разговор",
    "Message was successfully scheduled" : "Пораката е успешно закажана",
    "Add emoji" : "Додади емотикон",
    "Adding a mention will only notify users who did not read the message." : "Додавање на споменување ќе ги извести само корисниците кои не ја прочитале пораката.",
    "Send later" : "Испрати покасно",
    "Show scheduled messages" : "Прикажи закажани пораки",
    "Cancel editing" : "Откажи уредување",
    "Share from {nextcloud}" : "Сподели од {nextcloud}",
    "Share from Files" : "Сподели од датотеките",
    "Share files to the conversation" : "Сподели датотеки во разговорот",
    "Upload from device" : "Прикачи од уред",
    "Create new poll" : "Направи анкета",
    "Smart picker" : "Паметен избирач",
    "Record voice message" : "Сними гласовна порака",
    "End recording and send" : "Заврши снимање и испрати",
    "Dismiss recording" : "Отфрли снимање",
    "Error while recording audio" : "Грешка при снимање звук",
    "New file" : "Нова датотека",
    "Blank" : "Празно",
    "Create and share a new file" : "Креирај и сподели датотека",
    "Create file" : "Креирај датотека",
    "Someone is typing …" : "Некој пишува …",
    "{user1} is typing …" : "{user1} пишува …",
    "{user1} and {user2} are typing …" : "{user1} и {user2} пишуваат …",
    "{user1}, {user2} and {user3} are typing …" : "{user1}, {user2} и {user3} пишуваат …",
    "_{user1}, {user2}, {user3} and %n other are typing …_::_{user1}, {user2}, {user3} and %n others are typing …_" : ["{user1}, {user2}, {user3} и %n друг пишуваат …","{user1}, {user2}, {user3} и %n други пишуваат …"],
    "Add more files" : "Додади повеќе датотеки",
    "Send" : "Испрати",
    "In this conversation <strong>{user}</strong> can:" : "Во овој разговор <strong>{user}</strong> може:",
    "Edit default permissions for participants in <strong>{conversationName}</strong>" : "Уреди ги стандардните дозволи за учесниците во <strong>{conversationName}</strong>",
    "Start a call" : "Повик",
    "Skip the lobby" : "Прескокни го лобито",
    "Can post messages and reactions" : "Може да се пишуваат пораки и рекции",
    "Enable the microphone" : "Овозможи микрофон",
    "Enable the camera" : "Овозможи камера",
    "Share the screen" : "Споделување екран",
    "Update permissions" : "Ажурирај дозволи",
    "Updating permissions" : "Ажурирање на дозволи",
    "No poll drafts" : "Нема нацрти за анкета",
    "There is no poll drafts yet saved for this conversation" : "Сè уште нема зачувани нацрти за анкета во овој разговор",
    "Create poll" : "Креирај анкета",
    "Question" : "Прашање",
    "Ask a question" : "Постави прашање",
    "Import draft from file" : "Увези нацрт од датотека",
    "Answers" : "Одговори",
    "Answer {option}" : "Одговор {option}",
    "Delete poll option" : "Избриши ја опцијата за анкета",
    "Add answer" : "Додади одговор",
    "Settings" : "Параметри",
    "Anonymous poll" : "Анонимна анкета",
    "Multiple answers" : "Повеќе одговори",
    "Save as draft" : "Зачувај како нацрт",
    "Export draft to file" : "Извези го нацртот во датотека",
    "_%n vote • Your vote is anonymous_::_%n votes • Your vote is anonymous_" : ["%n глас • Вашиот глас е анонимен","%n гласови • Вашиот глас е анонимен"],
    "Your vote is anonymous" : "Вашиот глас е анонимен",
    "You voted for this option" : "Вие гласавте за оваа опција",
    "End poll" : "Затвори анкета",
    "Change your vote" : "Измени го твојот глас",
    "Results" : "Резултати",
    "Back to main room" : "Врати се во главната соба",
    "Back to your room" : "Врати се во твојата соба",
    "Disable lobby" : "Оневозможи лоби",
    "Settings for participant \"{user}\"" : "Параметри за учесникот \"{user}\"",
    "Participant \"{user}\"" : "Учесник \"{user}\"",
    "moderator" : "модератор",
    "bot" : "бот",
    "guest" : "гостин",
    "{time} talking …" : "{time} зборува …",
    "Raised their hand" : "Крена рака",
    "Joined with video" : "Приклучи се со видео",
    "Joined via phone" : "Приклучи се преку телефон",
    "Joined with audio" : "Приклучи се со звук",
    "Remove group and members" : "Избриши група и членови",
    "Remove participant" : "Отстрани учесник",
    "Do you really want to remove group \"{displayName}\" and its members from this conversation?" : "Дали навистина сакате да ја отстраните групата \"{displayName}\" и нејзините членови од овој разговор?",
    "Do you really want to remove team \"{displayName}\" and its members from this conversation?" : "Дали навистина сакате да го отстраните тимот \"{displayName}\" и неговите членови од овој разговор?",
    "Do you really want to remove {displayName} from this conversation?" : "Дали навистина сакате да го отстраните {displayName} од овој разговор?",
    "Notification was sent to {displayName}" : "Известување е испратено до {displayName}",
    "Could not send notification to {displayName}" : "Неможе да се ипспрати известување до {displayName}",
    "Permissions granted to {displayName}" : "Доделени дозволи на {displayName}",
    "Could not modify permissions for {displayName}" : "Неможе да се променат дозволите на {displayName}",
    "Permissions removed for {displayName}" : "Отстранети дозволи на {displayName}",
    "Permissions set to default for {displayName}" : "Доделени стандардни дозволи на {displayName}",
    "in the lobby" : "во лобито",
    "Move back to lobby" : "Врати се назад кон лобито",
    "Demote from moderator" : "Деградирај од модератор",
    "Promote to moderator" : "Промовирај во модератор",
    "Resend invitation" : "Повторно испратете ги поканите",
    "Send call notification" : "Испрати известување за повик",
    "Reset custom permissions" : "Ресетирај ги прилагодените дозволи",
    "Grant all permissions" : "Додели ги сите дозволи",
    "Remove all permissions" : "Отстрани ги сите дозволи",
    "Also ban from this conversation" : "Исто така, забрани пристап до овој разговор",
    "Internal note (reason to ban)" : "Внатрешна белешка (причина за забрана)",
    "Remove" : "Отстрани ",
    "Permissions modified for {displayName}" : "Дозволите на {displayName} се променети",
    "Add users or groups" : "Add users or groups",
    "Add users" : "Додади корисници",
    "Add groups" : "Додади групи",
    "Add other sources" : "Додади други извори",
    "Add emails" : "Додади Е-пошти",
    "Integrations" : "Интеграцијии",
    "Add federated users" : "Додади федерални корисници",
    "Searching …" : "Пребарување ...",
    "Search for more users" : "Пребарувај повеќе корисници",
    "Search or add participants" : "Барај или додади учесници",
    "Invitation was sent to {actorId}" : "Покана е испратена до {actorId}",
    "An error occurred while adding the participants" : "Настана грешка при обидот за додавање на учесници",
    "Participants" : "Учесници",
    "Participants ({count})" : "Учесници ({count})",
    "Open chat" : "Започни разговор",
    "You have new unread messages in the chat." : "Имате непрочитана порака во разговор.",
    "You have been mentioned in the chat." : "Бевте споменати во разговор.",
    "Chat" : "Разговор",
    "Details" : "Детали",
    "Shared items" : "Споделени предмети",
    "Search messages …" : "Пребарувај пораки ...",
    "No results found" : "Нема пронајдено резултати",
    "Load more results" : "Вчитај повеќе резултати",
    "Projects" : "Проекти",
    "No shared items" : "Нема споделени предмети",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "Link to a conversation" : "Линк до разговорот",
    "No open conversations found" : "Не се пронајдени отворени разговори",
    "Either there are no open conversations or you joined all of them." : "Или нема отворени разговори или си се придружил на сите.",
    "Search conversations or users" : "Пребарување на разговори или корисници",
    "Select conversation" : "Избери разговор",
    "Display name: {name}" : "Име: {name}",
    "Edit display name" : "Уреди име",
    "Display name (required)" : "Име (задолжително)",
    "Save name" : "Зачувај име",
    "I picked message bubbles" : "Избрав балончиња за пораки",
    "I picked the list style" : "Го одбрав стилот на листа",
    "Error while saving sounds setting" : "Грешка при зачувување на параметрите за звуци",
    "Compact conversations list" : "Компактна листа на разговори",
    "Chat appearance" : "Изглед на разговор",
    "Messages list" : "Листа со пораки",
    "Play sounds when participants join or leave a call" : "Репродуцирајте звуци кога учесниците се придружуваат или оставаат повик",
    "Currently not available on iPhone and iPad due to technical restrictions by the manufacturer" : "Моментално не е достапно на iPhone и iPad поради технички ограничувања од производителот",
    "Notification settings" : "Параметри за известување",
    "Sounds for chat and call notifications" : "Звуци за известувања за разговор и повици",
    "Default language" : "Стандарден јазик",
    "Select location for attachments" : "Избери локација за прилози",
    "Error while setting attachment folder" : "Грешка при поставување на папка за прилози",
    "Error while setting read status privacy" : "Грешка при зачувување на поставките за приватност",
    "Turn camera and microphone off by default" : "Исклучете ја камерата и микрофонот по дифолт",
    "Blur camera background by default" : "Заматете ја позадината на камерата по стандард",
    "Skip device preview before joining a call" : "Прескокни го прегледот на уредот пред да се придружиш на повик",
    "Camera will be turned off when joining. Always shown if recording consent is required." : "Камерата ќе биде исклучена при приклучување. Секогаш се прикажува ако е потребна согласност за снимање.",
    "Appearance & Sounds" : "Изглед & Звуци",
    "Privacy" : "Приватност",
    "Send read receipts" : "Испрати потврди за читање",
    "When off, all read statuses will be hidden" : "Кога е исклучено, сите статуси на читање ќе бидат скриени",
    "Share typing status" : "Сподели статус на пишување",
    "When off, all typing indicators will be hidden" : "Кога е исклучено, сите индикатори за пишување ќе бидат скриени",
    "Attachments folder" : "Папка со прилози",
    "Toggle full screen" : "Вклучи на цел екран",
    "Return to Home screen" : "Врати се на почетниот екран",
    "Search" : "Барај",
    "Shortcuts while in a chat" : "Кратенки додека сте во разговор",
    "Focus the chat input" : "Фокусирајте го курсорот на разговорот",
    "Unfocus the chat input to use shortcuts" : "Отстранаете го курсорот од разговорот за да користите кратенки преку тастатура",
    "Edit your last message" : "Уреди ја последната порака",
    "Shortcuts while in a call" : "Кратенки за време на повик",
    "Camera on and off" : "Вклучување и исклучување на камерата",
    "Microphone on and off" : "Вклучување и исклучување на микрофонот",
    "Raise or lower hand" : "Крени или спушти рака",
    "Push to talk or push to mute" : "Притисни за разговор или притисни за занемување",
    "Zoom-in / zoom-out a screen share" : "Зголемување / намалување на споделување на екран",
    "Start call silently" : "Започни товок повик",
    "Start call" : "Повик",
    "You will be able to join the call only after a moderator starts it." : "Ќе може да се придружите на повикот само откако модераторот ќе го започне.",
    "Raise hand" : "Крени рака",
    "Raise hand (R)" : "Крени рака (R)",
    "Lower hand" : "Спушти рака",
    "Lower hand (R)" : "Спушти рака (R)",
    "Send a reaction" : "Испрати реакција",
    "React with {reaction}" : "Реагирај со {reaction}",
    "_%n participant in call_::_%n participants in call_" : ["%n учесник во повикот","%n учесници во повикот"],
    "Scheduled messages" : "Закажани пораки",
    "You are not allowed to enable screensharing" : "Не сте овластени да го овозможите споделување на екранот",
    "No screensharing" : "Нема споделување на екран",
    "Screensharing options" : "Опции за споделување на екранот",
    "Enable screensharing" : "Овозможи споделување на екранот",
    "Bad sent video and screen quality." : "Лош квалитет на испратено видео и квалитет на екран.",
    "Bad sent screen quality." : "Лош квалитет на испратен екран.",
    "Bad sent video quality." : "Лош квалитет на испратено видео",
    "Bad sent audio, video and screen quality." : "Лош квалитет на испратено аудио, видео и квалитет на екран.",
    "Bad sent audio and screen quality." : "Лош квалитет на испратено аудио и квалитет на екран.",
    "Bad sent audio and video quality." : "Лош квалитет на испратено аудио и видео.",
    "Bad sent audio quality." : "Лош квалитет на испратено аудио",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "Вашата интернет-врска или компјутер се зафатени и другите учесници можеби нема да можат да ве гледаат. За да ја подобрите ситуацијата, обидете се да го оневозможите вашето видео додека правите споделување на екранот.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "Вашата интернет-врска или компјутер се зафатени и другите учесници можеби нема да можат да ве гледаат. За да ја подобрите ситуацијата, обидете се да го оневозможите вашето видео додека правите споделување на екранот.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Вашата интернет-врска или компјутер се зафатени и другите учесници можеби нема да можат да го видат вашиот екран.",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "Вашата интернет-врска или компјутер се зафатени и другите учесници можеби нема да можат да ве гледаат.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Вашата интернет-врска или компјутер се зафатени и другите учесници можеби нема да можат да ве разберат и видат. За да ја подобрите ситуацијата, обидете се да го оневозможите вашето видео додека правите споделување на екранот.",
    "Disable screenshare" : "Оневозможи споделување на екранот",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Вашата интернет-врска или компјутер се зафатени и другите учесници можеби нема да можат да ве разберат и видат. За да ја подобрите ситуацијата, обидете се да го оневозможите вашето видео.",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "Вашата интернет-врска или компјутер се зафатени и другите учесници можеби нема да можат да ве разберат.",
    "Screen sharing is not supported by your browser." : "Споделување на екранот не е поддржано од вашиот пребарувач.",
    "Screen sharing requires the page to be loaded through HTTPS." : "За безбедно споделување на екран треба да се поврзете преку безбедна врска HTTPS.",
    "Screensharing requires the page to be loaded through HTTPS." : "За безбедно споделување на екран треба да се поврзете преку безбедна врска HTTPS.",
    "An error occurred while starting screensharing." : "Настана грешка при обидот за стартување на споделување на екранот.",
    "Select virtual background" : "Избери виртуелна позадина",
    "Show your screen" : "Прикажи го вашиот екран",
    "Stop screensharing" : "Запри споделување на екран",
    "Mute others" : "Занеми ги останатите",
    "Download attendance list" : "Преземи листа со учесници",
    "Open Calendar" : "Отвори календар",
    "Remove participant {name}" : "Избриши учесник {name}",
    "Keep" : "Задржи",
    "Select a region" : "Изберете регион",
    "Scheduled {datetime}" : "Закажано {datetime}",
    "Scheduled for {datetime}" : "Закажано за {datetime}",
    "Search …" : "Пребарај ...",
    "Message without mention" : "Пораки без спомнувања",
    "Mention myself" : "Спомни се себеси",
    "Select a conversation" : "Избери разговор",
    "Select a mode" : "Избери режим",
    "The conversation does not exist" : "Разговорот не постои",
    "Join a conversation or start a new one!" : "Приклучи се кон разговор или започни нов!",
    "Join a conversation or start a new one" : "Приклучи се кон разговор или започни нов",
    "Another user" : "Друг корисник",
    "Nextcloud URL" : "Nextcloud URL",
    "Nextcloud user" : "Nextcloud корисник",
    "User password" : "Лозинка на корисник",
    "Talk conversation" : "Talk раговор",
    "Matrix server URL" : "Matrix сервер URL",
    "User" : "Корисник",
    "Matrix channel" : "Matrix канал",
    "Bot user name" : "Име на ботот",
    "Bot API key" : "API клуч за ботот",
    "API token" : "API токен",
    "Login" : "Login",
    "Nickname" : "Прекар",
    "Client ID" : "Клиент ИД",
    "Media" : "Медија",
    "Polls" : "Анкети",
    "Voice messages" : "Говорни пораки",
    "Locations" : "Локации",
    "Audio" : "Аудио",
    "Show all media" : "Прикажи ги сите медиа датотеки",
    "Show all files" : "Прикажи ги сите датотеки",
    "Show all polls" : "Прикажи ги сите анкети",
    "Show all voice messages" : "Прикажи ги сите говорни пораки",
    "Show all locations" : "Прикажи ги сите локации",
    "Show all audio" : "Прикажи ги сите звуци",
    "Show all other" : "Прикажи ги сите останати",
    "Group" : "Група",
    "Team" : "Тим",
    "You removed {user0} and {user1}" : "Ги избришавте {user0} и {user1}",
    "_You removed {user0}, {user1} and %n more participant_::_You removed {user0}, {user1} and %n more participants_" : ["Ги избришавте {user0}, {user1} и %n друг учесник","Ги избришавте {user0}, {user1} и %n други учесници"],
    "{actor} removed {user0} and {user1}" : "{actor} ги избриша {user0} и {user1}",
    "You: {lastMessage}" : "Ти: {lastMessage}",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Се обидувате да се приклучите на разговор додека имате активна сесија во друг прозорец или уред. Ова во моментов не е поддржано. Што сакаш да правиш?",
    "Leave this page" : "Напушти ја оваа страна",
    "Join here" : "Приклучи се овде",
    "Post to a conversation" : "Објави во разговор",
    "Post to conversation" : "Објава во разговор",
    "An error occurred while posting location to conversation" : "Настана грешка при обид за објава на локација во разговор",
    "Share to a conversation" : "Сподели во разговор",
    "Share to conversation" : "Споделено во разговор",
    "Error while clearing conversation history" : "Грешка при чистење на историјата во разговорот",
    "Error occurred while allowing guests" : "Настана грешка при обидот за овозможување на гостите",
    "Error occurred while disallowing guests" : "Настана грешка при обидот за оневозможување на гостите",
    "Conversation password has been saved" : "Лозинката за разговорот е зачувана",
    "Conversation picture set" : "Поставена е слика за разговорот",
    "Could not post message: {errorMessage}" : "Неможе да се испрати пораката: {errorMessage}",
    "Participant is banned successfully" : "Учесникот е успешно баниран",
    "An error occurred while fetching the participants" : "Настана грешка при обидот за вчитување на учесниците",
    "Could not send invitation to {actorId}" : "Неможе да се ипспрати покана до {actorId}",
    "Invitations sent" : "Поканите се испратени",
    "An error occurred while resetting the request for assistance" : "Се појави грешка при ресетирањето на барањето за помош",
    "{guest} (guest)" : "{guest} (guest)",
    "Poll draft has been saved" : "Нацрт анкетата е зачувана",
    "An error occurred while saving the draft" : "Настана грешка при зачувување на нацртот",
    "An error occurred while submitting your vote" : "Настана грешка при гласање",
    "An error occurred while ending the poll" : "Настана грешка при затварање на анкетата",
    "An error occurred while deleting the poll draft" : "Настана грешка при зачувување на нацртот за анкета",
    "Error while uploading file \"{fileName}\"" : "Грешка при прикачување на датотека \"{fileName}\"",
    "Not enough free space to upload file \"{fileName}\"" : "Нема доволно простор за да се прикачи датотеката \"{fileName}\"",
    "Error while sharing file" : "Грешка при споделување на датотека",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Прелистувачот што го користите не е целосно поддржан. Користете ја најновата верзија на Mozilla Firefox, Microsoft Edge, Google Chrome, Opera или Apple Safari.",
    "_%n hour_::_%n hours_" : ["1 час","%n часа"],
    "_%n day_::_%n days_" : ["1 ден","%n дена"],
    "_%n week_::_%n weeks_" : ["1 недела","%n недели"],
    "Later today – {timeLocale}" : "Денес покасно – {timeLocale}",
    "Tomorrow – {timeLocale}" : "Утре – {timeLocale}",
    "This weekend – {timeLocale}" : "Овој викенд – {timeLocale}",
    "Next week – {timeLocale}" : "Следна недела – {timeLocale}",
    "Message link copied to clipboard" : "Линкот до пораката е копиран во клипборд",
    "Conversation link copied to clipboard" : "Линк до разговорот е копиран во клипборд",
    "Error while parsing a PROPFIND error" : "Грешка при обработка на PROPFIND грешката",
    "Please reload the page." : "Превчитајте ја страницата.",
    "Do not disturb" : "Не вознемирувај",
    "Away" : "Далеку",
    "Microphone {number}" : "Микрофон {number}",
    "Camera {number}" : "Камера {number}",
    "Speaker {number}" : "Зборуваат {number}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Највероватно зборувавте додека вашиот микрофон е занемен (Mute), од-немете го микрофонот за да можете да бидете слушнати",
    "Access to microphone & camera is only possible with HTTPS" : "Пристап до микрофонот и камерата е возможен само преку безбедноска врска HTTPS",
    "Access to microphone & camera was denied" : "Нема пристап до микрофонот и камерата",
    "WebRTC is not supported in your browser" : "Вашиот прелистувач не поддржува WebRTC",
    "Please use a different browser like Firefox or Chrome" : "Користете друг прелистувач како Firefox или Chrome",
    "Error while accessing microphone & camera" : "Грешка при пристап до микрофон и камера",
    "%s Talk on your mobile devices" : "%s Разговор на вашиоте мобилни уреди",
    "Join conversations at any time, anywhere, on any device." : "Придружете се на разговор во секое време, каде и да било, на кој било уред.",
    "Android app" : "Android апликација",
    "iOS app" : "iOS апликација",
    "__language_name__" : "Македонски",
    "Tasks" : "Задачи",
    "Talk to %s" : "Разговор со %s",
    "Talk conversation for event" : "Talk разговор за настанот",
    "{notify_push} is not installed, this might lead to performance issues when using desktop clients." : "{notify_push} не е инсталиран, ова може да доведе до проблеми со перформансите при користење на десктоп клиенти.",
    "Schedule a meeting from your calendar. A Talk conversation needs to be set as location to show up here" : "Закажете состанок од вашиот календар. Разговорот треба да биде поставен како локација за да се прикаже тука.",
    "Set reminder for later today" : "Постави потсетник за денес покасно",
    "Set reminder for tomorrow" : "Постави потсетник за утре",
    "Set reminder for this weekend" : "Постави потсетник за овој викенд",
    "Set reminder for next week" : "Постави потсетник за наредната недела",
    "Open poll • You voted already" : "Отворена анкета •Имате гласано",
    "Open poll • Click to vote" : "Отворена анкета • Кликни за да гласаш",
    "Poll • Ended" : "Анкета • Завршена",
    "_Poll results • %n vote_::_Poll results • %n votes_" : ["Резултати од анкетата • %n глас","Резултати од анкетата • %n гласови"],
    "_Open poll • %n vote_::_Open poll • %n votes_" : ["Отворена анкета • %n глас","Отворена анкета • %n гласови"],
    "Submit vote" : "Гласај",
    "Your privacy setting has been saved" : "Вашите поставки за приватност се зачувани",
    "Failed to save sounds setting" : "Неуспешно зачувување на параметрите за звуци",
    "Sounds setting saved" : "Параматрите за звуци се зачувани",
    "Always shown if recording consent is required" : "Секогаш се прикажува ако е потребна согласност за снимање",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Се приклучивте на разговорот во друг прозорец или уред. Ова во моментов не е поддржано, па оваа сесија е затворена.",
    "I picked list style" : "Избрав стил на листа",
    "Hey! Are you using Talk in list style or with message bubbles?" : "Еј! Дали го користиш Talk во стил на листа или со балончиња за пораки?"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
