<?php

declare(strict_types=1);
/**
 * SPDX-FileCopyrightText: 2023 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */

/** @var \OCP\IL10N $l */
?>

<div id="admin_settings">
	<div class="settings-section-placeholder"></div>
	<div class="settings-section-placeholder"></div>
	<div class="settings-section-placeholder"></div>
	<div class="settings-section-placeholder"></div>
	<div class="settings-section-placeholder"></div>
	<div class="settings-section-placeholder"></div>
	<div class="settings-section-placeholder"></div>
	<div class="settings-section-placeholder"></div>
	<div class="settings-section-placeholder"></div>
	<div class="settings-section-placeholder"></div>
	<div class="settings-section-placeholder"></div>
	<div class="settings-section-placeholder"></div>
</div>
