.floating-call__container[data-v-38c66617]{z-index:2000;pointer-events:none;position:fixed;inset:0}.floating-call__container .floating-call__bar[data-v-38c66617],.floating-call__container .floating-call__bar[data-v-38c66617] *,.floating-call__container .floating-call__app[data-v-38c66617],.floating-call__container .floating-call__app[data-v-38c66617] *{pointer-events:auto;box-sizing:border-box}[data-v-38c66617] div{cursor:inherit}.floating-call[data-v-38c66617]{border-radius:var(--border-radius-element);box-shadow:0 0 4px 0 var(--color-box-shadow)}.floating-call[data-v-38c66617]:hover{cursor:grab}.floating-call--dragging[data-v-38c66617]{cursor:grabbing}.floating-call__bar[data-v-38c66617]{grid-template-columns:1fr var(--default-clickable-area) 1fr;gap:var(--default-grid-baseline);height:calc(var(--default-clickable-area) + var(--default-grid-baseline));padding:calc(.5*var(--default-grid-baseline)) calc(2*var(--default-grid-baseline));color:var(--color-primary-text);background-color:var(--color-primary);border-start-start-radius:var(--border-radius-element);border-start-end-radius:var(--border-radius-element);align-items:center;display:grid}.floating-call__name[data-v-38c66617]{white-space:nowrap;text-overflow:ellipsis;font-weight:700;overflow:hidden}.floating-call__controls[data-v-38c66617]{justify-content:flex-end;gap:var(--default-grid-baseline);display:flex}.floating-call__app[data-v-38c66617]{background:#000000b3;border-end-end-radius:var(--border-radius-element);border-end-start-radius:var(--border-radius-element);flex-direction:column;justify-content:center;width:100%;height:calc(100% - 34px);display:flex;position:relative;overflow:hidden}
/*# sourceMappingURL=src_FloatingCallOverlay_vue.chunk.css.map*/