OC.L10N.register(
    "spreed",
    {
    "(Duration %s)" : "(ხანგრძლივობა %s)",
    "You attended a call with {user1}" : "თქვენ დაესწარით ზარს მომხმარებელთან {user1}",
    "_%n guest_::_%n guests_" : ["%n სტუმრები","%n სტუმრები"],
    "You attended a call with {user1} and {user2}" : "თქვენ დაესწარით ზარს მომხმარებლებთან {user1} და {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "თქვენ დაესწარით ზარს მომხმარებლებთან {user1}, {user2} და {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "თქვენ დაესწარით ზარს მომხმარებლებთან {user1}, {user2}, {user3} და {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "თქვენ დაესწარით ზარს მომხმარებლებთან {user1}, {user2}, {user3}, {user4} და {user5}",
    "_%n other_::_%n others_" : ["%n სხვა","%n სხვა"],
    "{actor} invited you to {call}" : "მოწვევა {call} ზარზე მომხმარებლისგან {actor}",
    "Talk" : "საუბარი",
    "Guest" : "სტუმარი",
    "Administration" : "ადმინისტრაცია",
    "System" : "სისტემა",
    "File not found" : "ფაილი ვერ იქნა ნაპოვნი",
    "File is too big" : "ფაილი ზედმეტად დიდია",
    "Invalid file provided" : "არასწორი ფაილი",
    "Invalid image" : "არასწორი სურათი",
    "Unknown filetype" : "ამოუცნობი ფაილის ტიპი",
    "Description" : "აღწერილობა",
    "Accept" : "მიღება",
    "Decline" : "ურაყოფა",
    "New message" : "ახალი წერილი",
    "Join call" : "შეუერთდით ზარს",
    "A group call has started in {call}" : "ჯგუფური ზარი დაიწყო {call}-ში",
    "Open settings" : "პარამეტრების გახსნა",
    "Default" : "საწყისი",
    "Avatar image is not square" : "ავატარის სურათი არაა კვადრატი",
    "Favorites" : "რჩეულები",
    "Other" : "სხვა",
    "Federation" : "ფედერაცია",
    "Invalid date, date format must be YYYY-MM-DD" : "არასწორი თარიღი, თარიღის ფორმატი უნდა იყოს წწწწ-თთ-დდ",
    "Leave call" : "ზარის დატოვება",
    "The password is wrong. Try again." : "პაროლი არასწორია. სცადეთ ახლიდან.",
    "Password" : "პაროლი",
    "Submit" : "გაგზავნა",
    "Everyone" : "ყველა",
    "Save changes" : "ცვილებების შენახვა",
    "Saved!" : "შენახულია!",
    "Limit to groups" : "ლიმიტი ჯგუფებზე",
    "Enabled" : "მოქმედია",
    "Disabled" : "არაა მოქმედი",
    "Name" : "სახელი",
    "Permissions" : "უფლებები",
    "General settings" : "მთავარი პარამეტრები",
    "Enable encryption" : "შიფრაციის ამოქმედება",
    "Pending" : "მოლოდინში",
    "Error" : "შეცდომა",
    "Blocked" : "დაბლოკილია",
    "Expired" : "გაუქმდა",
    "Never" : "არასდროს",
    "Language" : "ენა",
    "Country" : "ქვეყანა",
    "Status" : "სტატუსი",
    "Created at" : "შეიქმნა",
    "Yes" : "დიახ",
    "Validate SSL certificate" : "SSL სერტიფიკატის ვალიდაცია",
    "Shared secret" : "გაზიარებული საიდუმლო",
    "STUN servers" : "STUN სერვერები",
    "A STUN server is used to determine the public IP address of participants behind a router." : "STUN სერვერი როუტერს მიღმა მყოფი მონაწილეების ღია IP მისამართების დადგენისთვის.",
    "TURN server protocols" : "TURN სერვერის პროტოკოლები",
    "OK" : "კარგი",
    "Checking …" : "მოწმდება ...",
    "Confirm" : "დადასტურება",
    "Reset" : "საწყის მდოგმარეობაში დაბრუნება",
    "Cancel" : "უარყოფა",
    "Back" : "უკან",
    "Calendar" : "კალენდარი",
    "Attendees" : "დამსწრეები",
    "Save" : "შენახვა",
    "No results" : "შედეგები არაა",
    "Done" : "დასრულდა",
    "Grid view" : "ბადისებური ხედი",
    "Waiting for others to join the call …" : "ზარში შემოსვლისთვის ველოდებით სხვებს …",
    "You can invite others in the participant tab of the sidebar" : "შეგიძლიათ სხვები მოიწვიოთ გვერდით ბარში, მონაწილებიის ტაბულით",
    "Share this link to invite others!" : "სხვების მოსაწვევად გააზიარეთ ეს ბმული!",
    "Copy link" : "ბმულის კოპირება",
    "Mute audio" : "ხმის ჩახშობა",
    "None" : "არც ერთი",
    "Disable video" : "ვიდეოს გათიშვა",
    "Enable video" : "ვიდეოს ამოქმედება",
    "You" : "თქვენ",
    "Show screen" : "ეკრანის ჩვენება",
    "Collapse" : "აკეცვა",
    "Favorite" : "რჩეული",
    "Hide details" : "დეტალების დამალვა",
    "Disable" : "გამორთვა",
    "Choose" : "აირჩიეთ",
    "Restricted" : "აკრძალული",
    "Personal" : "პირადი",
    "Password protection" : "პაროლით თავდაცვა",
    "Set a password" : "პაროლის დაყენება",
    "Edit" : "შეცვლა",
    "Delete" : "წაშლა",
    "Log content" : "ლოგის მოცულობა",
    "Notifications" : "შეტყობინებები",
    "Log in" : "შესვლა",
    "Mark as read" : "წაკითხულად მონიშვნა",
    "Mark as unread" : "წაუკითხავად მონიშვნა",
    "Remove from favorites" : "რჩეულებიდან ამოშლა",
    "Add to favorites" : "რჩეულებში დამატება",
    "Tags" : "ტეგები",
    "Home" : "სახლი",
    "Alphabetically" : "ანბანის მიხედვით",
    "Users" : "მომხმარებლები",
    "Groups" : "ჯგუფები",
    "Advanced" : "მოწინავე",
    "Devices" : "მოწყობილობები",
    "Upload" : "ატვირთვა",
    "Files" : "ფაილები",
    "24 hours" : "24 საათი",
    "Reply" : "პასუხი",
    "More actions" : "მეტი ქმედება",
    "Translate" : "გადათარგმნეთ",
    "Dismiss" : "დათხოვნა",
    "Message sent" : "წერილი გაგზავნილია",
    "Contact" : "კონტაქტი",
    "You voted" : "თქვენ მიეცით ხმა",
    "Create new poll" : "ახალი გამოკითხვის შექმნა",
    "Send" : "გაგზავნა",
    "Create poll" : "გამოკითხვის შექმნა",
    "Settings" : "პარამეტრები",
    "moderator" : "მოდერატორი",
    "Remove participant" : "მონაწილის ამოშლა",
    "Demote from moderator" : "ჩამოიქვეითება მოდერატორობისგან",
    "Promote to moderator" : "დაწინაურება მოდერატორობაზე",
    "Add users or groups" : "დაამატეთ მომხმარებლები ან ჯგუფები",
    "Participants" : "მონაწილეები",
    "Chat" : "ჩეთი",
    "Details" : "დეტალები",
    "Privacy" : "კონფიდენციალურობა",
    "Search" : "ძიება",
    "Screensharing options" : "ეკრანების გაზიარების პარამეტრები",
    "Enable screensharing" : "ეკრანების გაზიარების ნების დართვა",
    "Screensharing requires the page to be loaded through HTTPS." : "ეკრანების გაზიარება საჭიროებს გვერდის HTTPS პროტოკოლით ჩატვირთვას.",
    "An error occurred while starting screensharing." : "ეკრანის გაზიარებისას წარმოიშვა შეცდომა.",
    "Show your screen" : "თქვენი ეკრანის ჩვენება",
    "Stop screensharing" : "ეკრანის გაზიარების გათიშვა",
    "User" : "მომხმარებელი",
    "API token" : "API ტოკენი",
    "Login" : "ავტორიზაცია",
    "Nickname" : "ნიკნეიმი",
    "Client ID" : "კლიენტის ID",
    "Polls" : "გამოკითხვები",
    "Audio" : "აუდიო",
    "Group" : "ჯგუფი",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Please reload the page." : "გთხოვთ გადატვირთოთ გვერდი.",
    "Access to microphone & camera is only possible with HTTPS" : "წვდომა მიკროფონთან და კამერასთან მხარდაჭერილია მხოლოდ HTTPS პროტოკოლით",
    "Access to microphone & camera was denied" : "წვდომა მიკროფონზე და კამერაზე აიკრძალა",
    "WebRTC is not supported in your browser" : "თქვენი ბრაუზერი WebRTC-ს არ უჭერს მხარს",
    "Please use a different browser like Firefox or Chrome" : "გთხოვთ გამოიყენოთ სხვა ბრაუზერი, Firefox-ი ან Chrome-ი",
    "Error while accessing microphone & camera" : "მიკროფონზე და კამერაზე წვდომისას წარმოიშვა შეცდომა",
    "Android app" : "Android აპლიკაცია",
    "iOS app" : "iOS აპლიკაცია",
    "__language_name__" : "ქართული",
    "Tasks" : "დავალებები",
    "Notes" : "ჩანაწერები",
    "Talk to %s" : "საუბარი მომხმარებელთან %s"
},
"nplurals=2; plural=(n!=1);");
