.material-design-icon[data-v-8609a4c1]{justify-content:center;place-self:center;align-items:center;display:flex}.empty-content[data-v-8609a4c1]{padding:var(--default-grid-baseline);flex-direction:column;flex-grow:1;justify-content:center;align-items:center;display:flex}.modal-wrapper .empty-content[data-v-8609a4c1]{margin-top:5vh;margin-bottom:5vh}.empty-content__icon[data-v-8609a4c1]{opacity:.4;background-position:50%;background-repeat:no-repeat;background-size:64px;justify-content:center;align-items:center;width:64px;height:64px;margin:0 auto 15px;display:flex}.empty-content__icon[data-v-8609a4c1] svg{width:64px!important;max-width:64px!important;height:64px!important;max-height:64px!important}.empty-content__name[data-v-8609a4c1]{text-align:center;font-weight:var(--font-weight-heading,bold);margin-bottom:10px;font-size:20px;line-height:30px}.empty-content__description[data-v-8609a4c1]{color:var(--color-text-maxcontrast);text-align:center;text-wrap-style:balance}.empty-content__action[data-v-8609a4c1]{margin-top:8px}.modal-wrapper .empty-content__action[data-v-8609a4c1]{margin-top:20px;display:flex}.material-design-icon[data-v-7cec4a3e]{justify-content:center;place-self:center;align-items:center;display:flex}.vue-crumb[data-v-7cec4a3e]{height:var(--default-clickable-area);background-image:none;padding:0;display:inline-flex}.vue-crumb[data-v-7cec4a3e]:last-child{min-width:0}.vue-crumb:last-child .vue-crumb__separator[data-v-7cec4a3e],.vue-crumb--hidden[data-v-7cec4a3e]{display:none}.vue-crumb__separator[data-v-7cec4a3e]{color:var(--color-text-maxcontrast);padding:0}.vue-crumb.vue-crumb--hovered[data-v-7cec4a3e] .button-vue{background-color:var(--color-background-dark);color:var(--color-main-text)}.vue-crumb[data-v-7cec4a3e]:not(:last-child) .button-vue{color:var(--color-text-maxcontrast)}.vue-crumb[data-v-7cec4a3e]:not(:last-child) .button-vue:hover,.vue-crumb[data-v-7cec4a3e]:not(:last-child) .button-vue:focus{background-color:var(--color-background-dark);color:var(--color-main-text)}.vue-crumb[data-v-7cec4a3e]:not(:last-child) .button-vue__text{font-weight:var(--font-weight-element,normal)}.vue-crumb[data-v-7cec4a3e] .button-vue__text{margin:0}.vue-crumb[data-v-7cec4a3e]:not(.dropdown) .action-item{max-width:100%}.vue-crumb[data-v-7cec4a3e]:not(.dropdown) .action-item .button-vue{max-width:100%;padding:0 4px 0 16px}.vue-crumb[data-v-7cec4a3e]:not(.dropdown) .action-item .button-vue__wrapper{flex-direction:row-reverse}.vue-crumb[data-v-7cec4a3e]:not(.dropdown) .action-item.action-item--open .action-item__menutoggle{background-color:var(--color-background-dark);color:var(--color-main-text)}.material-design-icon[data-v-0015282c]{justify-content:center;place-self:center;align-items:center;display:flex}.breadcrumb[data-v-0015282c]{flex-grow:1;align-items:center;width:100%;display:inline-flex}.breadcrumb--collapsed[data-v-0015282c] .vue-crumb:last-child{min-width:100px}.breadcrumb nav[data-v-0015282c]{flex-shrink:1;min-width:0}.breadcrumb .breadcrumb__crumbs[data-v-0015282c]{max-width:100%}.breadcrumb .breadcrumb__crumbs[data-v-0015282c],.breadcrumb .breadcrumb__actions[data-v-0015282c]{display:inline-flex}
/*# sourceMappingURL=node_modules_nextcloud_vue_dist_assets_NcBreadcrumb-BxhZKQlW_css-node_modules_nextcloud_vue_d-9574b2.chunk.css.map*/