OC.L10N.register(
    "spreed",
    {
    "a conversation" : "a conversation",
    "(Duration %s)" : "(Duration %s)",
    "You attended a call with {user1}" : "You attended a call with {user1}",
    "_%n guest_::_%n guests_" : ["%n guest","%n guests"],
    "You attended a call with {user1} and {user2}" : "You attended a call with {user1} and {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "You attended a call with {user1}, {user2} and {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "You attended a call with {user1}, {user2}, {user3} and {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}",
    "_%n other_::_%n others_" : ["%n other","%n others"],
    "{actor} invited you to {call}" : "{actor} invited you to {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>",
    "Other activities" : "Other activities",
    "Talk" : "Talk",
    "Guest" : "Guest",
    "## Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "## Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk.",
    "## New in Talk %s" : "## New in Talk %s",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge and Safari can now be used to participate in audio and video calls",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- You can now notify all participants by posting \"@all\" into the chat",
    "- With the \"arrow-up\" key you can repost your last message" : "- With the \"arrow-up\" key you can repost your last message",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some",
    "- With projects you can create quick links between conversations, files and other items" : "- With projects you can create quick links between conversations, files and other items",
    "- You can now mention guests in the chat" : "- You can now mention guests in the chat",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- You can now directly reply to messages giving the other users more context what your message is about",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- You can now add custom user groups to conversations when the circles app is installed",
    "- Check out the new grid and call view" : "- Check out the new grid and call view",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- You can now upload and drag'n'drop files directly from your device into the chat",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- Shared files are now opened directly inside the chat view with the viewer apps",
    "- You can now search for chats and messages in the unified search in the top bar" : "- You can now search for chats and messages in the unified search in the top bar",
    "- Spice up your messages with emojis from the emoji picker" : "- Spice up your messages with emojis from the emoji picker",
    "- You can now change your camera and microphone while being in a call" : "- You can now change your camera and microphone while being in a call",
    "- Give your conversations some context with a description and open it up so logged in users can find it and join themselves" : "- Give your conversations some context with a description and open it up so logged in users can find it and join themselves",
    "- See a read status and send failed messages again" : "- See a read status and send failed messages again",
    "- Raise your hand in a call with the R key" : "- Raise your hand in a call with the R key",
    "- Join the same conversation and call from multiple devices" : "- Join the same conversation and call from multiple devices",
    "- Send voice messages, share your location or contact details" : "- Send voice messages, share your location or contact details",
    "- Add groups to a conversation and new group members will automatically be added as participants" : "- Add groups to a conversation and new group members will automatically be added as participants",
    "- A preview of your audio and video is shown before joining a call" : "- A preview of your audio and video is shown before joining a call",
    "- You can now blur your background in the newly designed call view" : "- You can now blur your background in the newly designed call view",
    "- Moderators can now assign general and individual permissions to participants" : "- Moderators can now assign general and individual permissions to participants",
    "- You can now react to chat messages" : "- You can now react to chat messages",
    "- In the sidebar you can now find an overview of the latest shared items" : "- In the sidebar you can now find an overview of the latest shared items",
    "- Use a poll to collect the opinions of others or settle on a date" : "- Use a poll to collect the opinions of others or settle on a date",
    "- Configure an expiration time for chat messages" : "- Configure an expiration time for chat messages",
    "- Start calls without notifying others in big conversations. You can send individual call notifications once the call has started." : "- Start calls without notifying others in big conversations. You can send individual call notifications once the call has started.",
    "- Send chat messages without notifying the recipients in case it is not urgent" : "- Send chat messages without notifying the recipients in case it is not urgent",
    "- Emojis can now be autocompleted by typing a \":\"" : "- Emojis can now be autocompleted by typing a \":\"",
    "- Link various items using the new smart-picker by typing a \"/\"" : "- Link various items using the new smart-picker by typing a \"/\"",
    "- Conversations can now have an avatar or emoji as icon" : "- Conversations can now have an avatar or emoji as icon",
    "- Virtual backgrounds are now available in addition to the blurred background in video calls" : "- Virtual backgrounds are now available in addition to the blurred background in video calls",
    "- Reactions are now available during calls" : "- Reactions are now available during calls",
    "- Typing indicators show which users are currently typing a message" : "- Typing indicators show which users are currently typing a message",
    "- Groups can now be mentioned in chats" : "- Groups can now be mentioned in chats",
    "- Call recordings are automatically transcribed if a transcription provider app is registered" : "- Call recordings are automatically transcribed if a transcription provider app is registered",
    "- Chat messages can be translated if a translation provider app is registered" : "- Chat messages can be translated if a translation provider app is registered",
    "- **Markdown** can now be used in _chat_ messages" : "- **Markdown** can now be used in _chat_ messages",
    "- Webhooks are now available to implement bots. See the documentation for more information https://nextcloud-talk.readthedocs.io/en/latest/bot-list/" : "- Webhooks are now available to implement bots. See the documentation for more information https://nextcloud-talk.readthedocs.io/en/latest/bot-list/",
    "- Set a reminder on a chat message to be notified later again" : "- Set a reminder on a chat message to be notified later again",
    "- Use the **Note to self** conversation to take notes and share information between your devices" : "- Use the **Note to self** conversation to take notes and share information between your devices",
    "- Captions allow to send a message with a file at the same time" : "- Captions allow to send a message with a file at the same time",
    "- Video of the speaker is now visible while sharing the screen and call reactions are animated" : "- Video of the speaker is now visible while sharing the screen and call reactions are animated",
    "Talk updates ✅" : "Talk updates ✅",
    "Reaction deleted by author" : "Reaction deleted by author",
    "{actor} created the conversation" : "{actor} created the conversation",
    "You created the conversation" : "You created the conversation",
    "System created the conversation" : "System created the conversation",
    "An administrator created the conversation" : "An administrator created the conversation",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "You renamed the conversation from \"%1$s\" to \"%2$s\"",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"",
    "{actor} set the description" : "{actor} set the description",
    "You set the description" : "You set the description",
    "An administrator set the description" : "An administrator set the description",
    "{actor} removed the description" : "{actor} removed the description",
    "You removed the description" : "You removed the description",
    "An administrator removed the description" : "An administrator removed the description",
    "You started a call" : "You started a call",
    "{actor} started a call" : "{actor} started a call",
    "{actor} joined the call" : "{actor} joined the call",
    "You joined the call" : "You joined the call",
    "{actor} left the call" : "{actor} left the call",
    "You left the call" : "You left the call",
    "{actor} unlocked the conversation" : "{actor} unlocked the conversation",
    "You unlocked the conversation" : "You unlocked the conversation",
    "An administrator unlocked the conversation" : "An administrator unlocked the conversation",
    "{actor} locked the conversation" : "{actor} locked the conversation",
    "You locked the conversation" : "You locked the conversation",
    "An administrator locked the conversation" : "An administrator locked the conversation",
    "{actor} limited the conversation to the current participants" : "{actor} limited the conversation to the current participants",
    "You limited the conversation to the current participants" : "You limited the conversation to the current participants",
    "An administrator limited the conversation to the current participants" : "An administrator limited the conversation to the current participants",
    "{actor} opened the conversation to registered users" : "{actor} opened the conversation to registered users",
    "You opened the conversation to registered users" : "You opened the conversation to registered users",
    "An administrator opened the conversation to registered users" : "An administrator opened the conversation to registered users",
    "{actor} opened the conversation to registered users and users created with the Guests app" : "{actor} opened the conversation to registered users and users created with the Guests app",
    "You opened the conversation to registered users and users created with the Guests app" : "You opened the conversation to registered users and users created with the Guests app",
    "An administrator opened the conversation to registered users and users created with the Guests app" : "An administrator opened the conversation to registered users and users created with the Guests app",
    "The conversation is now open to everyone" : "The conversation is now open to everyone",
    "{actor} opened the conversation to everyone" : "{actor} opened the conversation to everyone",
    "You opened the conversation to everyone" : "You opened the conversation to everyone",
    "{actor} restricted the conversation to moderators" : "{actor} restricted the conversation to moderators",
    "You restricted the conversation to moderators" : "You restricted the conversation to moderators",
    "{actor} started breakout rooms" : "{actor} started breakout rooms",
    "You started breakout rooms" : "You started breakout rooms",
    "{actor} stopped breakout rooms" : "{actor} stopped breakout rooms",
    "You stopped breakout rooms" : "You stopped breakout rooms",
    "{actor} allowed guests" : "{actor} allowed guests",
    "You allowed guests" : "You allowed guests",
    "An administrator allowed guests" : "An administrator allowed guests",
    "{actor} disallowed guests" : "{actor} disallowed guests",
    "You disallowed guests" : "You disallowed guests",
    "An administrator disallowed guests" : "An administrator disallowed guests",
    "{actor} set a password" : "{actor} set a password",
    "You set a password" : "You set a password",
    "An administrator set a password" : "An administrator set a password",
    "{actor} removed the password" : "{actor} removed the password",
    "You removed the password" : "You removed the password",
    "An administrator removed the password" : "An administrator removed the password",
    "{actor} added {user}" : "{actor} added {user}",
    "You joined the conversation" : "You joined the conversation",
    "{actor} joined the conversation" : "{actor} joined the conversation",
    "You added {user}" : "You added {user}",
    "{actor} added you" : "{actor} added you",
    "An administrator added you" : "An administrator added you",
    "An administrator added {user}" : "An administrator added {user}",
    "You left the conversation" : "You left the conversation",
    "{actor} left the conversation" : "{actor} left the conversation",
    "{actor} removed {user}" : "{actor} removed {user}",
    "You removed {user}" : "You removed {user}",
    "{actor} removed you" : "{actor} removed you",
    "An administrator removed you" : "An administrator removed you",
    "An administrator removed {user}" : "An administrator removed {user}",
    "{actor} invited {federated_user}" : "{actor} invited {federated_user}",
    "You invited {federated_user}" : "You invited {federated_user}",
    "An administrator invited {federated_user}" : "An administrator invited {federated_user}",
    "{federated_user} accepted the invitation" : "{federated_user} accepted the invitation",
    "{actor} removed {federated_user}" : "{actor} removed {federated_user}",
    "You removed {federated_user}" : "You removed {federated_user}",
    "An administrator removed {federated_user}" : "An administrator removed {federated_user}",
    "{federated_user} declined the invitation" : "{federated_user} declined the invitation",
    "{actor} added group {group}" : "{actor} added group {group}",
    "You added group {group}" : "You added group {group}",
    "An administrator added group {group}" : "An administrator added group {group}",
    "{actor} removed group {group}" : "{actor} removed group {group}",
    "You removed group {group}" : "You removed group {group}",
    "An administrator removed group {group}" : "An administrator removed group {group}",
    "{actor} added {phone}" : "{actor} added {phone}",
    "You added {phone}" : "You added {phone}",
    "An administrator added {phone}" : "An administrator added {phone}",
    "{actor} removed {phone}" : "{actor} removed {phone}",
    "You removed {phone}" : "You removed {phone}",
    "An administrator removed {phone}" : "An administrator removed {phone}",
    "{actor} promoted {user} to moderator" : "{actor} promoted {user} to moderator",
    "You promoted {user} to moderator" : "You promoted {user} to moderator",
    "{actor} promoted you to moderator" : "{actor} promoted you to moderator",
    "An administrator promoted you to moderator" : "An administrator promoted you to moderator",
    "An administrator promoted {user} to moderator" : "An administrator promoted {user} to moderator",
    "{actor} demoted {user} from moderator" : "{actor} demoted {user} from moderator",
    "You demoted {user} from moderator" : "You demoted {user} from moderator",
    "{actor} demoted you from moderator" : "{actor} demoted you from moderator",
    "An administrator demoted you from moderator" : "An administrator demoted you from moderator",
    "An administrator demoted {user} from moderator" : "An administrator demoted {user} from moderator",
    "{actor} shared a file which is no longer available" : "{actor} shared a file which is no longer available",
    "You shared a file which is no longer available" : "You shared a file which is no longer available",
    "The shared location is malformed" : "The shared location is malformed",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} set up Matterbridge to synchronize this conversation with other chats",
    "You set up Matterbridge to synchronize this conversation with other chats" : "You set up Matterbridge to synchronize this conversation with other chats",
    "{actor} updated the Matterbridge configuration" : "{actor} updated the Matterbridge configuration",
    "You updated the Matterbridge configuration" : "You updated the Matterbridge configuration",
    "{actor} removed the Matterbridge configuration" : "{actor} removed the Matterbridge configuration",
    "You removed the Matterbridge configuration" : "You removed the Matterbridge configuration",
    "{actor} started Matterbridge" : "{actor} started Matterbridge",
    "You started Matterbridge" : "You started Matterbridge",
    "{actor} stopped Matterbridge" : "{actor} stopped Matterbridge",
    "You stopped Matterbridge" : "You stopped Matterbridge",
    "{actor} deleted a message" : "{actor} deleted a message",
    "You deleted a message" : "You deleted a message",
    "{actor} deleted a reaction" : "{actor} deleted a reaction",
    "You deleted a reaction" : "You deleted a reaction",
    "_You set the message expiration to %n week_::_You set the message expiration to %n weeks_" : ["You set the message expiration to %n week","You set the message expiration to %n weeks"],
    "_You set the message expiration to %n day_::_You set the message expiration to %n days_" : ["You set the message expiration to %n day","You set the message expiration to %n days"],
    "_You set the message expiration to %n hour_::_You set the message expiration to %n hours_" : ["You set the message expiration to %n hour","You set the message expiration to %n hours"],
    "_You set the message expiration to %n minute_::_You set the message expiration to %n minutes_" : ["You set the message expiration to %n minute","You set the message expiration to %n minutes"],
    "_{actor} set the message expiration to %n week_::_{actor} set the message expiration to %n weeks_" : ["{actor} set the message expiration to %n week","{actor} set the message expiration to %n weeks"],
    "_{actor} set the message expiration to %n day_::_{actor} set the message expiration to %n days_" : ["{actor} set the message expiration to %n day","{actor} set the message expiration to %n days"],
    "_{actor} set the message expiration to %n hour_::_{actor} set the message expiration to %n hours_" : ["{actor} set the message expiration to %n hour","{actor} set the message expiration to %n hours"],
    "_{actor} set the message expiration to %n minute_::_{actor} set the message expiration to %n minutes_" : ["{actor} set the message expiration to %n minute","{actor} set the message expiration to %n minutes"],
    "{actor} disabled message expiration" : "{actor} disabled message expiration",
    "You disabled message expiration" : "You disabled message expiration",
    "{actor} cleared the history of the conversation" : "{actor} cleared the history of the conversation",
    "You cleared the history of the conversation" : "You cleared the history of the conversation",
    "{actor} set the conversation picture" : "{actor} set the conversation picture",
    "You set the conversation picture" : "You set the conversation picture",
    "{actor} removed the conversation picture" : "{actor} removed the conversation picture",
    "You removed the conversation picture" : "You removed the conversation picture",
    "{actor} ended the poll {poll}" : "{actor} ended the poll {poll}",
    "You ended the poll {poll}" : "You ended the poll {poll}",
    "{actor} started the video recording" : "{actor} started the video recording",
    "You started the video recording" : "You started the video recording",
    "{actor} stopped the video recording" : "{actor} stopped the video recording",
    "You stopped the video recording" : "You stopped the video recording",
    "{actor} started the audio recording" : "{actor} started the audio recording",
    "You started the audio recording" : "You started the audio recording",
    "{actor} stopped the audio recording" : "{actor} stopped the audio recording",
    "You stopped the audio recording" : "You stopped the audio recording",
    "The recording failed" : "The recording failed",
    "Someone voted on the poll {poll}" : "Someone voted on the poll {poll}",
    "Message deleted by author" : "Message deleted by author",
    "Message deleted by {actor}" : "Message deleted by {actor}",
    "Message deleted by you" : "Message deleted by you",
    "Deleted user" : "Deleted user",
    "Unknown number" : "Unknown number",
    "Administration" : "Administration",
    "System" : "System",
    "%s (guest)" : "%s (guest)",
    "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["{actor} ended the call with %n guest (Duration {duration})","{actor} ended the call with %n guests (Duration {duration})"],
    "{actor} ended the call with {user1} (Duration {duration})" : "{actor} ended the call with {user1} (Duration {duration})",
    "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor} ended the call with {user1} and {user2} (Duration {duration})",
    "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})",
    "Message of {user} in {conversation}" : "Message of {user} in {conversation}",
    "Message of {user}" : "Message of {user}",
    "Message of a deleted user in {conversation}" : "Message of a deleted user in {conversation}",
    "Talk conversations" : "Talk conversations",
    "Call %s" : "Call %s",
    "An error occurred. Please contact your administrator." : "An error occurred. Please contact your administrator.",
    "Storage quota exceeded" : "Storage quota exceeded",
    "File not found" : "File not found",
    "File is not shared, or shared but not with the user" : "File is not shared, or shared but not with the user",
    "No account available to delete." : "No account available to delete.",
    "Poll" : "Poll",
    "No image file provided" : "No image file provided",
    "File is too big" : "File is too big",
    "Invalid file provided" : "Invalid file provided",
    "Invalid image" : "Invalid image",
    "Unknown filetype" : "Unknown filetype",
    "Talk mentions" : "Talk mentions",
    "Say hi to your friends and colleagues!" : "Say hi to your friends and colleagues!",
    "No unread mentions" : "No unread mentions",
    "Call in progress" : "Call in progress",
    "You were mentioned" : "You were mentioned",
    "Write to conversation" : "Write to conversation",
    "Writes event information into a conversation of your choice" : "Writes event information into a conversation of your choice",
    "Conversation invitation" : "Conversation invitation",
    "Description" : "Description",
    "You can also dial-in via phone with the following details" : "You can also dial-in via phone with the following details",
    "Dial-in information" : "Dial-in information",
    "Meeting ID" : "Meeting ID",
    "Your PIN" : "Your PIN",
    "Meeting" : "Meeting",
    "Password request: %s" : "Password request: %s",
    "Private conversation" : "Private conversation",
    "Deleted user (%s)" : "Deleted user (%s)",
    "Failed to upload call recording" : "Failed to upload call recording",
    "The recording server failed to upload recording of call {call}. Please reach out to the administration." : "The recording server failed to upload recording of call {call}. Please reach out to the administration.",
    "Share to chat" : "Share to chat",
    "Dismiss notification" : "Dismiss notification",
    "Call recording now available" : "Call recording now available",
    "The recording for the call in {call} was uploaded to {file}." : "The recording for the call in {call} was uploaded to {file}.",
    "Transcript now available" : "Transcript now available",
    "The transcript for the call in {call} was uploaded to {file}." : "The transcript for the call in {call} was uploaded to {file}.",
    "Failed to transcript call recording" : "Failed to transcript call recording",
    "The server failed to transcript the recording at {file} for the call in {call}. Please reach out to the administration." : "The server failed to transcript the recording at {file} for the call in {call}. Please reach out to the administration.",
    "Accept" : "Accept",
    "Decline" : "Decline",
    "New message" : "New message",
    "Reminder" : "Reminder",
    "Notification" : "შეტყობინება",
    "Reminder: You in {call}" : "Reminder: You in {call}",
    "Reminder: {user} in {call}" : "Reminder: {user} in {call}",
    "Reminder: Deleted user in {call}" : "Reminder: Deleted user in {call}",
    "Reminder: {guest} (guest) in {call}" : "Reminder: {guest} (guest) in {call}",
    "Reminder: Guest in {call}" : "Reminder: Guest in {call}",
    "{user} reacted with {reaction}" : "{user} reacted with {reaction}",
    "{user} reacted with {reaction} in {call}" : "{user} reacted with {reaction} in {call}",
    "Deleted user reacted with {reaction} in {call}" : "Deleted user reacted with {reaction} in {call}",
    "{guest} (guest) reacted with {reaction} in {call}" : "{guest} (guest) reacted with {reaction} in {call}",
    "Guest reacted with {reaction} in {call}" : "Guest reacted with {reaction} in {call}",
    "{user} in {call}" : "{user} in {call}",
    "Deleted user in {call}" : "Deleted user in {call}",
    "{guest} (guest) in {call}" : "{guest} (guest) in {call}",
    "Guest in {call}" : "Guest in {call}",
    "{user} sent you a private message" : "{user} sent you a private message",
    "{user} sent a message in conversation {call}" : "{user} sent a message in conversation {call}",
    "A deleted user sent a message in conversation {call}" : "A deleted user sent a message in conversation {call}",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (guest) sent a message in conversation {call}",
    "A guest sent a message in conversation {call}" : "A guest sent a message in conversation {call}",
    "{user} replied to your private message" : "{user} replied to your private message",
    "{user} replied to your message in conversation {call}" : "{user} replied to your message in conversation {call}",
    "A deleted user replied to your message in conversation {call}" : "A deleted user replied to your message in conversation {call}",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (guest) replied to your message in conversation {call}",
    "A guest replied to your message in conversation {call}" : "A guest replied to your message in conversation {call}",
    "Reminder: You in private conversation {call}" : "Reminder: You in private conversation {call}",
    "Reminder: A deleted user in private conversation {call}" : "Reminder: A deleted user in private conversation {call}",
    "Reminder: {user} in private conversation" : "Reminder: {user} in private conversation",
    "Reminder: You in conversation {call}" : "Reminder: You in conversation {call}",
    "Reminder: {user} in conversation {call}" : "Reminder: {user} in conversation {call}",
    "Reminder: A deleted user in conversation {call}" : "Reminder: A deleted user in conversation {call}",
    "Reminder: {guest} (guest) in conversation {call}" : "Reminder: {guest} (guest) in conversation {call}",
    "Reminder: A guest in conversation {call}" : "Reminder: A guest in conversation {call}",
    "{user} reacted with {reaction} to your private message" : "{user} reacted with {reaction} to your private message",
    "{user} reacted with {reaction} to your message in conversation {call}" : "{user} reacted with {reaction} to your message in conversation {call}",
    "A deleted user reacted with {reaction} to your message in conversation {call}" : "A deleted user reacted with {reaction} to your message in conversation {call}",
    "{guest} (guest) reacted with {reaction} to your message in conversation {call}" : "{guest} (guest) reacted with {reaction} to your message in conversation {call}",
    "A guest reacted with {reaction} to your message in conversation {call}" : "A guest reacted with {reaction} to your message in conversation {call}",
    "{user} mentioned you in a private conversation" : "{user} mentioned you in a private conversation",
    "{user} mentioned group {group} in conversation {call}" : "{user} mentioned group {group} in conversation {call}",
    "{user} mentioned everyone in conversation {call}" : "{user} mentioned everyone in conversation {call}",
    "{user} mentioned you in conversation {call}" : "{user} mentioned you in conversation {call}",
    "A deleted user mentioned group {group} in conversation {call}" : "A deleted user mentioned group {group} in conversation {call}",
    "A deleted user mentioned everyone in conversation {call}" : "A deleted user mentioned everyone in conversation {call}",
    "A deleted user mentioned you in conversation {call}" : "A deleted user mentioned you in conversation {call}",
    "{guest} (guest) mentioned group {group} in conversation {call}" : "{guest} (guest) mentioned group {group} in conversation {call}",
    "{guest} (guest) mentioned everyone in conversation {call}" : "{guest} (guest) mentioned everyone in conversation {call}",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (guest) mentioned you in conversation {call}",
    "A guest mentioned group {group} in conversation {call}" : "A guest mentioned group {group} in conversation {call}",
    "A guest mentioned everyone in conversation {call}" : "A guest mentioned everyone in conversation {call}",
    "A guest mentioned you in conversation {call}" : "A guest mentioned you in conversation {call}",
    "View message" : "View message",
    "Dismiss reminder" : "Dismiss reminder",
    "View chat" : "View chat",
    "{user} invited you to a group conversation: {call}" : "{user} invited you to a group conversation: {call}",
    "Join call" : "Join call",
    "Answer call" : "Answer call",
    "{user} would like to talk with you" : "{user} would like to talk with you",
    "Call back" : "Call back",
    "You missed a call from {user}" : "You missed a call from {user}",
    "A group call has started in {call}" : "A group call has started in {call}",
    "You missed a group call in {call}" : "You missed a group call in {call}",
    "{email} is requesting the password to access {file}" : "{email} is requesting the password to access {file}",
    "{email} tried to request the password to access {file}" : "{email} tried to request the password to access {file}",
    "Someone is requesting the password to access {file}" : "Someone is requesting the password to access {file}",
    "Someone tried to request the password to access {file}" : "Someone tried to request the password to access {file}",
    "Open settings" : "Open settings",
    "Hosted signaling server added" : "Hosted signaling server added",
    "The hosted signaling server is now configured and will be used." : "The hosted signaling server is now configured and will be used.",
    "Hosted signaling server removed" : "Hosted signaling server removed",
    "The hosted signaling server was removed and will not be used anymore." : "The hosted signaling server was removed and will not be used anymore.",
    "Hosted signaling server changed" : "Hosted signaling server changed",
    "The hosted signaling server account has changed the status from \"{oldstatus}\" to \"{newstatus}\"." : "The hosted signaling server account has changed the status from \"{oldstatus}\" to \"{newstatus}\".",
    "pending" : "pending",
    "active" : "active",
    "expired" : "expired",
    "blocked" : "blocked",
    "error" : "error",
    "The certificate of {host} expires in {days} days" : "The certificate of {host} expires in {days} days",
    "The certificate of {host} expired" : "The certificate of {host} expired",
    "Contact via Talk" : "Contact via Talk",
    "Open Talk" : "Open Talk",
    "Default" : "Default",
    "Presentation" : "Presentation",
    "Conversations" : "Conversations",
    "Messages in current conversation" : "Messages in current conversation",
    "{user}" : "{user}",
    "Messages" : "Messages",
    "{user} in {conversation}" : "{user} in {conversation}",
    "Messages in other conversations" : "Messages in other conversations",
    "One-to-one rooms always need to show the other users avatar" : "One-to-one rooms always need to show the other users avatar",
    "Invalid emoji character" : "Invalid emoji character",
    "Invalid background color" : "Invalid background color",
    "Avatar image is not square" : "Avatar image is not square",
    "Room {number}" : "Room {number}",
    "Favorites" : "ფავორიტები",
    "Other" : "Other",
    "Failed to request trial because the trial server is unreachable. Please try again later." : "Failed to request trial because the trial server is unreachable. Please try again later.",
    "There is a problem with the authentication of this instance. Maybe it is not reachable from the outside to verify it's URL." : "There is a problem with the authentication of this instance. Maybe it is not reachable from the outside to verify it's URL.",
    "Something unexpected happened." : "Something unexpected happened.",
    "The URL is invalid." : "The URL is invalid.",
    "An HTTPS URL is required." : "An HTTPS URL is required.",
    "The email address is invalid." : "The email address is invalid.",
    "The language is invalid." : "The language is invalid.",
    "The country is invalid." : "The country is invalid.",
    "There is a problem with the request of the trial. Please check your logs for further information." : "There is a problem with the request of the trial. Please check your logs for further information.",
    "Too many requests are send from your servers address. Please try again later." : "Too many requests are send from your servers address. Please try again later.",
    "There is already a trial registered for this Nextcloud instance." : "There is already a trial registered for this Nextcloud instance.",
    "Something unexpected happened. Please try again later." : "Something unexpected happened. Please try again later.",
    "Failed to request trial because the trial server behaved wrongly. Please try again later." : "Failed to request trial because the trial server behaved wrongly. Please try again later.",
    "Trial requested but failed to get account information. Please check back later." : "Trial requested but failed to get account information. Please check back later.",
    "There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it's URL." : "There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it's URL.",
    "Failed to fetch account information because the trial server behaved wrongly. Please check back later." : "Failed to fetch account information because the trial server behaved wrongly. Please check back later.",
    "There is a problem with fetching the account information. Please check your logs for further information." : "There is a problem with fetching the account information. Please check your logs for further information.",
    "There is no such account registered." : "There is no such account registered.",
    "Failed to fetch account information because the trial server is unreachable. Please check back later." : "Failed to fetch account information because the trial server is unreachable. Please check back later.",
    "Deleting the hosted signaling server account failed. Please check back later." : "Deleting the hosted signaling server account failed. Please check back later.",
    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "Failed to delete the account because the trial server behaved wrongly. Please check back later.",
    "There is a problem with deleting the account. Please check your logs for further information." : "There is a problem with deleting the account. Please check your logs for further information.",
    "Too many requests are sent from your servers address. Please try again later." : "Too many requests are sent from your servers address. Please try again later.",
    "Failed to delete the account because the trial server is unreachable. Please check back later." : "Failed to delete the account because the trial server is unreachable. Please check back later.",
    "Note to self" : "Note to self",
    "A place for your private notes, thoughts and ideas" : "A place for your private notes, thoughts and ideas",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "United Arab Emirates",
    "Afghanistan" : "Afghanistan",
    "Antigua and Barbuda" : "Antigua and Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Antarctica" : "Antarctica",
    "Argentina" : "Argentina",
    "American Samoa" : "American Samoa",
    "Austria" : "Austria",
    "Australia" : "Australia",
    "Aruba" : "Aruba",
    "Åland Islands" : "Åland Islands",
    "Azerbaijan" : "Azerbaijan",
    "Bosnia and Herzegovina" : "Bosnia and Herzegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Belgium",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaria",
    "Bahrain" : "Bahrain",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Saint Barthélemy",
    "Bermuda" : "Bermuda",
    "Brunei Darussalam" : "Brunei Darussalam",
    "Bolivia, Plurinational State of" : "Bolivia, Plurinational State of",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius and Saba",
    "Brazil" : "Brazil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bhutan",
    "Bouvet Island" : "Bouvet Island",
    "Botswana" : "Botswana",
    "Belarus" : "Belarus",
    "Belize" : "Belize",
    "Canada" : "Canada",
    "Cocos (Keeling) Islands" : "Cocos (Keeling) Islands",
    "Congo, the Democratic Republic of the" : "Congo, the Democratic Republic of the",
    "Central African Republic" : "Central African Republic",
    "Congo" : "Congo",
    "Switzerland" : "Switzerland",
    "Côte d'Ivoire" : "Côte d'Ivoire",
    "Cook Islands" : "Cook Islands",
    "Chile" : "Chile",
    "Cameroon" : "Cameroon",
    "China" : "China",
    "Colombia" : "Colombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cabo Verde" : "Cabo Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Christmas Island",
    "Cyprus" : "Cyprus",
    "Czechia" : "Czechia",
    "Germany" : "Germany",
    "Djibouti" : "Djibouti",
    "Denmark" : "Denmark",
    "Dominica" : "Dominica",
    "Dominican Republic" : "Dominican Republic",
    "Algeria" : "Algeria",
    "Ecuador" : "Ecuador",
    "Estonia" : "Estonia",
    "Egypt" : "Egypt",
    "Western Sahara" : "Western Sahara",
    "Eritrea" : "Eritrea",
    "Spain" : "Spain",
    "Ethiopia" : "Ethiopia",
    "Finland" : "Finland",
    "Fiji" : "Fiji",
    "Falkland Islands (Malvinas)" : "Falkland Islands (Malvinas)",
    "Micronesia, Federated States of" : "Micronesia, Federated States of",
    "Faroe Islands" : "Faroe Islands",
    "France" : "France",
    "Gabon" : "Gabon",
    "United Kingdom of Great Britain and Northern Ireland" : "United Kingdom of Great Britain and Northern Ireland",
    "Grenada" : "Grenada",
    "Georgia" : "Georgia",
    "French Guiana" : "French Guiana",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Greenland",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Equatorial Guinea",
    "Greece" : "Greece",
    "South Georgia and the South Sandwich Islands" : "South Georgia and the South Sandwich Islands",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Heard Island and McDonald Islands",
    "Honduras" : "Honduras",
    "Croatia" : "Croatia",
    "Haiti" : "Haiti",
    "Hungary" : "Hungary",
    "Indonesia" : "Indonesia",
    "Ireland" : "Ireland",
    "Israel" : "Israel",
    "Isle of Man" : "Isle of Man",
    "India" : "India",
    "British Indian Ocean Territory" : "British Indian Ocean Territory",
    "Iraq" : "Iraq",
    "Iran, Islamic Republic of" : "Iran, Islamic Republic of",
    "Iceland" : "Iceland",
    "Italy" : "Italy",
    "Jersey" : "Jersey",
    "Jamaica" : "Jamaica",
    "Jordan" : "Jordan",
    "Japan" : "Japan",
    "Kenya" : "Kenya",
    "Kyrgyzstan" : "Kyrgyzstan",
    "Cambodia" : "Cambodia",
    "Kiribati" : "Kiribati",
    "Comoros" : "Comoros",
    "Saint Kitts and Nevis" : "Saint Kitts and Nevis",
    "Korea, Democratic People's Republic of" : "Korea, Democratic People's Republic of",
    "Korea, Republic of" : "Korea, Republic of",
    "Kuwait" : "Kuwait",
    "Cayman Islands" : "Cayman Islands",
    "Kazakhstan" : "Kazakhstan",
    "Lao People's Democratic Republic" : "Lao People's Democratic Republic",
    "Lebanon" : "Lebanon",
    "Saint Lucia" : "Saint Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Lithuania",
    "Luxembourg" : "Luxembourg",
    "Latvia" : "Latvia",
    "Libya" : "Libya",
    "Morocco" : "Morocco",
    "Monaco" : "Monaco",
    "Moldova, Republic of" : "Moldova, Republic of",
    "Montenegro" : "Montenegro",
    "Saint Martin (French part)" : "Saint Martin (French part)",
    "Madagascar" : "Madagascar",
    "Marshall Islands" : "Marshall Islands",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongolia",
    "Macao" : "Macao",
    "Northern Mariana Islands" : "Northern Mariana Islands",
    "Martinique" : "Martinique",
    "Mauritania" : "Mauritania",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauritius",
    "Maldives" : "Maldives",
    "Malawi" : "Malawi",
    "Mexico" : "Mexico",
    "Malaysia" : "Malaysia",
    "Mozambique" : "Mozambique",
    "Namibia" : "Namibia",
    "New Caledonia" : "New Caledonia",
    "Niger" : "Niger",
    "Norfolk Island" : "Norfolk Island",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Netherlands",
    "Norway" : "Norway",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "New Zealand",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "French Polynesia",
    "Papua New Guinea" : "Papua New Guinea",
    "Philippines" : "Philippines",
    "Pakistan" : "Pakistan",
    "Poland" : "Poland",
    "Saint Pierre and Miquelon" : "Saint Pierre and Miquelon",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Puerto Rico",
    "Palestine, State of" : "Palestine, State of",
    "Portugal" : "Portugal",
    "Palau" : "Palau",
    "Paraguay" : "Paraguay",
    "Qatar" : "Qatar",
    "Réunion" : "Réunion",
    "Romania" : "Romania",
    "Serbia" : "Serbia",
    "Russian Federation" : "Russian Federation",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Saudi Arabia",
    "Solomon Islands" : "Solomon Islands",
    "Seychelles" : "Seychelles",
    "Sudan" : "Sudan",
    "Sweden" : "Sweden",
    "Singapore" : "Singapore",
    "Saint Helena, Ascension and Tristan da Cunha" : "Saint Helena, Ascension and Tristan da Cunha",
    "Slovenia" : "Slovenia",
    "Svalbard and Jan Mayen" : "Svalbard and Jan Mayen",
    "Slovakia" : "Slovakia",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Suriname",
    "South Sudan" : "South Sudan",
    "Sao Tome and Principe" : "Sao Tome and Principe",
    "El Salvador" : "El Salvador",
    "Sint Maarten (Dutch part)" : "Sint Maarten (Dutch part)",
    "Syrian Arab Republic" : "Syrian Arab Republic",
    "Eswatini" : "Eswatini",
    "Turks and Caicos Islands" : "Turks and Caicos Islands",
    "Chad" : "Chad",
    "French Southern Territories" : "French Southern Territories",
    "Togo" : "Togo",
    "Thailand" : "Thailand",
    "Tajikistan" : "Tajikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor-Leste",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunisia",
    "Tonga" : "Tonga",
    "Turkey" : "Turkey",
    "Trinidad and Tobago" : "Trinidad and Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan, Province of China" : "Taiwan, Province of China",
    "Tanzania, United Republic of" : "Tanzania, United Republic of",
    "Ukraine" : "Ukraine",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "United States Minor Outlying Islands",
    "United States of America" : "United States of America",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Uzbekistan",
    "Holy See" : "Holy See",
    "Saint Vincent and the Grenadines" : "Saint Vincent and the Grenadines",
    "Venezuela, Bolivarian Republic of" : "Venezuela, Bolivarian Republic of",
    "Virgin Islands, British" : "Virgin Islands, British",
    "Virgin Islands, U.S." : "Virgin Islands, U.S.",
    "Viet Nam" : "Viet Nam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis and Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Yemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "South Africa",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Federation" : "Federation",
    "High-performance backend" : "High-performance backend",
    "Error: Cannot connect to server" : "Error: Cannot connect to server",
    "Error: Server did not respond with proper JSON" : "Error: Server did not respond with proper JSON",
    "Error: Certificate expired" : "Error: Certificate expired",
    "Could not get version" : "Could not get version",
    "Error: Running version: {version}; Server needs to be updated to be compatible with this version of Talk" : "Error: Running version: {version}; Server needs to be updated to be compatible with this version of Talk",
    "Error: Server responded with: {error}" : "Error: Server responded with: {error}",
    "Error: Unknown error occurred" : "Error: Unknown error occurred",
    "Warning: Running version: {version}; Server does not support all features of this Talk version, missing features: {features}" : "Warning: Running version: {version}; Server does not support all features of this Talk version, missing features: {features}",
    "Recording backend" : "Recording backend",
    "SIP configuration" : "SIP configuration",
    "Invalid date, date format must be YYYY-MM-DD" : "Invalid date, date format must be YYYY-MM-DD",
    "Conversation not found" : "Conversation not found",
    "Chat, video & audio-conferencing using WebRTC" : "Chat, video & audio-conferencing using WebRTC",
    "Leave call" : "Leave call",
    "Navigating away from the page will leave the call in {conversation}" : "Navigating away from the page will leave the call in {conversation}",
    "Stay in call" : "Stay in call",
    "Duplicate session" : "Duplicate session",
    "Discuss this file" : "Discuss this file",
    "Loading …" : "Loading …",
    "Share this file with others to discuss it" : "Share this file with others to discuss it",
    "Join conversation" : "Join conversation",
    "Share this file" : "Share this file",
    "Error occurred when joining the conversation" : "Error occurred when joining the conversation",
    "This conversation is password-protected." : "This conversation is password-protected.",
    "We have detected multiple invalid password attempts from your IP. Therefore your next attempt is throttled up to 30 seconds." : "We have detected multiple invalid password attempts from your IP. Therefore your next attempt is throttled up to 30 seconds.",
    "The password is wrong. Try again." : "The password is wrong. Try again.",
    "Password" : "პაროლი",
    "Submit" : "Submit",
    "Error requesting the password." : "Error requesting the password.",
    "Request password" : "Request password",
    "This conversation has ended" : "This conversation has ended",
    "Close Talk sidebar" : "Close Talk sidebar",
    "Open Talk sidebar" : "Open Talk sidebar",
    "Everyone" : "Everyone",
    "Users and moderators" : "Users and moderators",
    "Moderators only" : "Moderators only",
    "Disable calls" : "Disable calls",
    "Save changes" : "Save changes",
    "Saving …" : "Saving …",
    "Saved!" : "Saved!",
    "Limit to groups" : "Limit to groups",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "When at least one group is selected, only people of the listed groups can be part of conversations.",
    "Guests can still join public conversations." : "Guests can still join public conversations.",
    "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept.",
    "Limit using Talk" : "Limit using Talk",
    "Limit creating a public and group conversation" : "Limit creating a public and group conversation",
    "Limit creating conversations" : "Limit creating conversations",
    "Limit starting a call" : "Limit starting a call",
    "Limit starting calls" : "Limit starting calls",
    "When a call has started, everyone with access to the conversation can join the call." : "When a call has started, everyone with access to the conversation can join the call.",
    "The following bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "The following bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server.",
    "No bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "No bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server.",
    "Description is not provided" : "Description is not provided",
    "Locked for moderators" : "Locked for moderators",
    "Enabled" : "Enabled",
    "Disabled" : "Disabled",
    "Bots settings" : "Bots settings",
    "State" : "State",
    "Name" : "Name",
    "Last error" : "Last error",
    "Total errors count" : "Total errors count",
    "Find more bots" : "Find more bots",
    "Beta" : "Beta",
    "Permissions" : "Permissions",
    "All messages" : "All messages",
    "@-mentions only" : "@-mentions only",
    "Off" : "Off",
    "General settings" : "General settings",
    "Default notification settings" : "Default notification settings",
    "Default group notification" : "Default group notification",
    "Default group notification for new groups" : "Default group notification for new groups",
    "Integration into other apps" : "Integration into other apps",
    "Allow conversations on files" : "Allow conversations on files",
    "Allow conversations on public shares for files" : "Allow conversations on public shares for files",
    "Enable encryption" : "Enable encryption",
    "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}." : "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}.",
    "Pending" : "Pending",
    "Error" : "Error",
    "Blocked" : "Blocked",
    "Active" : "Active",
    "Expired" : "Expired",
    "Never" : "Never",
    "The trial could not be requested. Please try again later." : "The trial could not be requested. Please try again later.",
    "The account could not be deleted. Please try again later." : "The account could not be deleted. Please try again later.",
    "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings.",
    "URL of this Nextcloud instance" : "URL of this Nextcloud instance",
    "Full name of the user requesting the trial" : "Full name of the user requesting the trial",
    "Email of the user" : "Email of the user",
    "Language" : "Language",
    "Country" : "Country",
    "Request signaling server trial" : "Request signaling server trial",
    "You can see the current status of your hosted signaling server in the following table." : "You can see the current status of your hosted signaling server in the following table.",
    "Status" : "Status",
    "Created at" : "Created at",
    "Expires at" : "Expires at",
    "Limits" : "Limits",
    "Yes" : "Yes",
    "No" : "No",
    "Delete the signaling server account" : "Delete the signaling server account",
    "_%n user_::_%n users_" : ["%n user","%n users"],
    "Installed version: {version}" : "Installed version: {version}",
    "You can install the Matterbridge to link Nextcloud Talk to some other services, visit their {linkstart1}GitHub page{linkend} for more details. Downloading and installing the app can take a while. In case it times out, please install it manually from the {linkstart2}Nextcloud App Store{linkend}." : "You can install the Matterbridge to link Nextcloud Talk to some other services, visit their {linkstart1}GitHub page{linkend} for more details. Downloading and installing the app can take a while. In case it times out, please install it manually from the {linkstart2}Nextcloud App Store{linkend}.",
    "Matterbridge binary was not found or couldn't be executed." : "Matterbridge binary was not found or couldn't be executed.",
    "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information.",
    "Downloading …" : "Downloading …",
    "Install Talk Matterbridge" : "Install Talk Matterbridge",
    "An error occurred while installing the Matterbridge app" : "An error occurred while installing the Matterbridge app",
    "An error occurred while installing the Talk Matterbridge. Please install it manually" : "An error occurred while installing the Talk Matterbridge. Please install it manually",
    "Failed to execute Matterbridge binary." : "Failed to execute Matterbridge binary.",
    "Matterbridge integration" : "Matterbridge integration",
    "Enable Matterbridge integration" : "Enable Matterbridge integration",
    "Status: Checking connection" : "Status: Checking connection",
    "OK: Running version: {version}" : "OK: Running version: {version}",
    "Error: Server seems to be a Signaling server" : "Error: Server seems to be a Signaling server",
    "Recording backend URL" : "Recording backend URL",
    "Validate SSL certificate" : "Validate SSL certificate",
    "Delete this server" : "Delete this server",
    "Test this server" : "Test this server",
    "Disabled for all calls" : "Disabled for all calls",
    "Enabled for all calls" : "Enabled for all calls",
    "Configurable on conversation level by moderators" : "Configurable on conversation level by moderators",
    "The PHP settings \"upload_max_filesize\" or \"post_max_size\" only will allow to upload files up to {maxUpload}." : "The PHP settings \"upload_max_filesize\" or \"post_max_size\" only will allow to upload files up to {maxUpload}.",
    "Recording backend settings saved" : "Recording backend settings saved",
    "Moderators will be allowed to enable consent on conversation level. The consent to be recorded will be required for each participant before joining every call in this conversation." : "Moderators will be allowed to enable consent on conversation level. The consent to be recorded will be required for each participant before joining every call in this conversation.",
    "The consent to be recorded will be required for each participant before joining every call." : "The consent to be recorded will be required for each participant before joining every call.",
    "The consent to be recorded is not required." : "The consent to be recorded is not required.",
    "Add a new recording backend server" : "Add a new recording backend server",
    "Shared secret" : "Shared secret",
    "Recording consent" : "Recording consent",
    "SIP configuration saved!" : "SIP configuration saved!",
    "Enable SIP Dial-out option" : "Enable SIP Dial-out option",
    "Signaling server needs to be updated to supported SIP Dial-out feature." : "Signaling server needs to be updated to supported SIP Dial-out feature.",
    "Restrict SIP configuration" : "Restrict SIP configuration",
    "Enable SIP configuration" : "Enable SIP configuration",
    "Only users of the following groups can enable SIP in conversations they moderate" : "Only users of the following groups can enable SIP in conversations they moderate",
    "Phone number (Country)" : "Phone number (Country)",
    "This information is sent in invitation emails as well as displayed in the sidebar to all participants." : "This information is sent in invitation emails as well as displayed in the sidebar to all participants.",
    "High-performance backend URL" : "High-performance backend URL",
    "High-performance backend settings saved" : "High-performance backend settings saved",
    "STUN server URL" : "STUN server URL",
    "The server address is invalid" : "The server address is invalid",
    "STUN settings saved" : "STUN settings saved",
    "STUN servers" : "STUN servers",
    "A STUN server is used to determine the public IP address of participants behind a router." : "A STUN server is used to determine the public IP address of participants behind a router.",
    "Add a new STUN server" : "Add a new STUN server",
    "{schema} scheme must be used with a domain" : "{schema} scheme must be used with a domain",
    "{option1} and {option2}" : "{option1} and {option2}",
    "{option} only" : "{option} only",
    "OK: Successful ICE candidates returned by the TURN server" : "OK: Successful ICE candidates returned by the TURN server",
    "Error: No working ICE candidates returned by the TURN server" : "Error: No working ICE candidates returned by the TURN server",
    "Testing whether the TURN server returns ICE candidates" : "Testing whether the TURN server returns ICE candidates",
    "TURN server schemes" : "TURN server schemes",
    "TURN server URL" : "TURN server URL",
    "TURN server secret" : "TURN server secret",
    "TURN server protocols" : "TURN server protocols",
    "A TURN server is used to proxy the traffic from participants behind a firewall. If individual participants cannot connect to others a TURN server is most likely required. See {linkstart}this documentation{linkend} for setup instructions." : "A TURN server is used to proxy the traffic from participants behind a firewall. If individual participants cannot connect to others a TURN server is most likely required. See {linkstart}this documentation{linkend} for setup instructions.",
    "TURN settings saved" : "TURN settings saved",
    "TURN servers" : "TURN servers",
    "Add a new TURN server" : "Add a new TURN server",
    "Failed" : "Failed",
    "OK" : "OK",
    "Checking …" : "Checking …",
    "Failed: WebAssembly is disabled or not supported in this browser. Please enable WebAssembly or use a browser with support for it to do the check." : "Failed: WebAssembly is disabled or not supported in this browser. Please enable WebAssembly or use a browser with support for it to do the check.",
    "Failed: \".wasm\" and \".tflite\" files were not properly returned by the web server. Please check \"System requirements\" section in Talk documentation." : "Failed: \".wasm\" and \".tflite\" files were not properly returned by the web server. Please check \"System requirements\" section in Talk documentation.",
    "OK: \".wasm\" and \".tflite\" files were properly returned by the web server." : "OK: \".wasm\" and \".tflite\" files were properly returned by the web server.",
    "It seems that the PHP and Apache configuration is not compatible. Please note that PHP can only be used with the MPM_PREFORK module and PHP-FPM can only be used with the MPM_EVENT module." : "It seems that the PHP and Apache configuration is not compatible. Please note that PHP can only be used with the MPM_PREFORK module and PHP-FPM can only be used with the MPM_EVENT module.",
    "Web server setup checks" : "Web server setup checks",
    "Files required for virtual background can be loaded" : "Files required for virtual background can be loaded",
    "Federated user" : "გარე მომხმარებელი",
    "Assign participants to rooms" : "Assign participants to rooms",
    "Configure breakout rooms" : "Configure breakout rooms",
    "Number of breakout rooms" : "Number of breakout rooms",
    "Assignment method" : "Assignment method",
    "Automatically assign participants" : "Automatically assign participants",
    "Manually assign participants" : "Manually assign participants",
    "Allow participants to choose" : "Allow participants to choose",
    "Create rooms" : "Create rooms",
    "Confirm" : "Confirm",
    "Create breakout rooms" : "Create breakout rooms",
    "Reset" : "Reset",
    "Delete breakout rooms" : "Delete breakout rooms",
    "Room {roomNumber}" : "Room {roomNumber}",
    "Current breakout rooms and settings will be lost" : "Current breakout rooms and settings will be lost",
    "Cancel" : "Cancel",
    "Unassigned participants" : "Unassigned participants",
    "Back" : "Back",
    "Assign" : "Assign",
    "Add participant \"{user}\"" : "Add participant \"{user}\"",
    "From" : "From",
    "To" : "To",
    "Calendar" : "Calendar",
    "Attendees" : "Attendees",
    "Save" : "Save",
    "Search participants" : "Search participants",
    "No results" : "No results",
    "Done" : "Done",
    "Exit full screen (F)" : "Exit full screen (F)",
    "Full screen (F)" : "Full screen (F)",
    "Speaker view" : "Speaker view",
    "Grid view" : "Grid view",
    "This conversation is read-only" : "This conversation is read-only",
    "Reload" : "Reload",
    "{nickName} raised their hand." : "{nickName} raised their hand.",
    "A participant raised their hand." : "A participant raised their hand.",
    "Collapse stripe" : "Collapse stripe",
    "Expand stripe" : "Expand stripe",
    "Previous page of videos" : "Previous page of videos",
    "Next page of videos" : "Next page of videos",
    "Connecting …" : "Connecting …",
    "Calling …" : "Calling …",
    "Waiting for {user} to join the call" : "Waiting for {user} to join the call",
    "Waiting for others to join the call …" : "Waiting for others to join the call …",
    "You can invite others in the participant tab of the sidebar" : "You can invite others in the participant tab of the sidebar",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "You can invite others in the participant tab of the sidebar or share this link to invite others!",
    "Share this link to invite others!" : "Share this link to invite others!",
    "Copy link" : "Copy link",
    "You are not allowed to enable audio" : "You are not allowed to enable audio",
    "No audio. Click to select device" : "No audio. Click to select device",
    "Mute audio" : "Mute audio",
    "Mute audio (M)" : "Mute audio (M)",
    "Unmute audio" : "Unmute audio",
    "Unmute audio (M)" : "Unmute audio (M)",
    "None" : "None",
    "Access to camera was denied" : "Access to camera was denied",
    "Error while accessing camera: It is likely in use by another program" : "Error while accessing camera: It is likely in use by another program",
    "Error while accessing camera" : "Error while accessing camera",
    "You have been muted by a moderator" : "You have been muted by a moderator",
    "You are not allowed to enable video" : "You are not allowed to enable video",
    "No video. Click to select device" : "No video. Click to select device",
    "Disable video" : "Disable video",
    "Disable video (V)" : "Disable video (V)",
    "Enable video" : "Enable video",
    "Enable video (V)" : "Enable video (V)",
    "Enable video - Your connection will be briefly interrupted when enabling the video for the first time" : "Enable video - Your connection will be briefly interrupted when enabling the video for the first time",
    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Enable video. Your connection will be briefly interrupted when enabling the video for the first time",
    "Show presenter" : "Show presenter",
    "You" : "You",
    "Mute" : "Mute",
    "Muted" : "Muted",
    "Show screen" : "Show screen",
    "Stop following" : "Stop following",
    "Connection could not be established …" : "Connection could not be established …",
    "Connection was lost and could not be re-established …" : "Connection was lost and could not be re-established …",
    "Connection could not be established. Trying again …" : "Connection could not be established. Trying again …",
    "Connection lost. Trying to reconnect …" : "Connection lost. Trying to reconnect …",
    "Connection problems …" : "Connection problems …",
    "Collapse" : "Collapse",
    "Expand" : "Expand",
    "You need to be logged in to upload files" : "You need to be logged in to upload files",
    "Drop your files to upload" : "Drop your files to upload",
    "Conversation messages" : "Conversation messages",
    "Scroll to bottom" : "Scroll to bottom",
    "Post message" : "Post message",
    "Favorite" : "Favorite",
    "Date:" : "Date:",
    "Hide details" : "Hide details",
    "Show details" : "Show details",
    "Error while updating conversation name" : "Error while updating conversation name",
    "Error while updating conversation description" : "Error while updating conversation description",
    "Enter a name for this conversation" : "Enter a name for this conversation",
    "Edit conversation name" : "Edit conversation name",
    "Edit conversation description" : "Edit conversation description",
    "Enter a description for this conversation" : "Enter a description for this conversation",
    "Picture" : "Picture",
    "The following bots can be enabled in this conversation. Reach out to your administration to get more bots installed on this server." : "The following bots can be enabled in this conversation. Reach out to your administration to get more bots installed on this server.",
    "No bots are installed on this server. Reach out to your administration to get bots installed on this server." : "No bots are installed on this server. Reach out to your administration to get bots installed on this server.",
    "Disable" : "Disable",
    "Enable" : "Enable",
    "Breakout rooms" : "Breakout rooms",
    "Manage breakout rooms" : "Manage breakout rooms",
    "Set up breakout rooms for this conversation" : "Set up breakout rooms for this conversation",
    "Please select a valid PNG or JPG file" : "Please select a valid PNG or JPG file",
    "Choose your conversation picture" : "Choose your conversation picture",
    "Choose" : "Choose",
    "Error setting conversation picture" : "Error setting conversation picture",
    "Could not set the conversation picture: {error}" : "Could not set the conversation picture: {error}",
    "Error cropping conversation picture" : "Error cropping conversation picture",
    "Error removing conversation picture" : "Error removing conversation picture",
    "Set emoji as conversation picture" : "Set emoji as conversation picture",
    "Set background color for conversation picture" : "Set background color for conversation picture",
    "Upload conversation picture" : "Upload conversation picture",
    "Choose conversation picture from files" : "Choose conversation picture from files",
    "Remove conversation picture" : "Remove conversation picture",
    "The file must be a PNG or JPG" : "The file must be a PNG or JPG",
    "Set picture" : "Set picture",
    "Default permissions modified for {conversationName}" : "Default permissions modified for {conversationName}",
    "Could not modify default permissions for {conversationName}" : "Could not modify default permissions for {conversationName}",
    "Edit the default permissions for participants in this conversation. These settings do not affect moderators." : "Edit the default permissions for participants in this conversation. These settings do not affect moderators.",
    "Every time permissions are modified in this section, custom permissions previously assigned to individual participants will be lost." : "Every time permissions are modified in this section, custom permissions previously assigned to individual participants will be lost.",
    "All permissions" : "All permissions",
    "Participants have permissions to start a call, join a call, enable audio and video, and share screen." : "Participants have permissions to start a call, join a call, enable audio and video, and share screen.",
    "Restricted" : "Restricted",
    "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions.",
    "Advanced permissions" : "Advanced permissions",
    "Edit permissions" : "Edit permissions",
    "Conversation settings" : "Conversation settings",
    "Basic Info" : "Basic Info",
    "Personal" : "Personal",
    "Moderation" : "Moderation",
    "Setup overview" : "Setup overview",
    "Breakout Rooms" : "Breakout Rooms",
    "Matterbridge" : "Matterbridge",
    "Bots" : "Bots",
    "Danger zone" : "Danger zone",
    "Leave conversation" : "Leave conversation",
    "You need to promote a new moderator before you can leave the conversation" : "You need to promote a new moderator before you can leave the conversation",
    "Delete conversation" : "Delete conversation",
    "Do you really want to delete \"{displayName}\"?" : "Do you really want to delete \"{displayName}\"?",
    "Error while deleting conversation" : "Error while deleting conversation",
    "Delete all chat messages" : "Delete all chat messages",
    "Do you really want to delete all messages in \"{displayName}\"?" : "Do you really want to delete all messages in \"{displayName}\"?",
    "Error while clearing chat history" : "Error while clearing chat history",
    "Be careful, these actions cannot be undone." : "Be careful, these actions cannot be undone.",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time.",
    "Permanently delete this conversation." : "Permanently delete this conversation.",
    "Delete chat messages" : "Delete chat messages",
    "Permanently delete all the messages in this conversation." : "Permanently delete all the messages in this conversation.",
    "Custom expiration time" : "Custom expiration time",
    "Message expiration disabled" : "Message expiration disabled",
    "Message expiration set: {duration}" : "Message expiration set: {duration}",
    "Error when trying to set message expiration" : "Error when trying to set message expiration",
    "Message expiration" : "Message expiration",
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation.",
    "Set message expiration" : "Set message expiration",
    "Current message expiration" : "Current message expiration",
    "Guest access" : "Guest access",
    "Allow guests to join this conversation via link" : "Allow guests to join this conversation via link",
    "Password protection" : "Password protection",
    "Change password" : "Change password",
    "Enter new password" : "Enter new password",
    "Save password" : "Save password",
    "Guests are allowed to join this conversation via link" : "Guests are allowed to join this conversation via link",
    "Guests are not allowed to join this conversation" : "Guests are not allowed to join this conversation",
    "Resend invitations" : "Resend invitations",
    "This conversation is open to both registered users and users created with the Guests app" : "This conversation is open to both registered users and users created with the Guests app",
    "This conversation is open to registered users" : "This conversation is open to registered users",
    "This conversation is limited to the current participants" : "This conversation is limited to the current participants",
    "You opened the conversation to both registered users and users created with the Guests app" : "You opened the conversation to both registered users and users created with the Guests app",
    "Error occurred when opening or limiting the conversation" : "Error occurred when opening or limiting the conversation",
    "Open conversation to registered users, showing it in search results" : "Open conversation to registered users, showing it in search results",
    "Also open to users created with the Guests app" : "Also open to users created with the Guests app",
    "Open conversation" : "Open conversation",
    "Start time has been updated" : "Start time has been updated",
    "Error occurred while updating start time" : "Error occurred while updating start time",
    "Enabling the lobby will remove non-moderators from the ongoing call." : "Enabling the lobby will remove non-moderators from the ongoing call.",
    "Enable lobby, restricting the conversation to moderators" : "Enable lobby, restricting the conversation to moderators",
    "Meeting start time" : "Meeting start time",
    "Start time (optional)" : "Start time (optional)",
    "Error occurred when locking the conversation" : "Error occurred when locking the conversation",
    "Error occurred when unlocking the conversation" : "Error occurred when unlocking the conversation",
    "Lock conversation" : "Lock conversation",
    "This will also terminate the ongoing call." : "This will also terminate the ongoing call.",
    "Lock the conversation to prevent anyone to post messages or start calls" : "Lock the conversation to prevent anyone to post messages or start calls",
    "Edit" : "Edit",
    "More information" : "More information",
    "Delete" : "Delete",
    "Add new bridged channel to current conversation" : "Add new bridged channel to current conversation",
    "unknown state" : "unknown state",
    "running" : "running",
    "not running, check Matterbridge log" : "not running, check Matterbridge log",
    "not running" : "not running",
    "Bridge saved" : "Bridge saved",
    "You can bridge channels from various instant messaging systems with Matterbridge." : "You can bridge channels from various instant messaging systems with Matterbridge.",
    "More info on Matterbridge" : "More info on Matterbridge",
    "Enable bridge" : "Enable bridge",
    "Show Matterbridge log" : "Show Matterbridge log",
    "Log content" : "Log content",
    "Notifications" : "Notifications",
    "Notify about calls in this conversation" : "Notify about calls in this conversation",
    "Recording consent is required for calls in this conversation" : "Recording consent is required for calls in this conversation",
    "Recording consent is not required for calls in this conversation" : "Recording consent is not required for calls in this conversation",
    "Recording consent requirement was updated" : "Recording consent requirement was updated",
    "Error occurred while updating recording consent" : "Error occurred while updating recording consent",
    "Recording Consent" : "Recording Consent",
    "Recording consent cannot be changed once a call or breakout session has started." : "Recording consent cannot be changed once a call or breakout session has started.",
    "Require recording consent before joining call in this conversation" : "Require recording consent before joining call in this conversation",
    "Recording consent is required for all calls" : "Recording consent is required for all calls",
    "SIP dial-in is now possible without PIN requirement" : "SIP dial-in is now possible without PIN requirement",
    "SIP dial-in is now enabled" : "SIP dial-in is now enabled",
    "SIP dial-in is now disabled" : "SIP dial-in is now disabled",
    "Error occurred when enabling SIP dial-in" : "Error occurred when enabling SIP dial-in",
    "Error occurred when disabling SIP dial-in" : "Error occurred when disabling SIP dial-in",
    "Phone and SIP dial-in" : "Phone and SIP dial-in",
    "Enable phone and SIP dial-in" : "Enable phone and SIP dial-in",
    "Allow to dial-in without a PIN" : "Allow to dial-in without a PIN",
    "Join" : "Join",
    "Error while creating the conversation" : "Error while creating the conversation",
    "Create a new conversation" : "Create a new conversation",
    "Join open conversations" : "Join open conversations",
    "Call a phone number" : "Call a phone number",
    "Unread mentions" : "Unread mentions",
    "Create conversation" : "Create conversation",
    "Enter your name" : "Enter your name",
    "Submit name and join" : "Submit name and join",
    "Log in" : "Log in",
    "An error occurred while calling a phone number" : "An error occurred while calling a phone number",
    "Phone number could not be called: {error}" : "Phone number could not be called: {error}",
    "Phone number could not be called" : "Phone number could not be called",
    "Search participants or phone numbers" : "Search participants or phone numbers",
    "Creating the conversation …" : "Creating the conversation …",
    "Mark as read" : "Mark as read",
    "Mark as unread" : "Mark as unread",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "You need to promote a new moderator before you can leave the conversation." : "You need to promote a new moderator before you can leave the conversation.",
    "Tag name" : "Tag name",
    "Conversation actions" : "Conversation actions",
    "Tags" : "Tags",
    "Delete tag" : "Delete tag",
    "Move up" : "Move up",
    "Move down" : "Move down",
    "Home" : "მთავარი",
    "Unread" : "Unread",
    "Alphabetically" : "Alphabetically",
    "No matches found" : "No matches found",
    "No conversations found" : "No conversations found",
    "You have no unread mentions." : "You have no unread mentions.",
    "You have no unread messages." : "You have no unread messages.",
    "An error occurred while performing the search" : "An error occurred while performing the search",
    "Conversation list" : "Conversation list",
    "Unread messages" : "Unread messages",
    "Clear filters" : "Clear filters",
    "New personal note" : "New personal note",
    "Clear filter" : "Clear filter",
    "App settings" : "App settings",
    "Users" : "Users",
    "Groups" : "Groups",
    "Other sources" : "Other sources",
    "Open conversations" : "Open conversations",
    "No search results" : "No search results",
    "Users and groups" : "Users and groups",
    "The meeting will start soon" : "The meeting will start soon",
    "This meeting is scheduled for {startTime}" : "This meeting is scheduled for {startTime}",
    "You are currently waiting in the lobby" : "You are currently waiting in the lobby",
    "Advanced" : "Advanced",
    "Select microphone" : "Select microphone",
    "No microphone available" : "No microphone available",
    "Select camera" : "Select camera",
    "No camera available" : "No camera available",
    "Devices" : "Devices",
    "Backgrounds" : "Backgrounds",
    "No audio" : "No audio",
    "No camera" : "No camera",
    "Calls are not supported in your browser" : "Calls are not supported in your browser",
    "Access to microphone is only possible with HTTPS" : "Access to microphone is only possible with HTTPS",
    "Access to microphone was denied" : "Access to microphone was denied",
    "Error while accessing microphone" : "Error while accessing microphone",
    "Access to camera is only possible with HTTPS" : "Access to camera is only possible with HTTPS",
    "The call is being recorded." : "The call is being recorded.",
    "The call might be recorded." : "The call might be recorded.",
    "The recording might include your voice, video from camera, and screen share. Your consent is required before joining the call." : "The recording might include your voice, video from camera, and screen share. Your consent is required before joining the call.",
    "Give consent to the recording of this call" : "Give consent to the recording of this call",
    "Start recording immediately with the call" : "Start recording immediately with the call",
    "Apply settings" : "Apply settings",
    "Select virtual office background" : "Select virtual office background",
    "Select virtual home background" : "Select virtual home background",
    "Select virtual abstract background" : "Select virtual abstract background",
    "Select virtual beach background" : "Select virtual beach background",
    "Select virtual park background" : "Select virtual park background",
    "Select virtual theater background" : "Select virtual theater background",
    "Select virtual library background" : "Select virtual library background",
    "Select virtual space station background" : "Select virtual space station background",
    "Error while uploading the file" : "Error while uploading the file",
    "Invalid path selected" : "Invalid path selected",
    "Select virtual background from file {fileName}" : "Select virtual background from file {fileName}",
    "Blur" : "Blur",
    "Upload" : "Upload",
    "Files" : "ფაილები",
    "The message has expired or has been deleted" : "The message has expired or has been deleted",
    "Cancel quote" : "Cancel quote",
    "24 hours" : "24 hours",
    "Clear reminder – {timeLocale}" : "Clear reminder – {timeLocale}",
    "Message text copied to clipboard" : "Message text copied to clipboard",
    "Message text could not be copied" : "Message text could not be copied",
    "Message forwarded to \"Note to self\"" : "Message forwarded to \"Note to self\"",
    "Error while forwarding message to \"Note to self\"" : "Error while forwarding message to \"Note to self\"",
    "A reminder was successfully removed" : "A reminder was successfully removed",
    "Error occurred when removing a reminder" : "Error occurred when removing a reminder",
    "A reminder was successfully set at {datetime}" : "A reminder was successfully set at {datetime}",
    "Error occurred when creating a reminder" : "Error occurred when creating a reminder",
    "Add a reaction to this message" : "Add a reaction to this message",
    "Reply" : "Reply",
    "More actions" : "More actions",
    "Set reminder" : "Set reminder",
    "Reply privately" : "Reply privately",
    "Edit message" : "Edit message",
    "Copy message link" : "Copy message link",
    "Go to file" : "Go to file",
    "Forward message" : "Forward message",
    "Translate" : "Translate",
    "Set custom reminder" : "Set custom reminder",
    "Close reactions menu" : "Close reactions menu",
    "React with {emoji}" : "React with {emoji}",
    "React with another emoji" : "React with another emoji",
    "Choose a conversation to forward the selected message." : "Choose a conversation to forward the selected message.",
    "Error while forwarding message" : "Error while forwarding message",
    "The message has been forwarded to {selectedConversationName}" : "The message has been forwarded to {selectedConversationName}",
    "Dismiss" : "Dismiss",
    "Go to conversation" : "Go to conversation",
    "The message could not be translated" : "The message could not be translated",
    "Translation copied to clipboard" : "Translation copied to clipboard",
    "Translation could not be copied" : "Translation could not be copied",
    "Translate message" : "Translate message",
    "Source language to translate from" : "Source language to translate from",
    "Translate from" : "Translate from",
    "Target language to translate into" : "Target language to translate into",
    "Translate to" : "Translate to",
    "Translating" : "Translating",
    "Copy translated text" : "Copy translated text",
    "Send now" : "Send now",
    "Message read by everyone who shares their reading status" : "Message read by everyone who shares their reading status",
    "Message sent" : "Message sent",
    "Deleting message" : "Deleting message",
    "Message deleted successfully" : "Message deleted successfully",
    "Message could not be deleted because it is too old" : "Message could not be deleted because it is too old",
    "Only normal chat messages can be deleted" : "Only normal chat messages can be deleted",
    "An error occurred while deleting the message" : "An error occurred while deleting the message",
    "Your browser does not support playing audio files" : "Your browser does not support playing audio files",
    "Contact" : "Contact",
    "{stack} in {board}" : "{stack} in {board}",
    "Deck Card" : "Deck Card",
    "Remove {fileName}" : "Remove {fileName}",
    "Open this location in OpenStreetMap" : "Open this location in OpenStreetMap",
    "Sending message" : "Sending message",
    "Failed to send the message. Click to try again" : "Failed to send the message. Click to try again",
    "Not enough free space to upload file" : "Not enough free space to upload file",
    "You cannot send messages to this conversation at the moment" : "You cannot send messages to this conversation at the moment",
    "Open poll" : "Open poll",
    "See results" : "See results",
    "No permission to post reactions in this conversation" : "No permission to post reactions in this conversation",
    "Add more reactions" : "Add more reactions",
    "Show or collapse system messages" : "Show or collapse system messages",
    "No messages" : "No messages",
    "All messages have expired or have been deleted." : "All messages have expired or have been deleted.",
    "Unpin" : "Unpin",
    "Cancel search" : "Cancel search",
    "Add a phone number" : "Add a phone number",
    "All set, the conversation \"{conversationName}\" was created." : "All set, the conversation \"{conversationName}\" was created.",
    "Create a new group conversation" : "Create a new group conversation",
    "Add participants" : "Add participants",
    "Conversation visibility" : "Conversation visibility",
    "Allow guests to join via link" : "Allow guests to join via link",
    "Enter password" : "Enter password",
    "This conversation has been locked" : "This conversation has been locked",
    "No permission to post messages in this conversation" : "No permission to post messages in this conversation",
    "Joining conversation …" : "Joining conversation …",
    "Send message" : "Send message",
    "Send without notification" : "Send without notification",
    "File to share" : "File to share",
    "Add emoji" : "Add emoji",
    "Send later" : "Send later",
    "Cancel editing" : "Cancel editing",
    "{user} is out of office and might not respond." : "{user} is out of office and might not respond.",
    "Share from {nextcloud}" : "Share from {nextcloud}",
    "Share from Files" : "Share from Files",
    "Share files to the conversation" : "Share files to the conversation",
    "Upload from device" : "Upload from device",
    "Create new poll" : "Create new poll",
    "Smart picker" : "Smart picker",
    "Record voice message" : "Record voice message",
    "End recording and send" : "End recording and send",
    "Dismiss recording" : "Dismiss recording",
    "Access to the microphone was denied" : "Access to the microphone was denied",
    "Microphone either not available or disabled in settings" : "Microphone either not available or disabled in settings",
    "Error while recording audio" : "Error while recording audio",
    "New file" : "New file",
    "Blank" : "Blank",
    "Error while creating file" : "Error while creating file",
    "Create and share a new file" : "Create and share a new file",
    "Name of the new file" : "Name of the new file",
    "Create file" : "Create file",
    "Someone is typing …" : "Someone is typing …",
    "{user1} is typing …" : "{user1} is typing …",
    "{user1} and {user2} are typing …" : "{user1} and {user2} are typing …",
    "{user1}, {user2} and {user3} are typing …" : "{user1}, {user2} and {user3} are typing …",
    "_{user1}, {user2}, {user3} and %n other are typing …_::_{user1}, {user2}, {user3} and %n others are typing …_" : ["{user1}, {user2}, {user3} and %n other are typing …","{user1}, {user2}, {user3} and %n others are typing …"],
    "Add more files" : "Add more files",
    "Send" : "Send",
    "In this conversation <strong>{user}</strong> can:" : "In this conversation <strong>{user}</strong> can:",
    "Edit default permissions for participants in <strong>{conversationName}</strong>" : "Edit default permissions for participants in <strong>{conversationName}</strong>",
    "Start a call" : "Start a call",
    "Skip the lobby" : "Skip the lobby",
    "Can post messages and reactions" : "Can post messages and reactions",
    "Enable the microphone" : "Enable the microphone",
    "Enable the camera" : "Enable the camera",
    "Share the screen" : "Share the screen",
    "Update permissions" : "Update permissions",
    "Updating permissions" : "Updating permissions",
    "Create poll" : "Create poll",
    "Question" : "Question",
    "Ask a question" : "Ask a question",
    "Answers" : "Answers",
    "Answer {option}" : "Answer {option}",
    "Delete poll option" : "Delete poll option",
    "Add answer" : "Add answer",
    "Settings" : "Settings",
    "Multiple answers" : "Multiple answers",
    "You voted for this option" : "You voted for this option",
    "End poll" : "End poll",
    "Change your vote" : "Change your vote",
    "Results" : "შედეგები",
    "Voted participants" : "Voted participants",
    "Send a message to \"{roomName}\"" : "Send a message to \"{roomName}\"",
    "Hide list of participants" : "Hide list of participants",
    "Show list of participants" : "Show list of participants",
    "Assistance requested in {roomName}" : "Assistance requested in {roomName}",
    "The message was sent to \"{roomName}\"" : "The message was sent to \"{roomName}\"",
    "Dismiss request for assistance" : "Dismiss request for assistance",
    "Send message to room" : "Send message to room",
    "Back to main room" : "Back to main room",
    "Back to your room" : "Back to your room",
    "Message all rooms" : "Message all rooms",
    "Start session" : "Start session",
    "Start a call before you start a breakout room session" : "Start a call before you start a breakout room session",
    "Stop session" : "Stop session",
    "The message was sent to all breakout rooms" : "The message was sent to all breakout rooms",
    "Send a message to all breakout rooms" : "Send a message to all breakout rooms",
    "Breakout rooms are not started" : "Breakout rooms are not started",
    "Disable lobby" : "Disable lobby",
    "Settings for participant \"{user}\"" : "Settings for participant \"{user}\"",
    "Participant \"{user}\"" : "Participant \"{user}\"",
    "moderator" : "moderator",
    "bot" : "bot",
    "guest" : "guest",
    "Ringing …" : "Ringing …",
    "Call rejected" : "Call rejected",
    "{time} talking …" : "{time} talking …",
    "{time} talking time" : "{time} talking time",
    "Raised their hand" : "Raised their hand",
    "Joined with video" : "Joined with video",
    "Joined via phone" : "Joined via phone",
    "Joined with audio" : "Joined with audio",
    "The text must be less than or equal to {maxLength} characters long. Your current text is {charactersCount} characters long." : "The text must be less than or equal to {maxLength} characters long. Your current text is {charactersCount} characters long.",
    "Remove group and members" : "Remove group and members",
    "Remove participant" : "Remove participant",
    "Notification was sent to {displayName}" : "Notification was sent to {displayName}",
    "Could not send notification to {displayName}" : "Could not send notification to {displayName}",
    "Permissions granted to {displayName}" : "Permissions granted to {displayName}",
    "Could not modify permissions for {displayName}" : "Could not modify permissions for {displayName}",
    "Permissions removed for {displayName}" : "Permissions removed for {displayName}",
    "Permissions set to default for {displayName}" : "Permissions set to default for {displayName}",
    "Phone number could not be hung up" : "Phone number could not be hung up",
    "Phone number could not be put on hold" : "Phone number could not be put on hold",
    "Phone number could not be muted" : "Phone number could not be muted",
    "Phone number could not be unmuted" : "Phone number could not be unmuted",
    "DTMF message could not be sent" : "DTMF message could not be sent",
    "Phone number copied to clipboard" : "Phone number copied to clipboard",
    "Phone number could not be copied" : "Phone number could not be copied",
    "Dial out phone" : "Dial out phone",
    "Hang up phone" : "Hang up phone",
    "Dial-in PIN" : "Dial-in PIN",
    "Demote from moderator" : "Demote from moderator",
    "Promote to moderator" : "Promote to moderator",
    "Resend invitation" : "Resend invitation",
    "Send call notification" : "Send call notification",
    "Dial out phone number" : "Dial out phone number",
    "Resume call for phone number" : "Resume call for phone number",
    "Put phone number on hold" : "Put phone number on hold",
    "Unmute phone number" : "Unmute phone number",
    "Mute phone number" : "Mute phone number",
    "Copy phone number" : "Copy phone number",
    "Reset custom permissions" : "Reset custom permissions",
    "Grant all permissions" : "Grant all permissions",
    "Remove all permissions" : "Remove all permissions",
    "Remove" : "Remove",
    "Permissions modified for {displayName}" : "Permissions modified for {displayName}",
    "Add users or groups" : "Add users or groups",
    "Add users" : "Add users",
    "Add groups" : "Add groups",
    "Add other sources" : "Add other sources",
    "Add emails" : "Add emails",
    "Integrations" : "Integrations",
    "Add federated users" : "Add federated users",
    "Searching …" : "Searching …",
    "Search for more users" : "Search for more users",
    "Search or add participants" : "Search or add participants",
    "Invitation was sent to {actorId}" : "Invitation was sent to {actorId}",
    "An error occurred while adding the participants" : "An error occurred while adding the participants",
    "Participants" : "Participants",
    "Participants ({count})" : "Participants ({count})",
    "Open chat" : "Open chat",
    "You have new unread messages in the chat." : "You have new unread messages in the chat.",
    "You have been mentioned in the chat." : "You have been mentioned in the chat.",
    "Chat" : "Chat",
    "Details" : "Details",
    "Shared items" : "Shared items",
    "No results found" : "No results found",
    "Load more results" : "Load more results",
    "Projects" : "Projects",
    "No shared items" : "No shared items",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "Link to a conversation" : "Link to a conversation",
    "No open conversations found" : "No open conversations found",
    "Either there are no open conversations or you joined all of them." : "Either there are no open conversations or you joined all of them.",
    "Check spelling or use complete words." : "Check spelling or use complete words.",
    "Search conversations or users" : "Search conversations or users",
    "Select conversation" : "Select conversation",
    "Number length is not valid" : "Number length is not valid",
    "Region code is not valid" : "Region code is not valid",
    "Number length is too short" : "Number length is too short",
    "Number length is too long" : "Number length is too long",
    "Number is not valid" : "Number is not valid",
    "Phone numbers" : "Phone numbers",
    "Display name: {name}" : "Display name: {name}",
    "Edit display name" : "Edit display name",
    "Save name" : "Save name",
    "Error while saving sounds setting" : "Error while saving sounds setting",
    "Play sounds when participants join or leave a call" : "Play sounds when participants join or leave a call",
    "Notification settings" : "Notification settings",
    "Default language" : "Default language",
    "Select location for attachments" : "Select location for attachments",
    "Error while setting attachment folder" : "Error while setting attachment folder",
    "Error while setting read status privacy" : "Error while setting read status privacy",
    "Error while setting typing status privacy" : "Error while setting typing status privacy",
    "Privacy" : "Privacy",
    "Attachments folder" : "Attachments folder",
    "Toggle full screen" : "Toggle full screen",
    "Search" : "Search",
    "Focus the chat input" : "Focus the chat input",
    "Unfocus the chat input to use shortcuts" : "Unfocus the chat input to use shortcuts",
    "Shortcuts while in a call" : "Shortcuts while in a call",
    "Camera on and off" : "Camera on and off",
    "Microphone on and off" : "Microphone on and off",
    "Raise or lower hand" : "Raise or lower hand",
    "Push to talk or push to mute" : "Push to talk or push to mute",
    "Start call silently" : "Start call silently",
    "Start call" : "Start call",
    "End call" : "End call",
    "You will be able to join the call only after a moderator starts it." : "You will be able to join the call only after a moderator starts it.",
    "End call for everyone" : "End call for everyone",
    "Starting the recording" : "Starting the recording",
    "Recording" : "Recording",
    "The call has been running for one hour." : "The call has been running for one hour.",
    "Cancel recording start" : "Cancel recording start",
    "Stop recording" : "Stop recording",
    "Raise hand" : "Raise hand",
    "Raise hand (R)" : "Raise hand (R)",
    "Lower hand" : "Lower hand",
    "Lower hand (R)" : "Lower hand (R)",
    "Send a reaction" : "Send a reaction",
    "React with {reaction}" : "React with {reaction}",
    "_%n participant in call_::_%n participants in call_" : ["%n participant in call","%n participants in call"],
    "You are not allowed to enable screensharing" : "You are not allowed to enable screensharing",
    "No screensharing" : "No screensharing",
    "Screensharing options" : "Screensharing options",
    "Enable screensharing" : "Enable screensharing",
    "Bad sent video and screen quality." : "Bad sent video and screen quality.",
    "Bad sent screen quality." : "Bad sent screen quality.",
    "Bad sent video quality." : "Bad sent video quality.",
    "Bad sent audio, video and screen quality." : "Bad sent audio, video and screen quality.",
    "Bad sent audio and screen quality." : "Bad sent audio and screen quality.",
    "Bad sent audio and video quality." : "Bad sent audio and video quality.",
    "Bad sent audio quality." : "Bad sent audio quality.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share.",
    "Disable background blur" : "Disable background blur",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Your internet connection or computer are busy and other participants might be unable to see your screen.",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "Your internet connection or computer are busy and other participants might be unable to see you.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video while doing a screenshare." : "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video while doing a screenshare.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare.",
    "Your internet connection or computer are busy and other participants might be unable to understand you and see your screen. To improve the situation try to disable your screenshare." : "Your internet connection or computer are busy and other participants might be unable to understand you and see your screen. To improve the situation try to disable your screenshare.",
    "Disable screenshare" : "Disable screenshare",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video." : "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video.",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "Your internet connection or computer are busy and other participants might be unable to understand you.",
    "Screen sharing is not supported by your browser." : "Screen sharing is not supported by your browser.",
    "Screen sharing requires the page to be loaded through HTTPS." : "Screen sharing requires the page to be loaded through HTTPS.",
    "Screensharing requires the page to be loaded through HTTPS." : "Screensharing requires the page to be loaded through HTTPS.",
    "An error occurred while starting screensharing." : "An error occurred while starting screensharing.",
    "Show your screen" : "Show your screen",
    "Stop screensharing" : "Stop screensharing",
    "Mute others" : "Mute others",
    "Start recording" : "Start recording",
    "Set up breakout rooms" : "Set up breakout rooms",
    "Remove participant {name}" : "Remove participant {name}",
    "Keep" : "Keep",
    "Open dialpad" : "Open dialpad",
    "Select a region" : "Select a region",
    "Search …" : "Search …",
    "Message without mention" : "Message without mention",
    "Mention myself" : "Mention myself",
    "The conversation does not exist" : "The conversation does not exist",
    "Join a conversation or start a new one!" : "Join a conversation or start a new one!",
    "Join a conversation or start a new one" : "Join a conversation or start a new one",
    "Nextcloud URL" : "Nextcloud URL",
    "Nextcloud user" : "Nextcloud user",
    "User password" : "User password",
    "Talk conversation" : "Talk conversation",
    "Skip TLS verification" : "Skip TLS verification",
    "Matrix server URL" : "Matrix server URL",
    "User" : "User",
    "Matrix channel" : "Matrix channel",
    "Mattermost server URL" : "Mattermost server URL",
    "Mattermost user" : "Mattermost user",
    "Team name" : "Team name",
    "Channel name" : "Channel name",
    "Rocket.Chat server URL" : "Rocket.Chat server URL",
    "User name or email address" : "User name or email address",
    "Rocket.Chat channel" : "Rocket.Chat channel",
    "Zulip server URL" : "Zulip server URL",
    "Bot user name" : "Bot user name",
    "Bot API key" : "Bot API key",
    "Zulip channel" : "Zulip channel",
    "API token" : "API token",
    "Slack channel" : "Slack channel",
    "Server ID or name" : "Server ID or name",
    "Channel" : "Channel",
    "Login" : "Login",
    "Chat ID" : "Chat ID",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "IRC server URL (e.g. chat.freenode.net:6667)",
    "Nickname" : "Nickname",
    "Connection password" : "Connection password",
    "IRC channel" : "IRC channel",
    "Channel password" : "Channel password",
    "NickServ nickname" : "NickServ nickname",
    "NickServ password" : "NickServ password",
    "Use TLS" : "Use TLS",
    "Use SASL" : "Use SASL",
    "Tenant ID" : "Tenant ID",
    "Client ID" : "Client ID",
    "Team ID" : "Team ID",
    "Thread ID" : "Thread ID",
    "XMPP/Jabber server URL" : "XMPP/Jabber server URL",
    "MUC server URL" : "MUC server URL",
    "Jabber ID" : "Jabber ID",
    "Media" : "Media",
    "Polls" : "Polls",
    "Deck cards" : "Deck cards",
    "Voice messages" : "Voice messages",
    "Locations" : "Locations",
    "Call recordings" : "Call recordings",
    "Audio" : "Audio",
    "Show all media" : "Show all media",
    "Show all files" : "Show all files",
    "Show all polls" : "Show all polls",
    "Show all deck cards" : "Show all deck cards",
    "Show all voice messages" : "Show all voice messages",
    "Show all locations" : "Show all locations",
    "Show all call recordings" : "Show all call recordings",
    "Show all audio" : "Show all audio",
    "Show all other" : "Show all other",
    "Group" : "Group",
    "You reconnected to the call" : "You reconnected to the call",
    "{actor} reconnected to the call" : "{actor} reconnected to the call",
    "You added {user0} and {user1}" : "You added {user0} and {user1}",
    "_You added {user0}, {user1} and %n more participant_::_You added {user0}, {user1} and %n more participants_" : ["You added {user0}, {user1} and %n more participant","You added {user0}, {user1} and %n more participants"],
    "An administrator added you and {user0}" : "An administrator added you and {user0}",
    "{actor} added you and {user0}" : "{actor} added you and {user0}",
    "_An administrator added you, {user0} and %n more participant_::_An administrator added you, {user0} and %n more participants_" : ["An administrator added you, {user0} and %n more participant","An administrator added you, {user0} and %n more participants"],
    "_{actor} added you, {user0} and %n more participant_::_{actor} added you, {user0} and %n more participants_" : ["{actor} added you, {user0} and %n more participant","{actor} added you, {user0} and %n more participants"],
    "An administrator added {user0} and {user1}" : "An administrator added {user0} and {user1}",
    "{actor} added {user0} and {user1}" : "{actor} added {user0} and {user1}",
    "_An administrator added {user0}, {user1} and %n more participant_::_An administrator added {user0}, {user1} and %n more participants_" : ["An administrator added {user0}, {user1} and %n more participant","An administrator added {user0}, {user1} and %n more participants"],
    "_{actor} added {user0}, {user1} and %n more participant_::_{actor} added {user0}, {user1} and %n more participants_" : ["{actor} added {user0}, {user1} and %n more participant","{actor} added {user0}, {user1} and %n more participants"],
    "You and {user0} joined the call" : "You and {user0} joined the call",
    "_You, {user0} and %n more participant joined the call_::_You, {user0} and %n more participants joined the call_" : ["You, {user0} and %n more participant joined the call","You, {user0} and %n more participants joined the call"],
    "{user0} and {user1} joined the call" : "{user0} and {user1} joined the call",
    "_{user0}, {user1} and %n more participant joined the call_::_{user0}, {user1} and %n more participants joined the call_" : ["{user0}, {user1} and %n more participant joined the call","{user0}, {user1} and %n more participants joined the call"],
    "You and {user0} left the call" : "You and {user0} left the call",
    "_You, {user0} and %n more participant left the call_::_You, {user0} and %n more participants left the call_" : ["You, {user0} and %n more participant left the call","You, {user0} and %n more participants left the call"],
    "{user0} and {user1} left the call" : "{user0} and {user1} left the call",
    "_{user0}, {user1} and %n more participant left the call_::_{user0}, {user1} and %n more participants left the call_" : ["{user0}, {user1} and %n more participant left the call","{user0}, {user1} and %n more participants left the call"],
    "You promoted {user0} and {user1} to moderators" : "You promoted {user0} and {user1} to moderators",
    "_You promoted {user0}, {user1} and %n more participant to moderators_::_You promoted {user0}, {user1} and %n more participants to moderators_" : ["You promoted {user0}, {user1} and %n more participant to moderators","You promoted {user0}, {user1} and %n more participants to moderators"],
    "An administrator promoted you and {user0} to moderators" : "An administrator promoted you and {user0} to moderators",
    "{actor} promoted you and {user0} to moderators" : "{actor} promoted you and {user0} to moderators",
    "_An administrator promoted you, {user0} and %n more participant to moderators_::_An administrator promoted you, {user0} and %n more participants to moderators_" : ["An administrator promoted you, {user0} and %n more participant to moderators","An administrator promoted you, {user0} and %n more participants to moderators"],
    "_{actor} promoted you, {user0} and %n more participant to moderators_::_{actor} promoted you, {user0} and %n more participants to moderators_" : ["{actor} promoted you, {user0} and %n more participant to moderators","{actor} promoted you, {user0} and %n more participants to moderators"],
    "An administrator promoted {user0} and {user1} to moderators" : "An administrator promoted {user0} and {user1} to moderators",
    "{actor} promoted {user0} and {user1} to moderators" : "{actor} promoted {user0} and {user1} to moderators",
    "_An administrator promoted {user0}, {user1} and %n more participant to moderators_::_An administrator promoted {user0}, {user1} and %n more participants to moderators_" : ["An administrator promoted {user0}, {user1} and %n more participant to moderators","An administrator promoted {user0}, {user1} and %n more participants to moderators"],
    "_{actor} promoted {user0}, {user1} and %n more participant to moderators_::_{actor} promoted {user0}, {user1} and %n more participants to moderators_" : ["{actor} promoted {user0}, {user1} and %n more participant to moderators","{actor} promoted {user0}, {user1} and %n more participants to moderators"],
    "You demoted {user0} and {user1} from moderators" : "You demoted {user0} and {user1} from moderators",
    "_You demoted {user0}, {user1} and %n more participant from moderators_::_You demoted {user0}, {user1} and %n more participants from moderators_" : ["You demoted {user0}, {user1} and %n more participant from moderators","You demoted {user0}, {user1} and %n more participants from moderators"],
    "An administrator demoted you and {user0} from moderators" : "An administrator demoted you and {user0} from moderators",
    "{actor} demoted you and {user0} from moderators" : "{actor} demoted you and {user0} from moderators",
    "_An administrator demoted you, {user0} and %n more participant from moderators_::_An administrator demoted you, {user0} and %n more participants from moderators_" : ["An administrator demoted you, {user0} and %n more participant from moderators","An administrator demoted you, {user0} and %n more participants from moderators"],
    "_{actor} demoted you, {user0} and %n more participant from moderators_::_{actor} demoted you, {user0} and %n more participants from moderators_" : ["{actor} demoted you, {user0} and %n more participant from moderators","{actor} demoted you, {user0} and %n more participants from moderators"],
    "An administrator demoted {user0} and {user1} from moderators" : "An administrator demoted {user0} and {user1} from moderators",
    "{actor} demoted {user0} and {user1} from moderators" : "{actor} demoted {user0} and {user1} from moderators",
    "_An administrator demoted {user0}, {user1} and %n more participant from moderators_::_An administrator demoted {user0}, {user1} and %n more participants from moderators_" : ["An administrator demoted {user0}, {user1} and %n more participant from moderators","An administrator demoted {user0}, {user1} and %n more participants from moderators"],
    "_{actor} demoted {user0}, {user1} and %n more participant from moderators_::_{actor} demoted {user0}, {user1} and %n more participants from moderators_" : ["{actor} demoted {user0}, {user1} and %n more participant from moderators","{actor} demoted {user0}, {user1} and %n more participants from moderators"],
    "You: {lastMessage}" : "You: {lastMessage}",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "The recording failed. Please contact your administrator." : "The recording failed. Please contact your administrator.",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?",
    "Leave this page" : "Leave this page",
    "Join here" : "Join here",
    "Deck card has been posted to {conversation}" : "Deck card has been posted to {conversation}",
    "An error occurred while posting deck card to conversation" : "An error occurred while posting deck card to conversation",
    "Post to a conversation" : "Post to a conversation",
    "Post to conversation" : "Post to conversation",
    "An error occurred while posting location to conversation" : "An error occurred while posting location to conversation",
    "Share to a conversation" : "Share to a conversation",
    "Share to conversation" : "Share to conversation",
    "Error while clearing conversation history" : "Error while clearing conversation history",
    "Error occurred while allowing guests" : "Error occurred while allowing guests",
    "Error occurred while disallowing guests" : "Error occurred while disallowing guests",
    "Error occurred when restricting the conversation to moderator" : "Error occurred when restricting the conversation to moderator",
    "Error occurred when opening the conversation to everyone" : "Error occurred when opening the conversation to everyone",
    "Conversation password has been saved" : "Conversation password has been saved",
    "Conversation password has been removed" : "Conversation password has been removed",
    "Error occurred while saving conversation password" : "Error occurred while saving conversation password",
    "Call recording is starting." : "Call recording is starting.",
    "Call recording stopped while starting." : "Call recording stopped while starting.",
    "Call recording stopped. You will be notified once the recording is available." : "Call recording stopped. You will be notified once the recording is available.",
    "Conversation picture set" : "Conversation picture set",
    "Conversation picture deleted" : "Conversation picture deleted",
    "Could not delete the conversation picture" : "Could not delete the conversation picture",
    "Could not post message: {errorMessage}" : "Could not post message: {errorMessage}",
    "An error occurred while fetching the participants" : "An error occurred while fetching the participants",
    "Could not send invitation to {actorId}" : "Could not send invitation to {actorId}",
    "Invitations sent" : "Invitations sent",
    "Error occurred when sending invitations" : "Error occurred when sending invitations",
    "An error occurred while creating breakout rooms" : "An error occurred while creating breakout rooms",
    "An error occurred while re-ordering the attendees" : "An error occurred while re-ordering the attendees",
    "An error occurred while deleting breakout rooms" : "An error occurred while deleting breakout rooms",
    "An error occurred while starting breakout rooms" : "An error occurred while starting breakout rooms",
    "An error occurred while stopping breakout rooms" : "An error occurred while stopping breakout rooms",
    "An error occurred while sending a message to the breakout rooms" : "An error occurred while sending a message to the breakout rooms",
    "An error occurred while requesting assistance" : "An error occurred while requesting assistance",
    "An error occurred while resetting the request for assistance" : "An error occurred while resetting the request for assistance",
    "An error occurred while joining breakout room" : "An error occurred while joining breakout room",
    "{guest} (guest)" : "{guest} (guest)",
    "An error occurred while submitting your vote" : "An error occurred while submitting your vote",
    "An error occurred while ending the poll" : "An error occurred while ending the poll",
    "Failed to add reaction" : "Failed to add reaction",
    "Failed to remove reaction" : "Failed to remove reaction",
    "Error while uploading file \"{fileName}\"" : "Error while uploading file \"{fileName}\"",
    "Not enough free space to upload file \"{fileName}\"" : "Not enough free space to upload file \"{fileName}\"",
    "You are not allowed to share files" : "You are not allowed to share files",
    "Error while sharing file" : "Error while sharing file",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari.",
    "_%n hour_::_%n hours_" : ["%n hour","%n hours"],
    "_%n day_::_%n days_" : ["%n day","%n days"],
    "_%n week_::_%n weeks_" : ["%n week","%n weeks"],
    "Later today – {timeLocale}" : "Later today – {timeLocale}",
    "Tomorrow – {timeLocale}" : "Tomorrow – {timeLocale}",
    "This weekend – {timeLocale}" : "This weekend – {timeLocale}",
    "Next week – {timeLocale}" : "Next week – {timeLocale}",
    "Conversation link copied to clipboard" : "Conversation link copied to clipboard",
    "The link could not be copied" : "The link could not be copied",
    "Sending signaling message has failed" : "Sending signaling message has failed",
    "Lost connection to signaling server. Trying to reconnect." : "Lost connection to signaling server. Trying to reconnect.",
    "The configured signaling server needs to be updated to be compatible with this version of Talk. Please contact your administration." : "The configured signaling server needs to be updated to be compatible with this version of Talk. Please contact your administration.",
    "Please reload the page." : "Please reload the page.",
    "Do not disturb" : "Do not disturb",
    "Away" : "Away",
    "Microphone {number}" : "Microphone {number}",
    "Camera {number}" : "Camera {number}",
    "Speaker {number}" : "Speaker {number}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "You seem to be talking while muted, please unmute yourself for others to hear you",
    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}.",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing",
    "Access to microphone & camera is only possible with HTTPS" : "Access to microphone & camera is only possible with HTTPS",
    "Please move your setup to HTTPS" : "Please move your setup to HTTPS",
    "Access to microphone & camera was denied" : "Access to microphone & camera was denied",
    "WebRTC is not supported in your browser" : "WebRTC is not supported in your browser",
    "Please use a different browser like Firefox or Chrome" : "Please use a different browser like Firefox or Chrome",
    "Error while accessing microphone & camera" : "Error while accessing microphone & camera",
    "%s Talk on your mobile devices" : "%s Talk on your mobile devices",
    "Join conversations at any time, anywhere, on any device." : "Join conversations at any time, anywhere, on any device.",
    "Android app" : "Android app",
    "iOS app" : "iOS app",
    "__language_name__" : "ქართული ენა",
    "Tasks" : "Tasks",
    "Notes" : "Notes",
    "Talk to %s" : "Talk to %s",
    "Set reminder for later today" : "Set reminder for later today",
    "Set reminder for tomorrow" : "Set reminder for tomorrow",
    "Set reminder for this weekend" : "Set reminder for this weekend",
    "Set reminder for next week" : "Set reminder for next week",
    "Open poll • You voted already" : "Open poll • You voted already",
    "Open poll • Click to vote" : "Open poll • Click to vote",
    "Poll • Ended" : "Poll • Ended",
    "Talk recording from {time} ({conversation})" : "Talk recording from {time} ({conversation})",
    "_Poll results • %n vote_::_Poll results • %n votes_" : ["Poll results • %n vote","Poll results • %n votes"],
    "_Open poll • %n vote_::_Open poll • %n votes_" : ["Open poll • %n vote","Open poll • %n votes"],
    "Submit vote" : "Submit vote",
    "Your privacy setting has been saved" : "Your privacy setting has been saved",
    "Failed to save sounds setting" : "Failed to save sounds setting",
    "Sounds setting saved" : "Sounds setting saved",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed."
},
"nplurals=2; plural=(n!=1);");
