OC.L10N.register(
    "spreed",
    {
    "a conversation" : "en samtale",
    "(Duration %s)" : "(Varighed %s)",
    "You attended a call with {user1}" : "Du deltog i et opkald med {user1}",
    "_%n guest_::_%n guests_" : ["%n gæst","%n gæster"],
    "You attended a call with {user1} and {user2}" : "Du deltog i et opkald med {user1} og {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Du deltog i et opkald med {user1}, {user2} og {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Du deltog i et opkald med {user1}, {user2}, {user3} og {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Du deltog i et opkald med {user1}, {user2}, {user3}, {user4} og {user5}",
    "_%n other_::_%n others_" : ["%n andre","%n andre"],
    "{actor} invited you to {call}" : "{actor} inviterede dig til {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Du var inviteret til en <strong>samtale</strong> eller fik et <strong>opkald</strong>",
    "Other activities" : "Andre aktiviteter",
    "Talk" : "Snak",
    "Guest" : "Gæst",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge og Safari kan nu benyttes til at deltage i lyd- og videosamtaler",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- En-til-en-samtaler er nu vedvarende og kan ikke længere omdannes til gruppesamtaler ved et uheld. Derudover, når en af deltagerne forlader samtalen, slettes samtalen ikke længere automatisk. Kun hvis begge deltagere forlader samtalen, så slettes samtalen fra serveren",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Nu kan nu sende en notifikation til alle deltagere ved at skrive \"@all\" i chatten",
    "- With the \"arrow-up\" key you can repost your last message" : "- Ved at trykke på \"pil op\" kan du sende din sidste besked igen",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Snak understøtter nu kommandoer. Send \"/help\" som en chat-besked for at se om din administrator har konfigureret nogen",
    "- With projects you can create quick links between conversations, files and other items" : "- Med projekter kan du oprette hurtige links mellem samtaler, filer og andre objekter",
    "- You can now mention guests in the chat" : "- Du kan nu omtale gæster i samtalen",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Samtaler kan nu have en lobby. Dette giver mulighed for at moderatorer kan deltage i samtalen for at forberede mødet, mens almindelige brugere og gæster må vente",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- Du kan nu svare direkte på beskeder og dermed give andre brugere mere kontekst om hvad din besked handler om",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- Søgninger efter samtaler og deltagere vil nu også filtrere dine eksisterende samtaler, hvilke gør det meget nemmere at finde tidligere samtaler",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- Du kan nu tilføje brugerdefinerede brugergrupper til samtaler når cirkel-appen er installeret",
    "- Check out the new grid and call view" : "- Tjek den nye gitter og opkaldsvisning",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- Du kan nu uploade og trække og slippe filer direkte fra din enhed til chatten",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- Delte filer åbnes nu direkte inde i chatvisningen med fremviserapps",
    "- You can now search for chats and messages in the unified search in the top bar" : "- Du kan nu søge efter chats og beskeder i den samlede søgning i den øverste bjælke",
    "- Spice up your messages with emojis from the emoji picker" : "- Krydr dine beskeder med emojis fra emojivælgeren",
    "- You can now change your camera and microphone while being in a call" : "- Du kan nu skifte kamera og mikrofon, mens du er i et opkald",
    "- Give your conversations some context with a description and open it up so logged in users can find it and join themselves" : "- Giv dine samtaler en vis kontekst med en beskrivelse, og åbn den, så brugere der er logget på kan finde den og deltage selv",
    "- See a read status and send failed messages again" : "- Se en læst status og send mislykkede beskeder igen",
    "- Raise your hand in a call with the R key" : "- Ræk hånden op i et opkald med R-tasten",
    "- Join the same conversation and call from multiple devices" : "- Deltag i den samme samtale og opkald fra flere enheder",
    "- Send voice messages, share your location or contact details" : "- Send talebeskeder, del din placering eller kontaktoplysninger",
    "- Add groups to a conversation and new group members will automatically be added as participants" : "- Føj grupper til en samtale, og nye gruppemedlemmer vil automatisk blive tilføjet som deltagere",
    "- A preview of your audio and video is shown before joining a call" : "- En forhåndsvisning af din lyd og video vises, før du deltager i et opkald",
    "- You can now blur your background in the newly designed call view" : "- Du kan nu sløre din baggrund i den nydesignede opkaldsvisning",
    "- Moderators can now assign general and individual permissions to participants" : "- Moderatorer kan nu tildele generelle og individuelle tilladelser til deltagere",
    "- In the sidebar you can now find an overview of the latest shared items" : "- I sidebjælken kan du nu finde en oversigt over de seneste delte elementer",
    "- Use a poll to collect the opinions of others or settle on a date" : "- Brug en meningsmåling til at indsamle andres meninger eller til at vælge en dato",
    "- Configure an expiration time for chat messages" : "- Konfigurer en udløbstid for chatbeskeder",
    "- Start calls without notifying others in big conversations. You can send individual call notifications once the call has started." : "- Start opkald uden at underrette andre i store samtaler. Du kan sende individuelle opkaldsmeddelelser, når opkaldet er startet.",
    "- Send chat messages without notifying the recipients in case it is not urgent" : "- Send chatbeskeder uden at give modtagerne besked, hvis det ikke haster",
    "- Link various items using the new smart-picker by typing a \"/\"" : "- Link forskellige elementer ved at bruge den nye Smart Vælger ved at taste \"/\"",
    "- Moderators can now ban accounts and guests to prevent them from rejoining a conversation" : "- Moderatorer kan nu bandlyse konti og gæster for at forhindre dem i at gen-deltage i en samtale",
    "Talk updates ✅" : "Snak opdateringer ✅",
    "Reaction deleted by author" : "Reaktion slettet af forfatter",
    "{actor} created the conversation" : "{actor} oprettede samtalen",
    "You created the conversation" : "Du oprettede samtalen",
    "System created the conversation" : "Systemet oprettede samtalen",
    "An administrator created the conversation" : "En administrator oprettede samtalen",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} omdøbte samtalen fra \"%1$s\" til \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Du omdøbte samtalen fra \"%1$s\" til \"%2$s\"",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "En administrator omdøbte samtalen fra \"%1$s\" til \"%2$s\"",
    "{actor} set the description" : "{actor} satte beskrivelsen",
    "You set the description" : "Du satte beskrivelsen",
    "An administrator set the description" : "En administrator satte beskrivelsen",
    "{actor} removed the description" : "{actor} fjernede beskrivelsen",
    "You removed the description" : "Du fjernede beskrivelsen",
    "An administrator removed the description" : "En administrator fjernede beskrivelsen",
    "You started a call" : "Du startede et opkald",
    "{actor} started a call" : "{actor} startede et opkald",
    "{actor} joined the call" : "{actor} deltog i opkaldet",
    "You joined the call" : "Du deltog i opkaldet",
    "{actor} left the call" : "{actor} forlod opkaldet",
    "You left the call" : "Du forlod opkaldet",
    "{actor} unlocked the conversation" : "{actor} låste op for samtalen",
    "You unlocked the conversation" : "Du låste op for samtalen",
    "An administrator unlocked the conversation" : "En administrator låste samtalen op",
    "{actor} locked the conversation" : "{actor} låste samtalen",
    "You locked the conversation" : "Du låste samtalen",
    "An administrator locked the conversation" : "En administrator låste samtalen",
    "{actor} limited the conversation to the current participants" : "{actor} begrænsede samtalen til de nuværende deltagere",
    "You limited the conversation to the current participants" : "Du begrænsede samtalen til de nuværende deltagere",
    "An administrator limited the conversation to the current participants" : "En administrator begrænsede samtalen til de nuværende deltagere",
    "{actor} opened the conversation to registered users" : "{actor} åbnede samtalen for registrerede brugere",
    "You opened the conversation to registered users" : "Du åbnede samtalen for registrerede brugere",
    "An administrator opened the conversation to registered users" : "En administrator åbnede samtalen for registrerede brugere",
    "The conversation is now open to everyone" : "Samtalen er nu åben for alle",
    "{actor} opened the conversation to everyone" : "{actor} åbnede samtalen for alle",
    "You opened the conversation to everyone" : "Du åbnede samtalen for alle",
    "{actor} restricted the conversation to moderators" : "{actor} begrænsede samtalen til moderatorer",
    "You restricted the conversation to moderators" : "Du begrænsede samtalen til moderatorer",
    "{actor} started breakout rooms" : "{actor} started breakout rum",
    "You started breakout rooms" : "Du startede et breakout rum",
    "{actor} stopped breakout rooms" : "{actor} stoppede breakout rum",
    "You stopped breakout rooms" : "Du stoppede breakout rum",
    "{actor} allowed guests" : "{actor} tillod gæster",
    "You allowed guests" : "Du tillod gæster",
    "An administrator allowed guests" : "En administrator tillod gæster",
    "{actor} disallowed guests" : "{actor} forbød gæster",
    "You disallowed guests" : "Du forbød gæster",
    "An administrator disallowed guests" : "En administrator afviste gæster",
    "{actor} set a password" : "{actor} indstillede en adgangskode",
    "You set a password" : "Du indstillede en adgangskode",
    "An administrator set a password" : "En administrator satte et kodeord",
    "{actor} removed the password" : "{actor} fjernede adgangskoden",
    "You removed the password" : "Du fjernede adgangskoden",
    "An administrator removed the password" : "En administrator fjernede kodeordet",
    "{actor} added {user}" : "{actor} tilføjede {user}",
    "You joined the conversation" : "Du deltog i samtalen",
    "{actor} joined the conversation" : "{actor} deltog i samtalen",
    "You added {user}" : "Du tilføjede {user}",
    "{actor} added you" : "{actor} tilføjede dig",
    "An administrator added you" : "En administrator tilføjede dig",
    "An administrator added {user}" : "En administrator tilføjede {user}",
    "You left the conversation" : "Du forlod samtalen",
    "{actor} left the conversation" : "{actor} forlod samtalen",
    "{actor} removed {user}" : "{actor} fjernede {user}",
    "You removed {user}" : "Du fjernede {user}",
    "{actor} removed you" : "{actor} fjernede dig",
    "An administrator removed you" : "En administrator fjernede dig",
    "An administrator removed {user}" : "En administrator fjernede {user}",
    "{federated_user} accepted the invitation" : "{federated_user} tog imod invitationen",
    "{actor} removed {federated_user}" : "{actor} fjernede {federated_user}",
    "You removed {federated_user}" : "Du fjernede {federated_user}",
    "An administrator removed {federated_user}" : "En administrator fjernede {federated_user}",
    "{federated_user} declined the invitation" : "{federated_user} afviste invitationen",
    "{actor} added group {group}" : "{actor} tilføjede gruppen {group}",
    "You added group {group}" : "Du tilføjede en gruppen {group}",
    "An administrator added group {group}" : "En administrator tilføjede gruppen {group}",
    "{actor} removed group {group}" : "{actor} fjernede gruppen {group}",
    "You removed group {group}" : "Du fjernede gruppen {group}",
    "An administrator removed group {group}" : "En administrator fjernede gruppen {group}",
    "{actor} promoted {user} to moderator" : "{actor} forfremmede {user} til moderator",
    "You promoted {user} to moderator" : "Du forfremmede {user} til moderator",
    "{actor} promoted you to moderator" : "{actor} forfremmede dig til moderator",
    "{actor} demoted {user} from moderator" : "{actor} degraderede {user} fra moderator",
    "You demoted {user} from moderator" : "Du degraderede {user} fra moderator",
    "{actor} demoted you from moderator" : "{actor} degraderede dig fra moderator",
    "{actor} shared a file which is no longer available" : "{actor} delte en fil, der ikke længere er tilgængelig",
    "You shared a file which is no longer available" : "Du delte en fil, der ikke længere er tilgængelig",
    "You cleared the history of the conversation" : "Du ryddede samtalens historik",
    "Message deleted by author" : "Beskeden er slettet af forfatteren",
    "Message deleted by you" : "Besked slettet af dig",
    "Administration" : "Administration",
    "System" : "System",
    "%s (guest)" : "%s (gæst)",
    "Talk conversations" : "Snak samtaler",
    "Call %s" : "Ring op %s",
    "Storage quota exceeded" : "Lagringskvote overskredet",
    "File not found" : "Filen blev ikke fundet",
    "File is not shared, or shared but not with the user" : "Filen er ikke delt, eller den er delt men ikke med brugeren",
    "Poll" : "Afstemning",
    "File is too big" : "Filen er for stor",
    "Invalid file provided" : "Der er angivet en ugyldig fil",
    "Invalid image" : "Ugyldigt billede",
    "Unknown filetype" : "Ukendt filtype",
    "Talk mentions" : "Snak omtaler",
    "Say hi to your friends and colleagues!" : "Sig hej til dine venner og kollegaer.",
    "No unread mentions" : "Ingen ulæste omtaler",
    "Call in progress" : "Opkald i gang",
    "Write to conversation" : "Skriv til samtale",
    "Writes event information into a conversation of your choice" : "Skriver begivenhedsinformation i en samtale du vælger",
    "Conversation invitation" : "Invitation til samtale",
    "Description" : "Beskrivelse",
    "Meeting" : "Møde",
    "Password request: %s" : "Adgangskode-forespørgsel: %s",
    "Private conversation" : "Privat samtale",
    "Deleted user (%s)" : "Slettet bruger (%s)",
    "Dismiss notification" : "Fjern notifikation",
    "{user1} invited you to join {roomName} on {remoteServer}" : "{user1} inviterede dig til at deltage i {roomName} på {remoteServer}",
    "Accept" : "Accepter",
    "Decline" : "Afvis",
    "New message" : "Ny besked",
    "Reminder" : "Påmindelse",
    "{user} sent you a private message" : "{user} sendte dig en privat besked",
    "{user} sent a message in conversation {call}" : "{user} sendte en besked i samtalen {call}",
    "A deleted user sent a message in conversation {call}" : "En slettet bruger sendte en besked i samtalen {call}",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (gæst) sendte en besked i samtalen {call}",
    "A guest sent a message in conversation {call}" : "En gæst sendte en besked i samtalen {call}",
    "{user} replied to your private message" : "{user} svarede på din private besked",
    "{user} replied to your message in conversation {call}" : "{user} svarede på din besked i samtalen {call}",
    "A deleted user replied to your message in conversation {call}" : "En slettet bruger svarede på din besked i samtalen {call}",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (gæst) svarede på din besked i samtalen {call}",
    "A guest replied to your message in conversation {call}" : "En gæst svarede på din besked i samtalen {call}",
    "{user} mentioned you in a private conversation" : "{user} omtalte dig i en privat samtale",
    "{user} mentioned you in conversation {call}" : "{user} omtalte dig i samtalen {call}",
    "A deleted user mentioned you in conversation {call}" : "En slettet bruger omtalte dig i samtalen {call}",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (gæst) omtalte dig i samtalen {call}",
    "A guest mentioned you in conversation {call}" : "En gæst omtalte dig i samtalen {call}",
    "View chat" : "Se chat",
    "{user} invited you to a group conversation: {call}" : "{user} inviterede dig til en gruppesamtale: {call}",
    "Join call" : "Deltag i opkaldet",
    "Answer call" : "Besvar opkald",
    "Call back" : "Ring tilbage",
    "You missed a call from {user}" : "Du missede et opkald fra {user}",
    "A group call has started in {call}" : "Et gruppeopkald er startet i {call}",
    "You missed a group call in {call}" : "Du missede en gruppesamtale i {call}",
    "{email} is requesting the password to access {file}" : "{email} anmoder om adgangskoden til {file}",
    "{email} tried to request the password to access {file}" : "{email} forsøgte at anmode om adgangskoden til {file}",
    "Someone is requesting the password to access {file}" : "Nogen beder om adgangskoden til {file}",
    "Someone tried to request the password to access {file}" : "Nogen forsøgte at bede om adgangskoden til {file}",
    "Open settings" : "Indstillinger",
    "error" : "fejl",
    "Default" : "Standard",
    "Presentation" : "Præsentation",
    "Conversations" : "Samtaler",
    "Messages" : "Beskeder",
    "Avatar image is not square" : "Avatar billedet er ikke kvadratisk",
    "Favorites" : "Favoritter",
    "Other" : "Andet",
    "Note to self" : "Bemærkning til dig selv",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "De Forenede Arabiske Emirater",
    "Afghanistan" : "Afghanistan",
    "Antigua and Barbuda" : "Antigua og Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albanien",
    "Armenia" : "Armenien",
    "Angola" : "Angola",
    "Antarctica" : "Antarktis",
    "Argentina" : "Argentina",
    "American Samoa" : "Amerikansk Samoa",
    "Austria" : "Østrig",
    "Australia" : "Australien",
    "Aruba" : "Aruba",
    "Åland Islands" : "Ålandsøerne",
    "Azerbaijan" : "Aserbajdsjan",
    "Bosnia and Herzegovina" : "Bosnien-Hercegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Belgien",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgarien",
    "Bahrain" : "Bahrain",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Saint Barthélemy",
    "Bermuda" : "Bermuda",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius og Saba",
    "Brazil" : "Brasilien",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bhutanworld. kgm",
    "Bouvet Island" : "Bouvet Island",
    "Botswana" : "Botswana",
    "Belarus" : "Hviderusland",
    "Belize" : "Belize",
    "Canada" : "Canada",
    "Cocos (Keeling) Islands" : "Cocos (Keeling) Islands",
    "Central African Republic" : "Den Centralafrikanske Republik",
    "Congo" : "Congo",
    "Switzerland" : "Schweiz",
    "Cook Islands" : "Cook Islands",
    "Chile" : "Chile",
    "Cameroon" : "Cameroun",
    "China" : "Kina",
    "Colombia" : "Colombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cabo Verde" : "Cabo Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Juleøen",
    "Cyprus" : "Cypern",
    "Germany" : "Tyskland",
    "Djibouti" : "Djibouti",
    "Denmark" : "Danmark",
    "Dominican Republic" : "Den Dominikanske Republik",
    "Algeria" : "Algeriet",
    "Ecuador" : "Ecuador",
    "Estonia" : "Estland",
    "Egypt" : "Egypten",
    "Eritrea" : "Eritrea",
    "Spain" : "Spanien",
    "Ethiopia" : "Etiopien",
    "Finland" : "Finland",
    "Fiji" : "Fiji",
    "Faroe Islands" : "Færøerne",
    "France" : "Frankrig",
    "Gabon" : "Gabon",
    "Grenada" : "Grenada",
    "Georgia" : "Georgien",
    "French Guiana" : "Fransk Guyana",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Grønland",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Ækvatorialguinea",
    "Greece" : "Grækenland",
    "South Georgia and the South Sandwich Islands" : "Sydgeorgien og de sydlige Sandwichøer",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Hørt Island og McDonald Islands",
    "Honduras" : "Honduras",
    "Croatia" : "Kroatien",
    "Haiti" : "Haiti",
    "Hungary" : "Ungarn",
    "Indonesia" : "Indonesien",
    "Ireland" : "Irland",
    "Israel" : "Israel",
    "Isle of Man" : "Isle of Man",
    "India" : "Indien",
    "British Indian Ocean Territory" : "Britisk område i Det Indiske Ocean",
    "Iraq" : "Irak",
    "Iceland" : "Island",
    "Italy" : "Italien",
    "Jamaica" : "Jamaica",
    "Jordan" : "Jordan",
    "Japan" : "Japan",
    "Kenya" : "Kenya",
    "Kyrgyzstan" : "Kirgisistan",
    "Cambodia" : "Cambodja",
    "Kiribati" : "Kiribati",
    "Comoros" : "Comoros",
    "Saint Kitts and Nevis" : "Saint Christopher og Nevis",
    "Kuwait" : "Kuwait",
    "Cayman Islands" : "Caymanøerne",
    "Kazakhstan" : "Kasakhstan",
    "Lebanon" : "Libanon",
    "Saint Lucia" : "Saint Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Litauen",
    "Luxembourg" : "Luxembourg",
    "Latvia" : "Letland",
    "Libya" : "Libyen",
    "Morocco" : "Marokko",
    "Monaco" : "Monaco",
    "Montenegro" : "Montenegro",
    "Madagascar" : "Madagaskar",
    "Marshall Islands" : "Marshalløerne",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongoliet",
    "Macao" : "Macao",
    "Northern Mariana Islands" : "Nord Mariana øerne",
    "Mauritania" : "Mauretanien",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauritius",
    "Maldives" : "Maldiverne",
    "Malawi" : "Malawi",
    "Mexico" : "Mexico",
    "Malaysia" : "Malaysia",
    "Mozambique" : "Mozambique",
    "Namibia" : "Namibia",
    "New Caledonia" : "Ny kaledonien",
    "Niger" : "Niger",
    "Norfolk Island" : "Norfolk Island",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Holland",
    "Norway" : "Norge",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "New Zealand",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Fransk Polynesien",
    "Papua New Guinea" : "Papua Ny Guinea",
    "Philippines" : "Filippinerne",
    "Pakistan" : "Pakistan",
    "Poland" : "Polen",
    "Saint Pierre and Miquelon" : "Saint Pierre og Miquelon",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Puerto Rico",
    "Portugal" : "Portugal",
    "Palau" : "Palau",
    "Paraguay" : "Paraguay",
    "Qatar" : "Qatar",
    "Réunion" : "Réunion",
    "Romania" : "Rumænien",
    "Serbia" : "Serbien",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Saudi Arabien",
    "Solomon Islands" : "Salomonøerne",
    "Seychelles" : "Seychellerne",
    "Sudan" : "Sudan",
    "Sweden" : "Sverige",
    "Singapore" : "Singapore",
    "Saint Helena, Ascension and Tristan da Cunha" : "Saint Helena, Ascension og Tristan da Cunha",
    "Slovenia" : "Slovenien",
    "Svalbard and Jan Mayen" : "Svalbard og Jan Mayen",
    "Slovakia" : "Slovakiet",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Surinam",
    "South Sudan" : "Sydsudan",
    "Sao Tome and Principe" : "São Tomé og Príncipe",
    "El Salvador" : "El Salvador",
    "Turks and Caicos Islands" : "Turks- og Caicosøerne",
    "Chad" : "Chad",
    "Togo" : "Togo",
    "Thailand" : "Thailand",
    "Tajikistan" : "Tadsjikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor- Leste",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunesien",
    "Tonga" : "Tonga",
    "Turkey" : "Tyrkiet",
    "Trinidad and Tobago" : "Trinidad og Tobago",
    "Tuvalu" : "Tuvalu",
    "Ukraine" : "Ukraine",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "United States Minor Outliing Islands",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Usbekistan",
    "Holy See" : "Pavestolen",
    "Saint Vincent and the Grenadines" : "Saint Vincent og Grenadinerne",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis og Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Yemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Sydafrika",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Federation" : "Datafællesskab",
    "Invalid date, date format must be YYYY-MM-DD" : "Ugyldig dato. Brug formatet ÅÅÅÅ-MM-DD",
    "Conversation not found" : "Samtalen blev ikke fundet",
    "Chat, video & audio-conferencing using WebRTC" : "Chat, video- & lyd-samtaler over WebRTC",
    "Chat, video & audio-conferencing using WebRTC\n\n* 💬 **Chat** Nextcloud Talk comes with a simple text chat, allowing you to share or upload files from your Nextcloud Files app or local device and mention other participants.\n* 👥 **Private, group, public and password protected calls!** Invite someone, a whole group or send a public link to invite to a call.\n* 🌐 **Federated chats** Chat with other Nextcloud users on their servers\n* 💻 **Screen sharing!** Share your screen with the participants of your call.\n* 🚀 **Integration with other Nextcloud apps** like Files, Calendar, User status, Dashboard, Flow, Maps, Smart picker, Contacts, Deck, and many more.\n* 🌉 **Sync with other chat solutions** With [Matterbridge](https://github.com/42wim/matterbridge/) being integrated in Talk, you can easily sync a lot of other chat solutions to Nextcloud Talk and vice-versa." : "Chat, video & audio-konference ved anvendelse af WebRTC\n\n* 💬 **Chat** Nextcloud Snak kommer med en simpel tekst chat, der giver dig mulighed for at dele eller uploade filer fra din Nextcloud filer app eller lokale apparatog nævne andre deltagere.\n* 👥 **Privat, gruppe, offentlig og adgangskodebeskyttede opkald!** Inviter nogen, en hel gruppe eller send et offentligt link for at invitere til et opkald.\n* 🌐 **Sammenkoblede chats** Chat med andre Nextcloud brugere på deres servere\n* 💻 **Skærmdeling!** Del din skærm med deltagerne i dit opkald.\n* 🚀 **Integration med andre Nextcloud apps** såsom filer, kalender, Brugerstatus, Opslagstavle, Flow, Kort, Smart vælger, Kontakter, Opslag, og meget mere.\n* 🌉 **Synk med andre chatløsninger** Med [Matterbridge](https://github.com/42wim/matterbridge/) integreret i Snak, kan du let synkronisere mange andre chat løsninger med Nextcloud Snak og vice-versa.",
    "Leave call" : "Forlad opkald",
    "Discuss this file" : "Diskuter denne fil",
    "Loading …" : "Indlæser …",
    "Share this file with others to discuss it" : "Del denne fil med andre for at diskutere den",
    "Join conversation" : "Deltag i samtale",
    "Share this file" : "Del denne fil",
    "Error occurred when joining the conversation" : "Fejl under deltagelse i samtalen",
    "The password is wrong. Try again." : "Adgangskoden er forkert. Prøv igen.",
    "Password" : "Adgangskode",
    "Submit" : "Tilføj",
    "Error requesting the password." : "Der opstod en fejl ved anmodning om adgangskoden.",
    "Request password" : "Anmod om adgangskode",
    "This conversation has ended" : "Samtalen er slut",
    "Everyone" : "Alle",
    "Users and moderators" : "Brugere og moderatorer",
    "Moderators only" : "Kun moderatorer",
    "Save changes" : "Gem ændringer",
    "Saving …" : "Gemmer…",
    "Saved!" : "Gemt!",
    "Limit to groups" : "Begræns til grupper",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "Når en eller flere grupper er valgt kan kun personer i de valgte grupper deltage i samtaler.",
    "Guests can still join public conversations." : "Gæster kan stadig deltage i offentlige samtaler.",
    "When a call has started, everyone with access to the conversation can join the call." : "Når et opkald er startet, kan alle som har adgang til samtalen deltage i opkaldet.",
    "Enabled" : "Aktiveret",
    "Disabled" : "Deaktiveret",
    "State" : "Tilstand",
    "Name" : "Navn",
    "Beta" : "Beta",
    "Permissions" : "Rettigheder",
    "All messages" : "Alle beskeder",
    "@-mentions only" : "Kun omtalt med @",
    "Off" : "Slået fra",
    "General settings" : "Generelle indstillinger",
    "Default notification settings" : "Standardindstillinger for notifikationer",
    "Default group notification" : "Standardindstillinger for gruppenotifikation",
    "Default group notification for new groups" : "Standardindstillinger for gruppenotifikation for nye grupper",
    "Integration into other apps" : "Integration med andre apps",
    "Allow conversations on files" : "Tillad samtaler om filer",
    "Allow conversations on public shares for files" : "Tillad samtaler om offentlige delinger af filer",
    "Enable encryption" : "Slå kryptering til",
    "Pending" : "Afventer",
    "Error" : "Fejl",
    "Blocked" : "Blokeret",
    "Expired" : "Udløbet",
    "Never" : "Aldrig",
    "Language" : "Sprog",
    "Country" : "Land",
    "Status" : "Status",
    "Created at" : "Oprettet",
    "Yes" : "Ja",
    "No" : "Nej",
    "Downloading …" : "Downloader …",
    "OK: Running version: {version}" : "OK: Kørende version: {version}",
    "Validate SSL certificate" : "Godkend SSL certifikat",
    "Delete this server" : "Slet denne server",
    "Test this server" : "Test denne server",
    "Shared secret" : "Delt hemmelighed",
    "Recording consent" : "Optagelsessamtykke",
    "STUN server URL" : "STUN-server URL",
    "STUN servers" : "STUN-servere",
    "A STUN server is used to determine the public IP address of participants behind a router." : "En STUN-server bliver brugt til at bestemme den offentlige IP adresse for deltagerne bagved en router.",
    "OK: Successful ICE candidates returned by the TURN server" : "OK: Succesfulde ICE-kandidater returneret af TURN-serveren",
    "TURN server URL" : "TURN server URL",
    "TURN server secret" : "TURN-server hemmelighed",
    "TURN server protocols" : "TURN server protokoller ",
    "TURN servers" : "TURN-servere",
    "Failed" : "Mislykkede",
    "OK" : "OK",
    "Checking …" : "Kontrollerer...",
    "OK: \".wasm\" and \".tflite\" files were properly returned by the web server." : "OK: \".wasm\"- og \".tflite\" filer blev korrekt returneret af webserveren.",
    "It seems that the PHP and Apache configuration is not compatible. Please note that PHP can only be used with the MPM_PREFORK module and PHP-FPM can only be used with the MPM_EVENT module." : "Det ser ud til, at PHP og Apache konfigurationen ikke er kompatibel. Bemærk venligst, at PHP kun kan bruges med MPM_PREFORK modulet, og PHP-FPM kan kun bruges med MPM_EVENT modulet.",
    "Federated user" : "Fødereret bruger",
    "Confirm" : "Bekræft",
    "Reset" : "Nulstil",
    "Cancel" : "Annullér",
    "Back" : "Tilbage",
    "Now" : "Nu",
    "Meeting created" : "Møde oprettet",
    "Upcoming meetings" : "Kommende møder",
    "Schedule a meeting" : "Planlæg et møde",
    "Meeting title" : "Mødetitel",
    "From" : "Fra",
    "To" : "Til",
    "Calendar" : "Kalender",
    "Attendees" : "Deltagere",
    "Add attendees" : "Tilføj deltagere",
    "Save" : "Gem",
    "Search participants" : "Find deltagere",
    "No results" : "Ingen resultater",
    "Done" : "Færdig",
    "Grid view" : "Gittervisning",
    "Reload" : "Genindlæs",
    "Connecting …" : "Forbinder ...",
    "Waiting for {user} to join the call" : "Venter på at {user} deltager i kaldet",
    "Waiting for others to join the call …" : "Venter på at andre deltager i opkaldet ...",
    "You can invite others in the participant tab of the sidebar" : "Du kan invitere andre i fanen \"deltagere\" i menuen i siden",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Du kan invitere andre i fanen \"deltagere\" i menuen i siden, eller dele dette link for at invitere andre!",
    "Share this link to invite others!" : "Del dette link for at invitere andre!",
    "Copy link" : "Kopier link",
    "Mute audio" : "Slå lyden fra",
    "None" : "Ingen",
    "You have been muted by a moderator" : "Du er blevet sat på mute af en moderator",
    "Disable video" : "Deaktiver video",
    "Enable video" : "Slå video til",
    "You" : "Dig",
    "Mute" : "Mute",
    "Show screen" : "Vis skærm",
    "Collapse" : "Sammenfold",
    "Expand" : "Udvid",
    "You need to be logged in to upload files" : "Du skal være logget på for at kunne uploade filer",
    "Drop your files to upload" : "Drop dine filer for at uploade",
    "Scroll to bottom" : "Rul til bunden",
    "Public conversation" : "Offentlig samtale",
    "Favorite" : "Foretrukken",
    "Date:" : "Dato:",
    "Note:" : "Bemærkning:",
    "Hide details" : "Skjul detaljer",
    "Show details" : "Vis detaljer",
    "Unban" : "Fjern blokering",
    "Disable" : "Deaktiver",
    "Enable" : "Aktiver",
    "Choose" : "Vælg",
    "The file must be a PNG or JPG" : "Fil format: PNG eller JPG",
    "Restricted" : "Begrænset",
    "Conversation settings" : "Samtaleindstillinger",
    "Personal" : "Personlig",
    "Danger zone" : "Farezone",
    "Archive conversation" : "Arkiv samtale",
    "Do you really want to leave \"{displayName}\"?" : "Vil du virkelig forlade \"{displayName}\"?",
    "You can archive this conversation instead." : "Du kan arkivere denne samtale i stedet for.",
    "Leave conversation" : "Forlad samtale",
    "You need to promote a new moderator before you can leave the conversation" : "Du skal udnævne en ny moderator inden du kan forlade samtalen.",
    "Delete conversation" : "Slet samtale",
    "Do you really want to delete \"{displayName}\"?" : "Er du sikker på at du vil slette \"{displayName}\"?",
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "Chatbeskeder kan udløbe efter et vist tidsrum. Bemærk: Filer der er delt i chatten vil ikke blive slette for ejeren, men vil ikke længere deles i samtalen.",
    "Guest access" : "Gæsteadgang",
    "Password protection" : "Adgangskodebeskyttelse",
    "Set a password" : "Indstil en adgangskode",
    "Change password" : "Skift adgangskode",
    "Resend invitations" : "Gensend invitationer",
    "Invalid language" : "Ugyldigt sprog",
    "Start time (optional)" : "Starttid (valgfri)",
    "Lock conversation" : "Lås samtale",
    "Edit" : "Redigér",
    "More information" : "Mere information",
    "Delete" : "Slet",
    "Log content" : "Log indhold",
    "Notifications" : "Notifikationer",
    "Important conversation" : "Vigtig samtale",
    "\"Do not disturb\" user status is ignored for important conversations" : "Brugerstatus \"Forstyr ikke\" ignoreres ved vigtige samtaler",
    "Sensitive conversation" : "Følsom samtale",
    "Message preview will be disabled in conversation list and notifications" : "Forhåndsvisning af beskeder vil blive deaktiveret i samtalelisten og notifikationer",
    "Require recording consent before joining call in this conversation" : "Kræv optagelsessamtykke inden deltagelse i opkaldet i denne samtale",
    "Recording consent is required for all calls" : "Optagelsessamtykke er kræver for alle opkald",
    "Join" : "Deltag",
    "Error while creating the conversation" : "Fejl under oprettelse af samtalen",
    "Create a new conversation" : "Opret ny samtale",
    "Join open conversations" : "Deltag i åbne samtaler",
    "Unread mentions" : "Ulæste omtaler",
    "Create conversation" : "Opret samtale",
    "Enter your name" : "Angiv dit navn",
    "Submit name and join" : "Angiv navn og deltagname and join",
    "Do you already have an account?" : "Har du allerede en konto?",
    "Log in" : "Log på",
    "Mark as read" : "Marker som læst",
    "Mark as unread" : "Marker som ulæst",
    "Remove from favorites" : "Fjernet fra favoritter",
    "Add to favorites" : "Føj til favoritter",
    "Unarchive conversation" : "Fjern samtale fra arkiv",
    "You need to promote a new moderator before you can leave the conversation." : "Du skal udnævne en ny moderator før du kan forlade samtalen.",
    "New tag" : "Nyt tag",
    "Tag name" : "Tag navn",
    "Tags" : "Tags",
    "Move up" : "Flyt op",
    "Move down" : "Flyt ned",
    "No pending invitations" : "Ingen afventende invitationer",
    "Home" : "Hjem",
    "Unread" : "Ulæst",
    "Alphabetically" : "Alfabetisk",
    "You have no archived conversations." : "Du har ingen arkiverede samtaler.",
    "You have no unread mentions." : "Du har ingen ulæste omtaler",
    "An error occurred while performing the search" : "Der opstod en fejl under søgningen",
    "Unread messages" : "Ulæste beskedder",
    "Back to conversations" : "Tilbage til samtaler",
    "Threads" : "Tråde",
    "Archived conversations" : "Arkiverede samtaler",
    "Clear filter" : "Ryd filter",
    "Users" : "Brugere",
    "Groups" : "Grupper",
    "Teams" : "Teams",
    "Other sources" : "Andre kilder",
    "Open conversations" : "Åbne samtaler",
    "No search results" : "Ingen søgeresultater",
    "The meeting will start soon" : "Mødet starter snart",
    "This meeting is scheduled for {startTime}" : "Mødet er skemalagt til {startTime}",
    "You are currently waiting in the lobby" : "Du venter nu i lobbyen",
    "Advanced" : "Avanceret",
    "Select a device" : "Vælg en enhed",
    "Devices" : "Enhed",
    "No audio" : "Ingen lyd",
    "No camera" : "Intet kamera",
    "The call might be recorded." : "Opkaldes optages måske",
    "Select a file" : "Vælg en fil",
    "Invalid path selected" : "Ugyldig filsti valgt",
    "Blur" : "Slør",
    "Upload" : "Send",
    "Files" : "Filer",
    "(edited)" : "(redigeret)",
    "24 hours" : "24 timer",
    "7 days" : "7 dage",
    "Edited by {actor}" : "Redigeret af {actor}",
    "Reply" : "Besvar",
    "More actions" : "Flere handlinger",
    "Set reminder" : "Sæt påmindelse",
    "Reply privately" : "Svar privat",
    "Edit message" : "Redigér besked",
    "Copy message" : "Kopiér besked",
    "Copy message link" : "Kopier besked link",
    "Go to file" : "Gå til fil",
    "Go to thread" : "Gå til tråd",
    "Forward message" : "Videresend besked",
    "Translate" : "Oversæt",
    "Set custom reminder" : "Sæt brugerdefineret påmindelse",
    "Choose a conversation to forward the selected message." : "Vælg en samtale som den valgte besked skal videresendes til.",
    "Error while forwarding message" : "Der opstod en fejl ved videresendelse af beskeden.",
    "The message has been forwarded to {selectedConversationName}" : "Beskeden er videresendt til {selectedConversationName}",
    "Dismiss" : "Afvis",
    "Detect language" : "Detekter sprog",
    "Translate from" : "Oversæt fra",
    "Translate to" : "Oversæt til",
    "Copy translated text" : "Kopiér oversat tekst",
    "Send now" : "Send nu",
    "Message sent" : "Beskeden blev sendt",
    "Contact" : "Kontakt",
    "Deck Card" : "Opslagskort",
    "_%n reply_::_%n replies_" : ["%n svar","%n svar"],
    "You voted" : "Du stemte",
    "_%n vote_::_%n votes_" : ["%n stemme","%n stemmer"],
    "Edit poll draft" : "Redigér afstemningskladde",
    "No messages" : "Ingen beskeder",
    "Unpin" : "Frigør",
    "Create a new group conversation" : "Opret en ny gruppesamtale",
    "Add participants" : "Tilføj deltagere",
    "Allow guests to join via link" : "Tillad gæster at deltage via link",
    "Create a thread" : "Opret en tråd",
    "Send message" : "Send besked",
    "Send without notification" : "Send uden notifikation",
    "File to share" : "Vælg fil til deling",
    "Add emoji" : "Tilføj emoji",
    "Thread title" : "Trådtitel",
    "Send later" : "Send senere",
    "Cancel editing" : "Annullér redigering",
    "Share from {nextcloud}" : "Del fra {nextcloud}",
    "Share from Files" : "Del fra Filer",
    "Upload from device" : "Upload fra enhed",
    "Create new poll" : "Opret ny afstemning",
    "Smart picker" : "Smart Vælger",
    "Record voice message" : "Optag stemmebesked",
    "End recording and send" : "Afslut optagelse og send",
    "Dismiss recording" : "Forkast optagelse",
    "Error while recording audio" : "Fejl under optagelse af lyd",
    "New file" : "Ny fil",
    "Blank" : "Tom",
    "Send" : "Send",
    "Create poll in {name}" : "Opret afstemning i {name}",
    "Create poll" : "Opret afstemning",
    "Question" : "Spørgsmål",
    "Settings" : "Indstillinger",
    "Anonymous poll" : "Anonym afstemning",
    "Multiple answers" : "Multiple svar",
    "End poll" : "Afslut afstemning",
    "Results" : "Resultater",
    "Calls without High-performance backend can cause connectivity issues and high load on devices. {linkstart}Learn more{linkend}" : "Opkald uden højtydende backend kan forårsage forbindelsesproblemer og høj belastning af enheder. {linkstart}Få flere oplysninger{linkend}",
    "Talk setup incomplete" : "Snak opsætningen er ufuldstændig",
    "Settings for participant \"{user}\"" : "Indstillinger for deltager \"{user}\"",
    "moderator" : "moderator",
    "guest" : "gæst",
    "Joined with video" : "Deltager med video",
    "Joined via phone" : "Deltager via telefon",
    "Joined with audio" : "Deltager med audio",
    "Remove group and members" : "Fjern gruppe og medlemmer",
    "Remove team and members" : "Fjern team og medlemmer",
    "Remove participant" : "Fjern deltager",
    "Demote from moderator" : "Degrader fra moderator",
    "Promote to moderator" : "Forfrem til moderator",
    "Remove" : "Fjern",
    "Add users or groups" : "Tilføj brugere eller grupper",
    "Add users" : "Tilføj brugere",
    "Add groups" : "Tilføj grupper",
    "Add teams" : "Tilføj teams",
    "Add other sources" : "Tilføj andre kilder",
    "Add emails" : "Tilføj e-mails",
    "Integrations" : "Integrationer",
    "Searching …" : "Søger ...",
    "Participants" : "Deltagere",
    "Open chat" : "Åbn chat",
    "Search messages" : "Søg efter beskeder",
    "Chat" : "Chat",
    "Details" : "Detaljer",
    "Shared items" : "Delte elementer",
    "Search in {name}" : "Søg i {name}",
    "Search messages …" : "Søg efter beskeder ...",
    "Search options" : "Søgeindstillinger",
    "From User" : "Fra bruger",
    "Since" : "Siden",
    "Until" : "TIl",
    "No results found" : "Ingen resultater fundet",
    "Load more results" : "Indlæs flere resultater",
    "Recent threads" : "Seneste tråde",
    "Projects" : "Projekter",
    "No shared items" : "Ingen delte elementer",
    "Thread notifications" : "Trådnotifikationer",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "Link to a conversation" : "Link til samtale",
    "Search conversations or users" : "Søg samtaler eller kontakter",
    "Select conversation" : "Vælg samtale",
    "Edit display name" : "Redigér vist navn",
    "Error while setting personal setting" : "Fejl under angivelse af personlig indstilling",
    "Play sounds when participants join or leave a call" : "Afspil lyde, når personer deltager eller forlader et opkald",
    "Notification settings" : "Meddelelsesindstillinger",
    "Default language" : "Standardsprog",
    "Select location for attachments" : "Select location for attachments",
    "Error while setting attachment folder" : "Fejl under indstilling af mappe til vedhæftninger",
    "Error while setting default media state" : "Din standard medietilstand er blevet gemt",
    "Privacy" : "Privatliv",
    "Attachments folder" : "Mappe til vedhæftede filer",
    "Search" : "Søg",
    "Focus the chat input" : "Fokuser chat funktionen",
    "Unfocus the chat input to use shortcuts" : "Fjern fokus på chat funktionen for at bruge genveje",
    "Shortcuts while in a call" : "Genveje under et opkald",
    "Camera on and off" : "Kamera til og fra",
    "Microphone on and off" : "Mikrofon til og fra",
    "Raise or lower hand" : "Løft eller sænk hånden",
    "Push to talk or push to mute" : "Tryk for at tale eller tryk for at slå lyden fra",
    "Zoom-in / zoom-out a screen share" : "Zoom ind / zoom ud på en skærmdeling",
    "Mouse wheel" : "Musehjul",
    "Start call" : "Start opkald",
    "End call" : "Afslut opkald",
    "End call for everyone" : "Afslut opkald for alle",
    "Recording" : "Optagelse",
    "The call has been running for one hour." : "Opkaldet har været igang i en time.",
    "Cancel recording start" : "Annuller opstagelsesstart",
    "Stop recording" : "Stop optagelse",
    "Raise hand" : "Løft hånden",
    "Lower hand" : "Sænk hånden",
    "Screensharing options" : "Skærmdeling indstillinger",
    "Enable screensharing" : "Slå skærmdeling til",
    "Screen sharing is not supported by your browser." : "Skærmdeling er ikke understøttet af din browser.",
    "Screen sharing requires the page to be loaded through HTTPS." : "Skærmdeling kræver at siden er hentet over HTTPS.",
    "Screensharing requires the page to be loaded through HTTPS." : "Skærmdeling kræver at siden bliver vist gennem HTTPS.",
    "An error occurred while starting screensharing." : "Der opstod en fejl da du prøvede at dele skærm.",
    "Show your screen" : "Vis din skærm",
    "Stop screensharing" : "Stop skærmdeling",
    "Start recording" : "Start optagelse",
    "Delete now" : "Slet nu",
    "Keep" : "Behold",
    "Select a region" : "Vælg en region",
    "Local time: {time}" : "Lokal tid: {time}",
    "Search …" : "Søg ...",
    "Message without mention" : "Besked som ikke omtaler nogen",
    "Mention myself" : "Omtal mig selv",
    "The conversation does not exist" : "Samtalen findes ikke",
    "Join a conversation or start a new one!" : "Deltag i en samtale eller start en ny!",
    "Join a conversation or start a new one" : "Deltag i en samtale eller start en ny",
    "Nextcloud URL" : "Nextcloud URL",
    "Talk conversation" : "Snak samtale",
    "User" : "Bruger",
    "API token" : "API nøgle",
    "Login" : "Login",
    "Nickname" : "Kaldenavn",
    "Client ID" : "Klient-ID",
    "Media" : "Medier",
    "Polls" : "Afstemninger",
    "Deck cards" : "Opslagskort",
    "Locations" : "Steder",
    "Audio" : "Audio",
    "Show all files" : "Vis alle filer",
    "Show all deck cards" : "Vis alle opslagskort",
    "Follow conversation settings" : "Følg samtaleindstillinger",
    "Group" : "Gruppe",
    "Team" : "Team",
    "You removed {user0} and {user1}" : "Du fjernede {user0} og {user1}",
    "_You removed {user0}, {user1} and %n more participant_::_You removed {user0}, {user1} and %n more participants_" : ["Du fjernede {user0}, {user1} og yderligere %n deltager","Du fjernede {user0}, {user1} og yderligere %n deltagere"],
    "An administrator removed you and {user0}" : "En administrator fjernede dig og {user0}",
    "{actor} removed you and {user0}" : "{actor} fjernede dig og {user0}",
    "_An administrator removed you, {user0} and %n more participant_::_An administrator removed you, {user0} and %n more participants_" : ["En administrator fjernede dig, {user0} og yderligere%n deltager","En administrator fjernede dig, {user0} og yderligere %n deltagere"],
    "_{actor} removed you, {user0} and %n more participant_::_{actor} removed you, {user0} and %n more participants_" : ["{actor} fjernede dig, {user0} og yderligere %n deltagere","{actor} fjernede dig, {user0} og yderligere %n deltagere"],
    "An administrator removed {user0} and {user1}" : "En administrator fjernede {user0} og {user1}",
    "{actor} removed {user0} and {user1}" : "{actor} fjernede {user0} og {user1}",
    "_An administrator removed {user0}, {user1} and %n more participant_::_An administrator removed {user0}, {user1} and %n more participants_" : ["En administrator fjernede {user0}, {user1} og yderligere %n deltager","En administrator fjernede {user0}, {user1} og yderligere %n deltagere"],
    "_{actor} removed {user0}, {user1} and %n more participant_::_{actor} removed {user0}, {user1} and %n more participants_" : ["{actor} fjernede {user0}, {user1} og yderligere %n deltager","{actor} fjernede {user0}, {user1} og yderligere %n deltagere"],
    "You and {user0} joined the call" : "Du og {user0} deltog i opkaldet",
    "_You, {user0} and %n more participant joined the call_::_You, {user0} and %n more participants joined the call_" : ["Du, {user0} og yderligere %n deltagere deltog i opkaldet","Du, {user0} og yderligere %n deltog i opkaldet"],
    "{user0} and {user1} joined the call" : "{user0} og {user1} deltog i opkaldet",
    "_{user0}, {user1} and %n more participant joined the call_::_{user0}, {user1} and %n more participants joined the call_" : ["{user0}, {user1} og yderligere %n deltager deltog i opkaldet","{user0}, {user1} og yderligere %n deltagere deltog i opkaldet"],
    "You and {user0} left the call" : "Du og {user0} forlod opkaldet",
    "_You, {user0} and %n more participant left the call_::_You, {user0} and %n more participants left the call_" : ["Du, {user0} og yderligere %n deltager forlod opkaldet","Du, {user0} og yderligere %n deltagere forlod opkaldet"],
    "{user0} and {user1} left the call" : "{user0} og {user1} forlod opkaldet",
    "_{user0}, {user1} and %n more participant left the call_::_{user0}, {user1} and %n more participants left the call_" : ["{user0}, {user1} og yderligere %n deltager forlod opkaldet","{user0}, {user1} og yderligere %n deltagere forlod opkaldet"],
    "You promoted {user0} and {user1} to moderators" : "Du forfremmede {user0} og {user1} til moderatorer",
    "_You promoted {user0}, {user1} and %n more participant to moderators_::_You promoted {user0}, {user1} and %n more participants to moderators_" : ["Du forfremmede {user0}, {user1} og yderligere %n deltager til moderatorer","Du forfremmede {user0}, {user1} og yderligere %n deltagere til moderatorer"],
    "An administrator promoted you and {user0} to moderators" : "En administrator forfremmede dig og {user0} til moderatorer",
    "{actor} promoted you and {user0} to moderators" : "{actor} forfremmede dig og {user0} til moderatorer",
    "_An administrator promoted you, {user0} and %n more participant to moderators_::_An administrator promoted you, {user0} and %n more participants to moderators_" : ["En administrator forfremmede dig, {user0} og yderligere %n deltager til moderatorer","En administrator forfremmede dig, {user0} og yderligere %n deltagere til moderatorer"],
    "_{actor} promoted you, {user0} and %n more participant to moderators_::_{actor} promoted you, {user0} and %n more participants to moderators_" : ["{actor} forfremmede dig, {user0} og yderligere %n deltager til moderatorer","{actor} forfremmede dig, {user0} og yderligere %n deltagere til moderatorer"],
    "An administrator promoted {user0} and {user1} to moderators" : "En administrator forfremmede {user0} og {user1} til moderatorer",
    "{actor} promoted {user0} and {user1} to moderators" : "{actor} forfremmede {user0} og {user1} til moderatorer",
    "_An administrator promoted {user0}, {user1} and %n more participant to moderators_::_An administrator promoted {user0}, {user1} and %n more participants to moderators_" : ["En administrator forfremmede {user0}, {user1} og yderligere %n deltager til moderatorer","En administrator forfremmede {user0}, {user1} og yderligere %n deltagere til moderatorer"],
    "You:" : "Dig:",
    "You: {lastMessage}" : "Dig: {lastMessage}",
    "{actor}:" : "{actor}:",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "(edited by you)" : "(redigeret af dig)",
    "(edited by a deleted user)" : "(redigeret af en slettet bruger)",
    "(edited by {moderator})" : "(redigeret af {moderator})",
    "The recording failed. Please contact your administrator." : "Optagelsen fejlede. Kontakt venligst din administrator",
    "Leave this page" : "Forlad denne side",
    "Join here" : "Deltag her",
    "Deck card has been posted to {conversation}" : "Opslagskort er blevet postet til {conversation}",
    "An error occurred while fetching the participants" : "Kunne ikke hente listen over deltagere",
    "Failed to join the conversation." : "Kunne ikke deltage i samtalen.",
    "Error while sharing file" : "Fejl ved deling af fil",
    "Later today – {timeLocale}" : "Senere i dag – {timeLocale}",
    "Tomorrow – {timeLocale}" : "I morgen – {timeLocale}",
    "This weekend – {timeLocale}" : "Denne weekend – {timeLocale}",
    "Next week – {timeLocale}" : "Næste uge – {timeLocale}",
    "Error while parsing a PROPFIND error" : "Fejl under parsing af en PROPFIND-fejl",
    "Lost connection to signaling server." : "Mistet forbindelse til signalserver.",
    "Please restart the app." : "Genstart venligst app'en.",
    "Please reload the page." : "Genindlæs venligst siden.",
    "Please try to restart the app." : "Prøv at genstarte app'en.",
    "Please try to reload the page." : "Prøv at genindlæse siden.",
    "Do not disturb" : "Forstyr ikke",
    "Away" : "Ikke tilstede",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Det virker som om du taler mens lyden er slået fra, slå den til hvis du vil have at andre skal høre dig",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Dette tager lidt længere end forventet. Er medie-rettigheder allerede givet (eller nægtet)? Hvis ja så prøv at genstarte din browser, da lyd og video virker ikke lige nu",
    "Access to microphone & camera is only possible with HTTPS" : "Adgang til mikrofon og kamera er kun tilgængeligt over HTTPS",
    "Please move your setup to HTTPS" : "Flyt venligst din installation til HTTPS",
    "Access to microphone & camera was denied" : "Ingen adgang til mikrofon og kamera",
    "WebRTC is not supported in your browser" : "WebRTC er ikke undertøttet i din browser",
    "Please use a different browser like Firefox or Chrome" : "Anvend venligst en anden browser fx Firefox eller Chrome",
    "Error while accessing microphone & camera" : "Der opstod en fejl da vi prøvede at få adgang til din mikrofon og kamera",
    "%s Talk on your mobile devices" : "%s Snak på dine mobilenheder",
    "Join conversations at any time, anywhere, on any device." : "Deltag i samtaler når som helst, hvor som helst og på en hvilken som helst enhed.",
    "Android app" : "Android app",
    "iOS app" : "iOS app",
    "__language_name__" : "Dansk",
    "Webhook Demo" : "Webhook Demo",
    "Call summary (%s)" : "Opkaldssammendrag (%s)",
    "The call summary bot posts an overview message after the call listing all participants and outlining tasks" : "Opkaldsoversigts bot'en sender en oversigtsmeddelelse efter opkaldet med alle deltagere og skitserede opgaver",
    "Tasks" : "Opgaver",
    "Notes" : "Noter",
    "Reports" : "Raporter",
    "Decisions" : "Beslutninger",
    "Agenda" : "Dagsorden",
    "Call summary" : "Opkaldsoversigt",
    "Call summary - {title}" : "Opkaldsoversigt - {title}",
    "Talk to %s" : "Snak med %s",
    "Talk conversation for event" : "Snak samtale for begivenhed",
    "Next meeting" : "Næste møde",
    "Your default media state has been saved" : "Din standard medietilstand er blevet gemt",
    "Set reminder for later today" : "Sæt påmindelse for senere i dag",
    "Set reminder for tomorrow" : "Sæt påmindelse for i morgen",
    "Set reminder for this weekend" : "Sæt påmindelse for denne weekend",
    "Set reminder for next week" : "Sæt påmindelse for næste weekend",
    "Talk recording from {time} ({conversation})" : "Snak optagelse fra {time} ({conversation})",
    "Submit vote" : "Afgiv stemme",
    "Your personal setting has been saved" : "Din personlige indstilling er blevet gemt",
    "Nextcloud Talk was updated, you cannot start or join a call." : "Nextcloud Snak blev opdateret, du kan ikke starte eller deltage i et opkald.",
    "Nextcloud Talk was updated." : "Nextcloud Snak blev opdateret.",
    "Nextcloud is in maintenance mode." : "Nextcloud er i vedligeholdelsestilstand.",
    "Nextcloud Talk Federation was updated." : "Nextcloud Snak Sammenkobling blev opdateret."
},
"nplurals=2; plural=(n != 1);");
