<?php

declare (strict_types=1);
namespace OCA\Talk\Vendor\CuyZ\Valinor\Utility;

/** @internal */
final class Package
{
    /**
     * This must be updated manually whenever a new release is published.
     *
     * PHP8.3 const type
     */
    public const VERSION = '2.4.0';
}