OC.L10N.register(
    "spreed",
    {
    "a conversation" : "uma conversa",
    "(Duration %s)" : "(Duração %s)",
    "You attended a call with {user1}" : "Esteve numa chamada com {user1}",
    "_%n guest_::_%n guests_" : ["%n convidado","%n convidados","%n convidados"],
    "You attended a call with {user1} and {user2}" : "Esteve numa chamada com {user1} e {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Esteve numa chamada com {user1}, {user2} e {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Esteve numa chamada com {user1}, {user2}, {user3} e {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Esteve numa chamada com {user1}, {user2}, {user3}, {user4} e {user5}",
    "_%n other_::_%n others_" : ["%n outro","%n outros","%n outros"],
    "{actor} invited you to {call}" : "{actor} convidou-o para {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Foi convidado para uma <strong>conversa</strong> ou teve uma <strong>chamada</strong>",
    "Other activities" : "Outras atividades",
    "Talk" : "Falar",
    "Guest" : "Convidado",
    "## Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "## Bem-vindo ao Nextcloud Talk!\nNesta conversa será informado sobre as novidades disponíveis no Nextcloud Talk.",
    "## New in Talk %s" : "## Novo no Talk %s",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- O Microsoft Edge e o Safari podem, agora, ser utilizados para participar em chamadas áudio e vídeo.",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- Agora as conversas individuais são persistentes e já não podem ser convertidas em conversas de grupo por acidente. Além disso, quando um dos participantes deixa a conversa, esta passa a não ser apagada automaticamente. A conversa só é apagada do servidor se ambos os participantes a deixarem.",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Agora pode notificar todos os participantes ao escrever \"@all\" na conversa",
    "- With the \"arrow-up\" key you can repost your last message" : "- Com a tecla \"seta para cima\" você pode repostar sua última mensagem",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Agora o Talk aceita comandos, envie \"/help\" como mensagem na conversa para ver se o seu administrador configurou algum",
    "- With projects you can create quick links between conversations, files and other items" : "- Com projetos pode criar links rápidos entre conversas, ficheiros e outros itens",
    "- You can now mention guests in the chat" : "- Agora pode mencionar convidados na conversa",
    "Talk updates ✅" : "Atualizações do Falar ✅",
    "System created the conversation" : "O sistema criou a conversa",
    "Message deleted by author" : "Mensagem apagada pelo autor",
    "Administration" : "Administração",
    "System" : "Sistema",
    "Talk conversations" : "Conversas no Talk",
    "Call %s" : "Ligar a %s",
    "File not found" : "Ficheiro não encontrado",
    "File is too big" : "O ficheiro é demasiado grande",
    "Invalid file provided" : "Fornecido ficheiro inválido",
    "Invalid image" : "Imagem inválida",
    "Unknown filetype" : "Tipo de ficheiro desconhecido",
    "Talk mentions" : "Menções no Falar",
    "No unread mentions" : "Nenhuma menção por ler",
    "Description" : "Descrição",
    "Dismiss notification" : "Dispensar notificação",
    "Accept" : "Aceitar",
    "Decline" : "Recusar",
    "New message" : "Nova mensagem",
    "Reminder" : "Lembrete",
    "Join call" : "Juntar-se à chamada",
    "A group call has started in {call}" : "Uma chamada de grupo começou em {call}",
    "Open settings" : "Abrir definições",
    "error" : "erro",
    "Default" : "Predefinida",
    "Presentation" : "Apresentação",
    "Conversations" : "Conversações",
    "Messages" : "Mensagens",
    "Avatar image is not square" : "A imagem do avatar não é quadrada.",
    "Favorites" : "Favoritos",
    "Other" : "Outro",
    "Note to self" : "Nota a mim",
    "A place for your private notes, thoughts and ideas" : "Um local para os seus pensamentos, notas e ideias privados",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Emirados Árabes Unidos",
    "Afghanistan" : "Afeganistão",
    "Albania" : "Albânia",
    "Armenia" : "Arménia",
    "Angola" : "Angola",
    "Antarctica" : "Antárctica",
    "Argentina" : "Argentina",
    "American Samoa" : "Samoa Americana",
    "Austria" : "Áustria",
    "Australia" : "Austrália",
    "Aruba" : "Aruba",
    "Azerbaijan" : "Azerbaijão",
    "Bosnia and Herzegovina" : "Bosnia Herzegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Bélgica",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgária",
    "Burundi" : "Burundi",
    "Benin" : "Benim",
    "Brazil" : "Brasil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Butão",
    "Botswana" : "Botswana",
    "Belarus" : "Bielorrússia",
    "Belize" : "Belize",
    "Canada" : "Canada",
    "Central African Republic" : "República Central Africana",
    "Congo" : "Congo",
    "Switzerland" : "Suiça",
    "Cook Islands" : "Ilhas Cook",
    "Chile" : "Chile",
    "Cameroon" : "Camarões",
    "China" : "China",
    "Colombia" : "Colômbia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cabo Verde" : "Cabo Verde",
    "Cyprus" : "Chipre",
    "Germany" : "Alemanha",
    "Djibouti" : "Djibouti",
    "Denmark" : "Dinamarca",
    "Dominican Republic" : "República Dominicana",
    "Algeria" : "Algéria",
    "Ecuador" : "Equador",
    "Estonia" : "Estónia",
    "Egypt" : "Egipto",
    "Eritrea" : "Eritreia",
    "Spain" : "Espanha",
    "Ethiopia" : "Etiópia",
    "Finland" : "Finlândia",
    "Fiji" : "Ilhas Fiji",
    "Faroe Islands" : "Ilhas Faroe",
    "France" : "França",
    "Gabon" : "Gabão",
    "Grenada" : "Granada",
    "Georgia" : "Geórgia",
    "French Guiana" : "Guiana Francesa",
    "Guernsey" : "Guernsey",
    "Ghana" : "Gana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Islândia",
    "Gambia" : "Gambia",
    "Guinea" : "Guiné",
    "Guadeloupe" : "Guadalupe",
    "Equatorial Guinea" : "Guiné Equatorial",
    "Greece" : "Grécia",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guiné-Bissau",
    "Guyana" : "Guiana",
    "Hong Kong" : "Hong Kong",
    "Honduras" : "Honduras",
    "Croatia" : "Croácia",
    "Haiti" : "Haiti",
    "Hungary" : "Hungria",
    "Indonesia" : "Indonésia",
    "Ireland" : "Irlanda",
    "Israel" : "Israel",
    "Isle of Man" : "Ilha de Man",
    "India" : "Índia",
    "Iraq" : "Iraque",
    "Iceland" : "Islândia",
    "Italy" : "Italia",
    "Jamaica" : "Jamaica",
    "Jordan" : "Jordânia",
    "Japan" : "Japão",
    "Kenya" : "Quénia",
    "Kyrgyzstan" : "Quirquistão",
    "Cambodia" : "Cambodja",
    "Kuwait" : "Kuwait",
    "Cayman Islands" : "Ilhas Caimão",
    "Kazakhstan" : "Casaquistão",
    "Lebanon" : "Líbano",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Libéria",
    "Lesotho" : "Lesoto",
    "Lithuania" : "Lituania",
    "Luxembourg" : "Luxemburgo",
    "Latvia" : "Letónia",
    "Libya" : "Libia",
    "Morocco" : "Marrocos",
    "Monaco" : "Mónaco",
    "Montenegro" : "Montenegro",
    "Madagascar" : "Madagáscar",
    "Marshall Islands" : "Ilhas Marshall",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongolia",
    "Macao" : "Macau",
    "Mauritania" : "Mauritânia",
    "Montserrat" : "Monserrate",
    "Malta" : "Malta",
    "Mauritius" : "Ilhas Maurícias",
    "Maldives" : "Ilhas Maldivas",
    "Malawi" : "Malawi",
    "Mexico" : "México",
    "Malaysia" : "Malasia",
    "Mozambique" : "Moçambique",
    "Namibia" : "Namíbia",
    "New Caledonia" : "Nova Caledónia",
    "Niger" : "Níger",
    "Nigeria" : "Nigéria",
    "Nicaragua" : "Nicarágua",
    "Netherlands" : "Holanda",
    "Norway" : "Noruega",
    "Nepal" : "Nepal",
    "New Zealand" : "Nova Zelândia",
    "Oman" : "Oman",
    "Panama" : "Panamá",
    "Peru" : "Peru",
    "French Polynesia" : "Polinésia Francesa",
    "Papua New Guinea" : "Papua Nova Guiné",
    "Philippines" : "Filipinas",
    "Pakistan" : "Paquistão",
    "Poland" : "Polónia",
    "Puerto Rico" : "Porto Rico",
    "Portugal" : "Portugal",
    "Paraguay" : "Paraguai",
    "Qatar" : "Quatar ",
    "Romania" : "Roménia",
    "Serbia" : "Servia",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Arábia Saudita",
    "Solomon Islands" : "Ilhas Salomão",
    "Seychelles" : "Ilhas Seychelles",
    "Sudan" : "Sudão",
    "Sweden" : "Suécia",
    "Singapore" : "Singapura",
    "Slovenia" : "Eslovénia",
    "Sierra Leone" : "Serra Leoa",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somália",
    "Suriname" : "Suriname",
    "Sao Tome and Principe" : "São Tomé e Príncipe",
    "El Salvador" : "El Salvador",
    "Chad" : "Chade",
    "Togo" : "Togo",
    "Thailand" : "Tailândia",
    "Tajikistan" : "Tajaquistão",
    "Timor-Leste" : "Timor-Leste",
    "Turkmenistan" : "Turcomenistão",
    "Tunisia" : "Tunísia",
    "Tonga" : "Tonga",
    "Turkey" : "Turquia",
    "Trinidad and Tobago" : "Trinidad e Tobago",
    "Tuvalu" : "Tuvalu",
    "Ukraine" : "Ucrânia",
    "Uganda" : "Uganda",
    "Uruguay" : "Uruguai",
    "Uzbekistan" : "Uzbequistão",
    "Vanuatu" : "Vanuatu",
    "Samoa" : "Samoa",
    "Yemen" : "Iemen",
    "South Africa" : "África do Sul",
    "Zambia" : "Zâmbia",
    "Zimbabwe" : "Zimbábue ",
    "Federation" : "Federação",
    "Invalid date, date format must be YYYY-MM-DD" : "Data inválida, o formato da data deve ser AAAA-MM-DD",
    "Leave call" : "Sair da chamada",
    "The password is wrong. Try again." : "A palavra-passe está errada. Por favor, tente de novo.",
    "Password" : "Palavra-passe",
    "Submit" : "Submeter",
    "Everyone" : "Para todos",
    "Save changes" : "Guardar alterações",
    "Saving …" : "A guardar...",
    "Saved!" : "Gravado!",
    "Limit to groups" : "Limitado a grupos",
    "Enabled" : "Ativado",
    "Disabled" : "Desativado",
    "State" : "Estado",
    "Name" : "Nome",
    "General settings" : "Definições Gerais",
    "Enable encryption" : "Ativar a encriptação",
    "Pending" : "Pendente",
    "Error" : "Erro",
    "Blocked" : "Bloqueado",
    "Expired" : "Expirado",
    "Never" : "Nunca",
    "Language" : "Idioma",
    "Country" : "País",
    "Status" : "Estado",
    "Created at" : "Criado em",
    "Yes" : "Sim",
    "No" : "Não",
    "Downloading …" : "A transferir…",
    "Validate SSL certificate" : "Validar certificado SSL",
    "Shared secret" : "Segredo partilhado",
    "TURN server protocols" : "Protocolos do servidor TURN",
    "OK" : "Ok",
    "Checking …" : "A verificar...",
    "Federated user" : "Utilizador federado",
    "Confirm" : "Confirmar",
    "Reset" : "Reiniciar",
    "Cancel" : "Cancelar",
    "Back" : "Anterior",
    "Now" : "Agora",
    "From" : "De",
    "To" : "Para",
    "Calendar" : "Calendário",
    "Attendees" : "Participantes",
    "Save" : "Guardar",
    "No results" : "Sem resultados",
    "Done" : "Concluído",
    "Grid view" : "Vista em grelha",
    "Reload" : "Recarregar",
    "Waiting for others to join the call …" : "À espera que outros se juntem à chamada ..",
    "You can invite others in the participant tab of the sidebar" : "Pode convidar outros no separador participantes na barra lateral  ",
    "Share this link to invite others!" : "Envie este link para convidar outros!",
    "Copy link" : "Copiar ligação",
    "Mute audio" : "Silenciar áudio",
    "None" : "Nenhum",
    "Disable video" : "desativar vídeo",
    "Enable video" : "ativar vídeo",
    "You" : "Você",
    "Show screen" : "Mostrar ecrã",
    "Collapse" : "Expandir",
    "Favorite" : "Favorito",
    "Date:" : "Data:",
    "Hide details" : "Ocultar detalhes",
    "Show details" : "Mostrar detalhes",
    "Disable" : "Desativar",
    "Enable" : "Ativar",
    "Choose" : "Escolher",
    "Restricted" : "Restrito",
    "Personal" : "Pessoal",
    "Leave conversation" : "Sair da conversação",
    "Delete conversation" : "Eliminar conversação",
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "As mensagens de chat podem expirar após um determinado período. Nota: os ficheiros partilhados no chat não serão eliminados para o proprietário, mas deixarão de ser partilhados na conversa.",
    "Password protection" : "Protegido por palavra-passe",
    "Set a password" : "Definir uma palavra-passe",
    "Edit" : "Editar",
    "Delete" : "Apagar",
    "Notifications" : "Notificações",
    "Join" : "Aderir",
    "Create a new conversation" : "Criar nova conversa",
    "Join open conversations" : "Juntar-me a conversas abertas",
    "Log in" : "Iniciar sessão",
    "Remove from favorites" : "Remover de favoritos",
    "Add to favorites" : "Adicionar aos favoritos",
    "Tags" : "Etiquetas",
    "Move up" : "Mover para cima",
    "Move down" : "Mover para baixo",
    "Home" : "Início",
    "Alphabetically" : "Alfabeticamente",
    "Clear filter" : "Limpar filtro",
    "Users" : "Utilizadores",
    "Groups" : "Grupos",
    "Teams" : "Grupos",
    "Advanced" : "Avançado",
    "Test" : "Teste",
    "Invalid path selected" : "Caminho inválido selecionado",
    "Blur" : "Blur",
    "Upload" : "Enviar",
    "Files" : "Ficheiros",
    "24 hours" : "24 horas",
    "7 days" : "7 dias",
    "Message forwarded to \"Note to self\"" : "Mensagem reencaminhada para \"Nota a mim\"",
    "Error while forwarding message to \"Note to self\"" : "Erro ao reencaminhar mensagem para \"Nota a mim\"",
    "Reply" : "Resposta",
    "More actions" : "Mais ações",
    "Download file" : "Transferir ficheiro",
    "Translate" : "Traduzir",
    "Dismiss" : "Dispensar",
    "Contact" : "Contacto",
    "No messages" : "Sem mensagens",
    "Create a new group conversation" : "Criar nova conversa de grupo",
    "Send message" : "Enviar mensagem",
    "File to share" : "Ficheiro a partilhar",
    "New file" : "Ficheiro novo",
    "Send" : "Enviar",
    "Settings" : "Definições",
    "Results" : "Resultados",
    "moderator" : "moderador",
    "guest" : "convidado",
    "Remove participant" : "Remover participante",
    "Demote from moderator" : "Relegar de moderador",
    "Promote to moderator" : "Promover a moderador",
    "Remove" : "Remover",
    "Add users or groups" : "Add users or groups",
    "Add users" : "Adicionar utilizadores",
    "Integrations" : "Integrações",
    "Searching …" : "À procura …",
    "Participants" : "Participantes",
    "Chat" : "Conversa",
    "Details" : "Detalhes",
    "Search in {name}" : "Procurar em {name}",
    "No results found" : "No results found",
    "Load more results" : "Mostrar mais resultados",
    "Projects" : "Projectos",
    "No shared items" : "Sem itens partilhados",
    "Notification settings" : "Definições de notificação",
    "Appearance & Sounds" : "Aspeto e sons",
    "Privacy" : "Privacidade",
    "Search" : "Pesquisa sobre",
    "Screensharing options" : "Opções de partilha de ecrã",
    "Enable screensharing" : "Ativar partilha de ecrã",
    "Screensharing requires the page to be loaded through HTTPS." : "A partilha de ecrã requer que a página seja carregada através de HTTPS.",
    "An error occurred while starting screensharing." : "Ocorreu um erro enquanto iniciava a partilha de ecrã.",
    "Download attendance list" : "Transferir lista de presenças",
    "Keep" : "Manter",
    "Select a region" : "Selecione uma região",
    "User" : "Utilizador",
    "API token" : "Token de API",
    "Login" : "Iniciar sessão",
    "Nickname" : "Alcunha",
    "Client ID" : "Id. do Cliente",
    "Media" : "Media",
    "Locations" : "Localizações",
    "Audio" : "Áudio",
    "Group" : "Grupo",
    "Team" : "Grupo",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Error while sharing file" : "Erro ao partilhar ficheiro",
    "_%n hour_::_%n hours_" : ["%n hora","%n horas","%n horas"],
    "_%n day_::_%n days_" : ["%n dia","%n dias","%n dias"],
    "Please reload the page." : "Por favor, recarregue a página.",
    "Do not disturb" : "Não incomodar",
    "Away" : "Ausente",
    "Access to microphone & camera is only possible with HTTPS" : "Só é possível aceder ao microfone & câmera com HTTPS",
    "Access to microphone & camera was denied" : "Acesso recusado ao microfone & câmera",
    "WebRTC is not supported in your browser" : "WebRTC não é suportado pelo seu browser",
    "Please use a different browser like Firefox or Chrome" : "Por favor use um browser diferente como Firefox ou Chrome",
    "Error while accessing microphone & camera" : "Erro a aceder ao microfone & câmera",
    "Android app" : "Aplicação Android",
    "iOS app" : "Aplicação iOS",
    "__language_name__" : "Português",
    "Tasks" : "Tarefas",
    "Notes" : "Notas",
    "Reports" : "Relatórios",
    "Talk to %s" : "Falar com %s"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
