.talkChatTab[data-v-c0ac6f68]{flex-direction:column;flex-grow:1;height:100%;display:flex}.empty-content[data-v-c0ac6f68]{margin-top:unset;height:100%}.empty-content__icon[data-v-c0ac6f68]{opacity:1}.app-container[data-v-c0ac6f68]{display:contents}
/*# sourceMappingURL=src_FilesSidebarLoaderApp_vue.chunk.css.map*/