OC.L10N.register(
    "spreed",
    {
    "a conversation" : "percakapan",
    "(Duration %s)" : "(Durasi %s)",
    "You attended a call with {user1}" : "Anda menghadiri panggilan dengan {user1}",
    "_%n guest_::_%n guests_" : ["%n tamu"],
    "You attended a call with {user1} and {user2}" : "Anda menghadiri panggilan dengan {user1} dan {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Anda menghadiri panggilan dengan {user1}, {user2} dan {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Anda menghadiri panggilan dengan {user1}, {user2}, {user3} dan {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Anda menghadiri panggilan dengan {user1}, {user2}, {user3}, {user4} dan {user5}",
    "{actor} invited you to {call}" : "{actor} mengundang Anda untuk {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Anda diundang dalam <strong>percakapan</strong> atau mendapat <strong>panggilan</strong>",
    "Other activities" : "Aktivitas lain",
    "Talk" : "Talk",
    "Guest" : "Tamu",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge dan Safari sekarang dapat digunakan untuk berpartisipasi dalam panggilan audio dan video",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Sekarang Anda dapat memberi tahu semua peserta dengan memposting \"@all\" ke dalam obrolan",
    "- With the \"arrow-up\" key you can repost your last message" : "- Dengan tombol \"panah-atas\" Anda dapat memposting ulang pesan terakhir Anda",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Talk sekarang dapat memiliki perintah, kirim \"/help\" sebagai pesan obrolan untuk melihat apakah administrator Anda mengonfigurasi beberapa",
    "- You can now mention guests in the chat" : "- Anda sekarang dapat menyebut tamu di obrolan",
    "{actor} created the conversation" : "{actor} membuat sebuah percakapan",
    "You created the conversation" : "Anda membuat sebuah percakapan",
    "Message deleted by author" : "Pesan dihapus oleh penyusun",
    "Deleted user" : "Pengguna dihapus",
    "Administration" : "Administrasi",
    "System" : "Sistem",
    "Call %s" : "Hubungi %s",
    "Storage quota exceeded" : "Kuota penyimpanan terlampaui",
    "File not found" : "File tidak ditemukan",
    "Poll" : "Polling",
    "File is too big" : "Berkas terlalu besar",
    "Invalid file provided" : "Berkas tidak valid",
    "Invalid image" : "Gambar tidak valid",
    "Unknown filetype" : "Tipe berkas tak dikenal",
    "Say hi to your friends and colleagues!" : "Katakan halo kepada teman dan kolega Anda!",
    "You were mentioned" : "Anda disebutkan",
    "Description" : "Deskrisi",
    "Meeting" : "Rapat",
    "Dismiss notification" : "Abaikan notifikasi",
    "Accept" : "Terima",
    "Decline" : "Tolak",
    "New message" : "Pesan baru",
    "Notification" : "Notifikasi",
    "{user} in {call}" : "{user} di {call}",
    "Open settings" : "Buka pengaturan",
    "error" : "galat",
    "Default" : "Bawaan",
    "Presentation" : "Presentasi",
    "{user} in {conversation}" : "{user} di {conversation}",
    "Avatar image is not square" : "Gambar avatar tidak berbentuk persegi",
    "Favorites" : "Favorit",
    "Other" : "Lainnya",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Uni Emirat Arab",
    "Afghanistan" : "Afganistan",
    "Antigua and Barbuda" : "Antigua dan Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Antarctica" : "Antartika",
    "Argentina" : "Argentina",
    "American Samoa" : "Samoa Amerika",
    "Austria" : "Austria",
    "Australia" : "Australia",
    "Aruba" : "Aruba",
    "Åland Islands" : "Pulau Åland",
    "Azerbaijan" : "Azerbaijan",
    "Bosnia and Herzegovina" : "Bosnia dan Herzegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Belgium",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaria",
    "Bahrain" : "Bahrain",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Saint Barthelemy",
    "Bermuda" : "Bermuda",
    "Brunei Darussalam" : "Brunei Darussalam",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius dan Saba",
    "Brazil" : "Brazil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bhutan",
    "Bouvet Island" : "Bouvet Island",
    "Botswana" : "Botswana",
    "Belarus" : "Belarus",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Cocos (Keeling) Islands" : "Pulau Cocos (Keeling)",
    "Central African Republic" : "Republik Afrika Tengah",
    "Congo" : "Congo",
    "Switzerland" : "Swiss",
    "Côte d'Ivoire" : "Pantai Gading",
    "Cook Islands" : "Pulau Cook",
    "Chile" : "Chile",
    "Cameroon" : "Cameroon",
    "China" : "Cina",
    "Colombia" : "Colombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cabo Verde" : "Cabo Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Pulau Natal",
    "Cyprus" : "Cyprus",
    "Czechia" : "Ceko",
    "Germany" : "Jerman",
    "Djibouti" : "Djibouti",
    "Denmark" : "Denmark",
    "Dominica" : "Dominika",
    "Dominican Republic" : "Republik Dominika",
    "Algeria" : "Algeria",
    "Ecuador" : "Ekuador",
    "Estonia" : "Estonia",
    "Egypt" : "Mesir",
    "Western Sahara" : "Sahara Barat",
    "Eritrea" : "Eritrea",
    "Spain" : "Spanyol",
    "Ethiopia" : "Ethiopia",
    "Finland" : "Finlandia",
    "Fiji" : "Fiji",
    "Falkland Islands (Malvinas)" : "Kepulauan Falkland (Malvinas)",
    "Faroe Islands" : "Pulau Faroe",
    "France" : "Prancis",
    "Gabon" : "Gabon",
    "United Kingdom of Great Britain and Northern Ireland" : "Britania Raya Britania Raya dan Irlandia Utara",
    "Grenada" : "Grenada",
    "Georgia" : "Georgia",
    "French Guiana" : "Guyana Prancis",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Greenland",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Guinea Khatulistiwa",
    "Greece" : "Yunani",
    "South Georgia and the South Sandwich Islands" : "Georgia Selatan dan Kepulauan Sandwich Selatan",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Pulau Heard dan Kepulauan McDonald",
    "Honduras" : "Honduras",
    "Croatia" : "Kroatia",
    "Haiti" : "Haiti",
    "Hungary" : "Hungaria",
    "Indonesia" : "Indonesia",
    "Ireland" : "Irlandia",
    "Israel" : "Israel",
    "Isle of Man" : "Isle of Man",
    "India" : "India",
    "British Indian Ocean Territory" : "Wilayah Samudra Hindia Inggris",
    "Iraq" : "Irak",
    "Iceland" : "Islandia",
    "Italy" : "Italia",
    "Jersey" : "Jersey",
    "Jamaica" : "Jamaika",
    "Jordan" : "Jordan",
    "Japan" : "Jepang",
    "Kenya" : "Kenya",
    "Kyrgyzstan" : "Kirgizstan",
    "Cambodia" : "Kambodia",
    "Kiribati" : "Kiribati",
    "Comoros" : "Komoro",
    "Saint Kitts and Nevis" : "Saint Kitts dan Nevis",
    "Kuwait" : "Kuwait",
    "Cayman Islands" : "Kepulauan Cayman",
    "Kazakhstan" : "Kazakhstan",
    "Lao People's Democratic Republic" : "Laos (Republik Demokratik Rakyat)",
    "Lebanon" : "Lebanon",
    "Saint Lucia" : "Saint Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Lithuania",
    "Luxembourg" : "Luksemburg",
    "Latvia" : "Latvia",
    "Libya" : "Libya",
    "Morocco" : "Maroko",
    "Monaco" : "Monako",
    "Montenegro" : "Montenegro",
    "Saint Martin (French part)" : "Saint Martin (bagian Prancis)",
    "Madagascar" : "Madagascar",
    "Marshall Islands" : "Kepulauan Marshall",
    "North Macedonia" : "Makedonia Utara",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongolia",
    "Macao" : "Macao",
    "Northern Mariana Islands" : "Kepulauan Mariana Utara",
    "Martinique" : "Martinik",
    "Mauritania" : "Mauritania",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauritius",
    "Maldives" : "Maldives",
    "Malawi" : "Malawi",
    "Mexico" : "Meksiko",
    "Malaysia" : "Malaysia",
    "Mozambique" : "Mozambik",
    "Namibia" : "Namibia",
    "New Caledonia" : "Kaledonia Baru",
    "Niger" : "Niger",
    "Norfolk Island" : "Kepulauan Norfolk",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nikaragua",
    "Netherlands" : "Belanda",
    "Norway" : "Norwegia",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Selandia Baru",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Polinesia Prancis",
    "Papua New Guinea" : "Papua Nugini",
    "Philippines" : "Filipina",
    "Pakistan" : "Pakistan",
    "Poland" : "Polandia",
    "Saint Pierre and Miquelon" : "Saint Pierre dan Miquelon",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Puerto Rico",
    "Palestine, State of" : "Palestina, Negara",
    "Portugal" : "Portugis",
    "Palau" : "Palau",
    "Paraguay" : "Paraguay",
    "Qatar" : "Qatar",
    "Réunion" : "Réunion",
    "Romania" : "Romania",
    "Serbia" : "Serbia",
    "Russian Federation" : "Federasi Rusia",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Arab Saudi",
    "Solomon Islands" : "Kepulauan Solomon",
    "Seychelles" : "Seychelles",
    "Sudan" : "Sudan",
    "Sweden" : "Swedia",
    "Singapore" : "Singapora",
    "Saint Helena, Ascension and Tristan da Cunha" : "Saint Helena, Ascension dan Tristan da Cunha",
    "Slovenia" : "Slovenia",
    "Svalbard and Jan Mayen" : "Svalbard dan Jan Mayen",
    "Slovakia" : "Slovakia",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Suriname",
    "South Sudan" : "Sudan Selatan",
    "Sao Tome and Principe" : "Sao Tome dan Principe",
    "El Salvador" : "El Salvador",
    "Sint Maarten (Dutch part)" : "Sint Maarten (bagian Belanda)",
    "Syrian Arab Republic" : "Republik Arab Suriah",
    "Turks and Caicos Islands" : "Kepulauan Turks dan Caicos",
    "Chad" : "Chad",
    "French Southern Territories" : "Wilayah Selatan Prancis",
    "Togo" : "Togo",
    "Thailand" : "Thailand",
    "Tajikistan" : "Tajikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor Leste",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunisia",
    "Tonga" : "Tonga",
    "Turkey" : "Turki",
    "Trinidad and Tobago" : "Trinidad dan Tobago",
    "Tuvalu" : "Tuvalu",
    "Tanzania, United Republic of" : "Tanzania (Republik Bersatu)",
    "Ukraine" : "Ukraina",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Pulau Kecil Terluar Amerika Serikat",
    "United States of America" : "Amerika Serikat",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Uzbekistan",
    "Holy See" : "Holy See",
    "Saint Vincent and the Grenadines" : "Saint Vincent dan Grenadine",
    "Viet Nam" : "Viet Nam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis dan Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Yemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Afrika Selatan",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Federation" : "Federasi",
    "Invalid date, date format must be YYYY-MM-DD" : "Tanggal salah, format tanggal harus TTTT-BB-HH",
    "Loading …" : "Memuat …",
    "The password is wrong. Try again." : "Kata sandi salah. Coba lagi",
    "Password" : "Kata kunci",
    "Submit" : "Kirim",
    "Request password" : "Minta kata sandi",
    "Everyone" : "Semua orang",
    "Save changes" : "Simpan perubahan",
    "Saving …" : "Menyimpan ...",
    "Saved!" : "Disimpan!",
    "Limit to groups" : "Batasi ke grup",
    "Enabled" : "Diaktifkan",
    "Disabled" : "Dinonaktifkan",
    "State" : "Kondisi",
    "Name" : "Nama",
    "Beta" : "Beta",
    "Permissions" : "Izin",
    "Off" : "Nonaktif",
    "General settings" : "Pengaturan umum",
    "Enable encryption" : "Aktifkan enkripsi",
    "Pending" : "Tunggu",
    "Error" : "Kesalahan",
    "Active" : "Aktif",
    "Expired" : "Kedaluwarsa",
    "Never" : "Tidak pernah",
    "Language" : "Bahasa",
    "Country" : "Negara",
    "Status" : "Status",
    "Created at" : "Dibuat saat",
    "Yes" : "Ya",
    "No" : "Tidak",
    "Shared secret" : "Rahasia bersama",
    "{option1} and {option2}" : "{option1} dan {option2}",
    "Failed" : "Gagal",
    "OK" : "OK",
    "Federated user" : "Pengguna terfederasi",
    "Confirm" : "Konfirmasi",
    "Reset" : "Setel ulang",
    "Cancel" : "Membatalkan",
    "Back" : "Kembali",
    "Now" : "Sekarang",
    "From" : "Dari",
    "To" : "Hingga",
    "Calendar" : "Kalender",
    "Attendees" : "Peserta",
    "Save" : "Simpan",
    "No results" : "Tidak ada hasil",
    "Done" : "Selesai",
    "Grid view" : "Tampilan kotak",
    "Reload" : "Muat ulang",
    "Copy link" : "Salin tautan",
    "None" : "Tidak ada",
    "You" : "Anda",
    "Collapse" : "Tutup",
    "Expand" : "Perluas",
    "Drop your files to upload" : "Lepas berkas Anda untuk mengunggah",
    "Favorite" : "Favorit",
    "Date:" : "Tanggal:",
    "Note:" : "Catatan:",
    "Hide details" : "Sembunyikan detail",
    "Show details" : "Tampilkan detail",
    "Disable" : "Nonaktifkan",
    "Enable" : "Aktifkan",
    "Choose" : "Pilih",
    "The file must be a PNG or JPG" : "File harus berupa PNG atau JPG",
    "Restricted" : "Terbatas",
    "Personal" : "Pribadi",
    "Password protection" : "Password protection",
    "Set a password" : "Tetapkan kata sandi",
    "Change password" : "Ubah kata sandi",
    "Invalid language" : "Bahasa tidak valid",
    "Edit" : "Sunting",
    "More information" : "Informasi lebih lanjut",
    "Delete" : "Hapus",
    "Notifications" : "Pemberitahuan",
    "In {conversation}" : "Di {conversation}",
    "Join" : "Gabung",
    "Create conversation" : "Buat percakapan",
    "Enter your name" : "Masukkan nama Anda",
    "Log in" : "Masuk",
    "Browse" : "Telusuri",
    "Mark as read" : "tandai sudah dibaca",
    "Mark as unread" : "Tandai belum dibaca",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Tambah ke favorit",
    "New tag" : "Tag baru",
    "Tag name" : "Nama tag",
    "Tags" : "Tag",
    "Delete tag" : "Hapus tag",
    "Move up" : "Pindah ke atas",
    "Move down" : "Pindah ke bawah",
    "Home" : "Beranda",
    "Unread" : "Belum dibaca",
    "Alphabetically" : "Secara alfabet",
    "Unread messages" : "Pesan belum dibaca",
    "Clear filters" : "Hapus filter",
    "Threads" : "Utas",
    "Clear filter" : "Bersihkan filter",
    "Users" : "Pengguna",
    "Groups" : "Grup",
    "Teams" : "Tim",
    "No search results" : "Tidak ada hasil pencarian",
    "Advanced" : "Lanjutan",
    "Select a device" : "Pilih perangkat",
    "Devices" : "Perangkat",
    "Invalid path selected" : "Jalur terpilih invalid",
    "Blur" : "Kabur",
    "Upload" : "Unggah",
    "Files" : "Berkas",
    "7 days" : "7 hari",
    "Reply" : "Balas",
    "More actions" : "Tindakan lainnya",
    "Set reminder" : "Tetapkan pengingat",
    "Edit message" : "Edit pesan",
    "Copy message" : "Salin pesan",
    "Download file" : "Unduh berkas",
    "Translate" : "Terjemahkan",
    "Set custom reminder" : "Tetapkan pengingat kustom",
    "React with {emoji}" : "Bereaksi dengan {emoji}",
    "Dismiss" : "Batal",
    "Detect language" : "Deteksi bahasa",
    "The message could not be translated" : "Pesan tidak dapat diterjemahkan",
    "Translation copied to clipboard" : "Terjemahan disalin ke papan klip",
    "Translation could not be copied" : "Terjemahan tidak dapat disalin",
    "Translate message" : "Terjemahkan pesan",
    "Source language to translate from" : "Bahasa sumber untuk diterjemahkan dari",
    "Translate from" : "Terjemahkan dari",
    "Target language to translate into" : "Bahasa target untuk diterjemahkan ke",
    "Translate to" : "Terjemahkan ke",
    "Translating" : "Menerjemahkan",
    "Copy translated text" : "Salin teks terjemahan",
    "Send now" : "Kirim sekarang",
    "Message sent" : "Pesan terkirim",
    "Contact" : "Kontak",
    "{stack} in {board}" : "{stack} di {board}",
    "Remove {fileName}" : "Hapus {fileName}",
    "_%n reply_::_%n replies_" : ["%n balasan"],
    "_%n vote_::_%n votes_" : ["%n suara"],
    "No messages" : "Tidak ada pesan",
    "Unpin" : "Lepas sematan",
    "Add participants" : "Tambahkan peserta",
    "Allow guests to join via link" : "Izinkan tamu untuk bergabung melalui tautan",
    "File to share" : "Berkas untuk dibagikan",
    "Send later" : "Kirim nanti",
    "Cancel editing" : "Batalkan pengeditan",
    "Share from Files" : "Bagikan dari Berkas",
    "Upload from device" : "Unggah dari perangkat",
    "Smart picker" : "Pemilih cerdas",
    "End recording and send" : "Akhiri rekaman dan kirim",
    "Dismiss recording" : "Batalkan rekaman",
    "Error while recording audio" : "Kesalahan saat merekam audio",
    "New file" : "File baru",
    "Blank" : "Kosong",
    "Send" : "Kirim",
    "Question" : "Pertanyaan",
    "Settings" : "Setelan",
    "Results" : "Hasil",
    "guest" : "pengunjung",
    "Remove participant" : "Hapus peserta",
    "Remove" : "Hapus",
    "Add users or groups" : "Add users or groups",
    "Add users" : "Tambahkan pengguna",
    "Integrations" : "Integrasi",
    "Searching …" : "Mencari …",
    "Search or add participants" : "Cari atau tambah peserta",
    "An error occurred while adding the participants" : "Terjadi kesalahan saat menambahkan peserta",
    "Participants" : "Peserta",
    "You have new unread messages in the chat." : "Anda memiliki pesan baru yang belum dibaca dalam obrolan.",
    "Chat" : "Obrolan",
    "Details" : "Detail",
    "No results found" : "Tidak ada hasil ditemukan",
    "Load more results" : "Muat lebih banyak hasil",
    "Projects" : "Proyek",
    "Search conversations or users" : "Cari percakapan atau pengguna",
    "Select conversation" : "Pilih percakapan",
    "Notification settings" : "Pengaturan notifikasi",
    "Default language" : "Bahasa bawaan",
    "Privacy" : "Privasi",
    "Attachments folder" : "Folder lampiran",
    "Search" : "Cari",
    "Recording" : "Perekaman",
    "React with {reaction}" : "Bereaksi dengan {reaction}",
    "Start recording" : "Mulai merekam",
    "Keep" : "Simpan",
    "Select a region" : "Pilih wilayah",
    "Local time: {time}" : "Waktu lokal: {time}",
    "Join a conversation or start a new one!" : "Gabung dengan percakapan atau mulai yang baru!",
    "Join a conversation or start a new one" : "Gabung dengan percakapan atau mulai yang baru",
    "Nextcloud URL" : "URL Nextcloud",
    "Talk conversation" : "Percakapan Talk",
    "User" : "Pengguna",
    "API token" : "Token API",
    "Login" : "Log masuk",
    "Nickname" : "Nama panggilan",
    "Client ID" : "ID Klien",
    "Team ID" : "ID tim",
    "Media" : "Media",
    "Polls" : "Polling",
    "Locations" : "Lokasi",
    "Audio" : "Audio",
    "Show all files" : "Tampilkan semua berkas",
    "Group" : "Grup",
    "Team" : "Tim",
    "Error while sharing file" : "Kesalahan saat membagikan berkas",
    "_%n hour_::_%n hours_" : ["%n jam"],
    "_%n day_::_%n days_" : ["%n hari"],
    "_%n week_::_%n weeks_" : ["%n minggu"],
    "Later today – {timeLocale}" : "Nanti hari ini – {timeLocale}",
    "Tomorrow – {timeLocale}" : "Besok – {timeLocale}",
    "This weekend – {timeLocale}" : "Akhir pekan ini – {timeLocale}",
    "Next week – {timeLocale}" : "Minggu depan – {timeLocale}",
    "Error while parsing a PROPFIND error" : "Kesalahan saat mengurai kesalahan PROPFIND",
    "Please reload the page." : "Silakan muat ulang halaman.",
    "Do not disturb" : "Jangan diganggu",
    "Away" : "Jauh",
    "Android app" : "Aplikasi Android",
    "iOS app" : "Aplikasi iOS",
    "__language_name__" : "Bahasa Indonesia",
    "Call summary (%s)" : "Ringkasan panggilan ( %s )",
    "Tasks" : "Tugas",
    "Notes" : "Catatan",
    "Reports" : "Laporan",
    "Call summary - {title}" : "Ringkasan panggilan - {judul}",
    "Talk to %s" : "Chat dengan %s",
    "Talk conversation for event" : "Percakapan Talk untuk acara",
    "Set reminder for later today" : "Atur pengingat untuk nanti hari ini",
    "Set reminder for tomorrow" : "Atur pengingat untuk besok",
    "Set reminder for this weekend" : "Atur pengingat untuk akhir pekan ini",
    "Set reminder for next week" : "Atur pengingat untuk minggu depan"
},
"nplurals=1; plural=0;");
