OC.L10N.register(
    "spreed",
    {
    "a conversation" : "Suhbat",
    "(Duration %s)" : "(Davomiylik %s)",
    "You attended a call with {user1}" : "Siz {user1} bilan suhbatda ishtirok etdingiz",
    "_%n guest_::_%n guests_" : ["%n mehmon"],
    "You attended a call with {user1} and {user2}" : "Siz {user1} va {user2} bilan suhbatda ishtirok etdingiz",
    "You attended a call with {user1}, {user2} and {user3}" : "Siz {user1}, {user2} va {user3} bilan suhbatda ishtirok etdingiz",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Siz {user1}, {user2}, {user3} va {user4} bilan suhbatda ishtirok etdingiz",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Siz {user1}, {user2}, {user3}, {user4} va {user5} bilan suhbatda ishtirok etdingiz",
    "_%n other_::_%n others_" : ["%n boshqalar"],
    "Talk" : "Gaplash",
    "Incoming call" : "Kiruvchi qo'ng'iroq",
    "Message deleted by author" : "Xabar muallif tomonidan o'chirildi",
    "Deleted user" : "Deleted user",
    "System" : "System",
    "File not found" : "Fayl topilmadi",
    "File is too big" : "File is too big",
    "Invalid file provided" : "Invalid file provided",
    "Invalid image" : "Invalid image",
    "Unknown filetype" : "Unknown filetype",
    "Description" : "Tavsif",
    "Meeting" : "Uchrashuv",
    "Accept" : "Qabul qiling",
    "Decline" : "Rad etish",
    "Reminder" : "Eslatma",
    "Notification" : "Bildirishnomalar",
    "error" : "Xatolik",
    "Default" : "Standart",
    "Favorites" : "Sevimlilar",
    "Other" : "Boshqa",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Birlashgan Arab Amirliklari",
    "Afghanistan" : "Afg'oniston",
    "Antigua and Barbuda" : "Antigua va Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albaniya",
    "Armenia" : "Armaniston",
    "Angola" : "Angola",
    "Antarctica" : "Antarktida",
    "Argentina" : "Argentina",
    "American Samoa" : "Amerika Samoasi",
    "Austria" : "Avstriya",
    "Australia" : "Avstraliya",
    "Aruba" : "Aruba",
    "Åland Islands" : "Aland orollari",
    "Azerbaijan" : "Ozarbayjon",
    "Bosnia and Herzegovina" : "Bosnia and Herzegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Belgiya",
    "Burkina Faso" : "Burkina-Faso",
    "Bulgaria" : "Bolgariya",
    "Bahrain" : "Bahrayn",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Sent-Bartelemi",
    "Bermuda" : "Bermud orollari",
    "Brunei Darussalam" : "Bruney Darussalam",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius va Saba",
    "Brazil" : "Braziliya",
    "Bahamas" : "Bagama orollari",
    "Bhutan" : "Butan",
    "Bouvet Island" : "Bouvet Island",
    "Botswana" : "Botswana",
    "Belarus" : "Belarus",
    "Belize" : "Beliz",
    "Canada" : "Kanada",
    "Cocos (Keeling) Islands" : "Kokos (Kiling) orollari",
    "Central African Republic" : "Markaziy Afrika Respublikasi",
    "Congo" : "Kongo",
    "Switzerland" : "Shveytsariya",
    "Côte d'Ivoire" : "Kot-diuvar",
    "Cook Islands" : "Kuk orollari",
    "Chile" : "Chili",
    "Cameroon" : "Kamerun",
    "China" : "Xitoy",
    "Colombia" : "Kolumbiya",
    "Costa Rica" : "Kosta-Rika",
    "Cuba" : "Kuba",
    "Cabo Verde" : "Kabo Verde",
    "Curaçao" : "Kyurasao",
    "Christmas Island" : "Rojdestvo oroli",
    "Cyprus" : "Kipr",
    "Czechia" : "Chexiya",
    "Germany" : "Germaniya",
    "Djibouti" : "Djibouti",
    "Denmark" : "Denmark",
    "Dominica" : "Dominica",
    "Dominican Republic" : "Dominika Respublikasi",
    "Algeria" : "Jazoir",
    "Ecuador" : "Ekvador",
    "Estonia" : "Estoniya",
    "Egypt" : "Misr",
    "Western Sahara" : "G'arbiy Sahara",
    "Eritrea" : "Eritreya",
    "Spain" : "Ispaniya",
    "Ethiopia" : "Efiopiya",
    "Finland" : "Finlyandiya",
    "Fiji" : "Fiji",
    "Falkland Islands (Malvinas)" : "Folklend orollari (Malvin orollari)",
    "Faroe Islands" : "Farer orollari",
    "France" : "Fransiya",
    "Gabon" : "Gabon",
    "United Kingdom of Great Britain and Northern Ireland" : "Buyuk Britaniya va Shimoliy Irlandiya Birlashgan Qirolligi",
    "Grenada" : "Grenada",
    "Georgia" : "Gruziya",
    "French Guiana" : "Fransuz Gvianasi",
    "Guernsey" : "Guernsey",
    "Ghana" : "Gana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Grenlandiya",
    "Gambia" : "Gambiya",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Gvadelupa",
    "Equatorial Guinea" : "Ekvatorial Gvineya",
    "Greece" : "Gretsiya",
    "South Georgia and the South Sandwich Islands" : "Janubiy Jorjiya va Janubiy Sandvich orollari",
    "Guatemala" : "Gvatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Hong Kong" : "Gonkong",
    "Heard Island and McDonald Islands" : "Heard oroli va Makdonald orollari",
    "Honduras" : "Gonduras",
    "Croatia" : "Xorvatiya",
    "Haiti" : "Gaiti",
    "Hungary" : "Vengriya",
    "Indonesia" : "Indoneziya",
    "Ireland" : "Irlandiya",
    "Israel" : "Isroil",
    "Isle of Man" : "Man oroli",
    "India" : "Hindiston",
    "British Indian Ocean Territory" : "Britaniya Hind okeani hududi",
    "Iraq" : "Iroq",
    "Iceland" : "Islandiya",
    "Italy" : "Italiya",
    "Jersey" : "Jersi",
    "Jamaica" : "Yamayka",
    "Jordan" : "Iordaniya",
    "Japan" : "Yaponiya",
    "Kenya" : "Keniya",
    "Kyrgyzstan" : "Qirg'iziston",
    "Cambodia" : "Kambodja",
    "Kiribati" : "Kiribati",
    "Comoros" : "Komor orollari",
    "Saint Kitts and Nevis" : "Sent-Kitts va Nevis",
    "Korea, Republic of" : "Korea Republikasi",
    "Kuwait" : "Quvayt",
    "Cayman Islands" : "Kayman orollari",
    "Kazakhstan" : "Qozog'iston",
    "Lao People's Democratic Republic" : "Laos Xalq Demokratik Respublikasi",
    "Lebanon" : "Livan",
    "Saint Lucia" : "Sent-Lyusiya",
    "Liechtenstein" : "Lixtenshteyn",
    "Sri Lanka" : "Shri-Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Litva",
    "Luxembourg" : "Lyuksemburg",
    "Latvia" : "Latviya",
    "Libya" : "Libya",
    "Morocco" : "Marokash",
    "Monaco" : "Monako",
    "Moldova, Republic of" : "Moldova Republikasi",
    "Montenegro" : "Chernogoriya",
    "Saint Martin (French part)" : "Sent-Martin (frantsuz qismi)",
    "Madagascar" : "Madagaskar",
    "Marshall Islands" : "Marshall orollari",
    "North Macedonia" : "Shimoliy Makedoniya",
    "Mali" : "Mali",
    "Myanmar" : "Myanma",
    "Mongolia" : "Mo'g'uliston",
    "Macao" : "Makao",
    "Northern Mariana Islands" : "Shimoliy Mariana orollari",
    "Martinique" : "Martinika",
    "Mauritania" : "Mavritaniya",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mavrikiy",
    "Maldives" : "Maldiv orollari",
    "Malawi" : "Malavi",
    "Mexico" : "Meksika",
    "Malaysia" : "Malayziya",
    "Mozambique" : "Mozambik",
    "Namibia" : "Namibiya",
    "New Caledonia" : "New Caledonia",
    "Niger" : "Niger",
    "Norfolk Island" : "Norfolk oroli",
    "Nigeria" : "Nigeriya",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Niderlandiya",
    "Norway" : "Norvegiya",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "New Zealand",
    "Oman" : "Ummon",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Fransuz Polineziyasi",
    "Papua New Guinea" : "Papua-Yangi Gvineya",
    "Philippines" : "Filippin",
    "Pakistan" : "Pokiston",
    "Poland" : "Polsha",
    "Saint Pierre and Miquelon" : "Sent-Pyer va Mikelon",
    "Pitcairn" : "Pitkern",
    "Puerto Rico" : "Puerto-Riko",
    "Palestine, State of" : "Falastin, Davlat",
    "Portugal" : "Portugaliya",
    "Palau" : "Palau",
    "Paraguay" : "Paragvay",
    "Qatar" : "Qatar",
    "Réunion" : "Reunion",
    "Romania" : "Ruminiya",
    "Serbia" : "Serbiya",
    "Russian Federation" : "Rossiya Federatsiyasi",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Saudiya Arabistoni",
    "Solomon Islands" : "Solomon orollari",
    "Seychelles" : "Seyshel orollari",
    "Sudan" : "Sudan",
    "Sweden" : "Shvetsiya",
    "Singapore" : "Singapur",
    "Saint Helena, Ascension and Tristan da Cunha" : "Avliyo Yelena, Ko'tarilish va Tristan da Kunya",
    "Slovenia" : "Sloveniya",
    "Svalbard and Jan Mayen" : "Svalbard va Yan Mayen",
    "Slovakia" : "Slovakiya",
    "Sierra Leone" : "Syerra-Leone",
    "San Marino" : "San-Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somali",
    "Suriname" : "Surinam",
    "South Sudan" : "Janubiy Sudan",
    "Sao Tome and Principe" : "San-Tome va Prinsipi",
    "El Salvador" : "El Salvador",
    "Sint Maarten (Dutch part)" : "Sint-Marten (Gollandiya qismi)",
    "Syrian Arab Republic" : "Suriya Arab Respublikasi",
    "Eswatini" : "Esvatin",
    "Turks and Caicos Islands" : "Turks va Kaykos orollari",
    "Chad" : "Chad",
    "French Southern Territories" : "Frantsiyaning janubiy hududlari",
    "Togo" : "Togo",
    "Thailand" : "Thailand",
    "Tajikistan" : "Tojikiston",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor-Leste",
    "Turkmenistan" : "Turkmaniston",
    "Tunisia" : "Tunis",
    "Tonga" : "Tonga",
    "Turkey" : "Turkiya",
    "Trinidad and Tobago" : "Trinidad va Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan, Province of China" : "Taiwan, Xitoy provintsiyasi",
    "Tanzania, United Republic of" : "Tanzania, United Republic of",
    "Ukraine" : "Ukraina",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Amerika Qo'shma Shtatlarining Kichik Chet orollari",
    "United States of America" : "Amerika Qo'shma Shtatlari",
    "Uruguay" : "Urugvay",
    "Uzbekistan" : "O'zbekiston",
    "Holy See" : "Muqaddas orollar",
    "Saint Vincent and the Grenadines" : "Sent-Vinsent va Grenadin orollari",
    "Viet Nam" : "Vyetnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Uollis va Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Yaman",
    "Mayotte" : "Mayotte",
    "South Africa" : "Janubiy Afrika",
    "Zambia" : "Zambiya",
    "Zimbabwe" : "Zimbabve",
    "Federation" : "Jamg'arma",
    "It is highly recommended to configure \"memcache.locking\" when Talk Federation is enabled." : "Jamg'armaning muloqot moduli yoqilgan bo'lsa, \"memcache.locking\" ni sozlash tavsiya etiladi.",
    "Loading …" : "Yuklanmoqda…",
    "The password is wrong. Try again." : "Parol noto'g'ri. Qayta urinib ko'ring.",
    "Password" : "Password",
    "Submit" : "Submit",
    "Everyone" : "Everyone",
    "Save changes" : "Save changes",
    "Saving …" : "Saqlanmoqda...",
    "Saved!" : "Saqlandi!",
    "Name" : "Name",
    "Enable Federation in Talk app" : "Talk ilovasida Jamg'armani yoqish",
    "Permissions" : "Ruxsatnomalar",
    "Off" : "Oʻchirilgan",
    "Enable encryption" : "Enable encryption",
    "Pending" : "Pending",
    "Error" : "Xatolik",
    "Never" : "Hech qachon",
    "Language" : "Language",
    "Status" : "Status",
    "Yes" : "Yes",
    "No" : "No",
    "OK" : "Yaxshi",
    "Checking …" : "Checking …",
    "Federated user" : "Korporativ foydalanuvchi",
    "Confirm" : "Confirm",
    "Reset" : "Qayta tiklash",
    "Cancel" : "Bekor qilish",
    "Back" : "Orqaga",
    "Now" : "Hozir",
    "From" : "Dan",
    "To" : "Gacha",
    "Calendar" : "Calendar",
    "Attendees" : "Ishtirokchilar",
    "Save" : "Saqlash",
    "No results" : "Natija yo'q",
    "Done" : "Bajarildi",
    "Grid view" : "To‘r ko‘rinishi",
    "Reload" : "Qayta yuklash",
    "Copy link" : "Havolani nusxalash",
    "None" : "Yo'q",
    "Favorite" : "Favorite",
    "Date:" : "Sana:",
    "Hide details" : "Tafsilotlarni yashirish",
    "Show details" : "Tafsilotlarni ko'rsatish",
    "Disable" : "Oʻchirish",
    "Enable" : "Enable",
    "Choose" : "Choose",
    "Restricted" : "Cheklangan",
    "Personal" : "Personal",
    "Delete conversation" : "Delete conversation",
    "Password protection" : "Parol himoyasi",
    "Change password" : "Change password",
    "Edit" : "Tahrirlash",
    "Delete" : "O'chirish",
    "Notifications" : "Notifications",
    "Create a new conversation" : "Yangi suhbat yarating",
    "Log in" : "Kirish",
    "Remove from favorites" : "Sevimlilardan olib tashlang",
    "Add to favorites" : "Sevimlilarga qo'shing",
    "Tags" : "Teglar",
    "Home" : "Uy",
    "Users" : "Users",
    "Groups" : "Groups",
    "Teams" : "Jamoalar",
    "No search results" : "Qidiruv natijalari yo‘q",
    "Select a device" : "Qurilmani tanlang",
    "Test" : "Test",
    "Upload" : "Yuklash",
    "Files" : "Fayllar",
    "24 hours" : "24 soat",
    "Reply" : "Javob bering",
    "More actions" : "Ko'proq harakatlar",
    "Translate" : "Tarjima",
    "Dismiss" : "Dismiss",
    "Contact" : "Aloqa",
    "Remove {fileName}" : " {fileName} ni o'chirish",
    "Add emoji" : "Emoji qo'shing",
    "Upload from device" : "Qurilmadan yuklash",
    "Send" : "Send",
    "Settings" : "Sozlamalar",
    "Results" : "Natijalar",
    "Remove participant" : "Ishtirokchini olib tashlash",
    "Remove" : "O'chirish",
    "Searching …" : "Qidirilmoqda …",
    "Participants" : "Ishtirokchilar",
    "Details" : "Details",
    "Search in {name}" : " {name}ni qidirish",
    "No results found" : "Hech qanday natija topilmadi",
    "Load more results" : "Ko'proq natijalarni yuklang",
    "Projects" : "Loyihalar",
    "Select conversation" : "Suhbatni tanlang",
    "Notification settings" : "Bildirishnoma sozlamalari",
    "Privacy" : "Maxfiylik",
    "Attachments folder" : "Qo'shimchalar papkasi",
    "Search" : "Qidirish",
    "Select a region" : "Hududni tanlang",
    "User" : "Foydalanuvchi",
    "Login" : "Login",
    "Client ID" : "Mijoz identifikatori",
    "Audio" : "Audio",
    "Show all files" : "Barcha fayllarni ko'rsatish",
    "Group" : "Guruh",
    "Team" : "Jamoa",
    "Error while sharing file" : "Fayl almashishda xatolik yuz berdi",
    "_%n hour_::_%n hours_" : ["%n soat"],
    "_%n day_::_%n days_" : ["%n kun"],
    "_%n week_::_%n weeks_" : ["%n hafta"],
    "Error while parsing a PROPFIND error" : "PROPFIND xatosini tahlil qilishda xatolik yuz berdi",
    "Please reload the page." : "Please reload the page.",
    "Do not disturb" : "Do not disturb",
    "Away" : "Away",
    "Tasks" : "Tasks",
    "Notes" : "Eslatmalar",
    "Reports" : "Hisobotlar",
    "Talk conversation for event" : "Tadbir uchun suhbat",
    "Nextcloud Talk Federation was updated." : "Nextcloud Talkda jamg'arma yangilandi."
},
"nplurals=1; plural=0;");
