<?php return array(
    'root' => array(
        'name' => '__root__',
        'pretty_version' => 'v24.0.0',
        'version' => '24.0.0.0',
        'reference' => 'd141fc59af0d48e600b6717cb43a0250755e54ee',
        'type' => 'library',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'dev' => false,
    ),
    'versions' => array(
        '__root__' => array(
            'pretty_version' => 'v24.0.0',
            'version' => '24.0.0.0',
            'reference' => 'd141fc59af0d48e600b6717cb43a0250755e54ee',
            'type' => 'library',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'bamarni/composer-bin-plugin' => array(
            'pretty_version' => '1.9.1',
            'version' => '1.9.1.0',
            'reference' => '641d0663f5ac270b1aeec4337b7856f76204df47',
            'type' => 'composer-plugin',
            'install_path' => __DIR__ . '/../bamarni/composer-bin-plugin',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'cuyz/valinor' => array(
            'pretty_version' => '2.4.0',
            'version' => '2.4.0.0',
            'reference' => '3b0afa3a287ed7f3a69aab223726cf1139454c34',
            'type' => 'library',
            'install_path' => __DIR__ . '/../cuyz/valinor',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'cweagans/composer-configurable-plugin' => array(
            'pretty_version' => '2.0.0',
            'version' => '2.0.0.0',
            'reference' => '15433906511a108a1806710e988629fd24b89974',
            'type' => 'library',
            'install_path' => __DIR__ . '/../cweagans/composer-configurable-plugin',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'cweagans/composer-patches' => array(
            'pretty_version' => '2.0.0',
            'version' => '2.0.0.0',
            'reference' => 'bfa6018a5f864653d9ed899b902ea72f858a2cf7',
            'type' => 'composer-plugin',
            'install_path' => __DIR__ . '/../cweagans/composer-patches',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'firebase/php-jwt' => array(
            'pretty_version' => 'v7.0.5',
            'version' => '7.0.5.0',
            'reference' => '47ad26bab5e7c70ae8a6f08ed25ff83631121380',
            'type' => 'library',
            'install_path' => __DIR__ . '/../firebase/php-jwt',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
    ),
);
