<?php

// autoload_static.php @generated by Mozart

namespace Composer\Autoload;

class MozartStaticInitab226525016ef02c3736dbc767509078
{
    public static $prefixLengthsPsr4 = array (
        'O' =>
        array (
            'OCA\\Talk\\Vendor\\' => 16,
        ),
    );

    public static $prefixDirsPsr4 = array (
        'OCA\\Talk\\Vendor\\' =>
        array (
            0 => __DIR__ . '/..',
        ),
    );

    public static $classMap = array (
        'OCA\\Talk\\Vendor\\Firebase\\JWT\\JWTExceptionWithPayloadInterface' => __DIR__ . '/../Firebase/JWT/JWTExceptionWithPayloadInterface.php',
        'OCA\\Talk\\Vendor\\Firebase\\JWT\\JWT' => __DIR__ . '/../Firebase/JWT/JWT.php',
        'OCA\\Talk\\Vendor\\Firebase\\JWT\\JWK' => __DIR__ . '/../Firebase/JWT/JWK.php',
        'OCA\\Talk\\Vendor\\Firebase\\JWT\\Key' => __DIR__ . '/../Firebase/JWT/Key.php',
        'OCA\\Talk\\Vendor\\Firebase\\JWT\\BeforeValidException' => __DIR__ . '/../Firebase/JWT/BeforeValidException.php',
        'OCA\\Talk\\Vendor\\Firebase\\JWT\\ExpiredException' => __DIR__ . '/../Firebase/JWT/ExpiredException.php',
        'OCA\\Talk\\Vendor\\Firebase\\JWT\\SignatureInvalidException' => __DIR__ . '/../Firebase/JWT/SignatureInvalidException.php',
        'OCA\\Talk\\Vendor\\Firebase\\JWT\\CachedKeySet' => __DIR__ . '/../Firebase/JWT/CachedKeySet.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\NormalizerBuilder' => __DIR__ . '/../CuyZ/Valinor/NormalizerBuilder.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Utility\\IsSingleton' => __DIR__ . '/../CuyZ/Valinor/Utility/IsSingleton.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Utility\\Reflection\\TokenParser' => __DIR__ . '/../CuyZ/Valinor/Utility/Reflection/TokenParser.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Utility\\Reflection\\PhpParser' => __DIR__ . '/../CuyZ/Valinor/Utility/Reflection/PhpParser.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Utility\\Reflection\\Annotations' => __DIR__ . '/../CuyZ/Valinor/Utility/Reflection/Annotations.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Utility\\Reflection\\Reflection' => __DIR__ . '/../CuyZ/Valinor/Utility/Reflection/Reflection.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Utility\\Reflection\\NamespaceFinder' => __DIR__ . '/../CuyZ/Valinor/Utility/Reflection/NamespaceFinder.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Utility\\ValueDumper' => __DIR__ . '/../CuyZ/Valinor/Utility/ValueDumper.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Utility\\String\\StringFormatterError' => __DIR__ . '/../CuyZ/Valinor/Utility/String/StringFormatterError.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Utility\\String\\StringFormatter' => __DIR__ . '/../CuyZ/Valinor/Utility/String/StringFormatter.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Utility\\String\\StringCutter' => __DIR__ . '/../CuyZ/Valinor/Utility/String/StringCutter.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Utility\\Polyfill' => __DIR__ . '/../CuyZ/Valinor/Utility/Polyfill.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Utility\\TypeHelper' => __DIR__ . '/../CuyZ/Valinor/Utility/TypeHelper.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Utility\\Package' => __DIR__ . '/../CuyZ/Valinor/Utility/Package.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\MapperBuilder' => __DIR__ . '/../CuyZ/Valinor/MapperBuilder.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\FixedType' => __DIR__ . '/../CuyZ/Valinor/Type/FixedType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\ClassType' => __DIR__ . '/../CuyZ/Valinor/Type/ClassType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\ObjectWithGenericType' => __DIR__ . '/../CuyZ/Valinor/Type/ObjectWithGenericType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\IntegerType' => __DIR__ . '/../CuyZ/Valinor/Type/IntegerType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Dumper\\TypeDumpContext' => __DIR__ . '/../CuyZ/Valinor/Type/Dumper/TypeDumpContext.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Dumper\\TypeDumper' => __DIR__ . '/../CuyZ/Valinor/Type/Dumper/TypeDumper.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\StringType' => __DIR__ . '/../CuyZ/Valinor/Type/StringType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\CombiningType' => __DIR__ . '/../CuyZ/Valinor/Type/CombiningType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Type' => __DIR__ . '/../CuyZ/Valinor/Type/Type.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\FloatType' => __DIR__ . '/../CuyZ/Valinor/Type/FloatType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\CompositeTraversableType' => __DIR__ . '/../CuyZ/Valinor/Type/CompositeTraversableType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\NumericStringType' => __DIR__ . '/../CuyZ/Valinor/Type/Types/NumericStringType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\UnresolvableType' => __DIR__ . '/../CuyZ/Valinor/Type/Types/UnresolvableType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\NativeBooleanType' => __DIR__ . '/../CuyZ/Valinor/Type/Types/NativeBooleanType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\Factory\\ValueTypeFactory' => __DIR__ . '/../CuyZ/Valinor/Type/Types/Factory/ValueTypeFactory.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\Factory\\CannotBuildTypeFromValue' => __DIR__ . '/../CuyZ/Valinor/Type/Types/Factory/CannotBuildTypeFromValue.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\GenericType' => __DIR__ . '/../CuyZ/Valinor/Type/Types/GenericType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\NonEmptyStringType' => __DIR__ . '/../CuyZ/Valinor/Type/Types/NonEmptyStringType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\NativeFloatType' => __DIR__ . '/../CuyZ/Valinor/Type/Types/NativeFloatType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\NullType' => __DIR__ . '/../CuyZ/Valinor/Type/Types/NullType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\NativeStringType' => __DIR__ . '/../CuyZ/Valinor/Type/Types/NativeStringType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\ArrayKeyType' => __DIR__ . '/../CuyZ/Valinor/Type/Types/ArrayKeyType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\ClassStringType' => __DIR__ . '/../CuyZ/Valinor/Type/Types/ClassStringType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\IntegerValueType' => __DIR__ . '/../CuyZ/Valinor/Type/Types/IntegerValueType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\Generics' => __DIR__ . '/../CuyZ/Valinor/Type/Types/Generics.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\NegativeIntegerType' => __DIR__ . '/../CuyZ/Valinor/Type/Types/NegativeIntegerType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\ListType' => __DIR__ . '/../CuyZ/Valinor/Type/Types/ListType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\EnumType' => __DIR__ . '/../CuyZ/Valinor/Type/Types/EnumType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\ArrayType' => __DIR__ . '/../CuyZ/Valinor/Type/Types/ArrayType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\IntersectionType' => __DIR__ . '/../CuyZ/Valinor/Type/Types/IntersectionType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\ShapedArrayElement' => __DIR__ . '/../CuyZ/Valinor/Type/Types/ShapedArrayElement.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\NativeClassType' => __DIR__ . '/../CuyZ/Valinor/Type/Types/NativeClassType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\NonNegativeIntegerType' => __DIR__ . '/../CuyZ/Valinor/Type/Types/NonNegativeIntegerType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\InterfaceType' => __DIR__ . '/../CuyZ/Valinor/Type/Types/InterfaceType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\StringValueType' => __DIR__ . '/../CuyZ/Valinor/Type/Types/StringValueType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\ShapedArrayType' => __DIR__ . '/../CuyZ/Valinor/Type/Types/ShapedArrayType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\ScalarConcreteType' => __DIR__ . '/../CuyZ/Valinor/Type/Types/ScalarConcreteType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\MixedType' => __DIR__ . '/../CuyZ/Valinor/Type/Types/MixedType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\BooleanValueType' => __DIR__ . '/../CuyZ/Valinor/Type/Types/BooleanValueType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\IntegerRangeType' => __DIR__ . '/../CuyZ/Valinor/Type/Types/IntegerRangeType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\FloatValueType' => __DIR__ . '/../CuyZ/Valinor/Type/Types/FloatValueType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\PositiveIntegerType' => __DIR__ . '/../CuyZ/Valinor/Type/Types/PositiveIntegerType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\NativeIntegerType' => __DIR__ . '/../CuyZ/Valinor/Type/Types/NativeIntegerType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\UnionType' => __DIR__ . '/../CuyZ/Valinor/Type/Types/UnionType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\NonPositiveIntegerType' => __DIR__ . '/../CuyZ/Valinor/Type/Types/NonPositiveIntegerType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\IterableType' => __DIR__ . '/../CuyZ/Valinor/Type/Types/IterableType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\NonEmptyListType' => __DIR__ . '/../CuyZ/Valinor/Type/Types/NonEmptyListType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\UndefinedObjectType' => __DIR__ . '/../CuyZ/Valinor/Type/Types/UndefinedObjectType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\NonEmptyArrayType' => __DIR__ . '/../CuyZ/Valinor/Type/Types/NonEmptyArrayType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Types\\CallableType' => __DIR__ . '/../CuyZ/Valinor/Type/Types/CallableType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\BooleanType' => __DIR__ . '/../CuyZ/Valinor/Type/BooleanType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\VacantType' => __DIR__ . '/../CuyZ/Valinor/Type/VacantType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\ObjectType' => __DIR__ . '/../CuyZ/Valinor/Type/ObjectType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\CompositeType' => __DIR__ . '/../CuyZ/Valinor/Type/CompositeType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\DumpableType' => __DIR__ . '/../CuyZ/Valinor/Type/DumpableType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\LexingParser' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/LexingParser.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Factory\\TypeParserFactory' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Factory/TypeParserFactory.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Factory\\Specifications\\TypeParserSpecification' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Factory/Specifications/TypeParserSpecification.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Factory\\Specifications\\ObjectSpecification' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Factory/Specifications/ObjectSpecification.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Factory\\Specifications\\ClassContextSpecification' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Factory/Specifications/ClassContextSpecification.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Factory\\Specifications\\AliasSpecification' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Factory/Specifications/AliasSpecification.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\CachedParser' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/CachedParser.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\TypeParser' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/TypeParser.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\VacantTypeAssignerParser' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/VacantTypeAssignerParser.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Scalar\\IntegerRangeMissingMinValue' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Scalar/IntegerRangeMissingMinValue.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Scalar\\IntegerRangeInvalidMaxValue' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Scalar/IntegerRangeInvalidMaxValue.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Scalar\\NullableMissingRightType' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Scalar/NullableMissingRightType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Scalar\\IntegerRangeMissingComma' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Scalar/IntegerRangeMissingComma.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Scalar\\IntegerRangeMissingClosingBracket' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Scalar/IntegerRangeMissingClosingBracket.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Scalar\\ClassStringClosingBracketMissing' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Scalar/ClassStringClosingBracketMissing.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Scalar\\ClassStringMissingSubType' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Scalar/ClassStringMissingSubType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Scalar\\SameValueForIntegerRange' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Scalar/SameValueForIntegerRange.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Scalar\\ReversedValuesForIntegerRange' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Scalar/ReversedValuesForIntegerRange.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Scalar\\IntegerRangeInvalidMinValue' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Scalar/IntegerRangeInvalidMinValue.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Scalar\\IntegerRangeMissingMaxValue' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Scalar/IntegerRangeMissingMaxValue.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\InvalidType' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/InvalidType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Intersection\\InvalidIntersectionElement' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Intersection/InvalidIntersectionElement.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Intersection\\RightIntersectionTypeMissing' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Intersection/RightIntersectionTypeMissing.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Iterable\\ShapedArrayClosingBracketMissing' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Iterable/ShapedArrayClosingBracketMissing.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Iterable\\ShapedArrayElementTypeMissing' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Iterable/ShapedArrayElementTypeMissing.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Iterable\\ShapedArrayColonTokenMissing' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Iterable/ShapedArrayColonTokenMissing.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Iterable\\ShapedArrayElementDuplicatedKey' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Iterable/ShapedArrayElementDuplicatedKey.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Iterable\\ListClosingBracketMissing' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Iterable/ListClosingBracketMissing.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Iterable\\InvalidShapedArrayUnsealedType' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Iterable/InvalidShapedArrayUnsealedType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Iterable\\SimpleArrayClosingBracketMissing' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Iterable/SimpleArrayClosingBracketMissing.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Iterable\\InvalidArrayKey' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Iterable/InvalidArrayKey.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Iterable\\ShapedArrayCommaMissing' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Iterable/ShapedArrayCommaMissing.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Iterable\\ArrayCommaMissing' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Iterable/ArrayCommaMissing.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Iterable\\ShapedArrayUnexpectedTokenAfterSealedType' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Iterable/ShapedArrayUnexpectedTokenAfterSealedType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Iterable\\ArrayClosingBracketMissing' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Iterable/ArrayClosingBracketMissing.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Iterable\\ListMissingSubType' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Iterable/ListMissingSubType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Iterable\\ArrayExpectedCommaOrClosingBracket' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Iterable/ArrayExpectedCommaOrClosingBracket.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Iterable\\ArrayMissingSubType' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Iterable/ArrayMissingSubType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Iterable\\ShapedArrayWithoutElementsWithSealedType' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Iterable/ShapedArrayWithoutElementsWithSealedType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Magic\\ValueOfClosingBracketMissing' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Magic/ValueOfClosingBracketMissing.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Magic\\ValueOfMissingSubType' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Magic/ValueOfMissingSubType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Magic\\ValueOfOpeningBracketMissing' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Magic/ValueOfOpeningBracketMissing.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Magic\\ValueOfIncorrectSubType' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Magic/ValueOfIncorrectSubType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Enum\\MissingEnumCase' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Enum/MissingEnumCase.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Enum\\EnumCaseNotFound' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Enum/EnumCaseNotFound.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Enum\\EnumHasNoCase' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Enum/EnumHasNoCase.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Enum\\MissingSpecificEnumCase' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Enum/MissingSpecificEnumCase.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Generic\\GenericCommaMissing' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Generic/GenericCommaMissing.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Generic\\CannotAssignGeneric' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Generic/CannotAssignGeneric.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Generic\\GenericClosingBracketMissing' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Generic/GenericClosingBracketMissing.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Generic\\MissingGenerics' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Generic/MissingGenerics.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\UnexpectedToken' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/UnexpectedToken.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\MissingClosingQuoteChar' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/MissingClosingQuoteChar.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Constant\\MissingClassConstantCase' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Constant/MissingClassConstantCase.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Constant\\ClassConstantCaseNotFound' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Constant/ClassConstantCaseNotFound.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Callable\\ExpectedColonAfterCallableClosingParenthesis' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Callable/ExpectedColonAfterCallableClosingParenthesis.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Callable\\UnexpectedTokenAfterCallableClosingParenthesis' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Callable/UnexpectedTokenAfterCallableClosingParenthesis.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Callable\\ExpectedClosingParenthesisAfterCallable' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Callable/ExpectedClosingParenthesisAfterCallable.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Callable\\ExpectedReturnTypeAfterCallableColon' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Callable/ExpectedReturnTypeAfterCallableColon.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Callable\\ExpectedTypeForCallable' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Callable/ExpectedTypeForCallable.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Union\\ForbiddenMixedType' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Union/ForbiddenMixedType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Union\\InvalidClassStringElements' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Union/InvalidClassStringElements.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Exception\\Union\\RightUnionTypeMissing' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Exception/Union/RightUnionTypeMissing.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\SpecificationsLexer' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Lexer/SpecificationsLexer.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\NativeLexer' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Lexer/NativeLexer.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\TokenizedAnnotation' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Lexer/TokenizedAnnotation.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\TokensExtractor' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Lexer/TokensExtractor.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\TypeLexer' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Lexer/TypeLexer.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\OpeningCurlyBracketToken' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Lexer/Token/OpeningCurlyBracketToken.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\TripleDotsToken' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Lexer/Token/TripleDotsToken.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\EnumNameToken' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Lexer/Token/EnumNameToken.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\OpeningSquareBracketToken' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Lexer/Token/OpeningSquareBracketToken.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\FloatValueToken' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Lexer/Token/FloatValueToken.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\UnionToken' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Lexer/Token/UnionToken.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\ColonToken' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Lexer/Token/ColonToken.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\VacantToken' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Lexer/Token/VacantToken.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\ClassNameToken' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Lexer/Token/ClassNameToken.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\OpeningBracketToken' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Lexer/Token/OpeningBracketToken.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\ValueOfToken' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Lexer/Token/ValueOfToken.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\ObjectToken' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Lexer/Token/ObjectToken.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\StringValueToken' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Lexer/Token/StringValueToken.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\LeftTraversingToken' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Lexer/Token/LeftTraversingToken.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\ListToken' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Lexer/Token/ListToken.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\OpeningParenthesisToken' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Lexer/Token/OpeningParenthesisToken.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\ClassStringToken' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Lexer/Token/ClassStringToken.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\TypeToken' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Lexer/Token/TypeToken.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\CaseFinder' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Lexer/Token/CaseFinder.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\DoubleColonToken' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Lexer/Token/DoubleColonToken.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\TraversingToken' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Lexer/Token/TraversingToken.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\CommaToken' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Lexer/Token/CommaToken.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\Token' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Lexer/Token/Token.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\ClosingSquareBracketToken' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Lexer/Token/ClosingSquareBracketToken.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\ArrayToken' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Lexer/Token/ArrayToken.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\IntersectionToken' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Lexer/Token/IntersectionToken.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\ClosingCurlyBracketToken' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Lexer/Token/ClosingCurlyBracketToken.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\NullableToken' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Lexer/Token/NullableToken.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\ClosingParenthesisToken' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Lexer/Token/ClosingParenthesisToken.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\IntegerValueToken' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Lexer/Token/IntegerValueToken.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\IntegerToken' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Lexer/Token/IntegerToken.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\CallableToken' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Lexer/Token/CallableToken.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\Token\\ClosingBracketToken' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Lexer/Token/ClosingBracketToken.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\Lexer\\TokenStream' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/Lexer/TokenStream.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\Parser\\UnresolvableTypeFinderParser' => __DIR__ . '/../CuyZ/Valinor/Type/Parser/UnresolvableTypeFinderParser.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Type\\ScalarType' => __DIR__ . '/../CuyZ/Valinor/Type/ScalarType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\JsonNormalizer' => __DIR__ . '/../CuyZ/Valinor/Normalizer/JsonNormalizer.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\ArrayNormalizer' => __DIR__ . '/../CuyZ/Valinor/Normalizer/ArrayNormalizer.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\Transformer' => __DIR__ . '/../CuyZ/Valinor/Normalizer/Transformer/Transformer.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\EmptyObject' => __DIR__ . '/../CuyZ/Valinor/Normalizer/Transformer/EmptyObject.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\RecursiveTransformer' => __DIR__ . '/../CuyZ/Valinor/Normalizer/Transformer/RecursiveTransformer.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\TransformerContainer' => __DIR__ . '/../CuyZ/Valinor/Normalizer/Transformer/TransformerContainer.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\CompiledTransformer' => __DIR__ . '/../CuyZ/Valinor/Normalizer/Transformer/CompiledTransformer.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\Compiler\\TransformerRootNode' => __DIR__ . '/../CuyZ/Valinor/Normalizer/Transformer/Compiler/TransformerRootNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\Compiler\\TransformerDefinition' => __DIR__ . '/../CuyZ/Valinor/Normalizer/Transformer/Compiler/TransformerDefinition.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\Compiler\\TypeFormatter\\InterfaceFormatter' => __DIR__ . '/../CuyZ/Valinor/Normalizer/Transformer/Compiler/TypeFormatter/InterfaceFormatter.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\Compiler\\TypeFormatter\\ScalarFormatter' => __DIR__ . '/../CuyZ/Valinor/Normalizer/Transformer/Compiler/TypeFormatter/ScalarFormatter.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\Compiler\\TypeFormatter\\NullFormatter' => __DIR__ . '/../CuyZ/Valinor/Normalizer/Transformer/Compiler/TypeFormatter/NullFormatter.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\Compiler\\TypeFormatter\\TypeFormatter' => __DIR__ . '/../CuyZ/Valinor/Normalizer/Transformer/Compiler/TypeFormatter/TypeFormatter.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\Compiler\\TypeFormatter\\DateTimeZoneFormatter' => __DIR__ . '/../CuyZ/Valinor/Normalizer/Transformer/Compiler/TypeFormatter/DateTimeZoneFormatter.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\Compiler\\TypeFormatter\\StdClassFormatter' => __DIR__ . '/../CuyZ/Valinor/Normalizer/Transformer/Compiler/TypeFormatter/StdClassFormatter.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\Compiler\\TypeFormatter\\ShapedArrayFormatter' => __DIR__ . '/../CuyZ/Valinor/Normalizer/Transformer/Compiler/TypeFormatter/ShapedArrayFormatter.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\Compiler\\TypeFormatter\\UnsureTypeFormatter' => __DIR__ . '/../CuyZ/Valinor/Normalizer/Transformer/Compiler/TypeFormatter/UnsureTypeFormatter.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\Compiler\\TypeFormatter\\UnitEnumFormatter' => __DIR__ . '/../CuyZ/Valinor/Normalizer/Transformer/Compiler/TypeFormatter/UnitEnumFormatter.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\Compiler\\TypeFormatter\\ClassFormatter' => __DIR__ . '/../CuyZ/Valinor/Normalizer/Transformer/Compiler/TypeFormatter/ClassFormatter.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\Compiler\\TypeFormatter\\TraversableFormatter' => __DIR__ . '/../CuyZ/Valinor/Normalizer/Transformer/Compiler/TypeFormatter/TraversableFormatter.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\Compiler\\TypeFormatter\\RegisteredTransformersFormatter' => __DIR__ . '/../CuyZ/Valinor/Normalizer/Transformer/Compiler/TypeFormatter/RegisteredTransformersFormatter.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\Compiler\\TypeFormatter\\DateTimeFormatter' => __DIR__ . '/../CuyZ/Valinor/Normalizer/Transformer/Compiler/TypeFormatter/DateTimeFormatter.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\Compiler\\TypeFormatter\\EnumFormatter' => __DIR__ . '/../CuyZ/Valinor/Normalizer/Transformer/Compiler/TypeFormatter/EnumFormatter.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\Compiler\\TypeFormatter\\UnionFormatter' => __DIR__ . '/../CuyZ/Valinor/Normalizer/Transformer/Compiler/TypeFormatter/UnionFormatter.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\Compiler\\TypeFormatter\\MixedFormatter' => __DIR__ . '/../CuyZ/Valinor/Normalizer/Transformer/Compiler/TypeFormatter/MixedFormatter.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Transformer\\Compiler\\TransformerDefinitionBuilder' => __DIR__ . '/../CuyZ/Valinor/Normalizer/Transformer/Compiler/TransformerDefinitionBuilder.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Exception\\KeyTransformerHasTooManyParameters' => __DIR__ . '/../CuyZ/Valinor/Normalizer/Exception/KeyTransformerHasTooManyParameters.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Exception\\TransformerHasTooManyParameters' => __DIR__ . '/../CuyZ/Valinor/Normalizer/Exception/TransformerHasTooManyParameters.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Exception\\TypeUnhandledByNormalizer' => __DIR__ . '/../CuyZ/Valinor/Normalizer/Exception/TypeUnhandledByNormalizer.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Exception\\KeyTransformerParameterInvalidType' => __DIR__ . '/../CuyZ/Valinor/Normalizer/Exception/KeyTransformerParameterInvalidType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Exception\\TransformerHasNoParameter' => __DIR__ . '/../CuyZ/Valinor/Normalizer/Exception/TransformerHasNoParameter.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Exception\\TransformerHasInvalidCallableParameter' => __DIR__ . '/../CuyZ/Valinor/Normalizer/Exception/TransformerHasInvalidCallableParameter.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Exception\\CircularReferenceFoundDuringNormalization' => __DIR__ . '/../CuyZ/Valinor/Normalizer/Exception/CircularReferenceFoundDuringNormalization.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Formatter\\JsonFormatter' => __DIR__ . '/../CuyZ/Valinor/Normalizer/Formatter/JsonFormatter.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Formatter\\Exception\\CannotFormatInvalidTypeToJson' => __DIR__ . '/../CuyZ/Valinor/Normalizer/Formatter/Exception/CannotFormatInvalidTypeToJson.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Format' => __DIR__ . '/../CuyZ/Valinor/Normalizer/Format.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\AsTransformer' => __DIR__ . '/../CuyZ/Valinor/Normalizer/AsTransformer.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Normalizer' => __DIR__ . '/../CuyZ/Valinor/Normalizer/Normalizer.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\StreamNormalizer' => __DIR__ . '/../CuyZ/Valinor/Normalizer/StreamNormalizer.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Normalizer\\Configurator\\NormalizerBuilderConfigurator' => __DIR__ . '/../CuyZ/Valinor/Normalizer/Configurator/NormalizerBuilderConfigurator.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Message\\UserlandError' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Message/UserlandError.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Message\\NodeMessage' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Message/NodeMessage.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Message\\HasCode' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Message/HasCode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Message\\Messages' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Message/Messages.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Message\\HasParameters' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Message/HasParameters.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Message\\MessageBuilder' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Message/MessageBuilder.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Message\\Formatter\\CallbackMessageFormatter' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Message/Formatter/CallbackMessageFormatter.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Message\\Formatter\\TranslationMessageFormatter' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Message/Formatter/TranslationMessageFormatter.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Message\\Formatter\\MessageMapFormatter' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Message/Formatter/MessageMapFormatter.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Message\\Formatter\\LocaleMessageFormatter' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Message/Formatter/LocaleMessageFormatter.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Message\\Formatter\\MessageFormatter' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Message/Formatter/MessageFormatter.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Message\\Formatter\\AggregateMessageFormatter' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Message/Formatter/AggregateMessageFormatter.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Message\\DefaultMessage' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Message/DefaultMessage.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Message\\Message' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Message/Message.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Message\\ErrorMessage' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Message/ErrorMessage.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\RootNodeBuilder' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/RootNodeBuilder.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\MissingObjectImplementationRegistration' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Exception/MissingObjectImplementationRegistration.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\ObjectImplementationNotRegistered' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Exception/ObjectImplementationNotRegistered.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\InvalidNodeValue' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Exception/InvalidNodeValue.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\InvalidIterableKeyType' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Exception/InvalidIterableKeyType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\KeyConverterHasInvalidStringParameter' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Exception/KeyConverterHasInvalidStringParameter.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\ConverterHasInvalidReturnType' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Exception/ConverterHasInvalidReturnType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\TooManyResolvedTypesFromUnion' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Exception/TooManyResolvedTypesFromUnion.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\InvalidResolvedImplementationValue' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Exception/InvalidResolvedImplementationValue.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\InvalidNodeDuringValueConversion' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Exception/InvalidNodeDuringValueConversion.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\InvalidArrayKey' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Exception/InvalidArrayKey.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\CircularDependencyDetected' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Exception/CircularDependencyDetected.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\CannotResolveTypeFromUnion' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Exception/CannotResolveTypeFromUnion.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\CannotResolveObjectType' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Exception/CannotResolveObjectType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\CannotUseBothFromBodyAttributes' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Exception/CannotUseBothFromBodyAttributes.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\InterfaceHasBothConstructorAndInfer' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Exception/InterfaceHasBothConstructorAndInfer.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\SourceIsEmptyList' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Exception/SourceIsEmptyList.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\ObjectImplementationCallbackError' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Exception/ObjectImplementationCallbackError.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\KeyConverterHasTooManyParameters' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Exception/KeyConverterHasTooManyParameters.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\UnexpectedKeyInSource' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Exception/UnexpectedKeyInSource.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\ConverterHasNoParameter' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Exception/ConverterHasNoParameter.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\HttpRequestKeyCollision' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Exception/HttpRequestKeyCollision.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\CannotMapToPermissiveType' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Exception/CannotMapToPermissiveType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\CannotInferFinalClass' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Exception/CannotInferFinalClass.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\KeyConverterHasNoParameter' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Exception/KeyConverterHasNoParameter.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\ResolvedImplementationIsNotAccepted' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Exception/ResolvedImplementationIsNotAccepted.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\CannotUseBothFromQueryAttributes' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Exception/CannotUseBothFromQueryAttributes.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\InvalidListKey' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Exception/InvalidListKey.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\ConverterHasTooManyParameters' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Exception/ConverterHasTooManyParameters.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\SourceMustBeIterable' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Exception/SourceMustBeIterable.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\UnresolvableShellType' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Exception/UnresolvableShellType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\SourceIsNotNull' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Exception/SourceIsNotNull.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\KeysCollision' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Exception/KeysCollision.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\ConverterHasInvalidCallableParameter' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Exception/ConverterHasInvalidCallableParameter.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\SourceIsEmptyArray' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Exception/SourceIsEmptyArray.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\MissingNodeValue' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Exception/MissingNodeValue.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Exception\\CannotMapHttpRequestToUnsealedShapedArray' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Exception/CannotMapHttpRequestToUnsealedShapedArray.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Builder\\MixedNodeBuilder' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Builder/MixedNodeBuilder.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Builder\\InterfaceInferringContainer' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Builder/InterfaceInferringContainer.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Builder\\Node' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Builder/Node.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Builder\\ConverterContainer' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Builder/ConverterContainer.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Builder\\UndefinedObjectNodeBuilder' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Builder/UndefinedObjectNodeBuilder.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Builder\\TypeNodeBuilder' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Builder/TypeNodeBuilder.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Builder\\KeyConverterNodeBuilder' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Builder/KeyConverterNodeBuilder.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Builder\\UnionNodeBuilder' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Builder/UnionNodeBuilder.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Builder\\NodeBuilder' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Builder/NodeBuilder.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Builder\\ObjectNodeBuilder' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Builder/ObjectNodeBuilder.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Builder\\ListNodeBuilder' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Builder/ListNodeBuilder.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Builder\\KeyConversionPipeline' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Builder/KeyConversionPipeline.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Builder\\InterfaceNodeBuilder' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Builder/InterfaceNodeBuilder.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Builder\\HttpRequestNodeBuilder' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Builder/HttpRequestNodeBuilder.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Builder\\ScalarNodeBuilder' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Builder/ScalarNodeBuilder.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Builder\\ShapedArrayNodeBuilder' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Builder/ShapedArrayNodeBuilder.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Builder\\NullNodeBuilder' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Builder/NullNodeBuilder.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Builder\\ArrayNodeBuilder' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Builder/ArrayNodeBuilder.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Builder\\ValueConverterNodeBuilder' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Builder/ValueConverterNodeBuilder.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Tree\\Shell' => __DIR__ . '/../CuyZ/Valinor/Mapper/Tree/Shell.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\TypeTreeMapperError' => __DIR__ . '/../CuyZ/Valinor/Mapper/TypeTreeMapperError.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Source\\Modifier\\CamelCaseKeys' => __DIR__ . '/../CuyZ/Valinor/Mapper/Source/Modifier/CamelCaseKeys.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Source\\Modifier\\Mapping' => __DIR__ . '/../CuyZ/Valinor/Mapper/Source/Modifier/Mapping.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Source\\Modifier\\PathMapping' => __DIR__ . '/../CuyZ/Valinor/Mapper/Source/Modifier/PathMapping.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Source\\JsonSource' => __DIR__ . '/../CuyZ/Valinor/Mapper/Source/JsonSource.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Source\\FileSource' => __DIR__ . '/../CuyZ/Valinor/Mapper/Source/FileSource.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Source\\Source' => __DIR__ . '/../CuyZ/Valinor/Mapper/Source/Source.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Source\\YamlSource' => __DIR__ . '/../CuyZ/Valinor/Mapper/Source/YamlSource.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Source\\Exception\\YamlExtensionNotEnabled' => __DIR__ . '/../CuyZ/Valinor/Mapper/Source/Exception/YamlExtensionNotEnabled.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Source\\Exception\\SourceNotIterable' => __DIR__ . '/../CuyZ/Valinor/Mapper/Source/Exception/SourceNotIterable.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Source\\Exception\\UnableToReadFile' => __DIR__ . '/../CuyZ/Valinor/Mapper/Source/Exception/UnableToReadFile.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Source\\Exception\\InvalidSource' => __DIR__ . '/../CuyZ/Valinor/Mapper/Source/Exception/InvalidSource.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Source\\Exception\\InvalidYaml' => __DIR__ . '/../CuyZ/Valinor/Mapper/Source/Exception/InvalidYaml.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Source\\Exception\\FileExtensionNotHandled' => __DIR__ . '/../CuyZ/Valinor/Mapper/Source/Exception/FileExtensionNotHandled.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Source\\Exception\\InvalidJson' => __DIR__ . '/../CuyZ/Valinor/Mapper/Source/Exception/InvalidJson.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\TypeArgumentsMapper' => __DIR__ . '/../CuyZ/Valinor/Mapper/TypeArgumentsMapper.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\TreeMapper' => __DIR__ . '/../CuyZ/Valinor/Mapper/TreeMapper.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\MappingError' => __DIR__ . '/../CuyZ/Valinor/Mapper/MappingError.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\TypeTreeMapper' => __DIR__ . '/../CuyZ/Valinor/Mapper/TypeTreeMapper.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Http\\FromBody' => __DIR__ . '/../CuyZ/Valinor/Mapper/Http/FromBody.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Http\\HttpRequest' => __DIR__ . '/../CuyZ/Valinor/Mapper/Http/HttpRequest.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Http\\FromQuery' => __DIR__ . '/../CuyZ/Valinor/Mapper/Http/FromQuery.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Http\\FromRoute' => __DIR__ . '/../CuyZ/Valinor/Mapper/Http/FromRoute.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Exception\\PsrRequestParsedBodyIsObject' => __DIR__ . '/../CuyZ/Valinor/Mapper/Exception/PsrRequestParsedBodyIsObject.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Exception\\TypeErrorDuringArgumentsMapping' => __DIR__ . '/../CuyZ/Valinor/Mapper/Exception/TypeErrorDuringArgumentsMapping.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Exception\\InvalidMappingTypeSignature' => __DIR__ . '/../CuyZ/Valinor/Mapper/Exception/InvalidMappingTypeSignature.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Exception\\MappingLogicalException' => __DIR__ . '/../CuyZ/Valinor/Mapper/Exception/MappingLogicalException.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Exception\\TypeErrorDuringMapping' => __DIR__ . '/../CuyZ/Valinor/Mapper/Exception/TypeErrorDuringMapping.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\ArgumentsMapper' => __DIR__ . '/../CuyZ/Valinor/Mapper/ArgumentsMapper.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\ArgumentsMapperError' => __DIR__ . '/../CuyZ/Valinor/Mapper/ArgumentsMapperError.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\ObjectBuilder' => __DIR__ . '/../CuyZ/Valinor/Mapper/Object/ObjectBuilder.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\Constructor' => __DIR__ . '/../CuyZ/Valinor/Mapper/Object/Constructor.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\Factory\\CircularDependencyDetectorObjectBuilderFactory' => __DIR__ . '/../CuyZ/Valinor/Mapper/Object/Factory/CircularDependencyDetectorObjectBuilderFactory.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\Factory\\ConstructorObjectBuilderFactory' => __DIR__ . '/../CuyZ/Valinor/Mapper/Object/Factory/ConstructorObjectBuilderFactory.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\Factory\\SortingObjectBuilderFactory' => __DIR__ . '/../CuyZ/Valinor/Mapper/Object/Factory/SortingObjectBuilderFactory.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\Factory\\ObjectBuilderFactory' => __DIR__ . '/../CuyZ/Valinor/Mapper/Object/Factory/ObjectBuilderFactory.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\Factory\\InMemoryObjectBuilderFactory' => __DIR__ . '/../CuyZ/Valinor/Mapper/Object/Factory/InMemoryObjectBuilderFactory.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\Factory\\DateTimeZoneObjectBuilderFactory' => __DIR__ . '/../CuyZ/Valinor/Mapper/Object/Factory/DateTimeZoneObjectBuilderFactory.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\Factory\\ReflectionObjectBuilderFactory' => __DIR__ . '/../CuyZ/Valinor/Mapper/Object/Factory/ReflectionObjectBuilderFactory.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\Factory\\StrictTypesObjectBuilderFactory' => __DIR__ . '/../CuyZ/Valinor/Mapper/Object/Factory/StrictTypesObjectBuilderFactory.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\Factory\\DateTimeObjectBuilderFactory' => __DIR__ . '/../CuyZ/Valinor/Mapper/Object/Factory/DateTimeObjectBuilderFactory.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\MethodArguments' => __DIR__ . '/../CuyZ/Valinor/Mapper/Object/MethodArguments.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\Argument' => __DIR__ . '/../CuyZ/Valinor/Mapper/Object/Argument.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\ReflectionObjectBuilder' => __DIR__ . '/../CuyZ/Valinor/Mapper/Object/ReflectionObjectBuilder.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\ArgumentsValues' => __DIR__ . '/../CuyZ/Valinor/Mapper/Object/ArgumentsValues.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\NativeEnumObjectBuilder' => __DIR__ . '/../CuyZ/Valinor/Mapper/Object/NativeEnumObjectBuilder.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\NativeConstructorObjectBuilder' => __DIR__ . '/../CuyZ/Valinor/Mapper/Object/NativeConstructorObjectBuilder.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\Exception\\InvalidConstructorMethodWithAttributeReturnType' => __DIR__ . '/../CuyZ/Valinor/Mapper/Object/Exception/InvalidConstructorMethodWithAttributeReturnType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\Exception\\InvalidConstructorClassTypeParameter' => __DIR__ . '/../CuyZ/Valinor/Mapper/Object/Exception/InvalidConstructorClassTypeParameter.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\Exception\\CannotInstantiateObject' => __DIR__ . '/../CuyZ/Valinor/Mapper/Object/Exception/CannotInstantiateObject.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\Exception\\MissingConstructorClassTypeParameter' => __DIR__ . '/../CuyZ/Valinor/Mapper/Object/Exception/MissingConstructorClassTypeParameter.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\Exception\\CannotFindObjectBuilder' => __DIR__ . '/../CuyZ/Valinor/Mapper/Object/Exception/CannotFindObjectBuilder.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\Exception\\ObjectBuildersCollision' => __DIR__ . '/../CuyZ/Valinor/Mapper/Object/Exception/ObjectBuildersCollision.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\Exception\\CannotParseToDateTime' => __DIR__ . '/../CuyZ/Valinor/Mapper/Object/Exception/CannotParseToDateTime.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\Exception\\PermissiveTypeNotAllowed' => __DIR__ . '/../CuyZ/Valinor/Mapper/Object/Exception/PermissiveTypeNotAllowed.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\Exception\\InvalidConstructorReturnType' => __DIR__ . '/../CuyZ/Valinor/Mapper/Object/Exception/InvalidConstructorReturnType.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\DateTimeFormatConstructor' => __DIR__ . '/../CuyZ/Valinor/Mapper/Object/DateTimeFormatConstructor.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\MethodObjectBuilder' => __DIR__ . '/../CuyZ/Valinor/Mapper/Object/MethodObjectBuilder.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\FunctionObjectBuilder' => __DIR__ . '/../CuyZ/Valinor/Mapper/Object/FunctionObjectBuilder.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\DynamicConstructor' => __DIR__ . '/../CuyZ/Valinor/Mapper/Object/DynamicConstructor.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Object\\Arguments' => __DIR__ . '/../CuyZ/Valinor/Mapper/Object/Arguments.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\AsConverter' => __DIR__ . '/../CuyZ/Valinor/Mapper/AsConverter.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Configurator\\MapperBuilderConfigurator' => __DIR__ . '/../CuyZ/Valinor/Mapper/Configurator/MapperBuilderConfigurator.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Configurator\\RestrictKeysToCamelCase' => __DIR__ . '/../CuyZ/Valinor/Mapper/Configurator/RestrictKeysToCamelCase.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Configurator\\RestrictKeysToKebabCase' => __DIR__ . '/../CuyZ/Valinor/Mapper/Configurator/RestrictKeysToKebabCase.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Configurator\\ConvertKeysToCamelCase' => __DIR__ . '/../CuyZ/Valinor/Mapper/Configurator/ConvertKeysToCamelCase.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Configurator\\RestrictKeysToSnakeCase' => __DIR__ . '/../CuyZ/Valinor/Mapper/Configurator/RestrictKeysToSnakeCase.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Configurator\\RestrictKeysToPascalCase' => __DIR__ . '/../CuyZ/Valinor/Mapper/Configurator/RestrictKeysToPascalCase.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Mapper\\Configurator\\ConvertKeysToSnakeCase' => __DIR__ . '/../CuyZ/Valinor/Mapper/Configurator/ConvertKeysToSnakeCase.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\PropertyDefinition' => __DIR__ . '/../CuyZ/Valinor/Definition/PropertyDefinition.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\FunctionDefinition' => __DIR__ . '/../CuyZ/Valinor/Definition/FunctionDefinition.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Properties' => __DIR__ . '/../CuyZ/Valinor/Definition/Properties.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\FunctionsContainer' => __DIR__ . '/../CuyZ/Valinor/Definition/FunctionsContainer.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\ParameterDefinition' => __DIR__ . '/../CuyZ/Valinor/Definition/ParameterDefinition.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Parameters' => __DIR__ . '/../CuyZ/Valinor/Definition/Parameters.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\MethodDefinition' => __DIR__ . '/../CuyZ/Valinor/Definition/MethodDefinition.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\ClassDefinition' => __DIR__ . '/../CuyZ/Valinor/Definition/ClassDefinition.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Attributes' => __DIR__ . '/../CuyZ/Valinor/Definition/Attributes.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\FunctionObject' => __DIR__ . '/../CuyZ/Valinor/Definition/FunctionObject.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Methods' => __DIR__ . '/../CuyZ/Valinor/Definition/Methods.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\AttributeDefinition' => __DIR__ . '/../CuyZ/Valinor/Definition/AttributeDefinition.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Reflection\\ReflectionParameterDefinitionBuilder' => __DIR__ . '/../CuyZ/Valinor/Definition/Repository/Reflection/ReflectionParameterDefinitionBuilder.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Reflection\\ReflectionFunctionDefinitionRepository' => __DIR__ . '/../CuyZ/Valinor/Definition/Repository/Reflection/ReflectionFunctionDefinitionRepository.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Reflection\\TypeResolver\\ReflectionTypeResolver' => __DIR__ . '/../CuyZ/Valinor/Definition/Repository/Reflection/TypeResolver/ReflectionTypeResolver.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Reflection\\TypeResolver\\TemplateResolver' => __DIR__ . '/../CuyZ/Valinor/Definition/Repository/Reflection/TypeResolver/TemplateResolver.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Reflection\\TypeResolver\\FunctionReturnTypeResolver' => __DIR__ . '/../CuyZ/Valinor/Definition/Repository/Reflection/TypeResolver/FunctionReturnTypeResolver.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Reflection\\TypeResolver\\ClassLocalTypeAliasResolver' => __DIR__ . '/../CuyZ/Valinor/Definition/Repository/Reflection/TypeResolver/ClassLocalTypeAliasResolver.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Reflection\\TypeResolver\\ClassGenericResolver' => __DIR__ . '/../CuyZ/Valinor/Definition/Repository/Reflection/TypeResolver/ClassGenericResolver.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Reflection\\TypeResolver\\PropertyTypeResolver' => __DIR__ . '/../CuyZ/Valinor/Definition/Repository/Reflection/TypeResolver/PropertyTypeResolver.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Reflection\\TypeResolver\\ParameterTypeResolver' => __DIR__ . '/../CuyZ/Valinor/Definition/Repository/Reflection/TypeResolver/ParameterTypeResolver.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Reflection\\TypeResolver\\ClassImportedTypeAliasResolver' => __DIR__ . '/../CuyZ/Valinor/Definition/Repository/Reflection/TypeResolver/ClassImportedTypeAliasResolver.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Reflection\\TypeResolver\\ClassParentTypeResolver' => __DIR__ . '/../CuyZ/Valinor/Definition/Repository/Reflection/TypeResolver/ClassParentTypeResolver.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Reflection\\ReflectionClassDefinitionRepository' => __DIR__ . '/../CuyZ/Valinor/Definition/Repository/Reflection/ReflectionClassDefinitionRepository.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Reflection\\ReflectionMethodDefinitionBuilder' => __DIR__ . '/../CuyZ/Valinor/Definition/Repository/Reflection/ReflectionMethodDefinitionBuilder.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Reflection\\ReflectionPropertyDefinitionBuilder' => __DIR__ . '/../CuyZ/Valinor/Definition/Repository/Reflection/ReflectionPropertyDefinitionBuilder.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Reflection\\ReflectionAttributesRepository' => __DIR__ . '/../CuyZ/Valinor/Definition/Repository/Reflection/ReflectionAttributesRepository.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\FunctionDefinitionRepository' => __DIR__ . '/../CuyZ/Valinor/Definition/Repository/FunctionDefinitionRepository.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\ClassDefinitionRepository' => __DIR__ . '/../CuyZ/Valinor/Definition/Repository/ClassDefinitionRepository.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\AttributesRepository' => __DIR__ . '/../CuyZ/Valinor/Definition/Repository/AttributesRepository.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Cache\\InMemoryFunctionDefinitionRepository' => __DIR__ . '/../CuyZ/Valinor/Definition/Repository/Cache/InMemoryFunctionDefinitionRepository.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Cache\\InMemoryClassDefinitionRepository' => __DIR__ . '/../CuyZ/Valinor/Definition/Repository/Cache/InMemoryClassDefinitionRepository.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Cache\\Compiler\\PropertyDefinitionCompiler' => __DIR__ . '/../CuyZ/Valinor/Definition/Repository/Cache/Compiler/PropertyDefinitionCompiler.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Cache\\Compiler\\TypeCompiler' => __DIR__ . '/../CuyZ/Valinor/Definition/Repository/Cache/Compiler/TypeCompiler.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Cache\\Compiler\\FunctionDefinitionCompiler' => __DIR__ . '/../CuyZ/Valinor/Definition/Repository/Cache/Compiler/FunctionDefinitionCompiler.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Cache\\Compiler\\AttributesCompiler' => __DIR__ . '/../CuyZ/Valinor/Definition/Repository/Cache/Compiler/AttributesCompiler.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Cache\\Compiler\\ParameterDefinitionCompiler' => __DIR__ . '/../CuyZ/Valinor/Definition/Repository/Cache/Compiler/ParameterDefinitionCompiler.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Cache\\Compiler\\Exception\\TypeCannotBeCompiled' => __DIR__ . '/../CuyZ/Valinor/Definition/Repository/Cache/Compiler/Exception/TypeCannotBeCompiled.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Cache\\Compiler\\ClassDefinitionCompiler' => __DIR__ . '/../CuyZ/Valinor/Definition/Repository/Cache/Compiler/ClassDefinitionCompiler.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Cache\\Compiler\\MethodDefinitionCompiler' => __DIR__ . '/../CuyZ/Valinor/Definition/Repository/Cache/Compiler/MethodDefinitionCompiler.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Cache\\CompiledClassDefinitionRepository' => __DIR__ . '/../CuyZ/Valinor/Definition/Repository/Cache/CompiledClassDefinitionRepository.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Definition\\Repository\\Cache\\CompiledFunctionDefinitionRepository' => __DIR__ . '/../CuyZ/Valinor/Definition/Repository/Cache/CompiledFunctionDefinitionRepository.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Cache\\RuntimeCache' => __DIR__ . '/../CuyZ/Valinor/Cache/RuntimeCache.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Cache\\Warmup\\RecursiveCacheWarmupService' => __DIR__ . '/../CuyZ/Valinor/Cache/Warmup/RecursiveCacheWarmupService.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Cache\\TypeFilesWatcher' => __DIR__ . '/../CuyZ/Valinor/Cache/TypeFilesWatcher.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Cache\\FileWatchingCache' => __DIR__ . '/../CuyZ/Valinor/Cache/FileWatchingCache.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Cache\\FileSystemCache' => __DIR__ . '/../CuyZ/Valinor/Cache/FileSystemCache.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Cache\\Cache' => __DIR__ . '/../CuyZ/Valinor/Cache/Cache.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Cache\\CacheEntry' => __DIR__ . '/../CuyZ/Valinor/Cache/CacheEntry.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Cache\\KeySanitizerCache' => __DIR__ . '/../CuyZ/Valinor/Cache/KeySanitizerCache.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Cache\\Exception\\CompiledPhpCacheFileNotWritten' => __DIR__ . '/../CuyZ/Valinor/Cache/Exception/CompiledPhpCacheFileNotWritten.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Cache\\Exception\\CorruptedCompiledPhpCacheFile' => __DIR__ . '/../CuyZ/Valinor/Cache/Exception/CorruptedCompiledPhpCacheFile.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Cache\\Exception\\CacheDirectoryNotWritable' => __DIR__ . '/../CuyZ/Valinor/Cache/Exception/CacheDirectoryNotWritable.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Cache\\Exception\\InvalidSignatureToWarmup' => __DIR__ . '/../CuyZ/Valinor/Cache/Exception/InvalidSignatureToWarmup.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Node' => __DIR__ . '/../CuyZ/Valinor/Compiler/Node.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\ClassNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Native/ClassNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\ShortClosureNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Native/ShortClosureNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\FunctionCallNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Native/FunctionCallNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\DifferentNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Native/DifferentNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\ArrayNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Native/ArrayNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\PropertyNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Native/PropertyNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\AssignNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Native/AssignNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\ForEachNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Native/ForEachNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\CallNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Native/CallNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\ArrayKeyAccessNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Native/ArrayKeyAccessNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\LessThanNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Native/LessThanNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\GreaterThanNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Native/GreaterThanNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\CastNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Native/CastNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\StaticMethodCallNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Native/StaticMethodCallNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\PhpFileNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Native/PhpFileNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\LogicalOrNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Native/LogicalOrNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\VariableAccessNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Native/VariableAccessNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\ReturnNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Native/ReturnNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\GreaterOrEqualsToNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Native/GreaterOrEqualsToNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\AnonymousClassNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Native/AnonymousClassNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\MethodNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Native/MethodNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\ComplianceNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Native/ComplianceNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\EqualsNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Native/EqualsNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\TernaryNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Native/TernaryNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\LessOrEqualsToNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Native/LessOrEqualsToNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\MatchNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Native/MatchNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\StaticAccessNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Native/StaticAccessNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\IfNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Native/IfNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\YieldNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Native/YieldNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\WrapNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Native/WrapNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\LogicalAndNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Native/LogicalAndNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\FunctionNameNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Native/FunctionNameNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\NewClassNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Native/NewClassNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\PropertyDeclarationNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Native/PropertyDeclarationNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\ClosureNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Native/ClosureNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\ThrowNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Native/ThrowNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\MethodCallNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Native/MethodCallNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\ParameterDeclarationNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Native/ParameterDeclarationNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\CloneNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Native/CloneNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\InstanceOfNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Native/InstanceOfNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\ExpressionNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Native/ExpressionNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\VariableNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Native/VariableNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\NegateNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Native/NegateNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\ValueNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Native/ValueNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Native\\ClassNameNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Native/ClassNameNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Compiler' => __DIR__ . '/../CuyZ/Valinor/Compiler/Compiler.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Library\\NewAttributeNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Library/NewAttributeNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Compiler\\Library\\TypeAcceptNode' => __DIR__ . '/../CuyZ/Valinor/Compiler/Library/TypeAcceptNode.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Library\\Container' => __DIR__ . '/../CuyZ/Valinor/Library/Container.php',
        'OCA\\Talk\\Vendor\\CuyZ\\Valinor\\Library\\Settings' => __DIR__ . '/../CuyZ/Valinor/Library/Settings.php',
    );


    public static function getInitializer(ClassLoader $loader)
    {
        return \Closure::bind(function () use ($loader) {
            $loader->prefixLengthsPsr4 = MozartStaticInitab226525016ef02c3736dbc767509078::$prefixLengthsPsr4;
            $loader->prefixDirsPsr4 = MozartStaticInitab226525016ef02c3736dbc767509078::$prefixDirsPsr4;
            $loader->classMap = MozartStaticInitab226525016ef02c3736dbc767509078::$classMap;
        }, null, ClassLoader::class);
    }
}
