header.app-sidebar-header.hidden-by-call>div:not(.talk-sidebar-callview){display:none!important}#call-container[data-v-0ce438c2]{padding-bottom:var(--sidebar-container-height,56.25%);max-height:var(--sidebar-container-height,56.25%);position:relative;overflow:hidden}.call-loading[data-v-0ce438c2]{padding-bottom:var(--sidebar-container-height,56.25%);max-height:var(--sidebar-container-height,56.25%);background-color:#000000b3}.drafts[data-v-279f66a6] .dialog__content{min-height:200px}.drafts__wrapper[data-v-279f66a6]{gap:var(--default-grid-baseline);grid-template-columns:1fr 1fr;display:grid}.drafts__empty[data-v-279f66a6]{margin:0!important}.poll-editor__wrapper[data-v-48fe904c]{align-items:flex-end;gap:var(--default-grid-baseline);display:flex}.poll-editor__caption[data-v-48fe904c]{margin:calc(var(--default-grid-baseline)*2) 0 var(--default-grid-baseline);color:var(--color-primary-element);font-weight:700}.poll-editor__option[data-v-48fe904c]{align-items:flex-end;gap:var(--default-grid-baseline);width:100%;margin-bottom:calc(var(--default-grid-baseline)*2);display:flex}.poll-editor__settings[data-v-48fe904c]{flex-direction:column;gap:4px;margin-bottom:8px;display:flex}.poll-editor__back-button[data-v-48fe904c]{top:var(--default-grid-baseline);z-index:1;inset-inline-start:var(--default-grid-baseline);position:absolute!important}.internal-warning[data-v-680baaf2]{margin:var(--default-grid-baseline)!important}.talk-tab__wrapper[data-v-3e07a5ca]{height:100%;padding:var(--default-grid-baseline) 0;flex-direction:column;justify-content:flex-end;display:flex}.talk-tab__call-button[data-v-3e07a5ca]{margin:0 auto calc(var(--default-grid-baseline)*2)}.talk-tab__chat-view[data-v-3e07a5ca]{overflow:hidden}body .modal-wrapper h2.nc-dialog-alike-header{text-align:center;height:fit-content;min-height:var(--default-clickable-area);font-size:21px;line-height:var(--default-clickable-area);overflow-wrap:break-word;margin-block:0 12px}
/*# sourceMappingURL=src_components_PollViewer_PollDraftHandler_vue-src_components_PollViewer_PollEditor_vue-src_c-c57ac2.chunk.css.map*/