OC.L10N.register(
    "spreed",
    {
    "a conversation" : "o conversație",
    "(Duration %s)" : "(Durata %s)",
    "You attended a call with {user1}" : "Ați participat la un apel cu {user1}",
    "_%n guest_::_%n guests_" : ["%n oaspete","%n oaspeți","%n oaspeți"],
    "You attended a call with {user1} and {user2}" : "Ați participat la un apel cu {user1} și {user2}.",
    "You attended a call with {user1}, {user2} and {user3}" : "Ați participat la un apel cu {user1}, {user2} și {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Ați participat la un apel cu {user1}, {user2}, {user3} și {user4}.",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Ați participat la un apel cu {user1}, {user2}, {user3}, {user4} și {user5}",
    "_%n other_::_%n others_" : ["%n altul","& alții","& alții"],
    "{actor} invited you to {call}" : "{actor} te-a invitat la {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Ați fost invitat la o <strong>conversație</strong> sau ați primit un <strong>apel</strong>",
    "Other activities" : "Alte activități",
    "Talk" : "Discuție",
    "Guest" : "Invitat",
    "## Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "## Bine ați venit la Nextcloud Talk!\nÎn această conversație veți fi informat despre noile caracteristici disponibile în  Nextcloud Talk.",
    "## New in Talk %s" : "## Nou în Talk %s",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge și Safari pot fi folosite acum pentru a participa la apeluri audio și video",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- Conversațiile individuale sunt acum persistente și nu mai pot fi transformate din greșeală în conversații de grup. De asemenea, atunci când unul dintre participanți părăsește conversația, aceasta nu mai este ștearsă automat. Numai dacă ambii participanți pleacă, conversația este ștearsă de pe server",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Acum puteți notifica toți participanții prin postarea \"@all\" în chat.",
    "- With the \"arrow-up\" key you can repost your last message" : "- Cu ajutorul tastei \"săgeată în sus\" puteți reposta ultimul mesaj.",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Talk poate avea acum comenzi, trimiteți \"/help\" ca mesaj de chat pentru a vedea dacă administratorul dvs. a configurat câteva",
    "- With projects you can create quick links between conversations, files and other items" : "- Cu ajutorul proiectelor puteți crea legături rapide între conversații, fișiere și alte elemente.",
    "- You can now mention guests in the chat" : "- Acum puteți menționa oaspeții în chat",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Conversațiile pot avea acum un lobby. Acest lucru va permite moderatorilor să se alăture conversației și să sune deja pentru a pregăti întâlnirea, în timp ce utilizatorii și invitații trebuie să aștepte",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- Acum puteți răspunde direct la mesaje, oferindu-le celorlalți utilizatori mai mult context despre ce este vorba în mesajul dvs.",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- Căutarea conversațiilor și a participanților va filtra acum și conversațiile existente, facilitând astfel găsirea conversațiilor anterioare",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- Acum puteți adăuga grupuri de utilizatori personalizați la conversații atunci când este instalată aplicația cercuri",
    "- Check out the new grid and call view" : "- Consultați noua grilă și vizualizarea apelurilor",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- Acum puteți încărca și glisa fișiere direct de pe dispozitiv în chat.",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- Fişierele partajate se vor deschide direct in chat cu aplicaţia de vizualizare",
    "Reaction deleted by author" : "Reacție ștearsă de autor",
    "{actor} created the conversation" : "{actor} a creat conversația",
    "You created the conversation" : "Ați creat această conversație",
    "System created the conversation" : "Conversație creată de sistem",
    "An administrator created the conversation" : "Conversație creată de administrator",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} a redenumit conversația din \"%1$s\" în \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Ați redenumit conversația din \"%1$s\" în \"%2$s\"",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Un administrator a redenumit conversația din \"%1$s\" în \"%2$s\"",
    "{actor} set the description" : "{actor} a configurat descrierea",
    "You set the description" : "Ați configurat descrierea",
    "An administrator set the description" : "Un administrator a configurat descrierea",
    "{actor} removed the description" : "{actor} a șters descrierea",
    "You removed the description" : "Ați șters descrierea",
    "An administrator removed the description" : "Un administrator a șters descrierea",
    "You started a call" : "Ați inițiat o videoconferință",
    "{actor} started a call" : "{actor} a inițiat o videoconferință",
    "{actor} joined the call" : "{actor} s-a alăturat videoconferinței",
    "You joined the call" : "V-ați alăturat la videoconferință",
    "{actor} left the call" : "{actor} a părăsit videoconferința",
    "You left the call" : "Ați părăsit videoconferința",
    "{actor} unlocked the conversation" : "{actor} a deblocat conversația",
    "You unlocked the conversation" : "Ați deblocat conversația",
    "An administrator unlocked the conversation" : "Un administrator a deblocat conversația",
    "{actor} locked the conversation" : "{actor} a blocat conversația",
    "You locked the conversation" : "Ați blocat conversația",
    "An administrator locked the conversation" : "Un administrator a blocat conversația",
    "{actor} limited the conversation to the current participants" : "{actor} a limitat conversația la participanții actuali",
    "You limited the conversation to the current participants" : "Ați limitat conversația la participanții actuali",
    "An administrator limited the conversation to the current participants" : "Un administrator a limitat conversația la participanții actuali",
    "The conversation is now open to everyone" : "Conversația este deschisă acum oricui",
    "{actor} set a password" : "{actor} a configurat o parolă",
    "You set a password" : "Ați pus o parolă",
    "An administrator set a password" : "Un administrator a pus o parolă",
    "{actor} added {user}" : "{actor} a adăugat pe {user}",
    "You joined the conversation" : "V-ați alăturat conversației",
    "{actor} joined the conversation" : "{actor} s-a alăturat conversației",
    "You added {user}" : "Ați adăugat pe {user}",
    "{actor} added you" : "{actor} v-a adăugat",
    "An administrator added you" : "V-a adăugat un administrator",
    "An administrator added {user}" : "Un administrator a adăugat pe {user}",
    "You left the conversation" : "Ați părăsit conversația",
    "{actor} left the conversation" : "{actor} a părăsit conversația",
    "{actor} removed {user}" : "{actor} a eliminat pe {user}",
    "You removed {user}" : "Ați eliminat pe {user}",
    "{actor} removed you" : "{actor} v-a eliminat",
    "An administrator removed you" : "V-a eliminat un administrator",
    "An administrator removed {user}" : "Un administrator a eliminat pe {user}",
    "{actor} added group {group}" : "{actor} a adăugat grupul {group}",
    "You added group {group}" : "Ați adăugat grupul {group}",
    "An administrator added group {group}" : "Un administrator a adăugat grupul {group}",
    "{actor} removed group {group}" : "{actor} a eliminat grupul {group}",
    "You removed group {group}" : "Ați eliminat grupul {group}",
    "An administrator removed group {group}" : "Un administrator a eliminat grupul {group}",
    "{actor} deleted a message" : "{actor} a șters un mesaj",
    "You deleted a message" : "Ați șters un mesaj",
    "{actor} deleted a reaction" : "{actor} a șters o reacție",
    "You deleted a reaction" : "Ați șters o reacție",
    "{actor} disabled message expiration" : "{actor} a eliminat timpul de expirare a mesajului",
    "You disabled message expiration" : "Ați eliminat timpul de expirare al mesajului",
    "{actor} cleared the history of the conversation" : "{actor} a șters istoricul conversației",
    "You cleared the history of the conversation" : "Ați șters istoricul conversației",
    "{actor} set the conversation picture" : "{actor} a setat imaginea conversației",
    "You set the conversation picture" : "Ați setat imaginea conversației",
    "{actor} ended the poll {poll}" : "{actor} a încheiat votul {poll}",
    "You ended the poll {poll}" : "Ați încheiat votul {poll}",
    "{actor} started the video recording" : "{actor} a pornit înregistrarea video",
    "You started the video recording" : "Ați pornit înregistrarea video",
    "{actor} stopped the video recording" : "{actor} a oprit înregistrarea video",
    "You stopped the video recording" : "Ați oprit înregistrarea video",
    "{actor} started the audio recording" : "{actor} a pornit înregistrarea audio",
    "You started the audio recording" : "Ați pornit înregistrarea audio",
    "{actor} stopped the audio recording" : "{actor} a oprit înregistrarea audio",
    "You stopped the audio recording" : "Ați oprit înregistrarea audio",
    "The recording failed" : "Înregistrarea a eșuat",
    "Someone voted on the poll {poll}" : "A votat cineva în {poll}",
    "Message deleted by author" : "Mesaj șters de autor",
    "Message deleted by {actor}" : "Mesaj șters de {actor}",
    "Message deleted by you" : "Ați șters mesajul",
    "Deleted user" : "Utilizator șters",
    "Unknown number" : "Număr necunoscut",
    "Administration" : "Administrare",
    "System" : "Sistem",
    "{actor} ended the call with {user1} (Duration {duration})" : "{actor} a închis apelul cu {user1} (Durată {duration})",
    "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor} a închis apelul cu {user1} și {user2} (Durată {duration})",
    "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor} a încheiat apelul cu {user1}, {user2} și {user3} (Durată {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{actor} a încheiat apelul cu {user1}, {user2}, {user3} și {user4} (Durată {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{actor} a încheiat apelul cu {user1}, {user2}, {user3}, {user4} și {user5} (Durată {duration})",
    "Message of {user} in {conversation}" : "Mesaj al {user} în {conversation}",
    "Message of {user}" : "Mesaj al {user}",
    "Message of a deleted user in {conversation}" : "Mesaj al unui utilizator șters în {conversation}",
    "Talk conversations" : "Conversații",
    "Call %s" : "Apel %s",
    "An error occurred. Please contact your administrator." : "A apărut o eroare. Contactați administratorul.",
    "File not found" : "Fișierul nu a fost găsit",
    "File is not shared, or shared but not with the user" : "Fișierul nu este partajat sau nu este partajat cu utilizatorul",
    "No image file provided" : "Nu s-a furnizat un fișier de imagine",
    "File is too big" : "Fișierul este prea mare",
    "Invalid file provided" : "Numele fișierului pe care l-ai oferit este invalid",
    "Invalid image" : "Imagine invalidă",
    "Unknown filetype" : "Tip fișier necunoscut",
    "Talk mentions" : "Menționări",
    "Say hi to your friends and colleagues!" : "Spuneți bună prietenilor și colegilor!",
    "No unread mentions" : "Nicio menționare necitită",
    "Call in progress" : "Videoconferință în curs",
    "You were mentioned" : "Ați fost menționat",
    "Write to conversation" : "Postați în conversație",
    "Conversation invitation" : "Invitație în conversație",
    "Description" : "Descriere",
    "Meeting ID" : "ID întâlnire",
    "Meeting" : "Videoconferință",
    "Password request: %s" : "Solicitare parolă: %s",
    "Private conversation" : "Conversație privată",
    "Deleted user (%s)" : "Utilizator (%s) șters",
    "Share to chat" : "Partajați în chat",
    "Dismiss notification" : "Elimină notificarea",
    "Call recording now available" : "Înregistrarea este acum disponibilă",
    "Transcript now available" : "Transcrierea este acum disponibilă",
    "Accept" : "Accept",
    "Decline" : "Refuză",
    "New message" : "Mesaj nou",
    "Reminder" : "Memento",
    "Notification" : "Notificări",
    "{user} reacted with {reaction}" : "{user} a reacționat cu {reaction}",
    "{user} reacted with {reaction} in {call}" : "{user} a reacționat cu {reaction} în {call}",
    "{user} in {call}" : "{user} în {call}",
    "{user} sent you a private message" : "{user} v-a trimis un mesaj privat",
    "{user} sent a message in conversation {call}" : "{user} a trimis un mesaj în conversația {call}",
    "{user} replied to your private message" : "{user} v-a răspuns la mesajul privat",
    "{user} replied to your message in conversation {call}" : "{user} v-a răspuns la mesajul din conversația {call}",
    "Reminder: You in private conversation {call}" : "Memento: Sunteți în conversația privată {call}",
    "Reminder: {user} in private conversation" : "Memento: {user} în conversație privată",
    "Reminder: You in conversation {call}" : "Memento: Sunteți în conversația privată {call}",
    "Reminder: {user} in conversation {call}" : "Memento: {user} în conversația privată {call}",
    "{user} reacted with {reaction} to your private message" : "{user} a reacționat cu {reaction} la mesajul privat",
    "{user} reacted with {reaction} to your message in conversation {call}" : "{user} a reacționat cu {reaction} la mesajul din conversația {call}",
    "{user} mentioned you in a private conversation" : "{user} v-a menționat într-o conversație privată",
    "{user} mentioned group {group} in conversation {call}" : "{user} a menționat grupul {group} în conversația {call}",
    "{user} mentioned everyone in conversation {call}" : "{user} i-a menționat pe toți în conversația {call}",
    "{user} mentioned you in conversation {call}" : "{user} v-a menționat în conversația {call}",
    "View message" : "Vedeți mesajul",
    "View chat" : "Vedeți chat",
    "{user} invited you to a group conversation: {call}" : "{user} v-a invitat la o conversație de grup: {call}",
    "Join call" : "Participați la videoconferință",
    "Answer call" : "Răspundeți apelului",
    "{user} would like to talk with you" : "{user} ar dori să vorbiți",
    "Call back" : "Apelează înapoi",
    "You missed a call from {user}" : "Ați pierdut un apel de la {user}",
    "A group call has started in {call}" : "A început un apel de grup în {call}",
    "You missed a group call in {call}" : "Ați pierdut un apel de grup în {call}",
    "{email} is requesting the password to access {file}" : "{email} solicită parola pentru a accesa {file}",
    "{email} tried to request the password to access {file}" : "{email} a încercat să solicite parola pentru a accesa {file}",
    "Someone is requesting the password to access {file}" : "Cineva solicită parola pentru a accesa {file}",
    "Someone tried to request the password to access {file}" : "Cineva a încercat să solicite parola pentru a accesa {file}",
    "Open settings" : "Deschide setările",
    "error" : "eroare",
    "Contact via Talk" : "Contactați via Talk",
    "Open Talk" : "Deschideți Talk",
    "Default" : "Implicit",
    "Presentation" : "Prezentare",
    "Conversations" : "Conversații",
    "Messages in current conversation" : "Mesajele din conversația curentă",
    "Messages" : "Mesaje",
    "Messages in other conversations" : "Mesaje din alte conversații",
    "Avatar image is not square" : "Imaginea de avatar nu este pătrată",
    "Favorites" : "Favorite",
    "Other" : "Altele",
    "Something unexpected happened." : "S-a întâmplat ceva neașteptat",
    "The URL is invalid." : "URL-ul este greșit",
    "The email address is invalid." : "Emailul este invalid",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "United Arab Emirates",
    "Afghanistan" : "Afghanistan",
    "Antigua and Barbuda" : "Antigua and Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Antarctica" : "Antarctica",
    "Argentina" : "Argentina",
    "American Samoa" : "American Samoa",
    "Austria" : "Austria",
    "Australia" : "Australia",
    "Aruba" : "Aruba",
    "Åland Islands" : "Åland Islands",
    "Azerbaijan" : "Azerbaijan",
    "Bosnia and Herzegovina" : "Bosnia and Herzegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Belgium",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaria",
    "Bahrain" : "Bahrain",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Saint Barthélemy",
    "Bermuda" : "Bermuda",
    "Brunei Darussalam" : "Brunei Darussalam",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius and Saba",
    "Brazil" : "Brazil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bhutan",
    "Bouvet Island" : "Bouvet Island",
    "Botswana" : "Botswana",
    "Belarus" : "Belarus",
    "Belize" : "Belize",
    "Canada" : "Canada",
    "Cocos (Keeling) Islands" : "Cocos (Keeling) Islands",
    "Central African Republic" : "Central African Republic",
    "Congo" : "Congo",
    "Switzerland" : "Switzerland",
    "Côte d'Ivoire" : "Côte d'Ivoire",
    "Cook Islands" : "Cook Islands",
    "Chile" : "Chile",
    "Cameroon" : "Cameroon",
    "China" : "China",
    "Colombia" : "Colombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cabo Verde" : "Cabo Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Christmas Island",
    "Cyprus" : "Cyprus",
    "Czechia" : "Czechia",
    "Germany" : "Germany",
    "Djibouti" : "Djibouti",
    "Denmark" : "Denmark",
    "Dominica" : "Dominica",
    "Dominican Republic" : "Dominican Republic",
    "Algeria" : "Algeria",
    "Ecuador" : "Ecuador",
    "Estonia" : "Estonia",
    "Egypt" : "Egypt",
    "Western Sahara" : "Western Sahara",
    "Eritrea" : "Eritrea",
    "Spain" : "Spain",
    "Ethiopia" : "Ethiopia",
    "Finland" : "Finland",
    "Fiji" : "Fiji",
    "Falkland Islands (Malvinas)" : "Falkland Islands (Malvinas)",
    "Faroe Islands" : "Faroe Islands",
    "France" : "France",
    "Gabon" : "Gabon",
    "United Kingdom of Great Britain and Northern Ireland" : "United Kingdom of Great Britain and Northern Ireland",
    "Grenada" : "Grenada",
    "Georgia" : "Georgia",
    "French Guiana" : "French Guiana",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Greenland",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Equatorial Guinea",
    "Greece" : "Greece",
    "South Georgia and the South Sandwich Islands" : "South Georgia and the South Sandwich Islands",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Heard Island and McDonald Islands",
    "Honduras" : "Honduras",
    "Croatia" : "Croatia",
    "Haiti" : "Haiti",
    "Hungary" : "Hungary",
    "Indonesia" : "Indonesia",
    "Ireland" : "Ireland",
    "Israel" : "Israel",
    "Isle of Man" : "Isle of Man",
    "India" : "India",
    "British Indian Ocean Territory" : "British Indian Ocean Territory",
    "Iraq" : "Iraq",
    "Iceland" : "Iceland",
    "Italy" : "Italy",
    "Jersey" : "Jersey",
    "Jamaica" : "Jamaica",
    "Jordan" : "Jordan",
    "Japan" : "Japan",
    "Kenya" : "Kenya",
    "Kyrgyzstan" : "Kyrgyzstan",
    "Cambodia" : "Cambodia",
    "Kiribati" : "Kiribati",
    "Comoros" : "Comoros",
    "Saint Kitts and Nevis" : "Saint Kitts and Nevis",
    "Kuwait" : "Kuwait",
    "Cayman Islands" : "Cayman Islands",
    "Kazakhstan" : "Kazakhstan",
    "Lao People's Democratic Republic" : "Lao People's Democratic Republic",
    "Lebanon" : "Lebanon",
    "Saint Lucia" : "Saint Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Lithuania",
    "Luxembourg" : "Luxembourg",
    "Latvia" : "Latvia",
    "Libya" : "Libya",
    "Morocco" : "Morocco",
    "Monaco" : "Monaco",
    "Montenegro" : "Montenegro",
    "Saint Martin (French part)" : "Saint Martin (French part)",
    "Madagascar" : "Madagascar",
    "Marshall Islands" : "Marshall Islands",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongolia",
    "Macao" : "Macao",
    "Northern Mariana Islands" : "Northern Mariana Islands",
    "Martinique" : "Martinique",
    "Mauritania" : "Mauritania",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauritius",
    "Maldives" : "Maldives",
    "Malawi" : "Malawi",
    "Mexico" : "Mexico",
    "Malaysia" : "Malaysia",
    "Mozambique" : "Mozambique",
    "Namibia" : "Namibia",
    "New Caledonia" : "New Caledonia",
    "Niger" : "Niger",
    "Norfolk Island" : "Norfolk Island",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Netherlands",
    "Norway" : "Norway",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "New Zealand",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "French Polynesia",
    "Papua New Guinea" : "Papua New Guinea",
    "Philippines" : "Philippines",
    "Pakistan" : "Pakistan",
    "Poland" : "Poland",
    "Saint Pierre and Miquelon" : "Saint Pierre and Miquelon",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Puerto Rico",
    "Palestine, State of" : "Palestine, State of",
    "Portugal" : "Portugal",
    "Palau" : "Palau",
    "Paraguay" : "Paraguay",
    "Qatar" : "Qatar",
    "Réunion" : "Réunion",
    "Romania" : "Romania",
    "Serbia" : "Serbia",
    "Russian Federation" : "Russian Federation",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Saudi Arabia",
    "Solomon Islands" : "Solomon Islands",
    "Seychelles" : "Seychelles",
    "Sudan" : "Sudan",
    "Sweden" : "Sweden",
    "Singapore" : "Singapore",
    "Saint Helena, Ascension and Tristan da Cunha" : "Saint Helena, Ascension and Tristan da Cunha",
    "Slovenia" : "Slovenia",
    "Svalbard and Jan Mayen" : "Svalbard and Jan Mayen",
    "Slovakia" : "Slovakia",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Suriname",
    "South Sudan" : "South Sudan",
    "Sao Tome and Principe" : "Sao Tome and Principe",
    "El Salvador" : "El Salvador",
    "Sint Maarten (Dutch part)" : "Sint Maarten (Dutch part)",
    "Syrian Arab Republic" : "Syrian Arab Republic",
    "Turks and Caicos Islands" : "Turks and Caicos Islands",
    "Chad" : "Chad",
    "French Southern Territories" : "French Southern Territories",
    "Togo" : "Togo",
    "Thailand" : "Thailand",
    "Tajikistan" : "Tajikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor-Leste",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunisia",
    "Tonga" : "Tonga",
    "Turkey" : "Turkey",
    "Trinidad and Tobago" : "Trinidad and Tobago",
    "Tuvalu" : "Tuvalu",
    "Tanzania, United Republic of" : "Tanzania, United Republic of",
    "Ukraine" : "Ukraine",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "United States Minor Outlying Islands",
    "United States of America" : "United States of America",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Uzbekistan",
    "Holy See" : "Holy See",
    "Saint Vincent and the Grenadines" : "Saint Vincent and the Grenadines",
    "Viet Nam" : "Viet Nam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis and Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Yemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "South Africa",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Federation" : "Federare",
    "Invalid date, date format must be YYYY-MM-DD" : "Dată invalidă, formatul trebuie să fie AAAA-LL-ZZ",
    "Conversation not found" : "Conversație negăsită",
    "Leave call" : "Părăsește videoconferința",
    "Navigating away from the page will leave the call in {conversation}" : "Părăsind pagina se va părăsi conversația {conversation}",
    "Stay in call" : "Rămâneți în videoconferință",
    "Duplicate session" : "Sesiune duplicat",
    "Discuss this file" : "Discutați acest fișier",
    "Share this file with others to discuss it" : "Partajați acest fișier cu ceilalți pentru a-l discuta",
    "Join conversation" : "Alăturați-vă conversației",
    "Share this file" : "Partajați acest fișier",
    "Error occurred when joining the conversation" : "Eroare la încercarea de participare la conversație",
    "The password is wrong. Try again." : "Parola este incorectă. Încercaţi din nou.",
    "Password" : "Parolă",
    "Submit" : "Trimite",
    "Error requesting the password." : "Eroare la solicitarea parolei",
    "Request password" : "Solicitați o parolă",
    "This conversation has ended" : "Această conversație s-a încheiat",
    "Close Talk sidebar" : "Închide bara laterală Talk",
    "Open Talk sidebar" : "Deschide bara laterală Talk",
    "Everyone" : "Toți",
    "Users and moderators" : "Utilizatori și moderatori",
    "Moderators only" : "Doar moderatori",
    "Disable calls" : "Dezactivează apelurile",
    "Save changes" : "Salvează modificările",
    "Saving …" : "Se salvează",
    "Saved!" : "Salvat!",
    "Limit to groups" : "Limitează pentru grupuri",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "Când este selectat cel puțin un grup, doar persoanele din grupurile listate pot lua parte la conversație.",
    "Description is not provided" : "Nu este furnizată o descriere",
    "Locked for moderators" : "Blocat pentru moderatori",
    "Enabled" : "Activat",
    "Disabled" : "Dezactivați",
    "State" : "Stadiu",
    "Name" : "Nume",
    "Last error" : "Ultima eroare",
    "Total errors count" : "Total erori",
    "Beta" : "Beta",
    "Permissions" : "Permisiuni",
    "All messages" : "Toate mesajele",
    "Off" : "Oprit",
    "Enable encryption" : "Activează criptarea",
    "Pending" : "În așteptare",
    "Error" : "Eroare",
    "Blocked" : "Blocat",
    "Active" : "Activ",
    "Never" : "Niciodată",
    "Language" : "Limba",
    "Country" : "Țară",
    "Status" : "Stare",
    "Created at" : "Creat la",
    "Yes" : "Da",
    "No" : "Nu",
    "Downloading …" : "Se descarcă ...",
    "Failed" : "Eșuat",
    "OK" : "OK",
    "Assignment method" : "Metoda de atribuire",
    "Automatically assign participants" : "Atribuie automat participanții",
    "Manually assign participants" : "Atribuie participanții manual",
    "Allow participants to choose" : "Permite participanților să aleagă",
    "Confirm" : "Confirmă",
    "Reset" : "Resetare",
    "Cancel" : "Anulare",
    "Unassigned participants" : "Participanți neasociați",
    "Back" : "Înapoi",
    "Assign" : "Atribuie",
    "Add participant \"{user}\"" : "Adaugă participant \"{user}\"",
    "Now" : "Acum",
    "From" : "De la",
    "To" : "Către",
    "Calendar" : "Calendar",
    "Attendees" : "Participanți",
    "Save" : "Salvează",
    "Search participants" : "Caută participanți",
    "No results" : "Niciun rezultat",
    "Done" : "Realizat",
    "Exit full screen (F)" : "Ieșire din ecran complet (F)",
    "Full screen (F)" : "Ecran complet (F)",
    "Speaker view" : "Vizualizare vorbitor",
    "Grid view" : "Afișare în grilă",
    "This conversation is read-only" : "Această conversație este read-only",
    "Reload" : "Reîncarcă",
    "{nickName} raised their hand." : "{nickName} a ridicat mâna.",
    "A participant raised their hand." : "Un participant a ridicat mâna.",
    "Connecting …" : "Se conectează ...",
    "Calling …" : "Se apelează ...",
    "Waiting for {user} to join the call" : "Se așteaptă ca {user} să intre în videoconferință",
    "Waiting for others to join the call …" : "Se așteaptă ca alții să intre în videoconferință ...",
    "You can invite others in the participant tab of the sidebar" : "Puteți invita pe alții din tabul Participanți, în bara laterală",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Puteți invita pe alții din tabul Participanți din bara laterală sau să partajați acest link pentru a invita pe altcineva!",
    "Share this link to invite others!" : "Partajați acest link pentru a invita pe altcineva!",
    "Copy link" : "Copiză link",
    "You are not allowed to enable audio" : "Nu aveți permisiunea de a activa sunetul",
    "No audio. Click to select device" : "Lipsă sunet. Click pentru selectare dispozitiv",
    "Mute audio" : "Oprire sunet",
    "Mute audio (M)" : "Oprire sunet (M)",
    "Unmute audio" : "Reactivare sunet",
    "Unmute audio (M)" : "Reactivare sunet (M)",
    "None" : "Niciuna",
    "Access to camera was denied" : "Accesul la cameră a fost respins",
    "Error while accessing camera: It is likely in use by another program" : "Eroare la accesul la cameră: Poate este folosită de alt program",
    "Error while accessing camera" : "Eroare la accesarea camerei",
    "You have been muted by a moderator" : "Vi s-a tăiat sonorul de către un moderator",
    "You are not allowed to enable video" : "Nu aveți permisiunea să activați video",
    "No video. Click to select device" : "Lipsă video. Click pentru selectare dispozitiv",
    "Disable video" : "Dezactivează video",
    "Disable video (V)" : "Dezactivează video (V)",
    "Enable video" : "Activează video",
    "Enable video (V)" : "Activează video (V) ",
    "Show presenter" : "Arată prezentatorul",
    "You" : "Tu",
    "Mute" : "Oprește sunetul",
    "Muted" : "Sunet oprit",
    "Show screen" : "Prezintă ecranul",
    "Stop following" : "Oprire urmărire",
    "Collapse" : "Restrânge",
    "Expand" : "Extinde",
    "You need to be logged in to upload files" : "Trebuie să fiți autentificat pentru a încărca fișiere",
    "Drop your files to upload" : "Trageți fișierele pentru încărcare",
    "Conversation messages" : "Mesajele conversației",
    "Scroll to bottom" : "Derulează la sfârșit",
    "Favorite" : "Favorite",
    "Date:" : "Data:",
    "Hide details" : "Ascunde detaliile",
    "Show details" : "Arată detaliile",
    "Enter a name for this conversation" : "Introduceți un nume pentru conversație",
    "Edit conversation name" : "Editează numele conversației",
    "Edit conversation description" : "Editează descrierea conversației",
    "Enter a description for this conversation" : "Introduceți o descriere pentru conversație",
    "Picture" : "Imagine",
    "Disable" : "Dezactivează",
    "Enable" : "Activare",
    "Choose your conversation picture" : "Alegeți imaginea conversației",
    "Choose" : "Alege",
    "Upload conversation picture" : "Încarcă imaginea pentru conversație",
    "Choose conversation picture from files" : "Selectează imaginea conversației din Fișiere",
    "Remove conversation picture" : "Înlătură imaginea conversației",
    "Set picture" : "Setează imaginea",
    "Default permissions modified for {conversationName}" : "Permisiunile implicite modificate pentru  {conversationName}",
    "Could not modify default permissions for {conversationName}" : "Nu au fost modificate permisiunile implicite pentru {conversationName}",
    "All permissions" : "Toate permisiunile",
    "Restricted" : "Restricționat",
    "Advanced permissions" : "Permisiuni avansate",
    "Edit permissions" : "Editare permisiuni",
    "Conversation settings" : "Configurația conversației",
    "Basic Info" : "Informații de bază",
    "Personal" : "Personal",
    "Moderation" : "Moderare",
    "Leave conversation" : "Părăsiți conversația",
    "Delete conversation" : "Șterge conversația",
    "Do you really want to delete \"{displayName}\"?" : "Sigur ștergeți \"{displayName}\"?",
    "Error while deleting conversation" : "Eroare la ștergerea conversației",
    "Delete all chat messages" : "Șterge toate mesajele de chat",
    "Do you really want to delete all messages in \"{displayName}\"?" : "Sigur ștergeți toate mesajele din \"{displayName}\"?",
    "Error while clearing chat history" : "Eroare la ștergerea istoricului de chat",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Odată ce ați părăsit o conversație, pentru a vă realătura aveți nevoie de o invitație. Conversațiile deschise pot fi accesate oricând.",
    "Permanently delete this conversation." : "Șterge permanent conversația",
    "Delete chat messages" : "Șterge mesajele de chat",
    "Permanently delete all the messages in this conversation." : "Șterge permanent toate mesajele din conversație",
    "Message expiration disabled" : "Expirarea mesajului dezactivată",
    "Message expiration set: {duration}" : "Expirarea mesajului la: {duration}",
    "Message expiration" : "Expirare mesaj",
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "Mesajele de chat pot fi configurate să expire după un timp. Notă: Fișierele partajate în chat nu vor fi șterse pentru posesor, dar nu vor mai fi partajate în conversație.",
    "Set message expiration" : "Setează expirarea mesajului",
    "Current message expiration" : "Data expirării mesajului",
    "Password protection" : "Password protection",
    "Enter new password" : "Introduceți o nouă parolă",
    "Save password" : "Salvează parola",
    "Resend invitations" : "Trimite din nou invitațiile",
    "Error occurred when opening or limiting the conversation" : "Eroare la deschiderea sau la limitarea conversației ",
    "Open conversation" : "Deschide conversația",
    "Start time has been updated" : "Ora de început a fost actualizată",
    "Meeting start time" : "Ora de început a videoconferinței",
    "Start time (optional)" : "Ora de început (opțional)",
    "Lock conversation" : "Blochează conversația",
    "This will also terminate the ongoing call." : "Aceasta va termina, de asemenea, videoconferința în curs.",
    "Lock the conversation to prevent anyone to post messages or start calls" : "Blocați conversația pentru a împiedica postarea mesajelor sau apelurile",
    "Edit" : "Editează",
    "More information" : "Mai multe informații",
    "Delete" : "Șterge",
    "Notifications" : "Notificări",
    "Create a new conversation" : "Creează o nouă conversație",
    "Unread mentions" : "Menționări necitite",
    "Create conversation" : "Creați o conversație",
    "Enter your name" : "Introduceți numele",
    "Submit name and join" : "Transmite numele și participați",
    "Log in" : "Autentificare",
    "Search participants or phone numbers" : "Căutare participanți sau numere de telefon",
    "Creating the conversation …" : "Se creează conversația ...",
    "Mark as read" : "Marchează ca citit",
    "Mark as unread" : "Marchează ca necitit",
    "Remove from favorites" : "Șterge din favorite",
    "Add to favorites" : "Adăugați la favorite",
    "Conversation actions" : "Acțiuni conversație",
    "Tags" : "Etichete",
    "Delete tag" : "Șterge eticheta",
    "Move up" : "Mută înainte",
    "Move down" : "Mută în jos",
    "Unread" : "Necitit",
    "Alphabetically" : "Alfabetic",
    "No matches found" : "Nicio potrivire",
    "No conversations found" : "Nu sunt conversații",
    "You have no unread mentions." : "Nu aveți menționări necitite.",
    "You have no unread messages." : "Nu aveți mesaje necitite.",
    "Conversation list" : "Lista de conversații",
    "Clear filters" : "Șterge filtrele",
    "New personal note" : "Notă personală nouă",
    "Clear filter" : "Șterge filtrul",
    "Users" : "Utilizatori",
    "Groups" : "Grupuri",
    "Other sources" : "Alte surse",
    "Open conversations" : "Conversații deschise",
    "No search results" : "Căutarea nu are rezultate",
    "Users and groups" : "Utilizatori și grupuri",
    "The meeting will start soon" : "Întâlnirea va începe în curând",
    "Advanced" : "Avansat",
    "Devices" : "Dispozitive",
    "Calls are not supported in your browser" : "Apelurile video nu sunt suportate de browser",
    "Access to microphone was denied" : "Accesul la microfon a fost respins",
    "Error while accessing microphone" : "Eroare la accesarea microfonului",
    "Invalid path selected" : "Calea selectată este invalidă",
    "Blur" : "Blurează",
    "Upload" : "Încărcare",
    "Files" : "Fișiere",
    "24 hours" : "24 de ore",
    "Clear reminder – {timeLocale}" : "Șterge memento – {timeLocale}",
    "Reply" : "Răspunde",
    "More actions" : "Mai multe acțiuni",
    "Set reminder" : "Setează memo",
    "Edit message" : "Editare mesaj",
    "Translate" : "Tradu",
    "Set custom reminder" : "Setează memento particular",
    "Dismiss" : "Elimină",
    "Send now" : "Trimite acum",
    "Message sent" : "Mesajul a fost transmis",
    "Contact" : "Contact",
    "{stack} in {board}" : "{stack} în {board}",
    "No messages" : "Niciun mesaj",
    "Cancel search" : "Renunță la căutare",
    "All set, the conversation \"{conversationName}\" was created." : "Totul a fost configurat, conversația \"{conversationName}\" a fost creată.",
    "Create a new group conversation" : "Creați o nouă conversație de grup",
    "Add participants" : "Adăugați participanți",
    "Conversation visibility" : "Vizibilitatea conversației",
    "Enter password" : "Introduceți parola",
    "Joining conversation …" : "Alăturare la conversație ...",
    "File to share" : "Fișier de partajat",
    "Send later" : "Trimite mai târziu",
    "Cancel editing" : "Anulează editarea",
    "Share from Files" : "Partajează din Fișiere",
    "Upload from device" : "Încarcă din dispozitiv",
    "New file" : "Fișier nou",
    "Blank" : "Gol",
    "Send" : "Trimite",
    "Question" : "Întrebare",
    "Settings" : "Setări",
    "Results" : "Rezultate",
    "Settings for participant \"{user}\"" : "Setări pentru  participant \"{user}\"",
    "guest" : "invitat",
    "Ringing …" : "Apel …",
    "Raised their hand" : "Au ridicat mâna",
    "The text must be less than or equal to {maxLength} characters long. Your current text is {charactersCount} characters long." : "Textul trebuie să fie mai scurt sau egal cu {maxLength} caractere. Textul curent are {charactersCount} caractere.",
    "Remove group and members" : "Elimină grup și membri",
    "Remove participant" : "Elimină participant",
    "Notification was sent to {displayName}" : "Notificarea a fost trimisă către {displayName}",
    "Could not send notification to {displayName}" : "Nu a fost trimisă notificarea către {displayName}",
    "Permissions granted to {displayName}" : "Permisiunile au fost acordate {displayName}",
    "Could not modify permissions for {displayName}" : "Nu au fost modificate permisiunile pentrur {displayName}",
    "Permissions removed for {displayName}" : "Au fost eliminate permisiunile pentru {displayName}",
    "Permissions set to default for {displayName}" : "Au fost aplicate permisiunile implicite pentru {displayName}",
    "Demote from moderator" : "Depromovează de la moderator",
    "Promote to moderator" : "Promovează la moderator",
    "Resend invitation" : "Retransmite invitația",
    "Send call notification" : "Trimite notificare de apel",
    "Grant all permissions" : "Acordă toate permisiunile",
    "Remove all permissions" : "Elimină toate permisiunile",
    "Remove" : "Elimină",
    "Permissions modified for {displayName}" : "Au fost modificate permisiunile pentru {displayName}",
    "Add users or groups" : "Add users or groups",
    "Add users" : "Adaugă utilizatori",
    "Add groups" : "Adaugă grupuri",
    "Add other sources" : "Adaugă alte surse",
    "Add emails" : "Adaugă emailuri",
    "Integrations" : "Integrări",
    "Searching …" : "Căutare ...",
    "Search for more users" : "Căutare mai mulți utilizatori",
    "Search or add participants" : "Căutare sau adăugare participanți",
    "Invitation was sent to {actorId}" : "Invitația a fost trimisă către {actorId}",
    "An error occurred while adding the participants" : "Eroare la adăugarea participanților",
    "Participants" : "Participanți",
    "Participants ({count})" : "Participanți ({count})",
    "Open chat" : "Dechide chat",
    "You have new unread messages in the chat." : "Aveți mesaje necitite în chat",
    "You have been mentioned in the chat." : "Ați fost menționat în chat",
    "Details" : "Detalii",
    "Shared items" : "Elemente partajate",
    "No results found" : "Nu s-a găsit nimic",
    "Load more results" : "Încarcă mai multe rezultate",
    "Projects" : "Proiecte",
    "No shared items" : "Nicio partajare",
    "Link to a conversation" : "Link la conversație",
    "No open conversations found" : "Nu au fost găsite conversații deschise",
    "Either there are no open conversations or you joined all of them." : "Nu sunt conversații deschise sau participați la toate",
    "Check spelling or use complete words." : "Verificați ortografia sau folosiți cuvinte întregi",
    "Search conversations or users" : "Căutare conversații sau utilizatori",
    "Select conversation" : "Selectare conversație",
    "Number length is not valid" : "Lungime număr incorectă",
    "Phone numbers" : "Numere de telefon",
    "Display name: {name}" : "Numele afișat: {name}",
    "Save name" : "Salvează numele",
    "Error while saving sounds setting" : "Eroare la salvarea setărilor de sunet",
    "Play sounds when participants join or leave a call" : "Avertizează sonor când cineva se alătură sau părăsește o videoconferință",
    "Notification settings" : "Setări notificări",
    "Default language" : "Limba implicită",
    "Select location for attachments" : "Selectați locația atașamentelor",
    "Error while setting attachment folder" : "Eroare la setarea dosarului pentru atașamente",
    "Error while setting read status privacy" : "Eroare la setarea confidențialității statusului de citire",
    "Error while setting typing status privacy" : "Eroare la setarea confidențialității tastării",
    "Privacy" : "Confidențialitate",
    "Attachments folder" : "Dosarul pentru atașamente",
    "Toggle full screen" : "Comută în ecran complet",
    "Search" : "Caută",
    "Focus the chat input" : "Focalizează inputul în chat",
    "Unfocus the chat input to use shortcuts" : "Defocalizează inputul în chat pentru folosirea scurtăturilor",
    "Shortcuts while in a call" : "Scurtături pentru videoconferință",
    "Camera on and off" : "Activează și dezactivează camera",
    "Microphone on and off" : "Activează și dezactivează microfonul",
    "Raise or lower hand" : "Ridicare sau coborâre mână",
    "Push to talk or push to mute" : "Apăsați pentru a vorbi sau pentru a suprima microfonul",
    "Start call silently" : "Pornește videoconferința fără sunet",
    "Start call" : "Pornește videoconferința",
    "End call" : "Închidere videoconferință",
    "You will be able to join the call only after a moderator starts it." : "Veți putea să participați după ce videoconferința va fi pornită de un moderator",
    "End call for everyone" : "Închide videoconferința pentru toți",
    "The call has been running for one hour." : "Videoconferința durează de o oră",
    "Raise hand" : "Ridică mâna",
    "Raise hand (R)" : "Ridică mâna (R)",
    "Lower hand" : "Coboară mâna",
    "Lower hand (R)" : "Coboară mâna (R)",
    "Send a reaction" : "Trimite o reacție",
    "React with {reaction}" : "Reacționează cu {reaction}",
    "You are not allowed to enable screensharing" : "Nu aveți permisiunea de partajare a ecranului",
    "No screensharing" : "Nicio partajare de ecran",
    "Screensharing options" : "Opțiuni pentru partajarea ecranului",
    "Enable screensharing" : "Activează partajarea ecranului",
    "Bad sent video and screen quality." : "Video transmis corupt și calitate proastă a imaginii.",
    "Bad sent screen quality." : "Calitate proastă a imaginii.",
    "Bad sent video quality." : "Calitate proastă video.",
    "Bad sent audio, video and screen quality." : "Calitate proastă audio și video.",
    "Bad sent audio and screen quality." : "Calitate proastă audio și imagine.",
    "Bad sent audio and video quality." : "Calitate proastă audio și video.",
    "Bad sent audio quality." : "Calitate audio proastă.",
    "Disable background blur" : "Dezactivează blurarea fundalului",
    "Disable screenshare" : "Dezactivează partajarea ecranului",
    "Screen sharing is not supported by your browser." : "Partajarea ecranului nu e posibilă în acest browser.",
    "An error occurred while starting screensharing." : "Eroare la partajarea ecranului.",
    "Show your screen" : "Prezentați ecranul",
    "Stop screensharing" : "Oprește partajarea ecranului",
    "Mute others" : "Închide microfonul celorlalți",
    "Remove participant {name}" : "Elimină participantul {name}",
    "Keep" : "Păstrare",
    "Select a region" : "Selectează o regiune",
    "Search …" : "Caută ...",
    "Message without mention" : "Mesaj fără mențiuni",
    "Mention myself" : "Mă menționez",
    "The conversation does not exist" : "Conversația nu există",
    "Join a conversation or start a new one!" : "Particiăați la o conversație sau creați una nouă!",
    "Join a conversation or start a new one" : "Participați la o conversație sau începeți una nouă",
    "Talk conversation" : "Conversație Talk",
    "User" : "Utilizator",
    "Login" : "Autentificare",
    "Nickname" : "Pseudonim",
    "Client ID" : "ID client",
    "Media" : "Media",
    "Polls" : "Voturi",
    "Deck cards" : "Carduri Deck",
    "Voice messages" : "Mesaje vocale",
    "Locations" : "Locații",
    "Audio" : "Audio",
    "Show all media" : "Arată toată media",
    "Show all files" : "Arată toate fișierele",
    "Show all polls" : "Arată toate voturile",
    "Show all deck cards" : "Arată toate cardurile Deck",
    "Show all voice messages" : "Arată toate mesajele vocale",
    "Show all locations" : "Arată toate locațiile",
    "Show all audio" : "Arată audio",
    "Show all other" : "Arată celelalte",
    "Group" : "Grup",
    "Team" : "Echipă",
    "You reconnected to the call" : "V-ați reconectat",
    "{actor} reconnected to the call" : "{actor} s-a reconectat",
    "You added {user0} and {user1}" : "Ați adăugat pe {user0} și {user1}",
    "An administrator added you and {user0}" : "V-a adăugat un administrator, și pe {user0}",
    "{actor} added you and {user0}" : "{actor} v-a adăugat, și pe {user0}",
    "An administrator added {user0} and {user1}" : "Un administrator a adăugat pe {user0} și pe {user1}",
    "{actor} added {user0} and {user1}" : "{actor} a adăugat pe {user0} și pe {user1}",
    "You: {lastMessage}" : "Tu: {lastMessage}",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Încercați să participați la o conversație având o sesiune activă în altă fereastră sau dispozitiv. Acest lucru nu este suportat în prezent în Nextcloud Talk. Ce doriți să faceți?",
    "Leave this page" : "Părăsește pagina",
    "Join here" : "Alăturare aici",
    "Deck card has been posted to {conversation}" : "Cardul Deck a fost postat la conversația {conversation}",
    "An error occurred while posting deck card to conversation" : "Eroare la postarea cardului Deck în conversație",
    "Post to a conversation" : "Postare într-o conversație",
    "Post to conversation" : "Postare în conversație",
    "Share to a conversation" : "Partajare la o conversație",
    "Share to conversation" : "Partajare la conversație",
    "Error while clearing conversation history" : "Eroare la ștergerea istoricului conversației",
    "Conversation password has been saved" : "Parola conversației a fost salvată",
    "Conversation password has been removed" : "Parola conversație a fost ștearsă",
    "Conversation picture set" : "Imaginea conversației a fost configurată",
    "Conversation picture deleted" : "Imaginea conversației a fost ștearsă",
    "Could not post message: {errorMessage}" : "Nu s-a putut posta mesajul: {errorMessage}",
    "An error occurred while fetching the participants" : "Eroare la preluarea listei de participanți",
    "Could not send invitation to {actorId}" : "Nu a fost trimisă invitația către {actorId}",
    "Invitations sent" : "Invitațiile au fost trimise",
    "An error occurred while requesting assistance" : "Eroare la solicitarea de asistență",
    "An error occurred while resetting the request for assistance" : "Eroare la resetarea solicitării de asistență",
    "An error occurred while submitting your vote" : "Eroare la transmiterea votului",
    "An error occurred while ending the poll" : "Eroare la încheierea votării",
    "Failed to add reaction" : "Eroare la adăugarea reacției",
    "Failed to remove reaction" : "Eroare la ștergerea reacției",
    "Error while uploading file \"{fileName}\"" : "Eroare la încărcarea fișierului \"{fileName}\"",
    "Not enough free space to upload file \"{fileName}\"" : "Spațiu insuficient pentru încărcarea fișierului \"{fileName}\"",
    "Error while sharing file" : "Eroare la partajarea fișierului",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Browserul folosit nu este compatibil cu Nextcloud Talk. Folosiți ultima versiune a Mozilla Firefox, Microsoft Edge, Google Chrome sau Apple Safari.",
    "Later today – {timeLocale}" : "Azi, mai târziu – {timeLocale}",
    "Tomorrow – {timeLocale}" : "Mâine – {timeLocale}",
    "This weekend – {timeLocale}" : "În acest weekend – {timeLocale}",
    "Next week – {timeLocale}" : "Săptămâna viitoare– {timeLocale}",
    "Message link copied to clipboard" : "Linkul mesajului a fost copiat",
    "Conversation link copied to clipboard" : "Linkul conversației a fost copiat",
    "The link could not be copied" : "Linkul nu s-a putut copia",
    "Please reload the page." : "Te rugăm să reîncarci pagina.",
    "Do not disturb" : "Nu deranja",
    "Away" : "Plecat",
    "Microphone {number}" : "Microfon {number}",
    "Speaker {number}" : "Vorbitor {number}",
    "Access to microphone & camera was denied" : "Accesul la microfon și cameră a fost refuzat",
    "Android app" : "Aplicație Android",
    "iOS app" : "Aplicație iOS",
    "__language_name__" : "Română",
    "Tasks" : "Sarcini",
    "Notes" : "Notițe",
    "Talk to %s" : "Conversați cu %s",
    "Set reminder for later today" : "Setează memo pentru azi, mai târziu",
    "Set reminder for tomorrow" : "Setează memo pentru mâine",
    "Set reminder for this weekend" : "Setează memo pentru acest weekend",
    "Set reminder for next week" : "Setează memo pentru săptămâna viitoare",
    "Your privacy setting has been saved" : "Setările de confidențialitate au fost salvate",
    "Failed to save sounds setting" : "Eroare la salvarea setărilor de sunet",
    "Sounds setting saved" : "Setările de sunet au fost salvate"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
