OC.L10N.register(
    "spreed",
    {
    "a conversation" : "una resonada",
    "(Duration %s)" : "(Tempus %s)",
    "You attended a call with {user1}" : "As partitzipadu a una mutida cun {user1}",
    "_%n guest_::_%n guests_" : ["%npersone invitada","%npersones invitadas"],
    "You attended a call with {user1} and {user2}" : "As partitzipadu a una mutida cun {user1} e {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "As partitzipadu a una mutida cun {user1}, {user2} e {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "As partitzipadu a una mutida cun {user1}, {user2}{user3} e {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "As partitzipadu a una mutida cun {user1}, {user2}, {user3}, {user4} e {user5}",
    "_%n other_::_%n others_" : ["%n other","%n àtere"],
    "{actor} invited you to {call}" : "{actor} t'at cumbidadu a {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "T'ant cumbidadu a una <strong>resonada</strong> o as tentu una <strong>mutida</strong>",
    "Other activities" : "Àteras atividades",
    "Talk" : "Faedda",
    "Guest" : "Persone invitada",
    "## New in Talk %s" : "## Nou in Talk %s",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "Immoe podes impreare Microsoft Edge e Safari pro partetzipare in mutidas àudio e vìdeo",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- Is resonadas fache a pare immoe sunt sighidas e non podent èssere furriadas prus in resonadas de grupu pro errore. Puru cando una persone lassat sa resonada, custa no si cantzellat prus de manera automàtica. Sa resonada si cantzellat dae su serbidore isceti chi is duas persones chi partetzipant dda lassant.",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Immoe podes imbiare notìficas a is partetzipantes iscriende \"@totus\" in sa tzarrada.",
    "- With the \"arrow-up\" key you can repost your last message" : "- Cun su tastu \"fertza-in-susu\" podes torrare a publicare s'ùrtimu messàgiu tuo.",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Immoe Talk podet tènnere cumandos, imbia \"agiudu\" comente messàgiu de sa tzarrada pro bìdere chi chie amministrat nd'at cunfiguradu calecunu",
    "- With projects you can create quick links between conversations, files and other items" : "- Cun is progetos podes creare ligòngios lestros intre resonadas, archìvios e àteros elementos",
    "- You can now mention guests in the chat" : "- Immoe podes mentovare zente istràngia in sa tzarrada",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Immoe is resonadas podent tènnere un'intrada. Custu at a permìtere a chie moderat de si collegare in antis a sa tzarrada po preparare s'atòbiu, in su interis chi is utentes e sa zente istràngia depent isetare",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- Immoe podes respòndere deretu a is messàgios donende a is utentes prus cuntestu subra de su messàgiu tuo",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- Sa chirca de resonadas e partitzipantes immoe at a filtrare cussas chi nche sunt giai, aici at a èssere prus fàtzile agatare resonadas pretzedentes",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- Immoe podes agiùnghere grupos de utentes abituales a is resonadas cando s'aplicatzione de tzìrculos est installada",
    "- Check out the new grid and call view" : "Controlla sa grìglia noa e sa vista de is mutidas",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- Immoe podes carrigare e trisinare archìvios deretu dae su dispositivu a sa tzarrada",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- Immoe is archìvios cumpartzidos s'aberrent deretu in sa vista de sa tzarrada cun is aplicatziones ammustradoras",
    "- You can now search for chats and messages in the unified search in the top bar" : "Immoe podes chircare tzarradas e messàgios in sa traessa generale de chirca de subra",
    "- Spice up your messages with emojis from the emoji picker" : "- Alluta is messàgios tuos cun is carigheddas dae sa regorta",
    "- You can now change your camera and microphone while being in a call" : "- Immoe podes cambiare sa càmera e su micròfono in s'interis chi ses in una mutida",
    "- Give your conversations some context with a description and open it up so logged in users can find it and join themselves" : "- Dona cuntestu a is resonadas cun una descritzione e lassa•dda visìbile gasi is utentes chi ant fatu s'atzessu dda podent agatare e intrare pro contu issoro",
    "- See a read status and send failed messages again" : "- Càstia is informatziones de letura e torra a mandare is messàgios faddidos",
    "- Raise your hand in a call with the R key" : "- Àrtzia sa manu in una mutida cun su tastu R",
    "- Join the same conversation and call from multiple devices" : "- Intra in sa pròpria resonada e tzèrria cun prus dispositivos",
    "- Send voice messages, share your location or contact details" : "- Imbia messàgios de boghe, cumpartzi sa positzione tua o is detàllios de cuntatu",
    "- Add groups to a conversation and new group members will automatically be added as participants" : "- Agiunghe grupos a una resonada e is membros noos ant a èssere agiuntos in automàticu comente partetzipantes",
    "Talk updates ✅" : "Agiornamentos de Talk ✅",
    "{actor} created the conversation" : "{actor} at creadu sa resonada",
    "You created the conversation" : "Tue as creadu sa resonada",
    "An administrator created the conversation" : "S'amministratzione at creadu sa resonada",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} at cambiadu su nùmene de sa resonada dae \"%1$s\" a \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Tue as cambiadu su nùmene de sa resonada dae \"%1$s\" a \"%2$s\"",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "S'amministratzione at cambiadu su nùmene de sa resonada dae \"%1$s\" a \"%2$s\"",
    "{actor} set the description" : "{actor} at cunfiguradu sa descritzione",
    "You set the description" : "As cunfiguradu sa descritzione",
    "An administrator set the description" : "S'amministratzione at cunfiguradu sa descritzione",
    "{actor} removed the description" : "{actor} nch'at bogadu sa descritzione",
    "You removed the description" : "Tue nch'as bogadu sa descritzione",
    "An administrator removed the description" : "S'amministratzione nch'at bogadu sa descritzione",
    "You started a call" : "Tue as abertu una mutida",
    "{actor} started a call" : "{actor} at abertu una mutida",
    "{actor} joined the call" : "{actor} at fatu s'atzessu in sa mutida",
    "You joined the call" : "As fatu s'atzessu in sa mutida",
    "{actor} left the call" : "{actor} at lassadu sa mutida",
    "You left the call" : "Tue as lassadu sa mutida",
    "{actor} unlocked the conversation" : "{actor} at isblocadu sa resonada",
    "You unlocked the conversation" : "Tue as isblocadu sa resonada",
    "An administrator unlocked the conversation" : "S'amministratzione at isblocadu sa resonada",
    "{actor} locked the conversation" : "{actor} at blocadu sa resonada",
    "You locked the conversation" : "Tue as blocadu sa resonada",
    "An administrator locked the conversation" : "S'amministratzione at blocadu sa resonada",
    "{actor} limited the conversation to the current participants" : "{actor} at limitadu sa resonada a is partetzipantes atuales",
    "You limited the conversation to the current participants" : "Tue as limitadu sa resonada a is partetzipantes atuales",
    "An administrator limited the conversation to the current participants" : "S'amministratzione at limitadu sa resonada a is partetzipantes atuales",
    "{actor} opened the conversation to registered users" : "{actor} at abertu sa resonada a s'utèntzia registrada",
    "You opened the conversation to registered users" : "Tue as abertu sa resonada a s'utèntzia registrada",
    "An administrator opened the conversation to registered users" : "S'amministratzione at abertu sa resonada a s'utèntzia registrada",
    "The conversation is now open to everyone" : "Immoe sa resonada est aberta a totus",
    "{actor} opened the conversation to everyone" : "{actor} at abertu sa resonada a totus",
    "You opened the conversation to everyone" : "Tue as abertu sa resonada a totus",
    "{actor} restricted the conversation to moderators" : "{actor} at istrintu sa resonada a chie moderat",
    "You restricted the conversation to moderators" : " Tue as istrintu sa resonada a chie moderat",
    "{actor} allowed guests" : "{actor} at ammìtidu s'utèntzia istràngia",
    "You allowed guests" : "Tue as ammìtidu s'utèntzia istràngia",
    "An administrator allowed guests" : "S'amministratzione at ammìtidu s'utèntzia istràngia",
    "{actor} disallowed guests" : "{actor} at refudadu s'utèntzia istràngia",
    "You disallowed guests" : "Tue as refudadu s'utèntzia istràngia",
    "An administrator disallowed guests" : "S'amministratzione at refudadu s'utèntzia istràngia",
    "{actor} set a password" : "{actor} at cunfiguradu una crae",
    "You set a password" : "As cunfiguradu una crae",
    "An administrator set a password" : "S'amministratzione at cunfiguradu una crae",
    "{actor} removed the password" : "{actor} nch'at bogadu sa crae",
    "You removed the password" : "Nch'as bogadu sa crae",
    "An administrator removed the password" : "S'amministratzione nch'at bogadu sa crae",
    "{actor} added {user}" : "{actor} at agiuntu a {user}",
    "You joined the conversation" : "As fatu s'atzessu in sa resonada",
    "{actor} joined the conversation" : "{actor} at fatu s'atzessu in sa resonada",
    "You added {user}" : "As agiuntu a {user}",
    "{actor} added you" : "{actor} t'at agiuntu",
    "An administrator added you" : "S'amministratzione t'at agiuntu",
    "An administrator added {user}" : "S'amministratzione at agiuntu {user}",
    "You left the conversation" : "As lassadu sa resonada",
    "{actor} left the conversation" : "{actor} at lassadu sa resonada",
    "{actor} removed {user}" : "{actor} nch'at bogadu a {user}",
    "You removed {user}" : "Nch'as bogadu a {user}",
    "{actor} removed you" : "{actor} ti nch'at bogadu",
    "An administrator removed you" : "S'amministratzione ti nch'at bogadu",
    "An administrator removed {user}" : "S'amministrazione nch'at bogadu {user}",
    "{actor} added group {group}" : "{actor} at agiuntu su grupu {group}",
    "You added group {group}" : "As agiuntu su grupu {group}",
    "An administrator added group {group}" : "S'amministratzione at agiuntu su grupu {group}",
    "{actor} removed group {group}" : "{actor} nch'at bogadu su grupu {group}",
    "You removed group {group}" : "Nch'as bogadu su grupu {group}",
    "An administrator removed group {group}" : "S'amministratzione nch'at bogadu su grupu {group}",
    "{actor} promoted {user} to moderator" : "{actor} at autorizadu {user} a moderare",
    "You promoted {user} to moderator" : "As autorizadu a {user} a moderare",
    "{actor} promoted you to moderator" : "{actor} t'at autorizadu a moderare",
    "An administrator promoted you to moderator" : "S'amministratzione t'at autorizadu a moderare",
    "An administrator promoted {user} to moderator" : "S'amministratzione at autorizadu {user} a moderare",
    "{actor} demoted {user} from moderator" : "{actor} nd'at leadu su permissu de moderare a {user} ",
    "You demoted {user} from moderator" : "Nd'as leadu su permissu de moderare a {user}",
    "{actor} demoted you from moderator" : "{actor} ti nd'at leadu su permissu de moderare",
    "An administrator demoted you from moderator" : "S'amministratzione ti nd'at leadu su permissu de moderare",
    "An administrator demoted {user} from moderator" : "S'amministratzione nd'at leadu su permissu de moderare a {user}",
    "{actor} shared a file which is no longer available" : "{actor} at cumpartzidu un'archìviu chi no est prus disponìbile",
    "You shared a file which is no longer available" : "As cumpartzidu un'archìviu chi no est prus disponìbile",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} at cunfiguradu Matterbridge pro sincronizare custa resonada cun àteras tzarradas",
    "You set up Matterbridge to synchronize this conversation with other chats" : "As cunfiguradu Matterbridge pro sincronizare custa resonada cun àteras tzarradas",
    "{actor} updated the Matterbridge configuration" : "{actor} at agiornadu sa cunfiguratzione de Matterbridge",
    "You updated the Matterbridge configuration" : "As agiornadu sa cunfiguratzione de Matterbridge",
    "{actor} removed the Matterbridge configuration" : "{actor} nch'at bogadu sa cunfiguratzione de Matterbridge",
    "You removed the Matterbridge configuration" : "Nch'as bogadu sa cunfiguratzione de Matterbridge",
    "{actor} started Matterbridge" : "{actor} at abertu Matterbridge",
    "You started Matterbridge" : "As abertu Matterbridge",
    "{actor} stopped Matterbridge" : "{actor} at firmadu Matterbridge",
    "You stopped Matterbridge" : "As firmadu Matterbridge",
    "{actor} deleted a message" : "{actor} at cantzelladu unu messàgiu",
    "You deleted a message" : "As cantzelladu unu messàgiu",
    "{actor} cleared the history of the conversation" : "{actor} at limpiadu s'istòria de sa resonada",
    "You cleared the history of the conversation" : "As limpiadu s'istòria de sa resonada",
    "Message deleted by author" : "Messàgiu cantzelladu dae s'autore",
    "Message deleted by {actor}" : "Messàgiu cantzelladu dae {actor}",
    "Message deleted by you" : "Messàgiu cantzelladu dae tue",
    "Administration" : "Amministratzione",
    "System" : "Sistema",
    "%s (guest)" : "%s (persone invitada)",
    "Talk conversations" : "Resonadas de Talk",
    "File not found" : "Archìviu no agatadu",
    "File is not shared, or shared but not with the user" : "S'archìviu no est cumpartzidu, o est cumpartzidu ma no cun s'utente",
    "No account available to delete." : "Perunu contu disponìbile de cantzellare.",
    "No image file provided" : "Perunu archìviu de immàgine frunidu",
    "File is too big" : "S'archìviu est tropu mannu",
    "Invalid file provided" : "S'archìviu frunidu no est vàlidu",
    "Invalid image" : "Immàgine non bàlida",
    "Unknown filetype" : "Genia de archìviu disconnota",
    "Talk mentions" : "Mentovos de Talk",
    "Say hi to your friends and colleagues!" : "Saluda a sa gente!",
    "No unread mentions" : "Perunu mentovu chena lèghere",
    "Call in progress" : "Mutida in cursu",
    "You were mentioned" : "Ses istadu mentovadu",
    "Write to conversation" : "Iscrie in sa resonada",
    "Writes event information into a conversation of your choice" : "Iscriet is informatziones de s'eventu in una resonada de sèberu tuo",
    "Conversation invitation" : "Cumbidu a sa resonada",
    "Description" : "Descritzione",
    "You can also dial-in via phone with the following details" : "Ti podes connètere puru cun su telèfono cun is detàllios in fatu",
    "Dial-in information" : "Informatziones de connessione",
    "Meeting ID" : "ID de s'atòbiu",
    "Your PIN" : "Su PIN tuo",
    "Meeting" : "Atòbiu",
    "Password request: %s" : "Rechesta de crae: %s",
    "Private conversation" : "Cunversatzione privada",
    "Deleted user (%s)" : "Utente cantzelladu (%s)",
    "Dismiss notification" : "Iscarta notìfica",
    "Accept" : "Atzeta",
    "Decline" : "Refuda",
    "New message" : "Messàgiu nou",
    "{user} in {call}" : "{user} in {call}",
    "Deleted user in {call}" : "Utente cantzelladu in {call}",
    "{guest} (guest) in {call}" : "{guest} (utèntzia istràngia) in {call}",
    "Guest in {call}" : "Utèntzia istràngia in {call}",
    "{user} sent you a private message" : "{user} t'at imbiadu unu messàgiu privadu",
    "{user} sent a message in conversation {call}" : "{user} at imbiadu unu messàgiu in sa resonada {call}",
    "A deleted user sent a message in conversation {call}" : "Un'utèntzia cantzellada at imbiadu unu messàgiu in sa resonada {call}",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (utèntzia istràngia) at imbiadu unu messàgiu in sa resonada {call}",
    "A guest sent a message in conversation {call}" : "Un'utèntzia istràngia at imbiadu unu messàgiu in sa resonada {call}",
    "{user} replied to your private message" : "{user} at respostu a su messàgiu privadu tuo",
    "{user} replied to your message in conversation {call}" : "{user} at respostu a su messàgiu tuo in sa resonada {call}",
    "A deleted user replied to your message in conversation {call}" : "Un'utèntzia cantzellada at respostu a su messàgiu tuo in sa resonada {call}",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (utèntzia istràngia) at respostu a su messàgiu tuo in sa resonada {call}",
    "A guest replied to your message in conversation {call}" : "Un'utèntzia istràngia at respostu a su messàgiu tuo in sa resonada {call}",
    "{user} mentioned you in a private conversation" : "{user} t'at mentovadu in una resonada privada",
    "{user} mentioned you in conversation {call}" : "{user} t'at mentovadu in sa resonada {call}",
    "A deleted user mentioned you in conversation {call}" : "Un'utèntzia cantzellada t'at mentovadu in sa resonada {call}",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (utèntzia istràngia) t'at mentovadu in sa resonada {call}",
    "A guest mentioned you in conversation {call}" : "Un'utèntzia istràngia t'at mentovadu in sa resonada {call}",
    "View chat" : "Visualiza sa tzarrada",
    "{user} invited you to a group conversation: {call}" : "{user} t'at invitadu a una resonada de grupu: {call}",
    "Join call" : "Intra in sa mutida",
    "Answer call" : "Responde a sa mutida",
    "{user} would like to talk with you" : "{user} diat bòlere faeddare cun tue",
    "Call back" : "Torra a mutire",
    "You missed a call from {user}" : "As pèrdidu una mutida dae {user}",
    "A group call has started in {call}" : "Est incarrerada una mutida de grupu in {call}",
    "You missed a group call in {call}" : "As pèrdidu una mutida de grupu in {call}",
    "{email} is requesting the password to access {file}" : "{email} est pedende sa crae pro atzèdere {file}",
    "{email} tried to request the password to access {file}" : "{email} at proadu a pedire sa crae pro atzèdere {file}",
    "Someone is requesting the password to access {file}" : "Calicunu est pedende sa crae pro atzèdere {file}",
    "Someone tried to request the password to access {file}" : "Calicunu at proadu a pedire sa crae pro atzèdere {file}",
    "Open settings" : "Aberi sa cunfiguratzione",
    "The hosted signaling server is now configured and will be used." : "Su serbidore de signalatzione retzidu immoe est cunfiguradu e podet èssere impreadu.",
    "The hosted signaling server was removed and will not be used anymore." : "Si nch'at bogadu su serbidore de signalatzione retzidu e non s'at a podère impreare prus.",
    "The hosted signaling server account has changed the status from \"{oldstatus}\" to \"{newstatus}\"." : "Su contu de su  serbidore de signalatzione retzidu at cambiadu s'istadu dae \"{oldstatus}\" a \"{newstatus}\".",
    "error" : "errore",
    "Contact via Talk" : "Cuntatu pro mèdiu de Talk",
    "Default" : "Predefinidu",
    "Presentation" : "Presentatzione",
    "Conversations" : "Cunversatziones",
    "{user}" : "{user}",
    "Messages" : "Messàgios",
    "{user} in {conversation}" : "{user} in {conversation}",
    "Messages in other conversations" : "Messàgios in àteras resonadas",
    "Avatar image is not square" : "S'immàgine de s'avatar no est cuadrada",
    "Favorites" : "Preferidos",
    "Other" : "Àteru",
    "Failed to request trial because the trial server is unreachable. Please try again later." : "No s'at pòdidu pedire sa versione de proa, ca su serbidore de proa no si podet cuntatare. Torra a proare luego.",
    "There is a problem with the authentication of this instance. Maybe it is not reachable from the outside to verify it's URL." : "B'at unu problema cun s'autenticatzione de custa istàntzia. Fortzis no si podet cuntatare dae foras pro verificare s'URL.",
    "Something unexpected happened." : "Est sutzèdida calincuna cosa no prevèdida.",
    "The URL is invalid." : "S'URL no est bàlidu.",
    "An HTTPS URL is required." : "Est rechertu unu HTTPS URL.",
    "The email address is invalid." : "S'indiritzu de posta eletrònica no est bàlidu.",
    "The language is invalid." : "Su limbàgiu no est bàlidu.",
    "The country is invalid." : "S'Istadu no est bàlidu.",
    "There is a problem with the request of the trial. Please check your logs for further information." : "B'at unu problema cun sa rechesta de sa versione de proa. Càstia is registros tuos pro àteras informatziones.",
    "Too many requests are send from your servers address. Please try again later." : "B'at tropu rechestas imbiadas dae s'indiritzu de su serbidore tuo. Torra a proare luego.",
    "There is already a trial registered for this Nextcloud instance." : "B'at giai una versione de proa registrada pro custa istàntzia de Nextcloud.",
    "Something unexpected happened. Please try again later." : "Est sutzèdida calincuna cosa no prevèdida. Torra a proare luego.",
    "Failed to request trial because the trial server behaved wrongly. Please try again later." : "No s'at pòdidu pedire sa versione de proa, ca b'at àpidu errores in su funtzionamentu de su serbidore de proa. Torra a proare luego.",
    "Trial requested but failed to get account information. Please check back later." : "Versione de proa rechèdida, ma no si podet atzèdere a is informatziones de su contu. Torra a castiare luego.",
    "There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it's URL." : "B'at unu problema cun s'autenticatzione de custa rechesta. Fortzis no si podet cuntatare dae foras pro verificare s'URL.",
    "Failed to fetch account information because the trial server behaved wrongly. Please check back later." : "No s'at pòdidu recuperare is informatziones de su contu, ca b'at àpidu errores in su funtzionamentu de su serbidore de proa. Torra a proare luego.",
    "There is a problem with fetching the account information. Please check your logs for further information." : "B'at unu problema cun su recùperu de is informatziones de su contu. Càstia is registros tuos pro àteras informatziones.",
    "There is no such account registered." : "Perunu contu de custa genia registradu.",
    "Failed to fetch account information because the trial server is unreachable. Please check back later." : "No s'at pòdidu recuperare is informatziones de su contu, ca su serbidore de proa no si podet cuntatare. Torra a proare luego.",
    "Deleting the hosted signaling server account failed. Please check back later." : "Cantzellende su contu faddidu de su serbidore de signalatzione retzidu. Torra a castiare luego.",
    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "No s'at pòdidu cantzellare su contu, ca b'at àpidu errores in su funtzionamentu de su serbidore de proa. Torra a proare luego.",
    "There is a problem with deleting the account. Please check your logs for further information." : "B'at unu problema pro cantzellare su contu. Càstia is registros tuos pro àtera informatziones.",
    "Too many requests are sent from your servers address. Please try again later." : "B'at tropu rechestas imbiadas dae s'indiritzu de su serbidore tuo. Torra a proare luego.",
    "Failed to delete the account because the trial server is unreachable. Please check back later." : "No s'at pòdidu cantzellare su contu, ca su serbidore de proa no si podet cuntatare. Torra a proare luego.",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Emirados Àrabos Unidos",
    "Afghanistan" : "Afganistàn",
    "Antigua and Barbuda" : "Antìgua e Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albania",
    "Armenia" : "Armènia",
    "Angola" : "Angola",
    "Antarctica" : "Antàrtide",
    "Argentina" : "Argentina",
    "American Samoa" : "Samoa Americanas",
    "Austria" : "Àustria",
    "Australia" : "Austràlia",
    "Aruba" : "Aruba",
    "Åland Islands" : "Ìsulas Åland ",
    "Azerbaijan" : "Azerbaijàn",
    "Bosnia and Herzegovina" : "Bòsnia e Erzegòvina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Bèlgiu",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaria",
    "Bahrain" : "Baharain",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Saint Barthélemy",
    "Bermuda" : "Bermuda",
    "Brunei Darussalam" : "Brunei ",
    "Bolivia, Plurinational State of" : "Bolìvia",
    "Bonaire, Sint Eustatius and Saba" : "Paisos Bassos Caraìbicos",
    "Brazil" : "Brasile",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bhutan",
    "Bouvet Island" : "Ìsula Bouvet",
    "Botswana" : "Botswana",
    "Belarus" : "Bielorùssia",
    "Belize" : "Belize",
    "Canada" : "Cànada",
    "Cocos (Keeling) Islands" : "Ìsulas Cocos (Keeling)",
    "Congo, the Democratic Republic of the" : "Repùblica Democràtica de su Congo",
    "Central African Republic" : "Rpùblica Tzentrafricana",
    "Congo" : "Repùblica de su Congo",
    "Switzerland" : "Isvìtzera",
    "Côte d'Ivoire" : "Costa Avòriu",
    "Cook Islands" : "Ìsulas Cook",
    "Chile" : "Cile",
    "Cameroon" : "Camerun",
    "China" : "Cina",
    "Colombia" : "Colòmbia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cabo Verde" : "Cabu Birde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Ìsula de Paschighedda",
    "Cyprus" : "Cipru",
    "Czechia" : "Repùbblica Ceca",
    "Germany" : "Germània",
    "Djibouti" : "Gibuti",
    "Denmark" : "Danimarca",
    "Dominica" : "Dominica",
    "Dominican Republic" : "Repùblica Dominicana",
    "Algeria" : "Algeria",
    "Ecuador" : "Ecuador",
    "Estonia" : "Estònia",
    "Egypt" : "Egitu",
    "Western Sahara" : "Sahara Otzidentale",
    "Eritrea" : "Eritrea",
    "Spain" : "Ispagna",
    "Ethiopia" : "Etiòpia",
    "Finland" : "Finlàndia",
    "Fiji" : "Figi",
    "Falkland Islands (Malvinas)" : "Ìsulas Falkand (Malvinas)",
    "Micronesia, Federated States of" : "Micronèsia",
    "Faroe Islands" : "Ìsulas Faroe",
    "France" : "Frantza",
    "Gabon" : "Gabon",
    "United Kingdom of Great Britain and Northern Ireland" : "Regnu Unidu",
    "Grenada" : "Grenada",
    "Georgia" : "Geòrgia",
    "French Guiana" : "Guyana Frantzesa",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibilterra",
    "Greenland" : "Groenlàndia",
    "Gambia" : "Gàmbia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadalupa",
    "Equatorial Guinea" : "Guinea Ecuatoriale",
    "Greece" : "Grècia",
    "South Georgia and the South Sandwich Islands" : "Geòrgia de su Sud e Ìsulas Sandwich Meridionales",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Ìsulas Heard e McDonald",
    "Honduras" : "Honduras",
    "Croatia" : "Croàtzia",
    "Haiti" : "Haiti",
    "Hungary" : "Ungheria",
    "Indonesia" : "Indonèsia",
    "Ireland" : "Irlanda",
    "Israel" : "Israele",
    "Isle of Man" : "Ìsula de Man",
    "India" : "Ìndia",
    "British Indian Ocean Territory" : "Territòriu Britànnicu de s'Oceanu Indianu",
    "Iraq" : "Iraq",
    "Iran, Islamic Republic of" : "Repùblica Islàmica de Iran",
    "Iceland" : "Islanda",
    "Italy" : "Itàlia",
    "Jersey" : "Jersey",
    "Jamaica" : "Giamàica",
    "Jordan" : "Giordània",
    "Japan" : "Giapone",
    "Kenya" : "Kènya",
    "Kyrgyzstan" : "Kirghizistan",
    "Cambodia" : "Cambògia",
    "Kiribati" : "Kiribati",
    "Comoros" : "Comore",
    "Saint Kitts and Nevis" : "San Kitts and Nevis",
    "Korea, Democratic People's Republic of" : "Corea de su Nord",
    "Korea, Republic of" : "Corea de su Sud",
    "Kuwait" : "Kuwait",
    "Cayman Islands" : "Ìsulas Caiman",
    "Kazakhstan" : "Kazakistan",
    "Lao People's Democratic Republic" : "Laos",
    "Lebanon" : "Lìbanu",
    "Saint Lucia" : "Santa Lughia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Libèria",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Lituània",
    "Luxembourg" : "Lussemburgu",
    "Latvia" : "Letònia",
    "Libya" : "Lìbia",
    "Morocco" : "Marocu",
    "Monaco" : "Printzipadu de Mònaco",
    "Moldova, Republic of" : "Moldàvia",
    "Montenegro" : "Montenegru",
    "Saint Martin (French part)" : "San Martin (parte Frantzesa)",
    "Madagascar" : "Madagascar",
    "Marshall Islands" : "Ìsulas Marshall",
    "North Macedonia" : "Macedònia de su Nord",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongòlia",
    "Macao" : "Macao",
    "Northern Mariana Islands" : "Ìsulas Mariannas Setentrionales",
    "Martinique" : "Martinica",
    "Mauritania" : "Mauritània",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Maurìtius",
    "Maldives" : "Maldivas",
    "Malawi" : "Malawi",
    "Mexico" : "Mèssicu",
    "Malaysia" : "Malèsia",
    "Mozambique" : "Mozambicu",
    "Namibia" : "Namìbia",
    "New Caledonia" : "Caledònia noa",
    "Niger" : "Niger",
    "Norfolk Island" : "Ìsulas Norfolk",
    "Nigeria" : "Nigèria",
    "Nicaragua" : "Nicaràgua",
    "Netherlands" : "Paisos Bàscios",
    "Norway" : "Norvègia",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Noa Zelanda",
    "Oman" : "Oman",
    "Panama" : "Pànama",
    "Peru" : "Perù",
    "French Polynesia" : "Polinèsia Frantzesa",
    "Papua New Guinea" : "Pàpua Guinea Noa",
    "Philippines" : "Filipinas",
    "Pakistan" : "Pakistan",
    "Poland" : "Polònia",
    "Saint Pierre and Miquelon" : "San Pierre e Miquelon",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Portu Ricu",
    "Palestine, State of" : "Istadu de Palestina",
    "Portugal" : "Portogallu",
    "Palau" : "Palau",
    "Paraguay" : "Paraguay",
    "Qatar" : "Qatar",
    "Réunion" : "Réunion",
    "Romania" : "Romania",
    "Serbia" : "Sèrbia",
    "Russian Federation" : "Rùssia",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Aràbia Saudita",
    "Solomon Islands" : "Ìsulas Solomon",
    "Seychelles" : "Seychelles",
    "Sudan" : "Sudan",
    "Sweden" : "Isvètzia",
    "Singapore" : "Singapore",
    "Saint Helena, Ascension and Tristan da Cunha" : "Sant Elene",
    "Slovenia" : "Slovènia",
    "Svalbard and Jan Mayen" : "Svalbarg e Jan Mayen",
    "Slovakia" : "Slovàchia",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "Santu Marinu",
    "Senegal" : "Senegal",
    "Somalia" : "Somàlia",
    "Suriname" : "Suriname",
    "South Sudan" : "Sudan de su Sud",
    "Sao Tome and Principe" : "Sao Tome e Principe",
    "El Salvador" : "El Salvador",
    "Sint Maarten (Dutch part)" : "Sint Marteen (parte Olandese)",
    "Syrian Arab Republic" : "Sìria",
    "Eswatini" : "Swaziland",
    "Turks and Caicos Islands" : "Ìsulas Turks e Caicos",
    "Chad" : "Ciad",
    "French Southern Territories" : "Territòrios Frantzesos de su Sud",
    "Togo" : "Togo",
    "Thailand" : "Tailàndia",
    "Tajikistan" : "Tagikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor de Est",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunisia",
    "Tonga" : "Tonga",
    "Turkey" : "Turchia",
    "Trinidad and Tobago" : "Trinidad e Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan, Province of China" : "Taiwan",
    "Tanzania, United Republic of" : "Tanzània",
    "Ukraine" : "Ucraina",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Ìsulas perifèricas secundàrias de Istados Unidos",
    "United States of America" : "Istados Unidos de Amèrica",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Uzbekistan",
    "Holy See" : "Tzitade de su Vaticanu",
    "Saint Vincent and the Grenadines" : "Saint Vincent and Grenadines",
    "Venezuela, Bolivarian Republic of" : "Venezuela",
    "Virgin Islands, British" : "Ìsulas Bìrghines de Regnu Unidu",
    "Virgin Islands, U.S." : "Ìsulas Bìrghines de Istados Unidos",
    "Viet Nam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis and Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Yemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Sudàfrica",
    "Zambia" : "Zàmbia",
    "Zimbabwe" : "Zimbabwe",
    "Federation" : "Federatzione",
    "High-performance backend" : "Motore de prestatziones artas",
    "Error: Cannot connect to server" : "Errore: non si podet istabilire connessione cun su serbidore",
    "Error: Server did not respond with proper JSON" : "Errore: Su serbidore non at respostu cun su JSON curretu",
    "Error: Server responded with: {error}" : "Errore: Su serbidore at respostu cun: {error}",
    "Error: Unknown error occurred" : "Errore: B'at àpidu un'errore disconnotu",
    "SIP configuration" : "Cunfiguratzione de SIP",
    "Invalid date, date format must be YYYY-MM-DD" : "Data non bàlida, su formadu de sa data depet èssere AAAA-MM-GG",
    "Conversation not found" : "Resonada no agatada",
    "Chat, video & audio-conferencing using WebRTC" : "Tzarradas, cunferèntzias vìdeo e àudio impreende WebRTC",
    "Leave call" : "Lassa sa mutida",
    "Navigating away from the page will leave the call in {conversation}" : "Bessire dae sa pàgina at a fàghere lassare sa mutida in {conversation}",
    "Stay in call" : "Abarra in sa mutida",
    "Duplicate session" : "Dùplica sa sessione",
    "Discuss this file" : "Chistiona de custu archìviu",
    "Loading …" : "Carrigamentu …",
    "Share this file with others to discuss it" : "Cumpartzi custu archìviu cun àtere pro nde chistionare",
    "Join conversation" : "Intra in sa resonada",
    "Share this file" : "Cumpartzi custu archìviu",
    "The password is wrong. Try again." : "Sa crae est isballiada. Torra a proare.",
    "Password" : "Crae",
    "Submit" : "Imbia",
    "Error requesting the password." : "Errore pedende sa crae.",
    "Request password" : "Pedi sa crae",
    "This conversation has ended" : "Custa resonada est acabada.",
    "Everyone" : "Chie chi siat",
    "Users and moderators" : "Lista de is utentes e de chie moderat",
    "Moderators only" : "Isceti chie moderat",
    "Save changes" : "Sarva càmbios",
    "Saving …" : "Sarvende ...",
    "Saved!" : "Sarvadu!",
    "Limit to groups" : "Lìmita a grupos",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "Cando a su mancu unu grupu est seletzionadu, isceti is persones de is grupos in sa lista podent pigare parte de sa resonada.",
    "Guests can still join public conversations." : "Is persones invitadas podent ancora intrare in resonadas pùblicas. ",
    "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Is utentes chi no podent prus impreare Talk ant a abarrare in sa lista comente partetzipantes in is resonadas pretzedentes e puru is messàgios issoro podent abarrare sarvados in sa tzarrada.",
    "Limit using Talk" : "Lìmita s'impreu de Talk",
    "Limit creating a public and group conversation" : "Lìmita sa creatzione de una resonada pùblica e de grupu.",
    "Limit creating conversations" : "Lìmita sa creatzione de resonadas",
    "Limit starting a call" : "Lìmita s'inghitzu de una mutida",
    "Limit starting calls" : "Lìmita s'inghitzu de mutidas",
    "When a call has started, everyone with access to the conversation can join the call." : "Cando una mutida est giai incarrerada, is chi tenent atzessu bi podent intrare.",
    "Enabled" : "Ativadu",
    "Disabled" : "Disabilitada",
    "State" : "Istadu",
    "Name" : "Nùmene",
    "Beta" : "Beta",
    "Permissions" : "Permissos",
    "All messages" : "Totu is messàgios",
    "@-mentions only" : "@-mentovos isceti",
    "Off" : "Istudadu",
    "General settings" : "Cunfiguratzione generale",
    "Default notification settings" : "Cunfiguratzione de notìficas predefinidas",
    "Default group notification" : "Notìfica de grupu predefinida",
    "Default group notification for new groups" : "Notìfica de grupu predefinida pro grupos noos",
    "Integration into other apps" : "Integratzione in àteras aplicatziones",
    "Allow conversations on files" : "Permite resonadas in is archìvios",
    "Allow conversations on public shares for files" : "Permite resonadas in is cumpartziduras pùblicas pro is archìvios",
    "Enable encryption" : "Ativa tzifradura",
    "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}." : "Incarchende su butone subra, s'informatzione in su mòdulu benit imbiada a is serbidores de Struktur AG. Podes agatare àteras informatzione in {linkstart}spreed.eu{linkend}.",
    "Pending" : "In suspesu",
    "Error" : "Errore",
    "Blocked" : "Blocadu",
    "Active" : "Ativu",
    "Expired" : "Iscadidu",
    "Never" : "Mai",
    "The trial could not be requested. Please try again later." : "Non si podet pedire sa proa. Torra a proare a coa.",
    "The account could not be deleted. Please try again later." : "Non si podet cantzellare su contu. Torra a proare a coa.",
    "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "Su partner nostru Struktur AG frunit unu servìtziu in ue si podet pedire unu serbidore de signalatzione retzidu. Bastat a compilare su mòdulu a suta e Nextcloud dd'at a pedire pro tue. Una borta chi su serbidore est cunfiguradu, is credentziales s'ant a compilare de manera automàtica. Custu at a subriscrìere sa cunfiguratzione esistente de su serbidore de signalatzione.",
    "URL of this Nextcloud instance" : "URL de custa istàntzia Nextcloud",
    "Full name of the user requesting the trial" : "Nùmene cumpridu de s'utente chi pedit sa proa",
    "Email of the user" : "Email de s'utente",
    "Language" : "Limba",
    "Country" : "Istadu",
    "Request signaling server trial" : "Pedi sa proa de su serbidore de signalatzione",
    "You can see the current status of your hosted signaling server in the following table." : "Podes bìdere s'istatus atuale de su serbidore de signalatzione retzidu in sa tabella in fatu.",
    "Status" : "Istadu",
    "Created at" : "Creadu su",
    "Expires at" : "Iscadit su",
    "Limits" : "Lìmites",
    "Yes" : "Si",
    "No" : "No",
    "Delete the signaling server account" : "Cantzella su contu de su serbidore de signalatzione",
    "_%n user_::_%n users_" : ["%nutente","%n utentes"],
    "Installed version: {version}" : "Versione installada: {version}",
    "Matterbridge binary was not found or couldn't be executed." : "Su binàriu de Matterbridge non est istadu agatadu o non podet èssere esecutadu.",
    "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "Podes agatare su percursu de su binàriu de Matterbridge a manu puru, cun sa cunfiguratzione. Controlla sa {linkstart}Documentatzione de s'integratzione de Matterbridge{linkend} pro àteras informatziones.",
    "Downloading …" : "Iscarrighende ...",
    "Install Talk Matterbridge" : "Installa Talk Matterbridge",
    "Failed to execute Matterbridge binary." : "No at fatu a esecutare su binàriu de Matterbridge.",
    "Matterbridge integration" : "Integratzione cun Matterbridge",
    "Enable Matterbridge integration" : "Ativa s'integratzione cun Matterbridge",
    "Status: Checking connection" : "Istatus: Controllende sa connessione",
    "OK: Running version: {version}" : "OK: Versione currente: {version}",
    "Validate SSL certificate" : "Cunvàlida su tzertificadu SSL",
    "Delete this server" : "Cantzella custu serbidore",
    "Test this server" : "Proa custu serbidore",
    "Shared secret" : "Segretu cumpartzidu",
    "Restrict SIP configuration" : "Lìmita sa cunfiguratzione SIP",
    "Enable SIP configuration" : "Ativa sa cunfiguratzione SIP",
    "Only users of the following groups can enable SIP in conversations they moderate" : "Isceti is utentes de custus grupos podent ativare SIP in is resonadas chi moderant.",
    "Phone number (Country)" : "Nùmero de telèfonu (Istadu)",
    "This information is sent in invitation emails as well as displayed in the sidebar to all participants." : "Custas informatziones s'imbiant cun s'email e si mustrant a in s'istanca laterale a totus is persones chi partetzipant.",
    "High-performance backend URL" : "URL de su motore de prestatziones artas",
    "STUN server URL" : "URL de su serbidore STUN",
    "STUN servers" : "Serbidores STUN",
    "A STUN server is used to determine the public IP address of participants behind a router." : "Unu serbidore STUN s'impreat pro determinare s'indiritzu IP pùblicu de is partetzipantes a secus de unu router.",
    "{schema} scheme must be used with a domain" : "S'ischema {schema} si depet impreare cun unu domìniu",
    "{option1} and {option2}" : "{option1} e {option2}",
    "{option} only" : "{option} isceti",
    "OK: Successful ICE candidates returned by the TURN server" : "OK: Candidados ICE bàlidos torrados dae su serbidore TURN",
    "Error: No working ICE candidates returned by the TURN server" : "Errore: Perunu candidadu ICE funtzionante torradu dae su serbidore TURN",
    "Testing whether the TURN server returns ICE candidates" : "Proende chi su serbidore TURN torrat candidados ICE",
    "TURN server schemes" : "Ischemas de su serbidore TURN",
    "TURN server URL" : "URL de su serbidore TURN",
    "TURN server secret" : "Segretu de su serbidore TURN",
    "TURN server protocols" : "Protocollos de su serbidore TURN",
    "A TURN server is used to proxy the traffic from participants behind a firewall. If individual participants cannot connect to others a TURN server is most likely required. See {linkstart}this documentation{linkend} for setup instructions." : "Unu serbidore TURN s'impreat pro imbiare su tràficu dae is partezipantes a secus de unu firewall. Chi is partetzipantes individuales non si podent connètere cun is àteras persones, est probàbile chi serbat unu serbidore TURN. Controlla {linkstart}custa documentatzione{linkend} pro is istrutziones de cunfiguratzione.",
    "TURN servers" : "TURN serbidores",
    "OK" : "AB",
    "Confirm" : "Cunfirma",
    "Reset" : "Ripristina",
    "Cancel" : "Annulla",
    "Back" : "In segus",
    "Add participant \"{user}\"" : "Agiunghe partetzipante \"{user}\"",
    "From" : "Dae",
    "To" : "A",
    "Calendar" : "Calendàriu",
    "Attendees" : "Partetzipantes",
    "Save" : "Sarva",
    "Search participants" : "Chirca partetzipantes",
    "No results" : "Perunu resurtadu",
    "Speaker view" : "Bista de sa persone chi faeddat",
    "Grid view" : "Bisione grìllia",
    "This conversation is read-only" : "Custa resonada est de letura sola",
    "Reload" : "Torra a carrigare",
    "{nickName} raised their hand." : "{nickName} ant artziadu sa manu",
    "A participant raised their hand." : "Una persona at artziadu sa manu",
    "Collapse stripe" : "Istringhe sa tira",
    "Expand stripe" : "Ammània sa tira",
    "Previous page of videos" : "Pàgina de vìdeos pretzedente ",
    "Next page of videos" : "Pàgina de vìdeos imbeniente",
    "Connecting …" : "Connetende ...",
    "Waiting for others to join the call …" : "Abetende chi is àteras persones intrent in sa mutida",
    "You can invite others in the participant tab of the sidebar" : "Podes invitare àteras persones in s'ischeda dei partetzipantes de s'istanca laterale",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Podes invitare àteras persones  in s'ischeda de is partetzipantes de s'istanca laterale o cumpartzende custu ligòngiu!",
    "Share this link to invite others!" : "Cumpartzi custu link pro invitare àteras persones!",
    "Copy link" : "Còpia ligòngiu",
    "You are not allowed to enable audio" : "Non tenes su permissu de ativare àudio",
    "Mute audio" : "Istuda s'àudiu",
    "Mute audio (M)" : "Istuda s'àudiu (M)",
    "Unmute audio" : "Allue s'àudiu ",
    "Unmute audio (M)" : "Allue s'àudiu (M)",
    "None" : "Perunu",
    "Access to camera was denied" : "S'atzessu a sa càmera est istadu negadu",
    "Error while accessing camera" : "Errore in s'atzessu a sa càmera",
    "You have been muted by a moderator" : "Una persona chi moderat ti nd'at tiradu s'àudiu",
    "You are not allowed to enable video" : "Non tenes su permissu pro ativare vìdeo",
    "Disable video" : "Disativa vìdeu",
    "Disable video (V)" : "Disativa vìdeu (V)",
    "Enable video" : "Ativa vìdeu",
    "Enable video (V)" : "Ativa vìdeu (V)",
    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "Ativa vìdeu (V) - Sa connessione s'at a blocare pro pagu tempus cando s'ativat su vìdeu pro sa prima borta",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Ativa vìdeu - Sa connessione s'at a blocare pro pagu tempus cando s'ativat su vìdeu pro sa prima borta",
    "You" : "Tue",
    "Mute" : "Tira s'àudiu",
    "Show screen" : "Mustra s'ischermu",
    "Stop following" : "No sigas prus",
    "Collapse" : "Cuntrae",
    "You need to be logged in to upload files" : "Depes fàghere s'atzessu pro carrigare is archìvios",
    "Drop your files to upload" : "Iscapa is archìvios pro ddus carrigare",
    "Conversation messages" : "Messàgios de sa resonada",
    "Scroll to bottom" : "Iscurre a bàsciu",
    "Post message" : "Pùblica messàgiu",
    "Favorite" : "Preferidu",
    "Date:" : "Data:",
    "Hide details" : "Cua detàllios",
    "Show details" : "Mustra detàllios",
    "Error while updating conversation description" : "Errore in s'agiornamentu de sa descritzione de sa resonada",
    "Edit conversation description" : "Modìfica sa descritzione de sa resonada",
    "Enter a description for this conversation" : "Inserta una descritzione pro custa resonada",
    "Disable" : "Disativa",
    "Enable" : "Ativa",
    "Choose" : "Sèbera",
    "The file must be a PNG or JPG" : "S'archìviu depet èssere unu PNG o JPG",
    "Every time permissions are modified in this section, custom permissions previously assigned to individual participants will be lost." : "Ogni borta chi is permissos sunt modificados in custa setzione, is permissos personalizados assignados in pretzedèntzia a partetzipantes individuales ant a èssere pèrdidos.",
    "Restricted" : "Limitadu",
    "Conversation settings" : "Cunfiguratzione de sa resonada",
    "Personal" : "Personale",
    "Matterbridge" : "Matterbridge",
    "Danger zone" : "Zona de perìgulu",
    "Leave conversation" : "Lassa sa resonada",
    "Delete conversation" : "Cantzella sa resonada",
    "Do you really want to delete \"{displayName}\"?" : "A beru boles cantzellare \"{displayName}\"?",
    "Error while deleting conversation" : "Errore in sa cantzelladura de sa resonada",
    "Delete all chat messages" : "Cantzella totu is messàgios de is tzarradas",
    "Do you really want to delete all messages in \"{displayName}\"?" : "A beru boles cantzellare totu is messàgios in \"{displayName}\"?",
    "Error while clearing chat history" : "Errore limpiende s'istòria de sa tzarrada",
    "Be careful, these actions cannot be undone." : "Atentzione, custas atziones non si podent annullare",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Lassada una resonada, pro torrare a intrare in una resonada serrada, tocat de tènnere s'invitu. Si podet semper torrare a intrare in una resonada aberta.",
    "Permanently delete this conversation." : "Cantzella in manera definitiva custa resonada.",
    "Delete chat messages" : "Cantzella is messàgios de is tzarradas",
    "Permanently delete all the messages in this conversation." : "Cantzella in manera definitiva totu is messàgios in custa resonada.",
    "Password protection" : "Bardiadura de sa crae",
    "Set a password" : "Cunfigura una crae",
    "Change password" : "Càmbia crae",
    "Enter new password" : "Inserta sa crae noa",
    "Save password" : "Sarva sa crae",
    "Resend invitations" : "Torra a imbiare is invitos",
    "Error occurred when opening or limiting the conversation" : "B'at àpidu un'errore aberrende o limitende sa resonada",
    "Start time has been updated" : "S'ora de cumintzu est istada agiornada",
    "Error occurred while updating start time" : "B'at àpidu un'errore agiornende s'ora de cumintzu",
    "Meeting start time" : "Ora de cumintzu de sa riunione",
    "Start time (optional)" : "Ora de cumintzu (a sèberu)",
    "Error occurred when locking the conversation" : "B'at àpidu un errore blochende sa resonada",
    "Error occurred when unlocking the conversation" : "B'at àpidu un'errore isblochende sa resonada",
    "Lock conversation" : "Bloca resonada",
    "This will also terminate the ongoing call." : "Cust'atzione at a acabare sa mutida in cursu puru.",
    "Edit" : "Modìfica ",
    "More information" : "Àteras informatziones",
    "Delete" : "Cantzella",
    "Add new bridged channel to current conversation" : "Agiunghe àteros canales collegados a custa resonada",
    "unknown state" : "istadu disconnotu",
    "running" : "in esecutzione",
    "not running, check Matterbridge log" : "non in esecutzione, controlla su registru de Matterbridge",
    "not running" : "non in esecutzione",
    "Bridge saved" : "Collegamentu sarvadu",
    "You can bridge channels from various instant messaging systems with Matterbridge." : "Podes collegare canales dae àteros sistemas de messàgios istantàneos cun Matterbridge.",
    "More info on Matterbridge" : "Àteras informatziones subra de Matterbridge",
    "Enable bridge" : "Ativa collegamentu",
    "Show Matterbridge log" : "Mustra su registru de Matterbridge",
    "Log content" : "Cuntenutu de is registros",
    "Notifications" : "Notìficas",
    "Important conversation" : "Tzarrada importante",
    "SIP dial-in is now enabled" : "S'atzessu SIP immoe est ativu",
    "SIP dial-in is now disabled" : "S'atzessu SIP immoe est disativu",
    "Error occurred when enabling SIP dial-in" : "B'at àpidu un'errore ativende s'atzessu SIP",
    "Error occurred when disabling SIP dial-in" : "B'at àpidu un'errore disativende s'atzessu SIP",
    "Join" : "Intra",
    "Error while creating the conversation" : "Errore creende sa resonada ",
    "Create a new conversation" : "Crea una resonada noa",
    "Create conversation" : "Crea resonada",
    "Enter your name" : "Inserta•nche su nùmene tuo",
    "Log in" : "Intra",
    "Mark as read" : "Marca comente lèghidu",
    "Mark as unread" : "Marca comente non lèghidu",
    "Remove from favorites" : "Boga dae preferidos",
    "Add to favorites" : "Agiunghe a preferidos",
    "You need to promote a new moderator before you can leave the conversation." : "Depes promòvere un'àtera persona chi moderet antis de lassare sa resonada.",
    "New tag" : "Eticheta noa",
    "Conversation actions" : "Atziones de is resonadas",
    "Tags" : "Etichetas",
    "Move up" : "Tràmuda fache a susu",
    "Move down" : "Tràmuda fache a bàsciu",
    "Home" : "Pàgina printzipale",
    "Unread" : "De lèghere",
    "Alphabetically" : "Òrdine alfabèticu",
    "No matches found" : "Peruna currispondèntzia agatada",
    "No conversations found" : "Peruna resonada agatada",
    "An error occurred while performing the search" : "B'at àpidu un'errore in sa chirca",
    "Conversation list" : "Lista de is resonadas",
    "Unread messages" : "Messàgios non lèghidos",
    "New personal note" : "Nota personale noa",
    "Clear filter" : "Lìmpia filtru",
    "App settings" : "Cunfiguratzione de s'aplicatzione",
    "Users" : "Utentes",
    "Groups" : "Grupos",
    "New private conversation" : "Resonada privada noa",
    "Other sources" : "Àteras fontes",
    "Open conversations" : "Aberre is resonadas",
    "No search results" : "Perunu resurtadu de chirca",
    "Users and groups" : "Utentes e grupos",
    "New group conversation" : "Resonada de grupu noa",
    "You are currently waiting in the lobby" : "Immoe ses abetende in s'intrada",
    "Advanced" : "Connoschèntzia avantzada",
    "Select microphone" : "Seletziona su micròfonu",
    "No microphone available" : "Perunu micròfonu a disponimentu",
    "Select camera" : "Seletziona sa fotocàmera",
    "No camera available" : "Peruna fotocàmera a disponimentu",
    "Test" : "Proa",
    "Devices" : "Dispositivos",
    "No audio" : "Àudiu perunu",
    "No camera" : "Peruna fotocàmera",
    "Calls are not supported in your browser" : "Is mutidas no sunt suportadas in su navigadore tuo",
    "Access to microphone is only possible with HTTPS" : "S'atzessu a su micròfonu si podet fàghere isceti cun HTTPS",
    "Access to microphone was denied" : "S'atzessu a su micròfonu est istadu negadu",
    "Error while accessing microphone" : "Errore in s'atzessu a su micròfonu",
    "Access to camera is only possible with HTTPS" : "S'atzessu a sa càmera si podet fàghere isceti cun HTTPS",
    "Invalid path selected" : "Percursu seletzionadu non bàlidu",
    "Upload" : "Càrriga",
    "Files" : "Archìvios",
    "24 hours" : "24 oras",
    "A reminder was successfully set at {datetime}" : "Apuntu cunfiguradu pro {datetime}",
    "Reply" : "Risponde",
    "More actions" : "Àteras atziones",
    "Set reminder" : "Cunfigura un'apuntu",
    "Reply privately" : "Risponde in privadu",
    "Copy message link" : "Còpia su ligòngiu de su messàgiu",
    "Go to file" : "Bae a s'archìviu",
    "Forward message" : "Torra a imbiare su messàgiu",
    "Translate" : "Borta",
    "Set custom reminder" : "Cunfigura un'apuntu personalizadu",
    "Choose a conversation to forward the selected message." : "Sèbera una resonada pro torrare a imbiare su messàgiu seletzionadu.",
    "Error while forwarding message" : "Errore torrende a imbiare su messàgiu",
    "The message has been forwarded to {selectedConversationName}" : "Messàgiu torradu a imbiare a {selectedConversationName}",
    "Dismiss" : "Iscarta",
    "Go to conversation" : "Bae a sa resonada",
    "Message read by everyone who shares their reading status" : "Messàgiu lèghidu dae totu is persones chi cumpartzint s'istadu de letura issoro",
    "Message sent" : "Messàgiu imbiadu",
    "Deleting message" : "Cantzellende su messàgiu",
    "Message deleted successfully" : "Messàgiu cantzelladu",
    "Message could not be deleted because it is too old" : "Su messàgiu non si podet cantzellare ca est tropu betzu",
    "Only normal chat messages can be deleted" : "Si podent cantzellare isceti is messàgios de tzarrada normales",
    "An error occurred while deleting the message" : "B'at àpidu un'errore cantzellende su messàgiu",
    "Your browser does not support playing audio files" : "Su serbidore tuo non suportat sa riprodutzione de archìvios àudio",
    "Contact" : "Cuntata",
    "{stack} in {board}" : "{stack} in {board}",
    "Deck Card" : "Ischeda de Deck",
    "Remove {fileName}" : "Boga•nche {fileName}",
    "Sending message" : "Imbiende su messàgiu",
    "Failed to send the message. Click to try again" : "No at fatu a imbiare su messàgiu. Incarca pro torrare a proare",
    "Not enough free space to upload file" : "Non b'at logu lìberu pro carrigare s'archìviu",
    "You cannot send messages to this conversation at the moment" : "Non podes imbiare messàgios in custa resonada in custu momentu",
    "No messages" : "Perunu messàgiu",
    "Unpin" : "No apicare",
    "Create a new group conversation" : "Crea unu grupu de resonada nou",
    "Add participants" : "Agiunghe partetzipantes",
    "Allow guests to join via link" : "Permite a is persones invitadas de intrare cun unu ligòngiu",
    "Enter password" : "Inserta crae",
    "This conversation has been locked" : "Custa resonada est istada blocada",
    "No permission to post messages in this conversation" : "Perunu permissu pro publicare messàgios in custa resonada",
    "Joining conversation …" : "Intrende in sa resonada",
    "Send message" : "Imbia messàgiu",
    "The participant will not be notified about new messages" : "Su partetzipante no ant a retzire notìficas de is messàgios noos",
    "Participants will not be notified about new messages" : "Is partetzipantes no ant a retzire notìficas de is messàgios noos",
    "File to share" : "Archìviu de cumpartzire",
    "Add emoji" : "Agiunghe carighedda",
    "Share from Files" : "Cumpartzi dae Archìvios",
    "Share files to the conversation" : "Cumpartzi archìvios in sa resonada",
    "Upload from device" : "Càrriga dae su dispositivu",
    "Create new poll" : "Crea unu sondàgiu nou",
    "Record voice message" : "Registra messàgiu de boghe",
    "End recording and send" : "Agabba sa registratzione e imbia",
    "Dismiss recording" : "Iscarta sa registratzione",
    "Access to the microphone was denied" : "S'atzessu a su mocròfonu est istadu negadu",
    "Microphone either not available or disabled in settings" : "Su micròfonu no est a disponimentu o est disativadu in sa cunfiguratzione",
    "Error while recording audio" : "Errore in sa registratzione de s'àudio",
    "New file" : "Archìviu nou",
    "Blank" : "Isbòidu",
    "Create and share a new file" : "Crea e cumpartzi un'archìviu nou",
    "Name of the new file" : "Nùmene de s'archìviu nou",
    "Add more files" : "Agiunghe àteros archìvios",
    "Send" : "Imbia",
    "Settings" : "Cunfiguratzione",
    "Anonymous poll" : "Sondàgiu anònimu",
    "Results" : "Resurtados",
    "Disable lobby" : "Disativa intrada",
    "Settings for participant \"{user}\"" : "Cunfiguratzione pro partetzipante \"{user}\"",
    "Participant \"{user}\"" : "Partetzipante \"{user}\"",
    "moderator" : "Chie moderat",
    "bot" : "bot",
    "guest" : "persone invitada",
    "Raised their hand" : "An artziadu sa manu",
    "Joined with video" : "Atzessu fatu cun vìdeu",
    "Joined via phone" : "Atzessu fatu dae telèfonu",
    "Joined with audio" : "Atzessu fatu cun àudio",
    "Remove group and members" : "Boga·nche grupu e partetzipantes",
    "Remove participant" : "Boga·nche partetzipante",
    "Dial-in PIN" : "PIN de atzessu",
    "Demote from moderator" : "Lea su permissu de moderare a ",
    "Promote to moderator" : "Autoriza a moderare",
    "Resend invitation" : "Torra a imbiare s'invitu",
    "Reset custom permissions" : "Riprìstina is permissos personalizados",
    "Remove" : "Boga",
    "Add users or groups" : "Agiunghe utentes o grupos",
    "Add users" : "Agiunghe utentes",
    "Add groups" : "Agiunghe grupos",
    "Add other sources" : "Agiunghe àteras fontes",
    "Add emails" : "Agiunghe email",
    "Integrations" : "Integratziones",
    "Searching …" : "Chirchende …",
    "Search for more users" : "Chirca àteras utèntzias",
    "Search or add participants" : "Chirca o agiunghe partetzipantes",
    "An error occurred while adding the participants" : "B'at àpidu un'errore agiunghende is partetzipantes",
    "Participants" : "Partetzipantes",
    "Open chat" : "Aberi tzarrada",
    "You have new unread messages in the chat." : "Tenes messàgios non lèghidos noos in sa tzarrada.",
    "You have been mentioned in the chat." : "T'ant mentovadu in sa tzarrada.",
    "Chat" : "Tzarrada",
    "Details" : "Detàllios",
    "No results found" : "Perunu resurtadu agatadu",
    "Load more results" : "Càrriga àteros resurtados",
    "Projects" : "Progetos",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "Link to a conversation" : "Collega a una resonada",
    "Search conversations or users" : "Chirca resonadas o utentes",
    "Select conversation" : "Seletziona resonada",
    "Error while saving sounds setting" : "Errore sarvende sa cunfiguratzione de is sonos",
    "Play sounds when participants join or leave a call" : "Ativa is sonos cando is partetzipantes intrant o lassant una mutida",
    "Notification settings" : "Cunfiguratzione de notìficas",
    "Default language" : "Limba predefinida",
    "Select location for attachments" : "Seletziona sa positzione pro is alligongiados",
    "Error while setting attachment folder" : "Errore in sa cunfiguratzione de sa cartella de is alligongiados",
    "Error while setting read status privacy" : "Errore in sa cunfiguratzione de sa riservadesa de s'istadu de letura",
    "Privacy" : "Riservadesa",
    "Attachments folder" : "Cartella de alligongiados",
    "Search" : "Chirca",
    "Focus the chat input" : "Ativa sa digitatzione de sa tzarrada",
    "Unfocus the chat input to use shortcuts" : "Disativa sa digitatzione de sa tzarrada pro impreare is curtziadòrgios",
    "Shortcuts while in a call" : "Curtziadòrgios in s'interis de una mutida",
    "Microphone on and off" : "Micròfonu allutu e istudadu",
    "Raise or lower hand" : "Àrtzia o bàscia sa manu",
    "Push to talk or push to mute" : "Ispinghe pro faeddare o ispinghe pro tirare s'àudio",
    "Start call" : "Cumintza mutida",
    "You will be able to join the call only after a moderator starts it." : "As a pòdere intrare in una mutida isceti a pustis chi una persone chi moderat dda cumintzet.",
    "Recording" : "Registratzione",
    "Raise hand" : "Àrtzia sa manu ",
    "Raise hand (R)" : "Àrtzia sa manu (R)",
    "Lower hand" : "Bàscia sa manu ",
    "Lower hand (R)" : "Bàscia sa manu (R)",
    "You are not allowed to enable screensharing" : "Non tenes su permissu de ativare sa cumpartzidura de s'ischermu",
    "No screensharing" : "Peruna cumpartzidura de ischermu",
    "Screensharing options" : "Sèberos de sa cumpartzidura de s'ischermu",
    "Enable screensharing" : "Ativa sa cumpartzidura de s'ischermu",
    "Bad sent video and screen quality." : "Calidade mala de su vìdeu e de s'ischermu imbiados.",
    "Bad sent screen quality." : "Calidade mala de s'ischermu imbiadu.",
    "Bad sent video quality." : "Calidade mala de su vìdeu imbiadu.",
    "Bad sent audio, video and screen quality." : "Calidade de s'àudiu, de su vìdeu e de s'ischermu imbiados.",
    "Bad sent audio and screen quality." : "Calidade mala de s'àudiu e de s'ischermu imbiados.",
    "Bad sent audio and video quality." : "Calidade mala de s'àudiu e de su vìdeu imbiados.",
    "Bad sent audio quality." : "Calidade mala de s'àudiu imbiadu.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Sa connessione o s'elaboradore tuo sunt ocupados e est possìbile chi is partetzipantes non bidant s'ischermu tuo.",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "Sa connessione o s'elaboradore tuo sunt ocupados e est possìbile chi is partetzipantes non ti bidant.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Sa connessione o s'elaboradore tuo sunt ocupados e est possìbile chi is partetzipantes non ti bidant nen ti cumprendant. Pro megiorare sa situatzione, proa a disativare s'ischermu tuo in s'interis chi faghes una cumpartzidura.",
    "Disable screenshare" : "Disativa sa cumpartzidura de s'ischermu",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Sa connessione o s'elaboradore tuo sunt ocupados e est possìbile chi is partetzipantes non ti cumprendant nen ti bidant. Pro megiorare sa situatzione, proa a disativare su vìdeu.",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "Sa connessione o s'elaboradore tuo sunt ocupados e est possìbile chi is partetzipantes non ti cumprendant.",
    "Screen sharing is not supported by your browser." : "Sa cumpartzidura de s'ischermu non est suportada dae su navigadore tuo",
    "Screen sharing requires the page to be loaded through HTTPS." : "Pro sa cumpartzidura de s'ischermu tocat a carrigare sa pàgina cun HTTPS.",
    "Screensharing requires the page to be loaded through HTTPS." : "Pro Screensharing tocat a carrigare sa pàgina cun HTTPS",
    "An error occurred while starting screensharing." : "B'at àpidu un'errore incarrerende sa cumpartzidura de s'ischermu.",
    "Show your screen" : "Mustra s'ischermu tuo",
    "Stop screensharing" : "Firma sa cumpartzidura de s'ischermu",
    "Mute others" : "Tira s'àudio a àtere",
    "Keep" : "Mantene",
    "Select a region" : "Seletziona una regione",
    "Message without mention" : "Messàgiu chena mentovu",
    "Mention myself" : "Mentova a mie etotu",
    "Join a different conversation or start a new one." : "Aderi a una resonada diferente o cumintza·nde una noa.",
    "The conversation does not exist" : "Sa resonada no esistit",
    "Join a conversation or start a new one!" : "Intra in una resonada o cumintza•nde una noa!",
    "Join a conversation or start a new one" : "Intra in una resonada o cumintza•nde una noa",
    "Nextcloud URL" : "URL de Nextcloud",
    "Nextcloud user" : "Utente de Nextcloud",
    "User password" : "Crae de s'utente",
    "Talk conversation" : "Resonada de Talk",
    "Skip TLS verification" : "Sàrtia sa verìfica TLS",
    "Matrix server URL" : "URL de su serbidore de Matrix",
    "User" : "Utente",
    "Matrix channel" : "Canale de Matrix",
    "Mattermost server URL" : "URL de su serbidore de Mattermost",
    "Mattermost user" : "Utente de Mattermost",
    "Team name" : "Nùmene de su grupu",
    "Channel name" : "Nùmene de su canale",
    "Rocket.Chat server URL" : "URL de su serbidore de Rocket.Chat",
    "User name or email address" : "Nùmene de s'utente o indiritzu email",
    "Rocket.Chat channel" : "Canale de Rocket.Chat",
    "Zulip server URL" : "URL de su serbidore de Zulip",
    "Bot user name" : "Nùmene de utente de su bot",
    "Bot API key" : "Crae API de su programma automàticu",
    "Zulip channel" : "Canale de Zulip",
    "API token" : "Token API",
    "Slack channel" : "Canale de Slack",
    "Server ID or name" : "ID o nùmene de su serbidore ",
    "Channel" : "Canale",
    "Login" : "Atzessu",
    "Chat ID" : "ID de sa tzarrada",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "URL de su serbidore IRC (esèmpiu: chat.freenode.net:6667)",
    "Nickname" : "Nùmene",
    "Connection password" : "Crae de connessione",
    "IRC channel" : "Canale IRC",
    "Channel password" : "Crae de su canale",
    "NickServ nickname" : "Nùmene de NickServ",
    "NickServ password" : "Crae de NickServ",
    "Use TLS" : "Imprea TLS",
    "Use SASL" : "Imprea SASL",
    "Tenant ID" : "ID de incuilinu",
    "Client ID" : "ID de cliente",
    "Team ID" : "ID de grupu",
    "Thread ID" : "ID de filu",
    "XMPP/Jabber server URL" : "URL de su serbidore XMPP/Jabber",
    "MUC server URL" : "URL de su serbidore MUC",
    "Jabber ID" : "ID de Jabber",
    "Media" : "Media",
    "Polls" : "Sondàgios",
    "Locations" : "Positziones",
    "Audio" : "Àudio",
    "Show all files" : "Mustra totu is documentos",
    "Group" : "Grupu",
    "You: {lastMessage}" : "Tue: {lastMessage}",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Ses proende a intrare in una resonada cun una sessione ativa in un'àtera ventana o dispositivu. In custu momentu cust'atzione no est suportada dae Nextcloud Talk. Ite boles fàghere?",
    "Leave this page" : "Lassa custa pàgina",
    "Join here" : "Intra inoghe",
    "Post to a conversation" : "Pùblica in una resonada",
    "Post to conversation" : "Pùblica in sa resonada",
    "Error while clearing conversation history" : "Errore limpiende s'istòria de sa resonada",
    "Error occurred while allowing guests" : "B'at àpidu un'errore autorizende is persones invitadas",
    "Error occurred while disallowing guests" : "B'at àpidu un'errore refudende is persones invitadas",
    "Error occurred when restricting the conversation to moderator" : "B'at àpidu un'errore limitende sa resonada a chie moderat",
    "Error occurred when opening the conversation to everyone" : "B'at àpidu un'errore aberrende sa resonada a totus",
    "Conversation password has been saved" : "Sa crae de sa resonada est istada sarvada",
    "Conversation password has been removed" : "Sa crae de sa resonada nch'est istada bogada",
    "Error occurred while saving conversation password" : "B'at àpidu un'errore sarvende sa crae de sa resonada",
    "Could not post message: {errorMessage}" : "No at fatu a publicare su messàgiu: {errorMessage}",
    "An error occurred while fetching the participants" : "B'at àpidu un'errore in su recùperu de is partetzipantes",
    "Could not send invitation to {actorId}" : "No at fatu a imbiare s'invitu a {actorId}.",
    "Invitations sent" : "Invitos imbiados",
    "Error occurred when sending invitations" : "B'at àpidu un'errore imbiende is invitos",
    "Error while uploading file \"{fileName}\"" : "Errore carrighende s'archìviu \"{fileName}\"",
    "Not enough free space to upload file \"{fileName}\"" : "Non b'at logu lìberu pro carrigare s'archìviu \"{fileName}\"",
    "You are not allowed to share files" : "Non tenes su permissu de cumpartzire archìvios",
    "Error while sharing file" : "Errore in sa cumpartzidura de s'archìviu",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Su navigadore chi ses impreende no est suportadu totu dae Nextcloud. Imprea s'ùrtima versione de Mozilla Firefox, Microsoft Edge, Google Chrome, Opera o Apple Safari.",
    "Lost connection to signaling server. Trying to reconnect." : "Connessione pèrdida cun su serbidore de signalatzione. Proende a torrare a connètere",
    "Please reload the page." : "Torra a carrigare sa pàgina.",
    "Do not disturb" : "No istorbes",
    "Away" : "Foras",
    "Microphone {number}" : "Micròfonu {number}",
    "Camera {number}" : "Fotocàmera {number}",
    "Speaker {number}" : "Altoparlante {number}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Parret chi siast faeddende cun s'àudio istudadu, allue•ddu pro chi is àteras persones ti potzant intèndere",
    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "No faghet a istabilire una connessione cun a su mancu una persone. In custu casu, unu serbidore TURN podet agiudare. Pregonta a s'amministratzione de nde cunfigurare unu sighende {linkstart}custa documentatzione{linkend}.",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Cust'atividade est istentende prus de su tempus prevèdidu. Is permissos multimediales sunt giai istados atzetados (o negados)? Chi eja, torra a abèrrere su navigadore, ca àudio e vìdeo no sunt funtzionende",
    "Access to microphone & camera is only possible with HTTPS" : "S'atzessu a micròfonu & fotocàmera si podet fàghere isceti cun HTTPS",
    "Please move your setup to HTTPS" : "Càmbia sa cunfiguratzione a HTTPS",
    "Access to microphone & camera was denied" : "S'atzessu a micròfonu &fotocàmera est istadu negadu",
    "WebRTC is not supported in your browser" : "WebRTC no est suportadu dae su navigadore tuo",
    "Please use a different browser like Firefox or Chrome" : "Imprea un'àteru navigadore, comente Firefox o Chrome",
    "Error while accessing microphone & camera" : "Errore in s'atzessu a micròfonu e fotocàmera",
    "%s Talk on your mobile devices" : "%s Talk in is dispositivos mòbiles tuos",
    "Join conversations at any time, anywhere, on any device." : "Intra in una resonada in cada momentu, dae cada parte, in cada dispositivu",
    "Android app" : "Aplicatzione Android",
    "iOS app" : "Aplicatzione iOS",
    "__language_name__" : "sardu",
    "Tasks" : "Fainas",
    "Notes" : "Notas",
    "Talk to %s" : "Faedda cun %s",
    "Set reminder for later today" : "Cunfigura un'apuntu pro luego",
    "Set reminder for tomorrow" : "Cunfigura un'apuntu pro cras",
    "Set reminder for this weekend" : "Cunfigura un'apuntu pro custu fine de chida",
    "Set reminder for next week" : "Cunfigura un'apuntu pro chida chi benit",
    "Talk recording from {time} ({conversation})" : "Registratzione de boghe {time} ({conversation})",
    "Your privacy setting has been saved" : "Sa cunfiguratzione de riservadesa tua est istada sarvada",
    "Failed to save sounds setting" : "Non at fatu a sarvare sa cunfiguratzione de is sonos",
    "Sounds setting saved" : "Cunfiguratzione de is sonos sarvada",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "As fatu s'atzessu in sa resonada in un'àtera ventana o dispositivu. In custu momentu cust'atzione no est suportada dae Nextcloud Talk tando sa sessione est istada serrada."
},
"nplurals=2; plural=(n != 1);");
